/* i-properties-provider.c generated by valac 0.37.1.4-3591e, the Vala compiler
 * generated from i-properties-provider.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <gtk/gtk.h>
#include <glib/gi18n-lib.h>
#include <float.h>
#include <math.h>
#include <osinfo/osinfo.h>


#define BOXES_TYPE_PROPERTY (boxes_property_get_type ())
#define BOXES_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTY, BoxesProperty))
#define BOXES_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTY, BoxesPropertyClass))
#define BOXES_IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTY))
#define BOXES_IS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTY))
#define BOXES_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTY, BoxesPropertyClass))

typedef struct _BoxesProperty BoxesProperty;
typedef struct _BoxesPropertyClass BoxesPropertyClass;
typedef struct _BoxesPropertyPrivate BoxesPropertyPrivate;
enum  {
	BOXES_PROPERTY_DUMMY_PROPERTY,
	BOXES_PROPERTY_DESCRIPTION,
	BOXES_PROPERTY_WIDGET,
	BOXES_PROPERTY_EXTRA_WIDGET,
	BOXES_PROPERTY_REBOOT_REQUIRED,
	BOXES_PROPERTY_DESCRIPTION_ALIGNMENT,
	BOXES_PROPERTY_DEFER_INTERVAL,
	BOXES_PROPERTY_SENSITIVE,
	BOXES_PROPERTY_LAST_PROPERTY
};
static GParamSpec* boxes_property_properties[BOXES_PROPERTY_LAST_PROPERTY];
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
enum  {
	BOXES_PROPERTY_REFRESH_PROPERTIES_SIGNAL,
	BOXES_PROPERTY_FLUSHED_SIGNAL,
	BOXES_PROPERTY_LAST_SIGNAL
};
static guint boxes_property_signals[BOXES_PROPERTY_LAST_SIGNAL] = {0};

#define BOXES_TYPE_SIZE_PROPERTY (boxes_size_property_get_type ())
#define BOXES_SIZE_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIZE_PROPERTY, BoxesSizeProperty))
#define BOXES_SIZE_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIZE_PROPERTY, BoxesSizePropertyClass))
#define BOXES_IS_SIZE_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIZE_PROPERTY))
#define BOXES_IS_SIZE_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIZE_PROPERTY))
#define BOXES_SIZE_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIZE_PROPERTY, BoxesSizePropertyClass))

typedef struct _BoxesSizeProperty BoxesSizeProperty;
typedef struct _BoxesSizePropertyClass BoxesSizePropertyClass;
typedef struct _BoxesSizePropertyPrivate BoxesSizePropertyPrivate;
enum  {
	BOXES_SIZE_PROPERTY_DUMMY_PROPERTY,
	BOXES_SIZE_PROPERTY_RECOMMENDED,
	BOXES_SIZE_PROPERTY_LAST_PROPERTY
};
static GParamSpec* boxes_size_property_properties[BOXES_SIZE_PROPERTY_LAST_PROPERTY];
typedef struct _Block26Data Block26Data;
enum  {
	BOXES_SIZE_PROPERTY_CHANGED_SIGNAL,
	BOXES_SIZE_PROPERTY_LAST_SIGNAL
};
static guint boxes_size_property_signals[BOXES_SIZE_PROPERTY_LAST_SIGNAL] = {0};

#define BOXES_TYPE_STRING_PROPERTY (boxes_string_property_get_type ())
#define BOXES_STRING_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_STRING_PROPERTY, BoxesStringProperty))
#define BOXES_STRING_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_STRING_PROPERTY, BoxesStringPropertyClass))
#define BOXES_IS_STRING_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_STRING_PROPERTY))
#define BOXES_IS_STRING_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_STRING_PROPERTY))
#define BOXES_STRING_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_STRING_PROPERTY, BoxesStringPropertyClass))

typedef struct _BoxesStringProperty BoxesStringProperty;
typedef struct _BoxesStringPropertyClass BoxesStringPropertyClass;
typedef struct _BoxesStringPropertyPrivate BoxesStringPropertyPrivate;
enum  {
	BOXES_STRING_PROPERTY_DUMMY_PROPERTY,
	BOXES_STRING_PROPERTY_TEXT,
	BOXES_STRING_PROPERTY_LAST_PROPERTY
};
static GParamSpec* boxes_string_property_properties[BOXES_STRING_PROPERTY_LAST_PROPERTY];

#define BOXES_TYPE_EDITABLE_STRING_PROPERTY (boxes_editable_string_property_get_type ())
#define BOXES_EDITABLE_STRING_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EDITABLE_STRING_PROPERTY, BoxesEditableStringProperty))
#define BOXES_EDITABLE_STRING_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EDITABLE_STRING_PROPERTY, BoxesEditableStringPropertyClass))
#define BOXES_IS_EDITABLE_STRING_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EDITABLE_STRING_PROPERTY))
#define BOXES_IS_EDITABLE_STRING_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EDITABLE_STRING_PROPERTY))
#define BOXES_EDITABLE_STRING_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EDITABLE_STRING_PROPERTY, BoxesEditableStringPropertyClass))

typedef struct _BoxesEditableStringProperty BoxesEditableStringProperty;
typedef struct _BoxesEditableStringPropertyClass BoxesEditableStringPropertyClass;
typedef struct _BoxesEditableStringPropertyPrivate BoxesEditableStringPropertyPrivate;
enum  {
	BOXES_EDITABLE_STRING_PROPERTY_DUMMY_PROPERTY,
	BOXES_EDITABLE_STRING_PROPERTY_TEXT,
	BOXES_EDITABLE_STRING_PROPERTY_LAST_PROPERTY
};
static GParamSpec* boxes_editable_string_property_properties[BOXES_EDITABLE_STRING_PROPERTY_LAST_PROPERTY];
typedef struct _Block27Data Block27Data;
enum  {
	BOXES_EDITABLE_STRING_PROPERTY_CHANGED_SIGNAL,
	BOXES_EDITABLE_STRING_PROPERTY_LAST_SIGNAL
};
static guint boxes_editable_string_property_signals[BOXES_EDITABLE_STRING_PROPERTY_LAST_SIGNAL] = {0};

#define BOXES_TYPE_IPROPERTIES_PROVIDER (boxes_iproperties_provider_get_type ())
#define BOXES_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProvider))
#define BOXES_IS_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER))
#define BOXES_IPROPERTIES_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProviderIface))

typedef struct _BoxesIPropertiesProvider BoxesIPropertiesProvider;
typedef struct _BoxesIPropertiesProviderIface BoxesIPropertiesProviderIface;

#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())

struct _BoxesProperty {
	GObject parent_instance;
	BoxesPropertyPrivate * priv;
};

struct _BoxesPropertyClass {
	GObjectClass parent_class;
};

struct _BoxesPropertyPrivate {
	gchar* _description;
	GtkWidget* _widget;
	GtkWidget* _extra_widget;
	gboolean _reboot_required;
	GtkAlign _description_alignment;
	guint _defer_interval;
	guint deferred_change_id;
	GSourceFunc _deferred_change;
	gpointer _deferred_change_target;
	GDestroyNotify _deferred_change_target_destroy_notify;
};

struct _BoxesSizeProperty {
	BoxesProperty parent_instance;
	BoxesSizePropertyPrivate * priv;
};

struct _BoxesSizePropertyClass {
	BoxesPropertyClass parent_class;
};

struct _BoxesSizePropertyPrivate {
	GtkScale* scale;
	GFormatSizeFlags format_flags;
};

struct _Block26Data {
	int _ref_count_;
	BoxesSizeProperty* self;
	GtkLabel* value_label;
	GtkScale* scale;
	guint64 allocation;
	GFormatSizeFlags format_flags;
};

struct _BoxesStringProperty {
	BoxesProperty parent_instance;
	BoxesStringPropertyPrivate * priv;
};

struct _BoxesStringPropertyClass {
	BoxesPropertyClass parent_class;
};

struct _BoxesEditableStringProperty {
	BoxesProperty parent_instance;
	BoxesEditableStringPropertyPrivate * priv;
};

struct _BoxesEditableStringPropertyClass {
	BoxesPropertyClass parent_class;
};

struct _BoxesEditableStringPropertyPrivate {
	GtkEntry* entry;
};

struct _Block27Data {
	int _ref_count_;
	BoxesEditableStringProperty* self;
	GtkEntry* entry;
};

typedef enum  {
	BOXES_PROPERTIES_PAGE_GENERAL,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_SNAPSHOTS,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

struct _BoxesIPropertiesProviderIface {
	GTypeInterface parent_iface;
	GList* (*get_properties) (BoxesIPropertiesProvider* self, BoxesPropertiesPage page);
};


static gpointer boxes_property_parent_class = NULL;
static gpointer boxes_size_property_parent_class = NULL;
static gpointer boxes_string_property_parent_class = NULL;
static gpointer boxes_editable_string_property_parent_class = NULL;

GType boxes_property_get_type (void) G_GNUC_CONST;
#define BOXES_PROPERTY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_PROPERTY, BoxesPropertyPrivate))
BoxesProperty* boxes_property_new (const gchar* description, GtkWidget* widget, GtkWidget* extra_widget);
BoxesProperty* boxes_property_construct (GType object_type, const gchar* description, GtkWidget* widget, GtkWidget* extra_widget);
void boxes_property_flush (BoxesProperty* self);
static void boxes_property_flush_changes (BoxesProperty* self);
GSourceFunc boxes_property_get_deferred_change (BoxesProperty* self, gpointer* result_target);
void boxes_property_set_deferred_change (BoxesProperty* self, GSourceFunc value, gpointer value_target, GDestroyNotify value_target_destroy_notify);
const gchar* boxes_property_get_description (BoxesProperty* self);
void boxes_property_set_description (BoxesProperty* self, const gchar* value);
GtkWidget* boxes_property_get_widget (BoxesProperty* self);
void boxes_property_set_widget (BoxesProperty* self, GtkWidget* value);
GtkWidget* boxes_property_get_extra_widget (BoxesProperty* self);
void boxes_property_set_extra_widget (BoxesProperty* self, GtkWidget* value);
gboolean boxes_property_get_reboot_required (BoxesProperty* self);
void boxes_property_set_reboot_required (BoxesProperty* self, gboolean value);
GtkAlign boxes_property_get_description_alignment (BoxesProperty* self);
void boxes_property_set_description_alignment (BoxesProperty* self, GtkAlign value);
guint boxes_property_get_defer_interval (BoxesProperty* self);
void boxes_property_set_defer_interval (BoxesProperty* self, guint value);
void boxes_property_set_sensitive (BoxesProperty* self, gboolean value);
static gboolean _boxes_property_deferred_change___lambda4_ (BoxesProperty* self);
static gboolean __boxes_property_deferred_change___lambda4__gsource_func (gpointer self);
static void boxes_property_finalize (GObject * obj);
static void _vala_boxes_property_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_property_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType boxes_size_property_get_type (void) G_GNUC_CONST;
#define BOXES_SIZE_PROPERTY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_SIZE_PROPERTY, BoxesSizePropertyPrivate))
static void boxes_size_property_set_size_value_label_msg (GtkLabel* label, guint64 size, guint64 allocation, GFormatSizeFlags format_flags);
BoxesSizeProperty* boxes_size_property_new (const gchar* name, guint64 size, guint64 min, guint64 max, guint64 allocation, guint64 step, GFormatSizeFlags format_flags);
BoxesSizeProperty* boxes_size_property_construct (GType object_type, const gchar* name, guint64 size, guint64 min, guint64 max, guint64 allocation, guint64 step, GFormatSizeFlags format_flags);
static Block26Data* block26_data_ref (Block26Data* _data26_);
static void block26_data_unref (void * _userdata_);
static void __lambda6_ (Block26Data* _data26_);
static void ___lambda6__gtk_range_value_changed (GtkRange* _sender, gpointer self);
void boxes_size_property_set_recommended (BoxesSizeProperty* self, guint64 value);
static void g_cclosure_user_marshal_VOID__UINT64 (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data);
static void boxes_size_property_finalize (GObject * obj);
static void _vala_boxes_size_property_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType boxes_string_property_get_type (void) G_GNUC_CONST;
BoxesStringProperty* boxes_string_property_new (const gchar* name, const gchar* value);
BoxesStringProperty* boxes_string_property_construct (GType object_type, const gchar* name, const gchar* value);
const gchar* boxes_string_property_get_text (BoxesStringProperty* self);
static void _vala_boxes_string_property_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
GType boxes_editable_string_property_get_type (void) G_GNUC_CONST;
#define BOXES_EDITABLE_STRING_PROPERTY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_EDITABLE_STRING_PROPERTY, BoxesEditableStringPropertyPrivate))
BoxesEditableStringProperty* boxes_editable_string_property_new (const gchar* name, const gchar* value);
BoxesEditableStringProperty* boxes_editable_string_property_construct (GType object_type, const gchar* name, const gchar* value);
static Block27Data* block27_data_ref (Block27Data* _data27_);
static void block27_data_unref (void * _userdata_);
static void __lambda5_ (Block27Data* _data27_);
static void ___lambda5__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
const gchar* boxes_editable_string_property_get_text (BoxesEditableStringProperty* self);
void boxes_editable_string_property_set_text (BoxesEditableStringProperty* self, const gchar* value);
static void boxes_editable_string_property_finalize (GObject * obj);
static void _vala_boxes_editable_string_property_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_editable_string_property_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType boxes_properties_page_get_type (void) G_GNUC_CONST;
GType boxes_iproperties_provider_get_type (void) G_GNUC_CONST;
GList* boxes_iproperties_provider_get_properties (BoxesIPropertiesProvider* self, BoxesPropertiesPage page);
BoxesProperty* boxes_iproperties_provider_add_property (BoxesIPropertiesProvider* self, GList* * list, const gchar* name, GtkWidget* widget, GtkWidget* extra_widget);
BoxesStringProperty* boxes_iproperties_provider_add_string_property (BoxesIPropertiesProvider* self, GList* * list, const gchar* name, const gchar* value);
BoxesEditableStringProperty* boxes_iproperties_provider_add_editable_string_property (BoxesIPropertiesProvider* self, GList* * list, const gchar* name, const gchar* value);
BoxesSizeProperty* boxes_iproperties_provider_add_size_property (BoxesIPropertiesProvider* self, GList* * list, const gchar* name, guint64 size, guint64 min, guint64 max, guint64 allocation, guint64 step, GFormatSizeFlags format_flags);


BoxesProperty* boxes_property_construct (GType object_type, const gchar* description, GtkWidget* widget, GtkWidget* extra_widget) {
	BoxesProperty * self = NULL;
	const gchar* _tmp0_;
	GtkWidget* _tmp1_;
	GtkWidget* _tmp2_;
#line 51 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_return_val_if_fail (widget != NULL, NULL);
#line 52 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp0_ = description;
#line 52 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp1_ = widget;
#line 52 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp2_ = extra_widget;
#line 52 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	self = (BoxesProperty*) g_object_new (object_type, "description", _tmp0_, "widget", _tmp1_, "extra-widget", _tmp2_, NULL);
#line 51 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	return self;
#line 297 "i-properties-provider.c"
}


BoxesProperty* boxes_property_new (const gchar* description, GtkWidget* widget, GtkWidget* extra_widget) {
#line 51 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	return boxes_property_construct (BOXES_TYPE_PROPERTY, description, widget, extra_widget);
#line 304 "i-properties-provider.c"
}


void boxes_property_flush (BoxesProperty* self) {
#line 55 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_return_if_fail (self != NULL);
#line 56 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	boxes_property_flush_changes (self);
#line 58 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_signal_emit (self, boxes_property_signals[BOXES_PROPERTY_FLUSHED_SIGNAL], 0);
#line 315 "i-properties-provider.c"
}


static void boxes_property_flush_changes (BoxesProperty* self) {
	GSourceFunc _tmp0_;
	void* _tmp0__target;
	GSourceFunc _tmp1_;
	void* _tmp1__target;
	GSourceFunc _tmp2_;
	void* _tmp2__target;
	GSourceFunc _tmp3_;
	void* _tmp3__target;
#line 61 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_return_if_fail (self != NULL);
#line 62 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp0_ = boxes_property_get_deferred_change (self, &_tmp0__target);
#line 62 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp1_ = _tmp0_;
#line 62 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp1__target = _tmp0__target;
#line 62 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	if (_tmp1_ == NULL) {
#line 63 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		return;
#line 340 "i-properties-provider.c"
	}
#line 65 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp2_ = boxes_property_get_deferred_change (self, &_tmp2__target);
#line 65 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp3_ = _tmp2_;
#line 65 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp3__target = _tmp2__target;
#line 65 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp3_ (_tmp3__target);
#line 67 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	boxes_property_set_deferred_change (self, NULL, NULL, NULL);
#line 352 "i-properties-provider.c"
}


const gchar* boxes_property_get_description (BoxesProperty* self) {
	const gchar* result;
	const gchar* _tmp0_;
#line 5 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 5 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp0_ = self->priv->_description;
#line 5 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	result = _tmp0_;
#line 5 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	return result;
#line 367 "i-properties-provider.c"
}


void boxes_property_set_description (BoxesProperty* self, const gchar* value) {
#line 5 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_return_if_fail (self != NULL);
#line 5 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	if (g_strcmp0 (value, boxes_property_get_description (self)) != 0) {
#line 376 "i-properties-provider.c"
		const gchar* _tmp0_;
		gchar* _tmp1_;
#line 5 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		_tmp0_ = value;
#line 5 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		_tmp1_ = g_strdup (_tmp0_);
#line 5 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		_g_free0 (self->priv->_description);
#line 5 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		self->priv->_description = _tmp1_;
#line 5 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		g_object_notify_by_pspec ((GObject *) self, boxes_property_properties[BOXES_PROPERTY_DESCRIPTION]);
#line 389 "i-properties-provider.c"
	}
}


GtkWidget* boxes_property_get_widget (BoxesProperty* self) {
	GtkWidget* result;
	GtkWidget* _tmp0_;
#line 6 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 6 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp0_ = self->priv->_widget;
#line 6 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	result = _tmp0_;
#line 6 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	return result;
#line 405 "i-properties-provider.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 6 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	return self ? g_object_ref (self) : NULL;
#line 412 "i-properties-provider.c"
}


void boxes_property_set_widget (BoxesProperty* self, GtkWidget* value) {
#line 6 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_return_if_fail (self != NULL);
#line 6 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	if (boxes_property_get_widget (self) != value) {
#line 421 "i-properties-provider.c"
		GtkWidget* _tmp0_;
		GtkWidget* _tmp1_;
#line 6 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		_tmp0_ = value;
#line 6 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		_tmp1_ = _g_object_ref0 (_tmp0_);
#line 6 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		_g_object_unref0 (self->priv->_widget);
#line 6 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		self->priv->_widget = _tmp1_;
#line 6 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		g_object_notify_by_pspec ((GObject *) self, boxes_property_properties[BOXES_PROPERTY_WIDGET]);
#line 434 "i-properties-provider.c"
	}
}


GtkWidget* boxes_property_get_extra_widget (BoxesProperty* self) {
	GtkWidget* result;
	GtkWidget* _tmp0_;
#line 7 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 7 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp0_ = self->priv->_extra_widget;
#line 7 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	result = _tmp0_;
#line 7 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	return result;
#line 450 "i-properties-provider.c"
}


void boxes_property_set_extra_widget (BoxesProperty* self, GtkWidget* value) {
#line 7 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_return_if_fail (self != NULL);
#line 7 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	if (boxes_property_get_extra_widget (self) != value) {
#line 459 "i-properties-provider.c"
		GtkWidget* _tmp0_;
		GtkWidget* _tmp1_;
#line 7 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		_tmp0_ = value;
#line 7 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		_tmp1_ = _g_object_ref0 (_tmp0_);
#line 7 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		_g_object_unref0 (self->priv->_extra_widget);
#line 7 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		self->priv->_extra_widget = _tmp1_;
#line 7 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		g_object_notify_by_pspec ((GObject *) self, boxes_property_properties[BOXES_PROPERTY_EXTRA_WIDGET]);
#line 472 "i-properties-provider.c"
	}
}


gboolean boxes_property_get_reboot_required (BoxesProperty* self) {
	gboolean result;
	gboolean _tmp0_;
#line 8 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 8 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp0_ = self->priv->_reboot_required;
#line 8 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	result = _tmp0_;
#line 8 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	return result;
#line 488 "i-properties-provider.c"
}


void boxes_property_set_reboot_required (BoxesProperty* self, gboolean value) {
#line 8 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_return_if_fail (self != NULL);
#line 8 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	if (boxes_property_get_reboot_required (self) != value) {
#line 497 "i-properties-provider.c"
		gboolean _tmp0_;
#line 8 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		_tmp0_ = value;
#line 8 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		self->priv->_reboot_required = _tmp0_;
#line 8 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		g_object_notify_by_pspec ((GObject *) self, boxes_property_properties[BOXES_PROPERTY_REBOOT_REQUIRED]);
#line 505 "i-properties-provider.c"
	}
}


GtkAlign boxes_property_get_description_alignment (BoxesProperty* self) {
	GtkAlign result;
	GtkAlign _tmp0_;
#line 9 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 9 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp0_ = self->priv->_description_alignment;
#line 9 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	result = _tmp0_;
#line 9 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	return result;
#line 521 "i-properties-provider.c"
}


void boxes_property_set_description_alignment (BoxesProperty* self, GtkAlign value) {
#line 9 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_return_if_fail (self != NULL);
#line 9 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	if (boxes_property_get_description_alignment (self) != value) {
#line 530 "i-properties-provider.c"
		GtkAlign _tmp0_;
#line 9 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		_tmp0_ = value;
#line 9 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		self->priv->_description_alignment = _tmp0_;
#line 9 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		g_object_notify_by_pspec ((GObject *) self, boxes_property_properties[BOXES_PROPERTY_DESCRIPTION_ALIGNMENT]);
#line 538 "i-properties-provider.c"
	}
}


guint boxes_property_get_defer_interval (BoxesProperty* self) {
	guint result;
	guint _tmp0_;
#line 14 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_return_val_if_fail (self != NULL, 0U);
#line 14 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp0_ = self->priv->_defer_interval;
#line 14 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	result = _tmp0_;
#line 14 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	return result;
#line 554 "i-properties-provider.c"
}


void boxes_property_set_defer_interval (BoxesProperty* self, guint value) {
#line 14 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_return_if_fail (self != NULL);
#line 14 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	if (boxes_property_get_defer_interval (self) != value) {
#line 563 "i-properties-provider.c"
		guint _tmp0_;
#line 14 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		_tmp0_ = value;
#line 14 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		self->priv->_defer_interval = _tmp0_;
#line 14 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		g_object_notify_by_pspec ((GObject *) self, boxes_property_properties[BOXES_PROPERTY_DEFER_INTERVAL]);
#line 571 "i-properties-provider.c"
	}
}


void boxes_property_set_sensitive (BoxesProperty* self, gboolean value) {
	GtkWidget* _tmp0_;
	gboolean _tmp1_;
	GtkWidget* _tmp2_;
	gboolean _tmp3_;
#line 17 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_return_if_fail (self != NULL);
#line 18 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp0_ = self->priv->_widget;
#line 18 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp1_ = value;
#line 18 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	gtk_widget_set_sensitive (_tmp0_, _tmp1_);
#line 19 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp2_ = self->priv->_extra_widget;
#line 19 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp3_ = value;
#line 19 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	gtk_widget_set_sensitive (_tmp2_, _tmp3_);
#line 17 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_object_notify_by_pspec ((GObject *) self, boxes_property_properties[BOXES_PROPERTY_SENSITIVE]);
#line 597 "i-properties-provider.c"
}


GSourceFunc boxes_property_get_deferred_change (BoxesProperty* self, gpointer* result_target) {
	GSourceFunc result;
	GSourceFunc _tmp0_;
	void* _tmp0__target;
	GSourceFunc _tmp1_;
	void* _tmp1__target;
#line 26 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 27 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp0_ = self->priv->_deferred_change;
#line 27 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp0__target = self->priv->_deferred_change_target;
#line 27 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp1_ = _tmp0_;
#line 27 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp1__target = _tmp0__target;
#line 27 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	*result_target = _tmp1__target;
#line 27 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	result = _tmp1_;
#line 27 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	return result;
#line 623 "i-properties-provider.c"
}


static gboolean _boxes_property_deferred_change___lambda4_ (BoxesProperty* self) {
	gboolean result = FALSE;
#line 44 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	boxes_property_flush_changes (self);
#line 46 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	result = FALSE;
#line 46 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	return result;
#line 635 "i-properties-provider.c"
}


static gboolean __boxes_property_deferred_change___lambda4__gsource_func (gpointer self) {
	gboolean result;
	result = _boxes_property_deferred_change___lambda4_ ((BoxesProperty*) self);
#line 43 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	return result;
#line 644 "i-properties-provider.c"
}


void boxes_property_set_deferred_change (BoxesProperty* self, GSourceFunc value, gpointer value_target, GDestroyNotify value_target_destroy_notify) {
	guint _tmp0_;
	GSourceFunc _tmp2_;
	void* _tmp2__target;
	GDestroyNotify _tmp2__target_destroy_notify;
	GSourceFunc _tmp3_;
	void* _tmp3__target;
	guint _tmp4_;
	guint _tmp5_;
	guint _tmp6_;
#line 30 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_return_if_fail (self != NULL);
#line 31 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp0_ = self->priv->deferred_change_id;
#line 31 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	if (_tmp0_ != ((guint) 0)) {
#line 664 "i-properties-provider.c"
		guint _tmp1_;
#line 32 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		_tmp1_ = self->priv->deferred_change_id;
#line 32 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		g_source_remove (_tmp1_);
#line 33 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		self->priv->deferred_change_id = (guint) 0;
#line 672 "i-properties-provider.c"
	}
#line 36 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp2_ = value;
#line 36 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp2__target = value_target;
#line 36 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp2__target_destroy_notify = value_target_destroy_notify;
#line 36 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	value = NULL;
#line 36 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	value_target = NULL;
#line 36 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	value_target_destroy_notify = NULL;
#line 36 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	(self->priv->_deferred_change_target_destroy_notify == NULL) ? NULL : (self->priv->_deferred_change_target_destroy_notify (self->priv->_deferred_change_target), NULL);
#line 36 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	self->priv->_deferred_change = NULL;
#line 36 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	self->priv->_deferred_change_target = NULL;
#line 36 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	self->priv->_deferred_change_target_destroy_notify = NULL;
#line 36 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	self->priv->_deferred_change = _tmp2_;
#line 36 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	self->priv->_deferred_change_target = _tmp2__target;
#line 36 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	self->priv->_deferred_change_target_destroy_notify = _tmp2__target_destroy_notify;
#line 37 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp3_ = self->priv->_deferred_change;
#line 37 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp3__target = self->priv->_deferred_change_target;
#line 37 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	if (_tmp3_ == NULL) {
#line 38 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		(value_target_destroy_notify == NULL) ? NULL : (value_target_destroy_notify (value_target), NULL);
#line 38 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		value = NULL;
#line 38 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		value_target = NULL;
#line 38 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		value_target_destroy_notify = NULL;
#line 38 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		return;
#line 716 "i-properties-provider.c"
	}
#line 40 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp4_ = self->priv->_defer_interval;
#line 40 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	if (_tmp4_ == ((guint) 0)) {
#line 41 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		(value_target_destroy_notify == NULL) ? NULL : (value_target_destroy_notify (value_target), NULL);
#line 41 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		value = NULL;
#line 41 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		value_target = NULL;
#line 41 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		value_target_destroy_notify = NULL;
#line 41 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		return;
#line 732 "i-properties-provider.c"
	}
#line 43 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp5_ = self->priv->_defer_interval;
#line 43 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp6_ = g_timeout_add_seconds_full (G_PRIORITY_DEFAULT, _tmp5_, __boxes_property_deferred_change___lambda4__gsource_func, g_object_ref (self), g_object_unref);
#line 43 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	self->priv->deferred_change_id = _tmp6_;
#line 30 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	(value_target_destroy_notify == NULL) ? NULL : (value_target_destroy_notify (value_target), NULL);
#line 30 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	value = NULL;
#line 30 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	value_target = NULL;
#line 30 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	value_target_destroy_notify = NULL;
#line 748 "i-properties-provider.c"
}


static void boxes_property_class_init (BoxesPropertyClass * klass) {
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	boxes_property_parent_class = g_type_class_peek_parent (klass);
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_type_class_add_private (klass, sizeof (BoxesPropertyPrivate));
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_property_get_property;
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_property_set_property;
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_property_finalize;
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_PROPERTY_DESCRIPTION, boxes_property_properties[BOXES_PROPERTY_DESCRIPTION] = g_param_spec_string ("description", "description", "description", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_PROPERTY_WIDGET, boxes_property_properties[BOXES_PROPERTY_WIDGET] = g_param_spec_object ("widget", "widget", "widget", gtk_widget_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_PROPERTY_EXTRA_WIDGET, boxes_property_properties[BOXES_PROPERTY_EXTRA_WIDGET] = g_param_spec_object ("extra-widget", "extra-widget", "extra-widget", gtk_widget_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_PROPERTY_REBOOT_REQUIRED, boxes_property_properties[BOXES_PROPERTY_REBOOT_REQUIRED] = g_param_spec_boolean ("reboot-required", "reboot-required", "reboot-required", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_PROPERTY_DESCRIPTION_ALIGNMENT, boxes_property_properties[BOXES_PROPERTY_DESCRIPTION_ALIGNMENT] = g_param_spec_enum ("description-alignment", "description-alignment", "description-alignment", GTK_TYPE_ALIGN, GTK_ALIGN_END, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_PROPERTY_DEFER_INTERVAL, boxes_property_properties[BOXES_PROPERTY_DEFER_INTERVAL] = g_param_spec_uint ("defer-interval", "defer-interval", "defer-interval", 0, G_MAXUINT, (guint) 1, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_PROPERTY_SENSITIVE, boxes_property_properties[BOXES_PROPERTY_SENSITIVE] = g_param_spec_boolean ("sensitive", "sensitive", "sensitive", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	boxes_property_signals[BOXES_PROPERTY_REFRESH_PROPERTIES_SIGNAL] = g_signal_new ("refresh-properties", BOXES_TYPE_PROPERTY, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	boxes_property_signals[BOXES_PROPERTY_FLUSHED_SIGNAL] = g_signal_new ("flushed", BOXES_TYPE_PROPERTY, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 781 "i-properties-provider.c"
}


static void boxes_property_instance_init (BoxesProperty * self) {
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	self->priv = BOXES_PROPERTY_GET_PRIVATE (self);
#line 9 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	self->priv->_description_alignment = GTK_ALIGN_END;
#line 14 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	self->priv->_defer_interval = (guint) 1;
#line 792 "i-properties-provider.c"
}


static void boxes_property_finalize (GObject * obj) {
	BoxesProperty * self;
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_PROPERTY, BoxesProperty);
#line 5 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_g_free0 (self->priv->_description);
#line 6 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_g_object_unref0 (self->priv->_widget);
#line 7 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_g_object_unref0 (self->priv->_extra_widget);
#line 24 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	(self->priv->_deferred_change_target_destroy_notify == NULL) ? NULL : (self->priv->_deferred_change_target_destroy_notify (self->priv->_deferred_change_target), NULL);
#line 24 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	self->priv->_deferred_change = NULL;
#line 24 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	self->priv->_deferred_change_target = NULL;
#line 24 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	self->priv->_deferred_change_target_destroy_notify = NULL;
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	G_OBJECT_CLASS (boxes_property_parent_class)->finalize (obj);
#line 816 "i-properties-provider.c"
}


GType boxes_property_get_type (void) {
	static volatile gsize boxes_property_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_property_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesPropertyClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_property_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesProperty), 0, (GInstanceInitFunc) boxes_property_instance_init, NULL };
		GType boxes_property_type_id;
		boxes_property_type_id = g_type_register_static (G_TYPE_OBJECT, "BoxesProperty", &g_define_type_info, 0);
		g_once_init_leave (&boxes_property_type_id__volatile, boxes_property_type_id);
	}
	return boxes_property_type_id__volatile;
}


static void _vala_boxes_property_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesProperty * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_PROPERTY, BoxesProperty);
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	switch (property_id) {
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		case BOXES_PROPERTY_DESCRIPTION:
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		g_value_set_string (value, boxes_property_get_description (self));
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		break;
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		case BOXES_PROPERTY_WIDGET:
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		g_value_set_object (value, boxes_property_get_widget (self));
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		break;
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		case BOXES_PROPERTY_EXTRA_WIDGET:
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		g_value_set_object (value, boxes_property_get_extra_widget (self));
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		break;
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		case BOXES_PROPERTY_REBOOT_REQUIRED:
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		g_value_set_boolean (value, boxes_property_get_reboot_required (self));
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		break;
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		case BOXES_PROPERTY_DESCRIPTION_ALIGNMENT:
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		g_value_set_enum (value, boxes_property_get_description_alignment (self));
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		break;
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		case BOXES_PROPERTY_DEFER_INTERVAL:
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		g_value_set_uint (value, boxes_property_get_defer_interval (self));
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		break;
#line 873 "i-properties-provider.c"
		default:
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		break;
#line 879 "i-properties-provider.c"
	}
}


static void _vala_boxes_property_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesProperty * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_PROPERTY, BoxesProperty);
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	switch (property_id) {
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		case BOXES_PROPERTY_DESCRIPTION:
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		boxes_property_set_description (self, g_value_get_string (value));
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		break;
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		case BOXES_PROPERTY_WIDGET:
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		boxes_property_set_widget (self, g_value_get_object (value));
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		break;
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		case BOXES_PROPERTY_EXTRA_WIDGET:
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		boxes_property_set_extra_widget (self, g_value_get_object (value));
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		break;
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		case BOXES_PROPERTY_REBOOT_REQUIRED:
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		boxes_property_set_reboot_required (self, g_value_get_boolean (value));
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		break;
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		case BOXES_PROPERTY_DESCRIPTION_ALIGNMENT:
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		boxes_property_set_description_alignment (self, g_value_get_enum (value));
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		break;
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		case BOXES_PROPERTY_DEFER_INTERVAL:
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		boxes_property_set_defer_interval (self, g_value_get_uint (value));
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		break;
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		case BOXES_PROPERTY_SENSITIVE:
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		boxes_property_set_sensitive (self, g_value_get_boolean (value));
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		break;
#line 931 "i-properties-provider.c"
		default:
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 4 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		break;
#line 937 "i-properties-provider.c"
	}
}


static void boxes_size_property_set_size_value_label_msg (GtkLabel* label, guint64 size, guint64 allocation, GFormatSizeFlags format_flags) {
	gchar* capacity = NULL;
	guint64 _tmp0_;
	GFormatSizeFlags _tmp1_;
	gchar* _tmp2_;
	guint64 _tmp3_;
#line 77 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_return_if_fail (label != NULL);
#line 81 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp0_ = size;
#line 81 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp1_ = format_flags;
#line 81 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp2_ = g_format_size_full (_tmp0_, _tmp1_);
#line 81 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	capacity = _tmp2_;
#line 83 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp3_ = allocation;
#line 83 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	if (_tmp3_ == ((guint64) 0)) {
#line 962 "i-properties-provider.c"
		GtkLabel* _tmp4_;
		const gchar* _tmp5_;
#line 84 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		_tmp4_ = label;
#line 84 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		_tmp5_ = capacity;
#line 84 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		gtk_label_set_text (_tmp4_, _tmp5_);
#line 971 "i-properties-provider.c"
	} else {
		gchar* allocation_str = NULL;
		guint64 _tmp6_;
		GFormatSizeFlags _tmp7_;
		gchar* _tmp8_;
		GtkLabel* _tmp9_;
		const gchar* _tmp10_;
		const gchar* _tmp11_;
		gchar* _tmp12_;
		gchar* _tmp13_;
#line 86 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		_tmp6_ = allocation;
#line 86 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		_tmp7_ = format_flags;
#line 86 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		_tmp8_ = g_format_size_full (_tmp6_, _tmp7_);
#line 86 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		allocation_str = _tmp8_;
#line 89 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		_tmp9_ = label;
#line 89 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		_tmp10_ = capacity;
#line 89 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		_tmp11_ = allocation_str;
#line 89 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		_tmp12_ = g_strdup_printf (_ ("%s <span color=\"grey\">(%s used)</span>"), _tmp10_, _tmp11_);
#line 89 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		_tmp13_ = _tmp12_;
#line 89 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		gtk_label_set_markup (_tmp9_, _tmp13_);
#line 89 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		_g_free0 (_tmp13_);
#line 83 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		_g_free0 (allocation_str);
#line 1006 "i-properties-provider.c"
	}
#line 77 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_g_free0 (capacity);
#line 1010 "i-properties-provider.c"
}


static Block26Data* block26_data_ref (Block26Data* _data26_) {
#line 106 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_atomic_int_inc (&_data26_->_ref_count_);
#line 106 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	return _data26_;
#line 1019 "i-properties-provider.c"
}


static void block26_data_unref (void * _userdata_) {
	Block26Data* _data26_;
	_data26_ = (Block26Data*) _userdata_;
#line 106 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	if (g_atomic_int_dec_and_test (&_data26_->_ref_count_)) {
#line 1028 "i-properties-provider.c"
		BoxesSizeProperty* self;
#line 106 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		self = _data26_->self;
#line 106 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		_g_object_unref0 (_data26_->scale);
#line 106 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		_g_object_unref0 (_data26_->value_label);
#line 106 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		_g_object_unref0 (self);
#line 106 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		g_slice_free (Block26Data, _data26_);
#line 1040 "i-properties-provider.c"
	}
}


static void __lambda6_ (Block26Data* _data26_) {
	BoxesSizeProperty* self;
	guint64 v = 0ULL;
	gdouble _tmp0_;
	guint64 _tmp1_;
	GFormatSizeFlags _tmp2_;
	gdouble _tmp3_;
#line 146 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	self = _data26_->self;
#line 147 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp0_ = gtk_range_get_value ((GtkRange*) _data26_->scale);
#line 147 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	v = (guint64) _tmp0_;
#line 148 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp1_ = _data26_->allocation;
#line 148 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp2_ = _data26_->format_flags;
#line 148 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	boxes_size_property_set_size_value_label_msg (_data26_->value_label, v, _tmp1_, _tmp2_);
#line 149 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	gtk_range_set_fill_level ((GtkRange*) _data26_->scale, (gdouble) v);
#line 151 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp3_ = gtk_range_get_value ((GtkRange*) _data26_->scale);
#line 151 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_signal_emit (self, boxes_size_property_signals[BOXES_SIZE_PROPERTY_CHANGED_SIGNAL], 0, (guint64) _tmp3_);
#line 1070 "i-properties-provider.c"
}


static void ___lambda6__gtk_range_value_changed (GtkRange* _sender, gpointer self) {
#line 146 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	__lambda6_ (self);
#line 1077 "i-properties-provider.c"
}


BoxesSizeProperty* boxes_size_property_construct (GType object_type, const gchar* name, guint64 size, guint64 min, guint64 max, guint64 allocation, guint64 step, GFormatSizeFlags format_flags) {
	BoxesSizeProperty * self = NULL;
	Block26Data* _data26_;
	guint64 _tmp0_;
	GFormatSizeFlags _tmp1_;
	GtkBox* box = NULL;
	GtkBox* _tmp2_;
	GtkLabel* name_label = NULL;
	const gchar* _tmp3_;
	GtkLabel* _tmp4_;
	GtkStyleContext* _tmp5_;
	GtkLabel* _tmp6_;
	guint64 _tmp7_;
	guint64 _tmp8_;
	GFormatSizeFlags _tmp9_;
	guint64 _tmp10_;
	guint64 _tmp11_;
	guint64 _tmp12_;
	GtkScale* _tmp13_;
	gchar* size_str = NULL;
	guint64 _tmp14_;
	GFormatSizeFlags _tmp15_;
	gchar* _tmp16_;
	const gchar* _tmp17_;
	gchar* _tmp18_;
	gchar* _tmp19_;
	gchar* _tmp20_;
	guint64 _tmp21_;
	const gchar* _tmp22_;
	guint64 _tmp23_;
	GFormatSizeFlags _tmp24_;
	gchar* _tmp25_;
	gchar* _tmp26_;
	gchar* _tmp27_;
	gchar* _tmp28_;
	gchar* _tmp29_;
	guint64 _tmp30_;
	const gchar* _tmp31_;
	guint64 _tmp32_;
	guint64 _tmp33_;
	GtkScale* _tmp34_;
	GFormatSizeFlags _tmp35_;
#line 106 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 106 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_data26_ = g_slice_new0 (Block26Data);
#line 106 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_data26_->_ref_count_ = 1;
#line 106 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp0_ = allocation;
#line 106 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_data26_->allocation = _tmp0_;
#line 106 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp1_ = format_flags;
#line 106 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_data26_->format_flags = _tmp1_;
#line 113 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp2_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
#line 113 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_object_ref_sink (_tmp2_);
#line 113 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	box = _tmp2_;
#line 114 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp3_ = name;
#line 114 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp4_ = (GtkLabel*) gtk_label_new_with_mnemonic (_tmp3_);
#line 114 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_object_ref_sink (_tmp4_);
#line 114 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	name_label = _tmp4_;
#line 115 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	gtk_widget_set_halign ((GtkWidget*) name_label, GTK_ALIGN_START);
#line 116 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp5_ = gtk_widget_get_style_context ((GtkWidget*) name_label);
#line 116 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	gtk_style_context_add_class (_tmp5_, "dim-label");
#line 117 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	gtk_container_add ((GtkContainer*) box, (GtkWidget*) name_label);
#line 118 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp6_ = (GtkLabel*) gtk_label_new ("");
#line 118 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_object_ref_sink (_tmp6_);
#line 118 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_data26_->value_label = _tmp6_;
#line 119 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp7_ = size;
#line 119 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp8_ = _data26_->allocation;
#line 119 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp9_ = _data26_->format_flags;
#line 119 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	boxes_size_property_set_size_value_label_msg (_data26_->value_label, _tmp7_, _tmp8_, _tmp9_);
#line 120 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	gtk_widget_set_halign ((GtkWidget*) _data26_->value_label, GTK_ALIGN_START);
#line 121 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	gtk_container_add ((GtkContainer*) box, (GtkWidget*) _data26_->value_label);
#line 123 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp10_ = min;
#line 123 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp11_ = max;
#line 123 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp12_ = step;
#line 123 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp13_ = (GtkScale*) gtk_scale_new_with_range (GTK_ORIENTATION_HORIZONTAL, (gdouble) _tmp10_, (gdouble) _tmp11_, (gdouble) _tmp12_);
#line 123 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_object_ref_sink (_tmp13_);
#line 123 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_data26_->scale = _tmp13_;
#line 124 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	gtk_label_set_mnemonic_widget (name_label, (GtkWidget*) _data26_->scale);
#line 126 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp14_ = min;
#line 126 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp15_ = _data26_->format_flags;
#line 126 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp16_ = g_format_size_full (_tmp14_, _tmp15_);
#line 126 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	size_str = _tmp16_;
#line 127 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp17_ = size_str;
#line 127 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp18_ = g_strconcat ("<small>", _tmp17_, NULL);
#line 127 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp19_ = _tmp18_;
#line 127 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp20_ = g_strconcat (_tmp19_, "</small>", NULL);
#line 127 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_g_free0 (size_str);
#line 127 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	size_str = _tmp20_;
#line 127 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_g_free0 (_tmp19_);
#line 128 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp21_ = min;
#line 128 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp22_ = size_str;
#line 128 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	gtk_scale_add_mark (_data26_->scale, (gdouble) _tmp21_, GTK_POS_BOTTOM, _tmp22_);
#line 130 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp23_ = max;
#line 130 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp24_ = _data26_->format_flags;
#line 130 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp25_ = g_format_size_full (_tmp23_, _tmp24_);
#line 130 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp26_ = _tmp25_;
#line 130 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp27_ = g_strconcat ("<small>", _tmp26_, NULL);
#line 130 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp28_ = _tmp27_;
#line 130 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp29_ = g_strconcat (_tmp28_, "</small>", NULL);
#line 130 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_g_free0 (size_str);
#line 130 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	size_str = _tmp29_;
#line 130 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_g_free0 (_tmp28_);
#line 130 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_g_free0 (_tmp26_);
#line 131 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp30_ = max;
#line 131 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp31_ = size_str;
#line 131 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	gtk_scale_add_mark (_data26_->scale, (gdouble) _tmp30_, GTK_POS_BOTTOM, _tmp31_);
#line 133 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	gtk_range_set_show_fill_level ((GtkRange*) _data26_->scale, TRUE);
#line 134 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	gtk_range_set_restrict_to_fill_level ((GtkRange*) _data26_->scale, FALSE);
#line 135 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp32_ = size;
#line 135 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	gtk_range_set_value ((GtkRange*) _data26_->scale, (gdouble) _tmp32_);
#line 136 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp33_ = size;
#line 136 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	gtk_range_set_fill_level ((GtkRange*) _data26_->scale, (gdouble) _tmp33_);
#line 137 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	gtk_scale_set_draw_value (_data26_->scale, FALSE);
#line 138 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	gtk_widget_set_hexpand ((GtkWidget*) _data26_->scale, TRUE);
#line 139 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	gtk_widget_set_margin_bottom ((GtkWidget*) _data26_->scale, 20);
#line 141 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	self = (BoxesSizeProperty*) boxes_property_construct (object_type, NULL, (GtkWidget*) box, (GtkWidget*) _data26_->scale);
#line 141 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_data26_->self = g_object_ref (self);
#line 143 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp34_ = _g_object_ref0 (_data26_->scale);
#line 143 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_g_object_unref0 (self->priv->scale);
#line 143 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	self->priv->scale = _tmp34_;
#line 144 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp35_ = _data26_->format_flags;
#line 144 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	self->priv->format_flags = _tmp35_;
#line 146 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_signal_connect_data ((GtkRange*) _data26_->scale, "value-changed", (GCallback) ___lambda6__gtk_range_value_changed, block26_data_ref (_data26_), (GClosureNotify) block26_data_unref, 0);
#line 106 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_g_free0 (size_str);
#line 106 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_g_object_unref0 (name_label);
#line 106 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_g_object_unref0 (box);
#line 106 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	block26_data_unref (_data26_);
#line 106 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_data26_ = NULL;
#line 106 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	return self;
#line 1293 "i-properties-provider.c"
}


BoxesSizeProperty* boxes_size_property_new (const gchar* name, guint64 size, guint64 min, guint64 max, guint64 allocation, guint64 step, GFormatSizeFlags format_flags) {
#line 106 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	return boxes_size_property_construct (BOXES_TYPE_SIZE_PROPERTY, name, size, min, max, allocation, step, format_flags);
#line 1300 "i-properties-provider.c"
}


void boxes_size_property_set_recommended (BoxesSizeProperty* self, guint64 value) {
	gboolean _tmp0_ = FALSE;
	guint64 _tmp1_;
	GtkScale* _tmp2_;
	GtkAdjustment* _tmp3_;
	GtkAdjustment* _tmp4_;
	gdouble _tmp5_;
	gdouble _tmp6_;
	gchar* size = NULL;
	guint64 _tmp13_;
	GFormatSizeFlags _tmp14_;
	gchar* _tmp15_;
	gchar* _tmp16_;
	gchar* _tmp17_;
	gchar* _tmp18_;
	gchar* _tmp19_;
	gchar* _tmp20_;
	gchar* _tmp21_;
	gchar* _tmp22_;
	GtkScale* _tmp23_;
	guint64 _tmp24_;
	const gchar* _tmp25_;
#line 94 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_return_if_fail (self != NULL);
#line 96 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp1_ = value;
#line 96 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp2_ = self->priv->scale;
#line 96 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp3_ = gtk_range_get_adjustment ((GtkRange*) _tmp2_);
#line 96 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp4_ = _tmp3_;
#line 96 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp5_ = gtk_adjustment_get_lower (_tmp4_);
#line 96 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp6_ = _tmp5_;
#line 96 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	if (((gdouble) _tmp1_) < (_tmp6_ + OSINFO_GIBIBYTES)) {
#line 96 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		_tmp0_ = TRUE;
#line 1344 "i-properties-provider.c"
	} else {
		guint64 _tmp7_;
		GtkScale* _tmp8_;
		GtkAdjustment* _tmp9_;
		GtkAdjustment* _tmp10_;
		gdouble _tmp11_;
		gdouble _tmp12_;
#line 97 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		_tmp7_ = value;
#line 97 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		_tmp8_ = self->priv->scale;
#line 97 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		_tmp9_ = gtk_range_get_adjustment ((GtkRange*) _tmp8_);
#line 97 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		_tmp10_ = _tmp9_;
#line 97 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		_tmp11_ = gtk_adjustment_get_upper (_tmp10_);
#line 97 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		_tmp12_ = _tmp11_;
#line 97 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		_tmp0_ = ((gdouble) _tmp7_) > (_tmp12_ - OSINFO_GIBIBYTES);
#line 1366 "i-properties-provider.c"
	}
#line 96 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	if (_tmp0_) {
#line 98 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		return;
#line 1372 "i-properties-provider.c"
	}
#line 101 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp13_ = value;
#line 101 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp14_ = self->priv->format_flags;
#line 101 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp15_ = g_format_size_full (_tmp13_, _tmp14_);
#line 101 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp16_ = _tmp15_;
#line 101 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp17_ = g_strdup_printf (_ ("%s (recommended)"), _tmp16_);
#line 101 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp18_ = _tmp17_;
#line 101 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp19_ = g_strconcat ("<small>", _tmp18_, NULL);
#line 101 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp20_ = _tmp19_;
#line 101 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp21_ = g_strconcat (_tmp20_, "</small>", NULL);
#line 101 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp22_ = _tmp21_;
#line 101 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_g_free0 (_tmp20_);
#line 101 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_g_free0 (_tmp18_);
#line 101 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_g_free0 (_tmp16_);
#line 101 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	size = _tmp22_;
#line 102 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp23_ = self->priv->scale;
#line 102 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp24_ = value;
#line 102 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp25_ = size;
#line 102 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	gtk_scale_add_mark (_tmp23_, (gdouble) _tmp24_, GTK_POS_BOTTOM, _tmp25_);
#line 94 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_g_free0 (size);
#line 94 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_object_notify_by_pspec ((GObject *) self, boxes_size_property_properties[BOXES_SIZE_PROPERTY_RECOMMENDED]);
#line 1414 "i-properties-provider.c"
}


static void g_cclosure_user_marshal_VOID__UINT64 (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data) {
	typedef void (*GMarshalFunc_VOID__UINT64) (gpointer data1, guint64 arg_1, gpointer data2);
	register GMarshalFunc_VOID__UINT64 callback;
	register GCClosure * cc;
	register gpointer data1;
	register gpointer data2;
	cc = (GCClosure *) closure;
#line 71 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_return_if_fail (n_param_values == 2);
#line 71 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	if (G_CCLOSURE_SWAP_DATA (closure)) {
#line 71 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		data1 = closure->data;
#line 71 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		data2 = param_values->data[0].v_pointer;
#line 1433 "i-properties-provider.c"
	} else {
#line 71 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		data1 = param_values->data[0].v_pointer;
#line 71 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		data2 = closure->data;
#line 1439 "i-properties-provider.c"
	}
#line 71 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	callback = (GMarshalFunc_VOID__UINT64) (marshal_data ? marshal_data : cc->callback);
#line 71 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	callback (data1, g_value_get_uint64 (param_values + 1), data2);
#line 1445 "i-properties-provider.c"
}


static void boxes_size_property_class_init (BoxesSizePropertyClass * klass) {
#line 71 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	boxes_size_property_parent_class = g_type_class_peek_parent (klass);
#line 71 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_type_class_add_private (klass, sizeof (BoxesSizePropertyPrivate));
#line 71 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_size_property_set_property;
#line 71 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_size_property_finalize;
#line 71 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_SIZE_PROPERTY_RECOMMENDED, boxes_size_property_properties[BOXES_SIZE_PROPERTY_RECOMMENDED] = g_param_spec_uint64 ("recommended", "recommended", "recommended", 0, G_MAXUINT64, 0U, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
#line 71 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	boxes_size_property_signals[BOXES_SIZE_PROPERTY_CHANGED_SIGNAL] = g_signal_new ("changed", BOXES_TYPE_SIZE_PROPERTY, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__UINT64, G_TYPE_NONE, 1, G_TYPE_UINT64);
#line 1462 "i-properties-provider.c"
}


static void boxes_size_property_instance_init (BoxesSizeProperty * self) {
#line 71 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	self->priv = BOXES_SIZE_PROPERTY_GET_PRIVATE (self);
#line 1469 "i-properties-provider.c"
}


static void boxes_size_property_finalize (GObject * obj) {
	BoxesSizeProperty * self;
#line 71 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_SIZE_PROPERTY, BoxesSizeProperty);
#line 74 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_g_object_unref0 (self->priv->scale);
#line 71 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	G_OBJECT_CLASS (boxes_size_property_parent_class)->finalize (obj);
#line 1481 "i-properties-provider.c"
}


GType boxes_size_property_get_type (void) {
	static volatile gsize boxes_size_property_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_size_property_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesSizePropertyClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_size_property_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesSizeProperty), 0, (GInstanceInitFunc) boxes_size_property_instance_init, NULL };
		GType boxes_size_property_type_id;
		boxes_size_property_type_id = g_type_register_static (BOXES_TYPE_PROPERTY, "BoxesSizeProperty", &g_define_type_info, 0);
		g_once_init_leave (&boxes_size_property_type_id__volatile, boxes_size_property_type_id);
	}
	return boxes_size_property_type_id__volatile;
}


static void _vala_boxes_size_property_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesSizeProperty * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_SIZE_PROPERTY, BoxesSizeProperty);
#line 71 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	switch (property_id) {
#line 71 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		case BOXES_SIZE_PROPERTY_RECOMMENDED:
#line 71 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		boxes_size_property_set_recommended (self, g_value_get_uint64 (value));
#line 71 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		break;
#line 1508 "i-properties-provider.c"
		default:
#line 71 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 71 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		break;
#line 1514 "i-properties-provider.c"
	}
}


BoxesStringProperty* boxes_string_property_construct (GType object_type, const gchar* name, const gchar* value) {
	BoxesStringProperty * self = NULL;
	GtkLabel* label = NULL;
	const gchar* _tmp0_;
	GtkLabel* _tmp1_;
	const gchar* _tmp2_;
#line 161 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 161 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_return_val_if_fail (value != NULL, NULL);
#line 162 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp0_ = value;
#line 162 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp1_ = (GtkLabel*) gtk_label_new (_tmp0_);
#line 162 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_object_ref_sink (_tmp1_);
#line 162 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	label = _tmp1_;
#line 163 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	gtk_widget_set_halign ((GtkWidget*) label, GTK_ALIGN_START);
#line 164 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	gtk_label_set_selectable (label, TRUE);
#line 166 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp2_ = name;
#line 166 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	self = (BoxesStringProperty*) boxes_property_construct (object_type, _tmp2_, (GtkWidget*) label, NULL);
#line 161 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_g_object_unref0 (label);
#line 161 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	return self;
#line 1549 "i-properties-provider.c"
}


BoxesStringProperty* boxes_string_property_new (const gchar* name, const gchar* value) {
#line 161 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	return boxes_string_property_construct (BOXES_TYPE_STRING_PROPERTY, name, value);
#line 1556 "i-properties-provider.c"
}


const gchar* boxes_string_property_get_text (BoxesStringProperty* self) {
	const gchar* result;
	GtkWidget* _tmp0_;
	GtkWidget* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
#line 158 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 158 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp0_ = boxes_property_get_widget ((BoxesProperty*) self);
#line 158 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp1_ = _tmp0_;
#line 158 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp2_ = gtk_label_get_label (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, gtk_label_get_type ()) ? ((GtkLabel*) _tmp1_) : NULL);
#line 158 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp3_ = _tmp2_;
#line 158 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	result = _tmp3_;
#line 158 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	return result;
#line 1580 "i-properties-provider.c"
}


static void boxes_string_property_class_init (BoxesStringPropertyClass * klass) {
#line 156 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	boxes_string_property_parent_class = g_type_class_peek_parent (klass);
#line 156 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_string_property_get_property;
#line 156 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_STRING_PROPERTY_TEXT, boxes_string_property_properties[BOXES_STRING_PROPERTY_TEXT] = g_param_spec_string ("text", "text", "text", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 1591 "i-properties-provider.c"
}


static void boxes_string_property_instance_init (BoxesStringProperty * self) {
}


GType boxes_string_property_get_type (void) {
	static volatile gsize boxes_string_property_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_string_property_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesStringPropertyClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_string_property_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesStringProperty), 0, (GInstanceInitFunc) boxes_string_property_instance_init, NULL };
		GType boxes_string_property_type_id;
		boxes_string_property_type_id = g_type_register_static (BOXES_TYPE_PROPERTY, "BoxesStringProperty", &g_define_type_info, 0);
		g_once_init_leave (&boxes_string_property_type_id__volatile, boxes_string_property_type_id);
	}
	return boxes_string_property_type_id__volatile;
}


static void _vala_boxes_string_property_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesStringProperty * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_STRING_PROPERTY, BoxesStringProperty);
#line 156 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	switch (property_id) {
#line 156 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		case BOXES_STRING_PROPERTY_TEXT:
#line 156 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		g_value_set_string (value, boxes_string_property_get_text (self));
#line 156 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		break;
#line 1622 "i-properties-provider.c"
		default:
#line 156 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 156 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		break;
#line 1628 "i-properties-provider.c"
	}
}


static Block27Data* block27_data_ref (Block27Data* _data27_) {
#line 180 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_atomic_int_inc (&_data27_->_ref_count_);
#line 180 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	return _data27_;
#line 1638 "i-properties-provider.c"
}


static void block27_data_unref (void * _userdata_) {
	Block27Data* _data27_;
	_data27_ = (Block27Data*) _userdata_;
#line 180 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	if (g_atomic_int_dec_and_test (&_data27_->_ref_count_)) {
#line 1647 "i-properties-provider.c"
		BoxesEditableStringProperty* self;
#line 180 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		self = _data27_->self;
#line 180 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		_g_object_unref0 (_data27_->entry);
#line 180 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		_g_object_unref0 (self);
#line 180 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		g_slice_free (Block27Data, _data27_);
#line 1657 "i-properties-provider.c"
	}
}


static void __lambda5_ (Block27Data* _data27_) {
	BoxesEditableStringProperty* self;
	const gchar* _tmp0_;
	const gchar* _tmp1_;
#line 188 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	self = _data27_->self;
#line 189 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp0_ = gtk_entry_get_text (_data27_->entry);
#line 189 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp1_ = _tmp0_;
#line 189 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_signal_emit (self, boxes_editable_string_property_signals[BOXES_EDITABLE_STRING_PROPERTY_CHANGED_SIGNAL], 0, _tmp1_);
#line 1674 "i-properties-provider.c"
}


static void ___lambda5__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 188 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	__lambda5_ (self);
#line 1681 "i-properties-provider.c"
}


BoxesEditableStringProperty* boxes_editable_string_property_construct (GType object_type, const gchar* name, const gchar* value) {
	BoxesEditableStringProperty * self = NULL;
	Block27Data* _data27_;
	GtkEntry* _tmp0_;
	const gchar* _tmp1_;
	GtkEntry* _tmp2_;
	const gchar* _tmp3_;
#line 180 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 180 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_return_val_if_fail (value != NULL, NULL);
#line 180 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_data27_ = g_slice_new0 (Block27Data);
#line 180 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_data27_->_ref_count_ = 1;
#line 181 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp0_ = (GtkEntry*) gtk_entry_new ();
#line 181 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_object_ref_sink (_tmp0_);
#line 181 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_data27_->entry = _tmp0_;
#line 183 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp1_ = name;
#line 183 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	self = (BoxesEditableStringProperty*) boxes_property_construct (object_type, _tmp1_, (GtkWidget*) _data27_->entry, NULL);
#line 183 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_data27_->self = g_object_ref (self);
#line 184 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp2_ = _g_object_ref0 (_data27_->entry);
#line 184 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_g_object_unref0 (self->priv->entry);
#line 184 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	self->priv->entry = _tmp2_;
#line 186 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp3_ = value;
#line 186 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	gtk_entry_set_text (_data27_->entry, _tmp3_);
#line 188 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_signal_connect_data ((GObject*) _data27_->entry, "notify::text", (GCallback) ___lambda5__g_object_notify, block27_data_ref (_data27_), (GClosureNotify) block27_data_unref, 0);
#line 180 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	block27_data_unref (_data27_);
#line 180 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_data27_ = NULL;
#line 180 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	return self;
#line 1730 "i-properties-provider.c"
}


BoxesEditableStringProperty* boxes_editable_string_property_new (const gchar* name, const gchar* value) {
#line 180 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	return boxes_editable_string_property_construct (BOXES_TYPE_EDITABLE_STRING_PROPERTY, name, value);
#line 1737 "i-properties-provider.c"
}


const gchar* boxes_editable_string_property_get_text (BoxesEditableStringProperty* self) {
	const gchar* result;
	GtkEntry* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
#line 174 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 174 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp0_ = self->priv->entry;
#line 174 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp1_ = gtk_entry_get_text (_tmp0_);
#line 174 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp2_ = _tmp1_;
#line 174 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	result = _tmp2_;
#line 174 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	return result;
#line 1758 "i-properties-provider.c"
}


void boxes_editable_string_property_set_text (BoxesEditableStringProperty* self, const gchar* value) {
	GtkEntry* _tmp0_;
	const gchar* _tmp1_;
#line 175 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_return_if_fail (self != NULL);
#line 175 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp0_ = self->priv->entry;
#line 175 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp1_ = value;
#line 175 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	gtk_entry_set_text (_tmp0_, _tmp1_);
#line 175 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_object_notify_by_pspec ((GObject *) self, boxes_editable_string_property_properties[BOXES_EDITABLE_STRING_PROPERTY_TEXT]);
#line 1775 "i-properties-provider.c"
}


static void boxes_editable_string_property_class_init (BoxesEditableStringPropertyClass * klass) {
#line 170 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	boxes_editable_string_property_parent_class = g_type_class_peek_parent (klass);
#line 170 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_type_class_add_private (klass, sizeof (BoxesEditableStringPropertyPrivate));
#line 170 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_editable_string_property_get_property;
#line 170 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_editable_string_property_set_property;
#line 170 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_editable_string_property_finalize;
#line 170 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_EDITABLE_STRING_PROPERTY_TEXT, boxes_editable_string_property_properties[BOXES_EDITABLE_STRING_PROPERTY_TEXT] = g_param_spec_string ("text", "text", "text", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 170 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	boxes_editable_string_property_signals[BOXES_EDITABLE_STRING_PROPERTY_CHANGED_SIGNAL] = g_signal_new ("changed", BOXES_TYPE_EDITABLE_STRING_PROPERTY, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__STRING, G_TYPE_NONE, 1, G_TYPE_STRING);
#line 1794 "i-properties-provider.c"
}


static void boxes_editable_string_property_instance_init (BoxesEditableStringProperty * self) {
#line 170 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	self->priv = BOXES_EDITABLE_STRING_PROPERTY_GET_PRIVATE (self);
#line 1801 "i-properties-provider.c"
}


static void boxes_editable_string_property_finalize (GObject * obj) {
	BoxesEditableStringProperty * self;
#line 170 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_EDITABLE_STRING_PROPERTY, BoxesEditableStringProperty);
#line 178 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_g_object_unref0 (self->priv->entry);
#line 170 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	G_OBJECT_CLASS (boxes_editable_string_property_parent_class)->finalize (obj);
#line 1813 "i-properties-provider.c"
}


GType boxes_editable_string_property_get_type (void) {
	static volatile gsize boxes_editable_string_property_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_editable_string_property_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesEditableStringPropertyClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_editable_string_property_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesEditableStringProperty), 0, (GInstanceInitFunc) boxes_editable_string_property_instance_init, NULL };
		GType boxes_editable_string_property_type_id;
		boxes_editable_string_property_type_id = g_type_register_static (BOXES_TYPE_PROPERTY, "BoxesEditableStringProperty", &g_define_type_info, 0);
		g_once_init_leave (&boxes_editable_string_property_type_id__volatile, boxes_editable_string_property_type_id);
	}
	return boxes_editable_string_property_type_id__volatile;
}


static void _vala_boxes_editable_string_property_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesEditableStringProperty * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_EDITABLE_STRING_PROPERTY, BoxesEditableStringProperty);
#line 170 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	switch (property_id) {
#line 170 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		case BOXES_EDITABLE_STRING_PROPERTY_TEXT:
#line 170 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		g_value_set_string (value, boxes_editable_string_property_get_text (self));
#line 170 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		break;
#line 1840 "i-properties-provider.c"
		default:
#line 170 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 170 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		break;
#line 1846 "i-properties-provider.c"
	}
}


static void _vala_boxes_editable_string_property_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesEditableStringProperty * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_EDITABLE_STRING_PROPERTY, BoxesEditableStringProperty);
#line 170 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	switch (property_id) {
#line 170 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		case BOXES_EDITABLE_STRING_PROPERTY_TEXT:
#line 170 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		boxes_editable_string_property_set_text (self, g_value_get_string (value));
#line 170 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		break;
#line 1862 "i-properties-provider.c"
		default:
#line 170 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 170 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		break;
#line 1868 "i-properties-provider.c"
	}
}


GList* boxes_iproperties_provider_get_properties (BoxesIPropertiesProvider* self, BoxesPropertiesPage page) {
#line 195 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 195 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	return BOXES_IPROPERTIES_PROVIDER_GET_INTERFACE (self)->get_properties (self, page);
#line 1878 "i-properties-provider.c"
}


BoxesProperty* boxes_iproperties_provider_add_property (BoxesIPropertiesProvider* self, GList* * list, const gchar* name, GtkWidget* widget, GtkWidget* extra_widget) {
	BoxesProperty* result = NULL;
	BoxesProperty* property = NULL;
	const gchar* _tmp0_;
	GtkWidget* _tmp1_;
	GtkWidget* _tmp2_;
	BoxesProperty* _tmp3_;
	BoxesProperty* _tmp4_;
#line 197 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_return_val_if_fail (widget != NULL, NULL);
#line 201 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp0_ = name;
#line 201 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp1_ = widget;
#line 201 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp2_ = extra_widget;
#line 201 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp3_ = boxes_property_new (_tmp0_, _tmp1_, _tmp2_);
#line 201 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	property = _tmp3_;
#line 202 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp4_ = _g_object_ref0 (property);
#line 202 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	*list = g_list_append (*list, _tmp4_);
#line 203 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	result = property;
#line 203 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	return result;
#line 1910 "i-properties-provider.c"
}


BoxesStringProperty* boxes_iproperties_provider_add_string_property (BoxesIPropertiesProvider* self, GList* * list, const gchar* name, const gchar* value) {
	BoxesStringProperty* result = NULL;
	BoxesStringProperty* property = NULL;
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	BoxesStringProperty* _tmp2_;
	BoxesProperty* _tmp3_;
#line 206 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 206 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_return_val_if_fail (value != NULL, NULL);
#line 209 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp0_ = name;
#line 209 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp1_ = value;
#line 209 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp2_ = boxes_string_property_new (_tmp0_, _tmp1_);
#line 209 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	property = _tmp2_;
#line 210 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp3_ = _g_object_ref0 ((BoxesProperty*) property);
#line 210 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	*list = g_list_append (*list, _tmp3_);
#line 212 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	result = property;
#line 212 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	return result;
#line 1941 "i-properties-provider.c"
}


BoxesEditableStringProperty* boxes_iproperties_provider_add_editable_string_property (BoxesIPropertiesProvider* self, GList* * list, const gchar* name, const gchar* value) {
	BoxesEditableStringProperty* result = NULL;
	BoxesEditableStringProperty* property = NULL;
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	BoxesEditableStringProperty* _tmp2_;
	BoxesProperty* _tmp3_;
#line 215 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 215 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_return_val_if_fail (value != NULL, NULL);
#line 218 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp0_ = name;
#line 218 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp1_ = value;
#line 218 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp2_ = boxes_editable_string_property_new (_tmp0_, _tmp1_);
#line 218 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	property = _tmp2_;
#line 219 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp3_ = _g_object_ref0 ((BoxesProperty*) property);
#line 219 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	*list = g_list_append (*list, _tmp3_);
#line 221 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	result = property;
#line 221 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	return result;
#line 1972 "i-properties-provider.c"
}


BoxesSizeProperty* boxes_iproperties_provider_add_size_property (BoxesIPropertiesProvider* self, GList* * list, const gchar* name, guint64 size, guint64 min, guint64 max, guint64 allocation, guint64 step, GFormatSizeFlags format_flags) {
	BoxesSizeProperty* result = NULL;
	BoxesSizeProperty* property = NULL;
	const gchar* _tmp0_;
	guint64 _tmp1_;
	guint64 _tmp2_;
	guint64 _tmp3_;
	guint64 _tmp4_;
	guint64 _tmp5_;
	GFormatSizeFlags _tmp6_;
	BoxesSizeProperty* _tmp7_;
	BoxesProperty* _tmp8_;
#line 224 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 232 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp0_ = name;
#line 232 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp1_ = size;
#line 232 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp2_ = min;
#line 232 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp3_ = max;
#line 232 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp4_ = allocation;
#line 232 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp5_ = step;
#line 232 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp6_ = format_flags;
#line 232 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp7_ = boxes_size_property_new (_tmp0_, _tmp1_, _tmp2_, _tmp3_, _tmp4_, _tmp5_, _tmp6_);
#line 232 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	property = _tmp7_;
#line 233 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	_tmp8_ = _g_object_ref0 ((BoxesProperty*) property);
#line 233 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	*list = g_list_append (*list, _tmp8_);
#line 235 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	result = property;
#line 235 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	return result;
#line 2016 "i-properties-provider.c"
}


static void boxes_iproperties_provider_base_init (BoxesIPropertiesProviderIface * iface) {
#line 194 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	static gboolean initialized = FALSE;
#line 194 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
	if (!initialized) {
#line 194 "/home/fborges/checkout/gnome-boxes/src/i-properties-provider.vala"
		initialized = TRUE;
#line 2027 "i-properties-provider.c"
	}
}


GType boxes_iproperties_provider_get_type (void) {
	static volatile gsize boxes_iproperties_provider_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_iproperties_provider_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesIPropertiesProviderIface), (GBaseInitFunc) boxes_iproperties_provider_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType boxes_iproperties_provider_type_id;
		boxes_iproperties_provider_type_id = g_type_register_static (G_TYPE_INTERFACE, "BoxesIPropertiesProvider", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (boxes_iproperties_provider_type_id, G_TYPE_OBJECT);
		g_once_init_leave (&boxes_iproperties_provider_type_id__volatile, boxes_iproperties_provider_type_id);
	}
	return boxes_iproperties_provider_type_id__volatile;
}



