/* troubleshoot-log.c generated by valac 0.37.1.4-3591e, the Vala compiler
 * generated from troubleshoot-log.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>


#define BOXES_TYPE_TROUBLESHOOT_LOG (boxes_troubleshoot_log_get_type ())
#define BOXES_TROUBLESHOOT_LOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TROUBLESHOOT_LOG, BoxesTroubleshootLog))
#define BOXES_TROUBLESHOOT_LOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TROUBLESHOOT_LOG, BoxesTroubleshootLogClass))
#define BOXES_IS_TROUBLESHOOT_LOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TROUBLESHOOT_LOG))
#define BOXES_IS_TROUBLESHOOT_LOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TROUBLESHOOT_LOG))
#define BOXES_TROUBLESHOOT_LOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TROUBLESHOOT_LOG, BoxesTroubleshootLogClass))

typedef struct _BoxesTroubleshootLog BoxesTroubleshootLog;
typedef struct _BoxesTroubleshootLogClass BoxesTroubleshootLogClass;
typedef struct _BoxesTroubleshootLogPrivate BoxesTroubleshootLogPrivate;
enum  {
	BOXES_TROUBLESHOOT_LOG_DUMMY_PROPERTY,
	BOXES_TROUBLESHOOT_LOG_LAST_PROPERTY
};
static GParamSpec* boxes_troubleshoot_log_properties[BOXES_TROUBLESHOOT_LOG_LAST_PROPERTY];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

struct _BoxesTroubleshootLog {
	GtkScrolledWindow parent_instance;
	BoxesTroubleshootLogPrivate * priv;
	GtkTextView* view;
};

struct _BoxesTroubleshootLogClass {
	GtkScrolledWindowClass parent_class;
};


static gpointer boxes_troubleshoot_log_parent_class = NULL;

GType boxes_troubleshoot_log_get_type (void) G_GNUC_CONST;
BoxesTroubleshootLog* boxes_troubleshoot_log_new (void);
BoxesTroubleshootLog* boxes_troubleshoot_log_construct (GType object_type);
static void boxes_troubleshoot_log_finalize (GObject * obj);


BoxesTroubleshootLog* boxes_troubleshoot_log_construct (GType object_type) {
	BoxesTroubleshootLog * self = NULL;
#line 5 "/home/fborges/checkout/gnome-boxes/src/troubleshoot-log.vala"
	self = (BoxesTroubleshootLog*) g_object_new (object_type, NULL);
#line 5 "/home/fborges/checkout/gnome-boxes/src/troubleshoot-log.vala"
	return self;
#line 54 "troubleshoot-log.c"
}


BoxesTroubleshootLog* boxes_troubleshoot_log_new (void) {
#line 5 "/home/fborges/checkout/gnome-boxes/src/troubleshoot-log.vala"
	return boxes_troubleshoot_log_construct (BOXES_TYPE_TROUBLESHOOT_LOG);
#line 61 "troubleshoot-log.c"
}


static void boxes_troubleshoot_log_class_init (BoxesTroubleshootLogClass * klass) {
#line 5 "/home/fborges/checkout/gnome-boxes/src/troubleshoot-log.vala"
	boxes_troubleshoot_log_parent_class = g_type_class_peek_parent (klass);
#line 5 "/home/fborges/checkout/gnome-boxes/src/troubleshoot-log.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_troubleshoot_log_finalize;
#line 5 "/home/fborges/checkout/gnome-boxes/src/troubleshoot-log.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Boxes/ui/troubleshoot-log.ui");
#line 5 "/home/fborges/checkout/gnome-boxes/src/troubleshoot-log.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "view", FALSE, G_STRUCT_OFFSET (BoxesTroubleshootLog, view));
#line 74 "troubleshoot-log.c"
}


static void boxes_troubleshoot_log_instance_init (BoxesTroubleshootLog * self) {
#line 5 "/home/fborges/checkout/gnome-boxes/src/troubleshoot-log.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 81 "troubleshoot-log.c"
}


static void boxes_troubleshoot_log_finalize (GObject * obj) {
	BoxesTroubleshootLog * self;
#line 5 "/home/fborges/checkout/gnome-boxes/src/troubleshoot-log.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_TROUBLESHOOT_LOG, BoxesTroubleshootLog);
#line 7 "/home/fborges/checkout/gnome-boxes/src/troubleshoot-log.vala"
	_g_object_unref0 (self->view);
#line 5 "/home/fborges/checkout/gnome-boxes/src/troubleshoot-log.vala"
	G_OBJECT_CLASS (boxes_troubleshoot_log_parent_class)->finalize (obj);
#line 93 "troubleshoot-log.c"
}


GType boxes_troubleshoot_log_get_type (void) {
	static volatile gsize boxes_troubleshoot_log_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_troubleshoot_log_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesTroubleshootLogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_troubleshoot_log_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesTroubleshootLog), 0, (GInstanceInitFunc) boxes_troubleshoot_log_instance_init, NULL };
		GType boxes_troubleshoot_log_type_id;
		boxes_troubleshoot_log_type_id = g_type_register_static (gtk_scrolled_window_get_type (), "BoxesTroubleshootLog", &g_define_type_info, 0);
		g_once_init_leave (&boxes_troubleshoot_log_type_id__volatile, boxes_troubleshoot_log_type_id);
	}
	return boxes_troubleshoot_log_type_id__volatile;
}



