/* actions-popover.c generated by valac 0.37.1.4-3591e, the Vala compiler
 * generated from actions-popover.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <gio/gio.h>
#include <atk/atk.h>
#include <glib/gi18n-lib.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <libcommon.h>
#include <stdlib.h>
#include <string.h>


#define BOXES_TYPE_ACTIONS_POPOVER (boxes_actions_popover_get_type ())
#define BOXES_ACTIONS_POPOVER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_ACTIONS_POPOVER, BoxesActionsPopover))
#define BOXES_ACTIONS_POPOVER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_ACTIONS_POPOVER, BoxesActionsPopoverClass))
#define BOXES_IS_ACTIONS_POPOVER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_ACTIONS_POPOVER))
#define BOXES_IS_ACTIONS_POPOVER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_ACTIONS_POPOVER))
#define BOXES_ACTIONS_POPOVER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_ACTIONS_POPOVER, BoxesActionsPopoverClass))

typedef struct _BoxesActionsPopover BoxesActionsPopover;
typedef struct _BoxesActionsPopoverClass BoxesActionsPopoverClass;
typedef struct _BoxesActionsPopoverPrivate BoxesActionsPopoverPrivate;

#define BOXES_TYPE_APP_WINDOW (boxes_app_window_get_type ())
#define BOXES_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindow))
#define BOXES_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))
#define BOXES_IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP_WINDOW))
#define BOXES_IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP_WINDOW))
#define BOXES_APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))

typedef struct _BoxesAppWindow BoxesAppWindow;
typedef struct _BoxesAppWindowClass BoxesAppWindowClass;
enum  {
	BOXES_ACTIONS_POPOVER_DUMMY_PROPERTY,
	BOXES_ACTIONS_POPOVER_LAST_PROPERTY
};
static GParamSpec* boxes_actions_popover_properties[BOXES_ACTIONS_POPOVER_LAST_PROPERTY];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;

#define BOXES_TYPE_LIBVIRT_MACHINE (boxes_libvirt_machine_get_type ())
#define BOXES_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachine))
#define BOXES_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))
#define BOXES_IS_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_IS_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_LIBVIRT_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))

typedef struct _BoxesLibvirtMachine BoxesLibvirtMachine;
typedef struct _BoxesLibvirtMachineClass BoxesLibvirtMachineClass;

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())
typedef struct _BoxesCollectionItemPrivate BoxesCollectionItemPrivate;

#define BOXES_TYPE_IPROPERTIES_PROVIDER (boxes_iproperties_provider_get_type ())
#define BOXES_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProvider))
#define BOXES_IS_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER))
#define BOXES_IPROPERTIES_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProviderIface))

typedef struct _BoxesIPropertiesProvider BoxesIPropertiesProvider;
typedef struct _BoxesIPropertiesProviderIface BoxesIPropertiesProviderIface;

#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())

#define BOXES_TYPE_PROPERTY (boxes_property_get_type ())
#define BOXES_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTY, BoxesProperty))
#define BOXES_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTY, BoxesPropertyClass))
#define BOXES_IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTY))
#define BOXES_IS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTY))
#define BOXES_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTY, BoxesPropertyClass))

typedef struct _BoxesProperty BoxesProperty;
typedef struct _BoxesPropertyClass BoxesPropertyClass;
typedef struct _BoxesMachinePrivate BoxesMachinePrivate;

#define BOXES_MACHINE_TYPE_CONNECT_FLAGS (boxes_machine_connect_flags_get_type ())

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_date_time_unref0(var) ((var == NULL) ? NULL : (var = (g_date_time_unref (var), NULL)))
typedef struct _Block12Data Block12Data;

#define BOXES_TYPE_DISPLAY (boxes_display_get_type ())
#define BOXES_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY, BoxesDisplay))
#define BOXES_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY, BoxesDisplayClass))
#define BOXES_IS_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY))
#define BOXES_IS_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY))
#define BOXES_DISPLAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY, BoxesDisplayClass))

typedef struct _BoxesDisplay BoxesDisplay;
typedef struct _BoxesDisplayClass BoxesDisplayClass;
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _BoxesAppWindowPrivate BoxesAppWindowPrivate;

#define BOXES_TYPE_WIZARD_WINDOW (boxes_wizard_window_get_type ())
#define BOXES_WIZARD_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD_WINDOW, BoxesWizardWindow))
#define BOXES_WIZARD_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD_WINDOW, BoxesWizardWindowClass))
#define BOXES_IS_WIZARD_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD_WINDOW))
#define BOXES_IS_WIZARD_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD_WINDOW))
#define BOXES_WIZARD_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD_WINDOW, BoxesWizardWindowClass))

typedef struct _BoxesWizardWindow BoxesWizardWindow;
typedef struct _BoxesWizardWindowClass BoxesWizardWindowClass;

#define BOXES_TYPE_PROPERTIES_WINDOW (boxes_properties_window_get_type ())
#define BOXES_PROPERTIES_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES_WINDOW, BoxesPropertiesWindow))
#define BOXES_PROPERTIES_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES_WINDOW, BoxesPropertiesWindowClass))
#define BOXES_IS_PROPERTIES_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES_WINDOW))
#define BOXES_IS_PROPERTIES_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES_WINDOW))
#define BOXES_PROPERTIES_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES_WINDOW, BoxesPropertiesWindowClass))

typedef struct _BoxesPropertiesWindow BoxesPropertiesWindow;
typedef struct _BoxesPropertiesWindowClass BoxesPropertiesWindowClass;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_SELECTIONBAR (boxes_selectionbar_get_type ())
#define BOXES_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar))
#define BOXES_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))
#define BOXES_IS_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SELECTIONBAR))
#define BOXES_IS_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SELECTIONBAR))
#define BOXES_SELECTIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))

typedef struct _BoxesSelectionbar BoxesSelectionbar;
typedef struct _BoxesSelectionbarClass BoxesSelectionbarClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_EMPTY_BOXES (boxes_empty_boxes_get_type ())
#define BOXES_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes))
#define BOXES_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))
#define BOXES_IS_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_IS_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_EMPTY_BOXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))

typedef struct _BoxesEmptyBoxes BoxesEmptyBoxes;
typedef struct _BoxesEmptyBoxesClass BoxesEmptyBoxesClass;
typedef struct _Block13Data Block13Data;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_NOTIFICATION (boxes_notification_get_type ())
#define BOXES_NOTIFICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATION, BoxesNotification))
#define BOXES_NOTIFICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATION, BoxesNotificationClass))
#define BOXES_IS_NOTIFICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATION))
#define BOXES_IS_NOTIFICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATION))
#define BOXES_NOTIFICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATION, BoxesNotificationClass))

typedef struct _BoxesNotification BoxesNotification;
typedef struct _BoxesNotificationClass BoxesNotificationClass;
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))

struct _BoxesActionsPopover {
	GtkPopover parent_instance;
	BoxesActionsPopoverPrivate * priv;
};

struct _BoxesActionsPopoverClass {
	GtkPopoverClass parent_class;
};

struct _BoxesActionsPopoverPrivate {
	BoxesAppWindow* window;
	GSimpleActionGroup* action_group;
};

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesCollectionItem {
	GObject parent_instance;
	BoxesCollectionItemPrivate * priv;
};

struct _BoxesCollectionItemClass {
	GObjectClass parent_class;
	gint (*compare) (BoxesCollectionItem* self, BoxesCollectionItem* other);
};

typedef enum  {
	BOXES_PROPERTIES_PAGE_GENERAL,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_SNAPSHOTS,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

struct _BoxesIPropertiesProviderIface {
	GTypeInterface parent_iface;
	GList* (*get_properties) (BoxesIPropertiesProvider* self, BoxesPropertiesPage page);
};

typedef enum  {
	BOXES_MACHINE_CONNECT_FLAGS_NONE = 0,
	BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE = 1 << 0
} BoxesMachineConnectFlags;

struct _BoxesMachine {
	BoxesCollectionItem parent_instance;
	BoxesMachinePrivate * priv;
	BoxesCollectionSource* source;
	BoxesBoxConfig* config;
	gboolean stay_on_display;
};

struct _BoxesMachineClass {
	BoxesCollectionItemClass parent_class;
	void (*save_real) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*save_real_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*take_screenshot) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GdkPixbuf* (*take_screenshot_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	GList* (*get_properties) (BoxesMachine* self, BoxesPropertiesPage page);
	void (*connect_display) (BoxesMachine* self, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*connect_display_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*restart) (BoxesMachine* self);
	void (*clone) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*clone_finish) (BoxesMachine* self, GAsyncResult* _res_);
	void (*disconnect_display) (BoxesMachine* self);
	void (*update_status) (BoxesMachine* self);
	void (*delete) (BoxesMachine* self, gboolean by_user);
	gboolean (*get_suspend_at_exit) (BoxesMachine* self);
	gboolean (*get_can_save) (BoxesMachine* self);
	gboolean (*get_can_restart) (BoxesMachine* self);
	gboolean (*get_can_clone) (BoxesMachine* self);
	gboolean (*get_should_autosave) (BoxesMachine* self);
	gboolean (*get_is_local) (BoxesMachine* self);
};

struct _Block12Data {
	int _ref_count_;
	BoxesActionsPopover* self;
	GtkStyleContext* ctx;
};

struct _BoxesAppWindow {
	GtkApplicationWindow parent_instance;
	BoxesAppWindowPrivate * priv;
	BoxesWizardWindow* wizard_window;
	BoxesPropertiesWindow* props_window;
	BoxesSearchbar* searchbar;
	BoxesTopbar* topbar;
	BoxesSelectionbar* selectionbar;
	BoxesDisplayPage* display_page;
	BoxesEmptyBoxes* empty_boxes;
	GtkStack* below_bin;
	GSettings* settings;
};

struct _BoxesAppWindowClass {
	GtkApplicationWindowClass parent_class;
};

struct _Block13Data {
	int _ref_count_;
	BoxesActionsPopover* self;
	BoxesMachine* machine;
};

typedef void (*BoxesAppUndoNotifyCallback) (void* user_data);

static gpointer boxes_actions_popover_parent_class = NULL;
extern BoxesApp* boxes_app_app;

GType boxes_actions_popover_get_type (void) G_GNUC_CONST;
GType boxes_app_window_get_type (void) G_GNUC_CONST;
#define BOXES_ACTIONS_POPOVER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_ACTIONS_POPOVER, BoxesActionsPopoverPrivate))
static void boxes_actions_popover_open_in_new_win_activated (BoxesActionsPopover* self);
static void _boxes_actions_popover_open_in_new_win_activated_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self);
static void boxes_actions_popover_favorite_activated (BoxesActionsPopover* self);
static void _boxes_actions_popover_favorite_activated_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self);
static void boxes_actions_popover_take_screenshot_activated (BoxesActionsPopover* self);
static void _boxes_actions_popover_take_screenshot_activated_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self);
static void boxes_actions_popover_pause_activated (BoxesActionsPopover* self);
static void _boxes_actions_popover_pause_activated_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self);
static void boxes_actions_popover_force_shutdown_activated (BoxesActionsPopover* self);
static void _boxes_actions_popover_force_shutdown_activated_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self);
static void boxes_actions_popover_delete_activated (BoxesActionsPopover* self);
static void _boxes_actions_popover_delete_activated_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self);
static void boxes_actions_popover_clone_activated (BoxesActionsPopover* self);
static void _boxes_actions_popover_clone_activated_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self);
static void boxes_actions_popover_properties_activated (BoxesActionsPopover* self);
static void _boxes_actions_popover_properties_activated_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self);
static void boxes_actions_popover_restart_activated (BoxesActionsPopover* self);
static void _boxes_actions_popover_restart_activated_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self);
BoxesActionsPopover* boxes_actions_popover_new (BoxesAppWindow* window);
BoxesActionsPopover* boxes_actions_popover_construct (GType object_type, BoxesAppWindow* window);
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
void boxes_actions_popover_update_for_item (BoxesActionsPopover* self, BoxesCollectionItem* item);
GType boxes_machine_get_type (void) G_GNUC_CONST;
GType boxes_libvirt_machine_get_type (void) G_GNUC_CONST;
gboolean boxes_libvirt_machine_get_importing (BoxesLibvirtMachine* self);
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
BoxesUIState boxes_ui_get_ui_state (BoxesUI* self);
GType boxes_properties_page_get_type (void) G_GNUC_CONST;
GType boxes_property_get_type (void) G_GNUC_CONST;
GType boxes_iproperties_provider_get_type (void) G_GNUC_CONST;
GType boxes_machine_connect_flags_get_type (void) G_GNUC_CONST;
static gboolean _vala_string_array_contains (gchar* * stack, int stack_length, gchar* needle);
gboolean boxes_machine_get_is_running (BoxesMachine* self);
gboolean boxes_machine_get_can_save (BoxesMachine* self);
gboolean boxes_machine_get_can_clone (BoxesMachine* self);
gboolean boxes_machine_get_can_delete (BoxesMachine* self);
gboolean boxes_machine_get_can_restart (BoxesMachine* self);
void boxes_app_window_set_current_item (BoxesAppWindow* self, BoxesCollectionItem* value);
GType boxes_app_get_type (void) G_GNUC_CONST;
void boxes_app_open_in_new_window (BoxesApp* self, BoxesMachine* machine);
BoxesCollectionItem* boxes_app_window_get_current_item (BoxesAppWindow* self);
static gchar* boxes_actions_popover_get_screenshot_filename (BoxesActionsPopover* self);
static Block12Data* block12_data_ref (Block12Data* _data12_);
static void block12_data_unref (void * _userdata_);
GType boxes_display_get_type (void) G_GNUC_CONST;
BoxesDisplay* boxes_machine_get_display (BoxesMachine* self);
GdkPixbuf* boxes_display_get_pixbuf (BoxesDisplay* self, gint n, GError** error);
GType boxes_wizard_window_get_type (void) G_GNUC_CONST;
GType boxes_properties_window_get_type (void) G_GNUC_CONST;
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_selectionbar_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_empty_boxes_get_type (void) G_GNUC_CONST;
static gboolean __lambda207_ (Block12Data* _data12_);
static gboolean ___lambda207__gsource_func (gpointer self);
static Block13Data* block13_data_ref (Block13Data* _data13_);
static void block13_data_unref (void * _userdata_);
void boxes_machine_save (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_machine_save_finish (BoxesMachine* self, GAsyncResult* _res_, GError** error);
static void __lambda208_ (Block13Data* _data13_, GObject* obj, GAsyncResult* _result_);
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
BoxesNotificationbar* boxes_app_window_get_notificationbar (BoxesAppWindow* self);
GType boxes_notification_get_type (void) G_GNUC_CONST;
BoxesNotification* boxes_notificationbar_display_error (BoxesNotificationbar* self, const gchar* message, gint timeout);
const gchar* boxes_collection_item_get_name (BoxesCollectionItem* self);
#define BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT 6
static void ___lambda208__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
void boxes_libvirt_machine_force_shutdown (BoxesLibvirtMachine* self);
void boxes_machine_restart (BoxesMachine* self);
void boxes_ui_set_state (BoxesUI* self, BoxesUIState new_state);
void boxes_app_delete_machines_undoable (BoxesApp* self, GList* items, const gchar* message, BoxesAppUndoNotifyCallback undo_notify_callback, void* undo_notify_callback_target, GDestroyNotify undo_notify_callback_target_destroy_notify);
static void _g_object_unref0_ (gpointer var);
static inline void _g_list_free__g_object_unref0_ (GList* self);
void boxes_machine_clone (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_machine_clone_finish (BoxesMachine* self, GAsyncResult* _res_);
void boxes_app_window_show_properties (BoxesAppWindow* self);
static void boxes_actions_popover_finalize (GObject * obj);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);

static const GActionEntry BOXES_ACTIONS_POPOVER_action_entries[9] = {{"open-in-new-win", _boxes_actions_popover_open_in_new_win_activated_gsimple_action_activate_callback}, {"favorite", _boxes_actions_popover_favorite_activated_gsimple_action_activate_callback}, {"take_screenshot", _boxes_actions_popover_take_screenshot_activated_gsimple_action_activate_callback}, {"pause", _boxes_actions_popover_pause_activated_gsimple_action_activate_callback}, {"force_shutdown", _boxes_actions_popover_force_shutdown_activated_gsimple_action_activate_callback}, {"delete", _boxes_actions_popover_delete_activated_gsimple_action_activate_callback}, {"clone", _boxes_actions_popover_clone_activated_gsimple_action_activate_callback}, {"properties", _boxes_actions_popover_properties_activated_gsimple_action_activate_callback}, {"restart", _boxes_actions_popover_restart_activated_gsimple_action_activate_callback}};

static void _boxes_actions_popover_open_in_new_win_activated_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self) {
#line 4 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	boxes_actions_popover_open_in_new_win_activated ((BoxesActionsPopover*) self);
#line 442 "actions-popover.c"
}


static void _boxes_actions_popover_favorite_activated_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self) {
#line 4 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	boxes_actions_popover_favorite_activated ((BoxesActionsPopover*) self);
#line 449 "actions-popover.c"
}


static void _boxes_actions_popover_take_screenshot_activated_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self) {
#line 4 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	boxes_actions_popover_take_screenshot_activated ((BoxesActionsPopover*) self);
#line 456 "actions-popover.c"
}


static void _boxes_actions_popover_pause_activated_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self) {
#line 4 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	boxes_actions_popover_pause_activated ((BoxesActionsPopover*) self);
#line 463 "actions-popover.c"
}


static void _boxes_actions_popover_force_shutdown_activated_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self) {
#line 4 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	boxes_actions_popover_force_shutdown_activated ((BoxesActionsPopover*) self);
#line 470 "actions-popover.c"
}


static void _boxes_actions_popover_delete_activated_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self) {
#line 4 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	boxes_actions_popover_delete_activated ((BoxesActionsPopover*) self);
#line 477 "actions-popover.c"
}


static void _boxes_actions_popover_clone_activated_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self) {
#line 4 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	boxes_actions_popover_clone_activated ((BoxesActionsPopover*) self);
#line 484 "actions-popover.c"
}


static void _boxes_actions_popover_properties_activated_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self) {
#line 4 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	boxes_actions_popover_properties_activated ((BoxesActionsPopover*) self);
#line 491 "actions-popover.c"
}


static void _boxes_actions_popover_restart_activated_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self) {
#line 4 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	boxes_actions_popover_restart_activated ((BoxesActionsPopover*) self);
#line 498 "actions-popover.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 20 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	return self ? g_object_ref (self) : NULL;
#line 505 "actions-popover.c"
}


BoxesActionsPopover* boxes_actions_popover_construct (GType object_type, BoxesAppWindow* window) {
	BoxesActionsPopover * self = NULL;
	BoxesAppWindow* _tmp0_;
	BoxesAppWindow* _tmp1_;
	GSimpleActionGroup* _tmp2_;
	GSimpleActionGroup* _tmp3_;
	GSimpleActionGroup* _tmp4_;
	AtkObject* a11y = NULL;
	AtkObject* _tmp5_;
	AtkObject* _tmp6_;
#line 19 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	g_return_val_if_fail (window != NULL, NULL);
#line 19 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	self = (BoxesActionsPopover*) g_object_new (object_type, NULL);
#line 20 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp0_ = window;
#line 20 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 20 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_g_object_unref0 (self->priv->window);
#line 20 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	self->priv->window = _tmp1_;
#line 22 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp2_ = g_simple_action_group_new ();
#line 22 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_g_object_unref0 (self->priv->action_group);
#line 22 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	self->priv->action_group = _tmp2_;
#line 23 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp3_ = self->priv->action_group;
#line 23 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	g_action_map_add_action_entries ((GActionMap*) _tmp3_, BOXES_ACTIONS_POPOVER_action_entries, G_N_ELEMENTS (BOXES_ACTIONS_POPOVER_action_entries), self);
#line 24 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp4_ = self->priv->action_group;
#line 24 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	gtk_widget_insert_action_group ((GtkWidget*) self, "box", (GActionGroup*) _tmp4_);
#line 26 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp5_ = gtk_widget_get_accessible ((GtkWidget*) self);
#line 26 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp6_ = _g_object_ref0 (_tmp5_);
#line 26 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	a11y = _tmp6_;
#line 27 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	a11y->role = ATK_ROLE_POPUP_MENU;
#line 29 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	a11y->name = _ ("Box actions");
#line 19 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_g_object_unref0 (a11y);
#line 19 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	return self;
#line 559 "actions-popover.c"
}


BoxesActionsPopover* boxes_actions_popover_new (BoxesAppWindow* window) {
#line 19 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	return boxes_actions_popover_construct (BOXES_TYPE_ACTIONS_POPOVER, window);
#line 566 "actions-popover.c"
}


static gboolean _vala_string_array_contains (gchar* * stack, int stack_length, gchar* needle) {
	int i;
#line 49 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	for (i = 0; i < stack_length; i++) {
#line 49 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		if (g_strcmp0 (stack[i], needle) == 0) {
#line 49 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
			return TRUE;
#line 578 "actions-popover.c"
		}
	}
#line 49 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	return FALSE;
#line 583 "actions-popover.c"
}


void boxes_actions_popover_update_for_item (BoxesActionsPopover* self, BoxesCollectionItem* item) {
	BoxesCollectionItem* _tmp0_;
	BoxesMachine* machine = NULL;
	BoxesCollectionItem* _tmp1_;
	BoxesMachine* _tmp2_;
	GMenu* menu = NULL;
	GMenu* _tmp3_;
	GMenu* section = NULL;
	GMenu* _tmp4_;
	gboolean _tmp5_ = FALSE;
	BoxesMachine* _tmp6_;
	gboolean importing = FALSE;
	BoxesAppWindow* _tmp10_;
	BoxesUIState _tmp11_;
	BoxesUIState _tmp12_;
	BoxesMachine* _tmp19_;
	BoxesBoxConfig* _tmp20_;
	gchar** _tmp21_;
	gint _tmp21__length1;
	gchar** _tmp22_;
	gint _tmp22__length1;
	gchar** _tmp23_;
	gint _tmp23__length1;
	gboolean _tmp24_;
	GMenu* _tmp27_;
	GMenu* _tmp28_;
	GMenu* _tmp29_;
	GMenu* _tmp30_;
	BoxesMachine* _tmp31_;
	BoxesAppWindow* _tmp40_;
	BoxesUIState _tmp41_;
	BoxesUIState _tmp42_;
	GMenu* _tmp75_;
	GMenu* _tmp76_;
	GMenu* _tmp77_;
	GMenu* _tmp78_;
	GMenu* _tmp79_;
	GMenu* _tmp80_;
	GSimpleAction* action = NULL;
	GSimpleActionGroup* _tmp81_;
	GAction* _tmp82_;
	GSimpleAction* _tmp83_;
	gboolean _tmp84_;
	GMenu* _tmp85_;
	BoxesAppWindow* _tmp86_;
	BoxesCollectionItem* _tmp87_;
#line 32 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	g_return_if_fail (self != NULL);
#line 32 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	g_return_if_fail (item != NULL);
#line 33 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp0_ = item;
#line 33 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, BOXES_TYPE_MACHINE));
#line 34 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp1_ = item;
#line 34 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp1_) : NULL);
#line 34 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	machine = _tmp2_;
#line 36 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp3_ = g_menu_new ();
#line 36 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	menu = _tmp3_;
#line 37 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp4_ = g_menu_new ();
#line 37 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	section = _tmp4_;
#line 39 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp6_ = machine;
#line 39 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp6_, BOXES_TYPE_LIBVIRT_MACHINE)) {
#line 659 "actions-popover.c"
		BoxesMachine* _tmp7_;
		gboolean _tmp8_;
		gboolean _tmp9_;
#line 39 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp7_ = machine;
#line 39 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp8_ = boxes_libvirt_machine_get_importing (G_TYPE_CHECK_INSTANCE_TYPE (_tmp7_, BOXES_TYPE_LIBVIRT_MACHINE) ? ((BoxesLibvirtMachine*) _tmp7_) : NULL);
#line 39 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp9_ = _tmp8_;
#line 39 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp5_ = _tmp9_;
#line 671 "actions-popover.c"
	} else {
#line 39 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp5_ = FALSE;
#line 675 "actions-popover.c"
	}
#line 39 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	importing = _tmp5_;
#line 42 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp10_ = self->priv->window;
#line 42 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp11_ = boxes_ui_get_ui_state ((BoxesUI*) _tmp10_);
#line 42 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp12_ = _tmp11_;
#line 42 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	if (_tmp12_ != BOXES_UI_STATE_DISPLAY) {
#line 687 "actions-popover.c"
		GMenu* _tmp13_;
		GSimpleAction* action = NULL;
		GSimpleActionGroup* _tmp14_;
		GAction* _tmp15_;
		GSimpleAction* _tmp16_;
		GSimpleAction* _tmp17_;
		gboolean _tmp18_;
#line 43 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp13_ = section;
#line 43 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		g_menu_append (_tmp13_, _ ("Open in New Window"), "box.open-in-new-win");
#line 44 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp14_ = self->priv->action_group;
#line 44 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp15_ = g_action_map_lookup_action ((GActionMap*) _tmp14_, "open-in-new-win");
#line 44 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp16_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp15_, g_simple_action_get_type ()) ? ((GSimpleAction*) _tmp15_) : NULL);
#line 44 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		action = _tmp16_;
#line 45 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp17_ = action;
#line 45 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp18_ = importing;
#line 45 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		g_simple_action_set_enabled (_tmp17_, !_tmp18_);
#line 42 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_g_object_unref0 (action);
#line 715 "actions-popover.c"
	}
#line 49 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp19_ = machine;
#line 49 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp20_ = _tmp19_->config;
#line 49 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp21_ = boxes_box_config_get_categories (_tmp20_, &_tmp21__length1);
#line 49 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp22_ = _tmp21_;
#line 49 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp22__length1 = _tmp21__length1;
#line 49 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp23_ = _tmp22_;
#line 49 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp23__length1 = _tmp22__length1;
#line 49 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp24_ = _vala_string_array_contains (_tmp23_, _tmp22__length1, "favorite");
#line 49 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp23_ = (_vala_array_free (_tmp23_, _tmp23__length1, (GDestroyNotify) g_free), NULL);
#line 49 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	if (_tmp24_) {
#line 737 "actions-popover.c"
		GMenu* _tmp25_;
#line 50 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp25_ = section;
#line 50 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		g_menu_append (_tmp25_, _ ("Remove from Favorites"), "box.favorite");
#line 743 "actions-popover.c"
	} else {
		GMenu* _tmp26_;
#line 52 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp26_ = section;
#line 52 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		g_menu_append (_tmp26_, _ ("Add to Favorites"), "box.favorite");
#line 750 "actions-popover.c"
	}
#line 53 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp27_ = menu;
#line 53 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp28_ = section;
#line 53 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	g_menu_append_section (_tmp27_, NULL, (GMenuModel*) _tmp28_);
#line 56 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp29_ = section;
#line 56 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	g_menu_append (_tmp29_, _ ("Take Screenshot"), "box.take_screenshot");
#line 59 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp30_ = g_menu_new ();
#line 59 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_g_object_unref0 (section);
#line 59 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	section = _tmp30_;
#line 61 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp31_ = machine;
#line 61 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp31_, BOXES_TYPE_LIBVIRT_MACHINE)) {
#line 772 "actions-popover.c"
		GMenu* _tmp32_;
		GSimpleAction* action = NULL;
		GSimpleActionGroup* _tmp33_;
		GAction* _tmp34_;
		GSimpleAction* _tmp35_;
		GSimpleAction* _tmp36_;
		BoxesMachine* _tmp37_;
		gboolean _tmp38_;
		gboolean _tmp39_;
#line 62 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp32_ = section;
#line 62 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		g_menu_append (_tmp32_, _ ("Force Shutdown"), "box.force_shutdown");
#line 63 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp33_ = self->priv->action_group;
#line 63 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp34_ = g_action_map_lookup_action ((GActionMap*) _tmp33_, "force_shutdown");
#line 63 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp35_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp34_, g_simple_action_get_type ()) ? ((GSimpleAction*) _tmp34_) : NULL);
#line 63 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		action = _tmp35_;
#line 64 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp36_ = action;
#line 64 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp37_ = machine;
#line 64 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp38_ = boxes_machine_get_is_running (_tmp37_);
#line 64 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp39_ = _tmp38_;
#line 64 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		g_simple_action_set_enabled (_tmp36_, _tmp39_);
#line 61 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_g_object_unref0 (action);
#line 806 "actions-popover.c"
	}
#line 67 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp40_ = self->priv->window;
#line 67 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp41_ = boxes_ui_get_ui_state ((BoxesUI*) _tmp40_);
#line 67 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp42_ = _tmp41_;
#line 67 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	if (_tmp42_ != BOXES_UI_STATE_DISPLAY) {
#line 816 "actions-popover.c"
		GMenu* _tmp43_;
		GSimpleAction* action = NULL;
		GSimpleActionGroup* _tmp44_;
		GAction* _tmp45_;
		GSimpleAction* _tmp46_;
		GSimpleAction* _tmp47_;
		BoxesMachine* _tmp48_;
		gboolean _tmp49_;
		gboolean _tmp50_;
		GMenu* _tmp51_;
		GSimpleActionGroup* _tmp52_;
		GAction* _tmp53_;
		GSimpleAction* _tmp54_;
		GSimpleAction* _tmp55_;
		BoxesMachine* _tmp56_;
		gboolean _tmp57_;
		gboolean _tmp58_;
		GMenu* _tmp59_;
		GSimpleActionGroup* _tmp60_;
		GAction* _tmp61_;
		GSimpleAction* _tmp62_;
		GSimpleAction* _tmp63_;
		BoxesMachine* _tmp64_;
		gboolean _tmp65_;
		gboolean _tmp66_;
#line 69 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp43_ = section;
#line 69 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		g_menu_append (_tmp43_, _ ("Pause"), "box.pause");
#line 70 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp44_ = self->priv->action_group;
#line 70 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp45_ = g_action_map_lookup_action ((GActionMap*) _tmp44_, "pause");
#line 70 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp46_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp45_, g_simple_action_get_type ()) ? ((GSimpleAction*) _tmp45_) : NULL);
#line 70 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		action = _tmp46_;
#line 71 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp47_ = action;
#line 71 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp48_ = machine;
#line 71 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp49_ = boxes_machine_get_can_save (_tmp48_);
#line 71 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp50_ = _tmp49_;
#line 71 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		g_simple_action_set_enabled (_tmp47_, _tmp50_);
#line 74 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp51_ = section;
#line 74 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		g_menu_append (_tmp51_, _ ("Clone"), "box.clone");
#line 75 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp52_ = self->priv->action_group;
#line 75 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp53_ = g_action_map_lookup_action ((GActionMap*) _tmp52_, "clone");
#line 75 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp54_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp53_, g_simple_action_get_type ()) ? ((GSimpleAction*) _tmp53_) : NULL);
#line 75 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_g_object_unref0 (action);
#line 75 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		action = _tmp54_;
#line 76 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp55_ = action;
#line 76 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp56_ = machine;
#line 76 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp57_ = boxes_machine_get_can_clone (_tmp56_);
#line 76 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp58_ = _tmp57_;
#line 76 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		g_simple_action_set_enabled (_tmp55_, _tmp58_);
#line 79 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp59_ = section;
#line 79 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		g_menu_append (_tmp59_, _ ("Delete"), "box.delete");
#line 80 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp60_ = self->priv->action_group;
#line 80 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp61_ = g_action_map_lookup_action ((GActionMap*) _tmp60_, "delete");
#line 80 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp62_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp61_, g_simple_action_get_type ()) ? ((GSimpleAction*) _tmp61_) : NULL);
#line 80 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_g_object_unref0 (action);
#line 80 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		action = _tmp62_;
#line 81 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp63_ = action;
#line 81 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp64_ = machine;
#line 81 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp65_ = boxes_machine_get_can_delete (_tmp64_);
#line 81 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp66_ = _tmp65_;
#line 81 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		g_simple_action_set_enabled (_tmp63_, _tmp66_);
#line 67 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_g_object_unref0 (action);
#line 914 "actions-popover.c"
	} else {
		GMenu* _tmp67_;
		GSimpleAction* action = NULL;
		GSimpleActionGroup* _tmp68_;
		GAction* _tmp69_;
		GSimpleAction* _tmp70_;
		GSimpleAction* _tmp71_;
		BoxesMachine* _tmp72_;
		gboolean _tmp73_;
		gboolean _tmp74_;
#line 83 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp67_ = section;
#line 83 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		g_menu_append (_tmp67_, _ ("Restart"), "box.restart");
#line 84 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp68_ = self->priv->action_group;
#line 84 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp69_ = g_action_map_lookup_action ((GActionMap*) _tmp68_, "restart");
#line 84 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp70_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp69_, g_simple_action_get_type ()) ? ((GSimpleAction*) _tmp69_) : NULL);
#line 84 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		action = _tmp70_;
#line 85 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp71_ = action;
#line 85 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp72_ = machine;
#line 85 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp73_ = boxes_machine_get_can_restart (_tmp72_);
#line 85 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp74_ = _tmp73_;
#line 85 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		g_simple_action_set_enabled (_tmp71_, _tmp74_);
#line 67 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_g_object_unref0 (action);
#line 949 "actions-popover.c"
	}
#line 88 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp75_ = menu;
#line 88 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp76_ = section;
#line 88 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	g_menu_append_section (_tmp75_, NULL, (GMenuModel*) _tmp76_);
#line 91 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp77_ = g_menu_new ();
#line 91 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_g_object_unref0 (section);
#line 91 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	section = _tmp77_;
#line 92 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp78_ = section;
#line 92 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	g_menu_append (_tmp78_, _ ("Properties"), "box.properties");
#line 93 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp79_ = menu;
#line 93 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp80_ = section;
#line 93 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	g_menu_append_section (_tmp79_, NULL, (GMenuModel*) _tmp80_);
#line 94 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp81_ = self->priv->action_group;
#line 94 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp82_ = g_action_map_lookup_action ((GActionMap*) _tmp81_, "properties");
#line 94 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp83_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp82_, g_simple_action_get_type ()) ? ((GSimpleAction*) _tmp82_) : NULL);
#line 94 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	action = _tmp83_;
#line 95 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp84_ = importing;
#line 95 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	g_simple_action_set_enabled (action, !_tmp84_);
#line 97 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp85_ = menu;
#line 97 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	gtk_popover_bind_model ((GtkPopover*) self, (GMenuModel*) _tmp85_, NULL);
#line 98 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp86_ = self->priv->window;
#line 98 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp87_ = item;
#line 98 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	boxes_app_window_set_current_item (_tmp86_, _tmp87_);
#line 32 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_g_object_unref0 (action);
#line 32 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_g_object_unref0 (section);
#line 32 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_g_object_unref0 (menu);
#line 32 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_g_object_unref0 (machine);
#line 1003 "actions-popover.c"
}


static void boxes_actions_popover_open_in_new_win_activated (BoxesActionsPopover* self) {
	BoxesApp* _tmp0_;
	BoxesAppWindow* _tmp1_;
	BoxesCollectionItem* _tmp2_;
	BoxesCollectionItem* _tmp3_;
#line 101 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	g_return_if_fail (self != NULL);
#line 102 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp0_ = boxes_app_app;
#line 102 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp1_ = self->priv->window;
#line 102 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp2_ = boxes_app_window_get_current_item (_tmp1_);
#line 102 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp3_ = _tmp2_;
#line 102 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	boxes_app_open_in_new_window (_tmp0_, G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp3_) : NULL);
#line 1024 "actions-popover.c"
}


static void boxes_actions_popover_favorite_activated (BoxesActionsPopover* self) {
	BoxesMachine* machine = NULL;
	BoxesAppWindow* _tmp0_;
	BoxesCollectionItem* _tmp1_;
	BoxesCollectionItem* _tmp2_;
	BoxesMachine* _tmp3_;
	gboolean enabled = FALSE;
	BoxesBoxConfig* _tmp4_;
	gchar** _tmp5_;
	gint _tmp5__length1;
	gchar** _tmp6_;
	gint _tmp6__length1;
	gchar** _tmp7_;
	gint _tmp7__length1;
	gboolean _tmp8_;
	BoxesBoxConfig* _tmp9_;
#line 105 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	g_return_if_fail (self != NULL);
#line 106 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp0_ = self->priv->window;
#line 106 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp1_ = boxes_app_window_get_current_item (_tmp0_);
#line 106 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp2_ = _tmp1_;
#line 106 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp3_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp2_) : NULL);
#line 106 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	machine = _tmp3_;
#line 107 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp4_ = machine->config;
#line 107 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp5_ = boxes_box_config_get_categories (_tmp4_, &_tmp5__length1);
#line 107 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp6_ = _tmp5_;
#line 107 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp6__length1 = _tmp5__length1;
#line 107 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp7_ = _tmp6_;
#line 107 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp7__length1 = _tmp6__length1;
#line 107 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp8_ = !_vala_string_array_contains (_tmp7_, _tmp6__length1, "favorite");
#line 107 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp7_ = (_vala_array_free (_tmp7_, _tmp7__length1, (GDestroyNotify) g_free), NULL);
#line 107 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	enabled = _tmp8_;
#line 108 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp9_ = machine->config;
#line 108 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	boxes_box_config_set_category (_tmp9_, "favorite", enabled);
#line 105 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_g_object_unref0 (machine);
#line 1080 "actions-popover.c"
}


static gchar* boxes_actions_popover_get_screenshot_filename (BoxesActionsPopover* self) {
	gchar* result = NULL;
	GDateTime* now = NULL;
	GDateTime* _tmp0_;
	gchar* timestamp = NULL;
	gchar* _tmp1_;
	gchar* filename = NULL;
	gchar* _tmp2_;
	const gchar* _tmp3_;
	gchar* _tmp4_;
#line 111 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 112 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp0_ = g_date_time_new_now_local ();
#line 112 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	now = _tmp0_;
#line 113 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp1_ = g_date_time_format (now, "%Y-%m-%d %H-%M-%S");
#line 113 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	timestamp = _tmp1_;
#line 116 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp2_ = g_strdup_printf (_ ("Screenshot from %s"), timestamp);
#line 116 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	filename = _tmp2_;
#line 118 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp3_ = g_get_user_special_dir (G_USER_DIRECTORY_PICTURES);
#line 118 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp4_ = g_build_filename (_tmp3_, filename, NULL);
#line 118 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	result = _tmp4_;
#line 118 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_g_free0 (filename);
#line 118 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_g_free0 (timestamp);
#line 118 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_g_date_time_unref0 (now);
#line 118 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	return result;
#line 1122 "actions-popover.c"
}


static Block12Data* block12_data_ref (Block12Data* _data12_) {
#line 122 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	g_atomic_int_inc (&_data12_->_ref_count_);
#line 122 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	return _data12_;
#line 1131 "actions-popover.c"
}


static void block12_data_unref (void * _userdata_) {
	Block12Data* _data12_;
	_data12_ = (Block12Data*) _userdata_;
#line 122 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	if (g_atomic_int_dec_and_test (&_data12_->_ref_count_)) {
#line 1140 "actions-popover.c"
		BoxesActionsPopover* self;
#line 122 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		self = _data12_->self;
#line 122 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_g_object_unref0 (_data12_->ctx);
#line 122 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_g_object_unref0 (self);
#line 122 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		g_slice_free (Block12Data, _data12_);
#line 1150 "actions-popover.c"
	}
}


static gboolean __lambda207_ (Block12Data* _data12_) {
	BoxesActionsPopover* self;
	gboolean result = FALSE;
#line 133 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	self = _data12_->self;
#line 134 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	gtk_style_context_remove_class (_data12_->ctx, "flash");
#line 136 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	result = FALSE;
#line 136 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	return result;
#line 1166 "actions-popover.c"
}


static gboolean ___lambda207__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda207_ (self);
#line 133 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	return result;
#line 1175 "actions-popover.c"
}


static void boxes_actions_popover_take_screenshot_activated (BoxesActionsPopover* self) {
	Block12Data* _data12_;
	BoxesMachine* machine = NULL;
	BoxesAppWindow* _tmp0_;
	BoxesCollectionItem* _tmp1_;
	BoxesCollectionItem* _tmp2_;
	BoxesMachine* _tmp3_;
	BoxesAppWindow* _tmp13_;
	GtkStack* _tmp14_;
	GtkStyleContext* _tmp15_;
	GtkStyleContext* _tmp16_;
	GError * _inner_error_ = NULL;
#line 122 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	g_return_if_fail (self != NULL);
#line 122 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_data12_ = g_slice_new0 (Block12Data);
#line 122 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_data12_->_ref_count_ = 1;
#line 122 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_data12_->self = g_object_ref (self);
#line 123 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp0_ = self->priv->window;
#line 123 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp1_ = boxes_app_window_get_current_item (_tmp0_);
#line 123 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp2_ = _tmp1_;
#line 123 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp3_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp2_) : NULL);
#line 123 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	machine = _tmp3_;
#line 1209 "actions-popover.c"
	{
		GdkPixbuf* pixbuf = NULL;
		BoxesMachine* _tmp4_;
		BoxesDisplay* _tmp5_;
		BoxesDisplay* _tmp6_;
		GdkPixbuf* _tmp7_;
		GdkPixbuf* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
#line 125 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp4_ = machine;
#line 125 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp5_ = boxes_machine_get_display (_tmp4_);
#line 125 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp6_ = _tmp5_;
#line 125 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp7_ = boxes_display_get_pixbuf (_tmp6_, 0, &_inner_error_);
#line 125 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		pixbuf = _tmp7_;
#line 125 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1231 "actions-popover.c"
			goto __catch7_g_error;
		}
#line 126 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp8_ = pixbuf;
#line 126 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp9_ = boxes_actions_popover_get_screenshot_filename (self);
#line 126 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp10_ = _tmp9_;
#line 126 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		gdk_pixbuf_save (_tmp8_, _tmp10_, "png", &_inner_error_, NULL);
#line 126 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_g_free0 (_tmp10_);
#line 126 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 126 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
			_g_object_unref0 (pixbuf);
#line 1248 "actions-popover.c"
			goto __catch7_g_error;
		}
#line 124 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_g_object_unref0 (pixbuf);
#line 1253 "actions-popover.c"
	}
	goto __finally7;
	__catch7_g_error:
	{
		GError* _error_ = NULL;
		GError* _tmp11_;
		const gchar* _tmp12_;
#line 124 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_error_ = _inner_error_;
#line 124 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_inner_error_ = NULL;
#line 128 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp11_ = _error_;
#line 128 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp12_ = _tmp11_->message;
#line 128 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		g_warning ("actions-popover.vala:128: %s", _tmp12_);
#line 124 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_g_error_free0 (_error_);
#line 1273 "actions-popover.c"
	}
	__finally7:
#line 124 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 124 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_g_object_unref0 (machine);
#line 124 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		block12_data_unref (_data12_);
#line 124 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_data12_ = NULL;
#line 124 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 124 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		g_clear_error (&_inner_error_);
#line 124 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		return;
#line 1290 "actions-popover.c"
	}
#line 131 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp13_ = self->priv->window;
#line 131 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp14_ = _tmp13_->below_bin;
#line 131 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp15_ = gtk_widget_get_style_context ((GtkWidget*) _tmp14_);
#line 131 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp16_ = _g_object_ref0 (_tmp15_);
#line 131 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_data12_->ctx = _tmp16_;
#line 132 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	gtk_style_context_add_class (_data12_->ctx, "flash");
#line 133 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	g_timeout_add_full (G_PRIORITY_DEFAULT, (guint) 200, ___lambda207__gsource_func, block12_data_ref (_data12_), block12_data_unref);
#line 122 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_g_object_unref0 (machine);
#line 122 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	block12_data_unref (_data12_);
#line 122 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_data12_ = NULL;
#line 1312 "actions-popover.c"
}


static Block13Data* block13_data_ref (Block13Data* _data13_) {
#line 140 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	g_atomic_int_inc (&_data13_->_ref_count_);
#line 140 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	return _data13_;
#line 1321 "actions-popover.c"
}


static void block13_data_unref (void * _userdata_) {
	Block13Data* _data13_;
	_data13_ = (Block13Data*) _userdata_;
#line 140 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	if (g_atomic_int_dec_and_test (&_data13_->_ref_count_)) {
#line 1330 "actions-popover.c"
		BoxesActionsPopover* self;
#line 140 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		self = _data13_->self;
#line 140 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_g_object_unref0 (_data13_->machine);
#line 140 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_g_object_unref0 (self);
#line 140 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		g_slice_free (Block13Data, _data13_);
#line 1340 "actions-popover.c"
	}
}


static void __lambda208_ (Block13Data* _data13_, GObject* obj, GAsyncResult* _result_) {
	BoxesActionsPopover* self;
	GError * _inner_error_ = NULL;
#line 143 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	self = _data13_->self;
#line 143 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	g_return_if_fail (_result_ != NULL);
#line 1352 "actions-popover.c"
	{
		GAsyncResult* _tmp0_;
#line 145 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp0_ = _result_;
#line 145 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		boxes_machine_save_finish (_data13_->machine, _tmp0_, &_inner_error_);
#line 145 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1361 "actions-popover.c"
			goto __catch8_g_error;
		}
	}
	goto __finally8;
	__catch8_g_error:
	{
		GError* e = NULL;
		BoxesAppWindow* _tmp1_;
		BoxesNotificationbar* _tmp2_;
		BoxesNotificationbar* _tmp3_;
		const gchar* _tmp4_;
		const gchar* _tmp5_;
		gchar* _tmp6_;
		gchar* _tmp7_;
		BoxesNotification* _tmp8_;
		BoxesNotification* _tmp9_;
#line 144 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		e = _inner_error_;
#line 144 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_inner_error_ = NULL;
#line 147 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp1_ = self->priv->window;
#line 147 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp2_ = boxes_app_window_get_notificationbar (_tmp1_);
#line 147 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp3_ = _tmp2_;
#line 147 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp4_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _data13_->machine);
#line 147 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp5_ = _tmp4_;
#line 147 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp6_ = g_strdup_printf (_ ("Pausing “%s” failed"), _tmp5_);
#line 147 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp7_ = _tmp6_;
#line 147 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp8_ = boxes_notificationbar_display_error (_tmp3_, _tmp7_, BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 147 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_tmp9_ = _tmp8_;
#line 147 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_g_object_unref0 (_tmp9_);
#line 147 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_g_free0 (_tmp7_);
#line 144 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		_g_error_free0 (e);
#line 1406 "actions-popover.c"
	}
	__finally8:
#line 144 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 144 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 144 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		g_clear_error (&_inner_error_);
#line 144 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
		return;
#line 1417 "actions-popover.c"
	}
}


static void ___lambda208__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 143 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	__lambda208_ (self, source_object, res);
#line 143 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	block13_data_unref (self);
#line 1427 "actions-popover.c"
}


static void boxes_actions_popover_pause_activated (BoxesActionsPopover* self) {
	Block13Data* _data13_;
	BoxesAppWindow* _tmp0_;
	BoxesCollectionItem* _tmp1_;
	BoxesCollectionItem* _tmp2_;
	BoxesMachine* _tmp3_;
#line 140 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	g_return_if_fail (self != NULL);
#line 140 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_data13_ = g_slice_new0 (Block13Data);
#line 140 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_data13_->_ref_count_ = 1;
#line 140 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_data13_->self = g_object_ref (self);
#line 141 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp0_ = self->priv->window;
#line 141 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp1_ = boxes_app_window_get_current_item (_tmp0_);
#line 141 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp2_ = _tmp1_;
#line 141 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp3_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp2_) : NULL);
#line 141 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_data13_->machine = _tmp3_;
#line 143 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	boxes_machine_save (_data13_->machine, ___lambda208__gasync_ready_callback, block13_data_ref (_data13_));
#line 140 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	block13_data_unref (_data13_);
#line 140 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_data13_ = NULL;
#line 1461 "actions-popover.c"
}


static void boxes_actions_popover_force_shutdown_activated (BoxesActionsPopover* self) {
	BoxesLibvirtMachine* machine = NULL;
	BoxesAppWindow* _tmp0_;
	BoxesCollectionItem* _tmp1_;
	BoxesCollectionItem* _tmp2_;
	BoxesLibvirtMachine* _tmp3_;
#line 152 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	g_return_if_fail (self != NULL);
#line 153 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp0_ = self->priv->window;
#line 153 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp1_ = boxes_app_window_get_current_item (_tmp0_);
#line 153 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp2_ = _tmp1_;
#line 153 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp3_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, BOXES_TYPE_LIBVIRT_MACHINE) ? ((BoxesLibvirtMachine*) _tmp2_) : NULL);
#line 153 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	machine = _tmp3_;
#line 155 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	boxes_libvirt_machine_force_shutdown (machine);
#line 152 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_g_object_unref0 (machine);
#line 1487 "actions-popover.c"
}


static void boxes_actions_popover_restart_activated (BoxesActionsPopover* self) {
	BoxesAppWindow* _tmp0_;
	BoxesCollectionItem* _tmp1_;
	BoxesCollectionItem* _tmp2_;
#line 158 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	g_return_if_fail (self != NULL);
#line 159 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp0_ = self->priv->window;
#line 159 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp1_ = boxes_app_window_get_current_item (_tmp0_);
#line 159 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp2_ = _tmp1_;
#line 159 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	boxes_machine_restart (G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp2_) : NULL);
#line 1505 "actions-popover.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 162 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 1512 "actions-popover.c"
}


static inline void _g_list_free__g_object_unref0_ (GList* self) {
#line 162 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	g_list_free_full (self, (GDestroyNotify) _g_object_unref0_);
#line 1519 "actions-popover.c"
}


static void boxes_actions_popover_delete_activated (BoxesActionsPopover* self) {
	BoxesAppWindow* _tmp0_;
	GList* items = NULL;
	BoxesAppWindow* _tmp1_;
	BoxesCollectionItem* _tmp2_;
	BoxesCollectionItem* _tmp3_;
	BoxesCollectionItem* _tmp4_;
	BoxesApp* _tmp5_;
	GList* _tmp6_;
#line 162 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	g_return_if_fail (self != NULL);
#line 163 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp0_ = self->priv->window;
#line 163 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	boxes_ui_set_state ((BoxesUI*) _tmp0_, BOXES_UI_STATE_COLLECTION);
#line 165 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	items = NULL;
#line 166 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp1_ = self->priv->window;
#line 166 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp2_ = boxes_app_window_get_current_item (_tmp1_);
#line 166 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp3_ = _tmp2_;
#line 166 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 166 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	items = g_list_append (items, _tmp4_);
#line 168 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp5_ = boxes_app_app;
#line 168 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp6_ = items;
#line 168 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	items = NULL;
#line 168 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	boxes_app_delete_machines_undoable (_tmp5_, _tmp6_, NULL, NULL, NULL, NULL);
#line 162 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	__g_list_free__g_object_unref0_0 (items);
#line 1560 "actions-popover.c"
}


static void boxes_actions_popover_clone_activated (BoxesActionsPopover* self) {
	BoxesAppWindow* _tmp0_;
	BoxesCollectionItem* _tmp1_;
	BoxesCollectionItem* _tmp2_;
#line 171 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	g_return_if_fail (self != NULL);
#line 172 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp0_ = self->priv->window;
#line 172 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp1_ = boxes_app_window_get_current_item (_tmp0_);
#line 172 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp2_ = _tmp1_;
#line 172 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	boxes_machine_clone (G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp2_) : NULL, NULL, NULL);
#line 1578 "actions-popover.c"
}


static void boxes_actions_popover_properties_activated (BoxesActionsPopover* self) {
	BoxesAppWindow* _tmp0_;
#line 175 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	g_return_if_fail (self != NULL);
#line 176 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_tmp0_ = self->priv->window;
#line 176 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	boxes_app_window_show_properties (_tmp0_);
#line 1590 "actions-popover.c"
}


static void boxes_actions_popover_class_init (BoxesActionsPopoverClass * klass) {
#line 3 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	boxes_actions_popover_parent_class = g_type_class_peek_parent (klass);
#line 3 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	g_type_class_add_private (klass, sizeof (BoxesActionsPopoverPrivate));
#line 3 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_actions_popover_finalize;
#line 1601 "actions-popover.c"
}


static void boxes_actions_popover_instance_init (BoxesActionsPopover * self) {
#line 3 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	self->priv = BOXES_ACTIONS_POPOVER_GET_PRIVATE (self);
#line 1608 "actions-popover.c"
}


static void boxes_actions_popover_finalize (GObject * obj) {
	BoxesActionsPopover * self;
#line 3 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_ACTIONS_POPOVER, BoxesActionsPopover);
#line 16 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_g_object_unref0 (self->priv->window);
#line 17 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	_g_object_unref0 (self->priv->action_group);
#line 3 "/home/fborges/checkout/gnome-boxes/src/actions-popover.vala"
	G_OBJECT_CLASS (boxes_actions_popover_parent_class)->finalize (obj);
#line 1622 "actions-popover.c"
}


GType boxes_actions_popover_get_type (void) {
	static volatile gsize boxes_actions_popover_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_actions_popover_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesActionsPopoverClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_actions_popover_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesActionsPopover), 0, (GInstanceInitFunc) boxes_actions_popover_instance_init, NULL };
		GType boxes_actions_popover_type_id;
		boxes_actions_popover_type_id = g_type_register_static (gtk_popover_get_type (), "BoxesActionsPopover", &g_define_type_info, 0);
		g_once_init_leave (&boxes_actions_popover_type_id__volatile, boxes_actions_popover_type_id);
	}
	return boxes_actions_popover_type_id__volatile;
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



