/* wizard.c generated by valac 0.37.1.4-3591e, the Vala compiler
 * generated from wizard.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <libcommon.h>
#include <gio/gio.h>
#include <float.h>
#include <math.h>
#include <stdlib.h>
#include <string.h>
#include <glib/gi18n-lib.h>
#include <libxml/uri.h>
#include <libvirt-gconfig/libvirt-gconfig.h>
#include <osinfo/osinfo.h>
#include <libvirt-gobject/libvirt-gobject.h>
#include <pango/pango.h>


#define BOXES_TYPE_WIZARD_PAGE (boxes_wizard_page_get_type ())

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;
typedef struct _BoxesWizardPrivate BoxesWizardPrivate;

#define BOXES_TYPE_WIZARD_SOURCE (boxes_wizard_source_get_type ())
#define BOXES_WIZARD_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD_SOURCE, BoxesWizardSource))
#define BOXES_WIZARD_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD_SOURCE, BoxesWizardSourceClass))
#define BOXES_IS_WIZARD_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD_SOURCE))
#define BOXES_IS_WIZARD_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD_SOURCE))
#define BOXES_WIZARD_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD_SOURCE, BoxesWizardSourceClass))

typedef struct _BoxesWizardSource BoxesWizardSource;
typedef struct _BoxesWizardSourceClass BoxesWizardSourceClass;

#define BOXES_TYPE_WIZARD_SUMMARY (boxes_wizard_summary_get_type ())
#define BOXES_WIZARD_SUMMARY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD_SUMMARY, BoxesWizardSummary))
#define BOXES_WIZARD_SUMMARY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD_SUMMARY, BoxesWizardSummaryClass))
#define BOXES_IS_WIZARD_SUMMARY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD_SUMMARY))
#define BOXES_IS_WIZARD_SUMMARY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD_SUMMARY))
#define BOXES_WIZARD_SUMMARY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD_SUMMARY, BoxesWizardSummaryClass))

typedef struct _BoxesWizardSummary BoxesWizardSummary;
typedef struct _BoxesWizardSummaryClass BoxesWizardSummaryClass;

#define BOXES_TYPE_APP_WINDOW (boxes_app_window_get_type ())
#define BOXES_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindow))
#define BOXES_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))
#define BOXES_IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP_WINDOW))
#define BOXES_IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP_WINDOW))
#define BOXES_APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))

typedef struct _BoxesAppWindow BoxesAppWindow;
typedef struct _BoxesAppWindowClass BoxesAppWindowClass;

#define BOXES_TYPE_WIZARD_WINDOW (boxes_wizard_window_get_type ())
#define BOXES_WIZARD_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD_WINDOW, BoxesWizardWindow))
#define BOXES_WIZARD_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD_WINDOW, BoxesWizardWindowClass))
#define BOXES_IS_WIZARD_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD_WINDOW))
#define BOXES_IS_WIZARD_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD_WINDOW))
#define BOXES_WIZARD_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD_WINDOW, BoxesWizardWindowClass))

typedef struct _BoxesWizardWindow BoxesWizardWindow;
typedef struct _BoxesWizardWindowClass BoxesWizardWindowClass;

#define BOXES_TYPE_MEDIA_MANAGER (boxes_media_manager_get_type ())
#define BOXES_MEDIA_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManager))
#define BOXES_MEDIA_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManagerClass))
#define BOXES_IS_MEDIA_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MEDIA_MANAGER))
#define BOXES_IS_MEDIA_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MEDIA_MANAGER))
#define BOXES_MEDIA_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManagerClass))

typedef struct _BoxesMediaManager BoxesMediaManager;
typedef struct _BoxesMediaManagerClass BoxesMediaManagerClass;

#define BOXES_TYPE_VM_CREATOR (boxes_vm_creator_get_type ())
#define BOXES_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreator))
#define BOXES_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))
#define BOXES_IS_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_VM_CREATOR))
#define BOXES_IS_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_VM_CREATOR))
#define BOXES_VM_CREATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))

typedef struct _BoxesVMCreator BoxesVMCreator;
typedef struct _BoxesVMCreatorClass BoxesVMCreatorClass;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;
enum  {
	BOXES_WIZARD_DUMMY_PROPERTY,
	BOXES_WIZARD_PREVIOUS_UI_STATE,
	BOXES_WIZARD_UI_STATE,
	BOXES_WIZARD_MACHINE,
	BOXES_WIZARD_PAGE,
	BOXES_WIZARD_LAST_PROPERTY
};
static GParamSpec* boxes_wizard_properties[BOXES_WIZARD_LAST_PROPERTY];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _boxes_vm_creator_unref0(var) ((var == NULL) ? NULL : (var = (boxes_vm_creator_unref (var), NULL)))
typedef struct _Block99Data Block99Data;

#define BOXES_TYPE_SOURCE_PAGE (boxes_source_page_get_type ())
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _BoxesWizardReviewData BoxesWizardReviewData;
typedef struct _Block100Data Block100Data;

#define BOXES_TYPE_LIBVIRT_MACHINE (boxes_libvirt_machine_get_type ())
#define BOXES_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachine))
#define BOXES_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))
#define BOXES_IS_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_IS_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_LIBVIRT_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))

typedef struct _BoxesLibvirtMachine BoxesLibvirtMachine;
typedef struct _BoxesLibvirtMachineClass BoxesLibvirtMachineClass;

#define BOXES_TYPE_INSTALLER_MEDIA (boxes_installer_media_get_type ())
#define BOXES_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMedia))
#define BOXES_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))
#define BOXES_IS_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_IS_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_INSTALLER_MEDIA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))

typedef struct _BoxesInstallerMedia BoxesInstallerMedia;
typedef struct _BoxesInstallerMediaClass BoxesInstallerMediaClass;
typedef struct _BoxesWizardSourcePrivate BoxesWizardSourcePrivate;

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;

#define BOXES_TYPE_LIBVIRT_SYSTEM_IMPORTER (boxes_libvirt_system_importer_get_type ())
#define BOXES_LIBVIRT_SYSTEM_IMPORTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_SYSTEM_IMPORTER, BoxesLibvirtSystemImporter))
#define BOXES_LIBVIRT_SYSTEM_IMPORTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_SYSTEM_IMPORTER, BoxesLibvirtSystemImporterClass))
#define BOXES_IS_LIBVIRT_SYSTEM_IMPORTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_SYSTEM_IMPORTER))
#define BOXES_IS_LIBVIRT_SYSTEM_IMPORTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_SYSTEM_IMPORTER))
#define BOXES_LIBVIRT_SYSTEM_IMPORTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_SYSTEM_IMPORTER, BoxesLibvirtSystemImporterClass))

typedef struct _BoxesLibvirtSystemImporter BoxesLibvirtSystemImporter;
typedef struct _BoxesLibvirtSystemImporterClass BoxesLibvirtSystemImporterClass;
typedef struct _BoxesWizardCreateData BoxesWizardCreateData;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _xmlFreeURI0(var) ((var == NULL) ? NULL : (var = (xmlFreeURI (var), NULL)))
typedef struct _Block101Data Block101Data;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_NOTIFICATION (boxes_notification_get_type ())
#define BOXES_NOTIFICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATION, BoxesNotification))
#define BOXES_NOTIFICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATION, BoxesNotificationClass))
#define BOXES_IS_NOTIFICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATION))
#define BOXES_IS_NOTIFICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATION))
#define BOXES_NOTIFICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATION, BoxesNotificationClass))

typedef struct _BoxesNotification BoxesNotification;
typedef struct _BoxesNotificationClass BoxesNotificationClass;
typedef struct _BoxesInstallerMediaPrivate BoxesInstallerMediaPrivate;
typedef struct _BoxesWizardPrepareMediaData BoxesWizardPrepareMediaData;

#define BOXES_TYPE_REMOTE_MACHINE (boxes_remote_machine_get_type ())
#define BOXES_REMOTE_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_REMOTE_MACHINE, BoxesRemoteMachine))
#define BOXES_REMOTE_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_REMOTE_MACHINE, BoxesRemoteMachineClass))
#define BOXES_IS_REMOTE_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_REMOTE_MACHINE))
#define BOXES_IS_REMOTE_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_REMOTE_MACHINE))
#define BOXES_REMOTE_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_REMOTE_MACHINE, BoxesRemoteMachineClass))

typedef struct _BoxesRemoteMachine BoxesRemoteMachine;
typedef struct _BoxesRemoteMachineClass BoxesRemoteMachineClass;
#define _boxes_pair_unref0(var) ((var == NULL) ? NULL : (var = (boxes_pair_unref (var), NULL)))
#define __g_list_free__boxes_pair_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__boxes_pair_unref0_ (var), NULL)))
typedef struct _Block102Data Block102Data;
typedef struct _BoxesAppPrivate BoxesAppPrivate;

#define BOXES_TYPE_COLLECTION (boxes_collection_get_type ())
#define BOXES_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION, BoxesCollection))
#define BOXES_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION, BoxesCollectionClass))
#define BOXES_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION))
#define BOXES_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION))
#define BOXES_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION, BoxesCollectionClass))

typedef struct _BoxesCollection BoxesCollection;
typedef struct _BoxesCollectionClass BoxesCollectionClass;
#define __vala_GVirStorageVolInfo_free0(var) ((var == NULL) ? NULL : (var = (_vala_GVirStorageVolInfo_free (var), NULL)))
typedef struct _BoxesWizardDoReviewCancellableData BoxesWizardDoReviewCancellableData;
typedef struct _BoxesWizardDownloadMediaData BoxesWizardDownloadMediaData;
typedef struct _BoxesWizardWindowPrivate BoxesWizardWindowPrivate;

#define BOXES_TYPE_WIZARD_TOOLBAR (boxes_wizard_toolbar_get_type ())
#define BOXES_WIZARD_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD_TOOLBAR, BoxesWizardToolbar))
#define BOXES_WIZARD_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD_TOOLBAR, BoxesWizardToolbarClass))
#define BOXES_IS_WIZARD_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD_TOOLBAR))
#define BOXES_IS_WIZARD_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD_TOOLBAR))
#define BOXES_WIZARD_TOOLBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD_TOOLBAR, BoxesWizardToolbarClass))

typedef struct _BoxesWizardToolbar BoxesWizardToolbar;
typedef struct _BoxesWizardToolbarClass BoxesWizardToolbarClass;
typedef struct _BoxesWizardToolbarPrivate BoxesWizardToolbarPrivate;
typedef struct _BoxesWizardSummaryPrivate BoxesWizardSummaryPrivate;
enum  {
	BOXES_WIZARD_SUMMARY_DUMMY_PROPERTY,
	BOXES_WIZARD_SUMMARY_LAST_PROPERTY
};
static GParamSpec* boxes_wizard_summary_properties[BOXES_WIZARD_SUMMARY_LAST_PROPERTY];
typedef struct _Block103Data Block103Data;
#define _g_list_free0(var) ((var == NULL) ? NULL : (var = (g_list_free (var), NULL)))
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

typedef enum  {
	BOXES_WIZARD_PAGE_SOURCE,
	BOXES_WIZARD_PAGE_PREPARATION,
	BOXES_WIZARD_PAGE_SETUP,
	BOXES_WIZARD_PAGE_REVIEW,
	BOXES_WIZARD_PAGE_LAST
} BoxesWizardPage;

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesWizard {
	GtkStack parent_instance;
	BoxesWizardPrivate * priv;
};

struct _BoxesWizardClass {
	GtkStackClass parent_class;
};

struct _BoxesWizardPrivate {
	BoxesUIState _previous_ui_state;
	BoxesUIState _ui_state;
	GtkButton* cancel_button;
	GtkButton* back_button;
	GtkButton* next_button;
	GtkButton* continue_button;
	GtkButton* create_button;
	BoxesCollectionSource* source;
	BoxesWizardSource* wizard_source;
	BoxesWizardSummary* summary;
	GtkProgressBar* prep_progress;
	GtkLabel* prep_media_label;
	GtkLabel* prep_status_label;
	GtkBox* setup_box;
	GtkLabel* review_label;
	GtkInfoBar* nokvm_infobar;
	GtkImage* installer_image;
	BoxesAppWindow* window;
	BoxesWizardWindow* wizard_window;
	BoxesMediaManager* media_manager;
	BoxesVMCreator* vm_creator;
	BoxesMachine* _machine;
	GCancellable* prepare_cancellable;
	GCancellable* review_cancellable;
	gboolean skip_review_for_live;
	BoxesWizardPage _page;
};

struct _Block99Data {
	int _ref_count_;
	BoxesWizard* self;
	BoxesActivityProgress* progress;
};

typedef enum  {
	BOXES_SOURCE_PAGE_MAIN,
	BOXES_SOURCE_PAGE_URL,
	BOXES_SOURCE_PAGE_LAST
} BoxesSourcePage;

struct _BoxesWizardReviewData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	BoxesWizard* self;
	gboolean result;
	GCancellable* _tmp0_;
	GCancellable* _tmp1_;
	gboolean _result_;
	gboolean _tmp2_;
};

struct _Block100Data {
	int _ref_count_;
	BoxesWizard* self;
	gpointer _async_data_;
};

struct _BoxesWizardSource {
	GtkStack parent_instance;
	BoxesWizardSourcePrivate * priv;
	gboolean libvirt_sys_import;
	GtkEntry* url_entry;
	BoxesMediaManager* media_manager;
};

struct _BoxesWizardSourceClass {
	GtkStackClass parent_class;
};

struct _BoxesWizardCreateData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	BoxesWizard* self;
	gboolean result;
	Block100Data* _data100_;
	BoxesVMCreator* _tmp0_;
	BoxesLibvirtMachine* _tmp1_;
	BoxesLibvirtMachine* _tmp2_;
	GCancellable* _tmp3_;
	gulong wait;
	gulong _tmp4_;
	gulong _tmp5_;
	BoxesLibvirtMachine* _tmp6_;
	BoxesLibvirtMachine* _tmp7_;
	GtkButton* _tmp8_;
	BoxesVMCreator* _tmp9_;
	BoxesLibvirtMachine* _tmp10_;
	BoxesLibvirtMachine* _tmp11_;
	GError* _error_;
	GError* _tmp12_;
	const gchar* _tmp13_;
	BoxesVMCreator* _tmp14_;
	BoxesInstallerMedia* _tmp15_;
	BoxesInstallerMedia* _tmp16_;
	BoxesWizardSource* _tmp17_;
	BoxesWizardSource* _tmp18_;
	BoxesCollectionSource* _tmp19_;
	BoxesCollectionSource* _tmp20_;
	BoxesApp* _tmp21_;
	BoxesCollectionSource* _tmp22_;
	BoxesWizardSource* _tmp23_;
	gboolean _tmp24_;
	BoxesWizardSource* _tmp25_;
	BoxesLibvirtSystemImporter* _tmp26_;
	BoxesLibvirtSystemImporter* _tmp27_;
	GError * _inner_error_;
};

struct _Block101Data {
	int _ref_count_;
	BoxesWizard* self;
	BoxesActivityProgress* progress;
};

struct _BoxesInstallerMedia {
	GObject parent_instance;
	BoxesInstallerMediaPrivate * priv;
	OsinfoOs* os;
	OsinfoResources* resources;
	OsinfoMedia* os_media;
	gchar* label;
	gchar* device_file;
	gchar* mount_point;
	gboolean from_image;
};

struct _BoxesInstallerMediaClass {
	GObjectClass parent_class;
	void (*set_direct_boot_params) (BoxesInstallerMedia* self, GVirConfigDomainOs* os);
	void (*prepare) (BoxesInstallerMedia* self, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	gboolean (*prepare_finish) (BoxesInstallerMedia* self, GAsyncResult* _res_);
	void (*prepare_for_installation) (BoxesInstallerMedia* self, const gchar* vm_name, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*prepare_for_installation_finish) (BoxesInstallerMedia* self, GAsyncResult* _res_);
	void (*prepare_to_continue_installation) (BoxesInstallerMedia* self, const gchar* vm_name);
	void (*clean_up) (BoxesInstallerMedia* self);
	void (*clean_up_preparation_cache) (BoxesInstallerMedia* self);
	void (*setup_domain_config) (BoxesInstallerMedia* self, GVirConfigDomain* domain);
	void (*setup_post_install_domain_config) (BoxesInstallerMedia* self, GVirConfigDomain* domain);
	void (*populate_setup_box) (BoxesInstallerMedia* self, GtkBox* setup_box);
	GList* (*get_vm_properties) (BoxesInstallerMedia* self);
	BoxesVMCreator* (*get_vm_creator) (BoxesInstallerMedia* self);
	OsinfoDeviceList* (*get_supported_devices) (BoxesInstallerMedia* self);
	guint64 (*get_installed_size) (BoxesInstallerMedia* self);
	gboolean (*get_need_user_input_for_vm_creation) (BoxesInstallerMedia* self);
	gboolean (*get_ready_to_create) (BoxesInstallerMedia* self);
	gboolean (*get_live) (BoxesInstallerMedia* self);
	gchar* (*get_architecture) (BoxesInstallerMedia* self);
};

struct _BoxesWizardPrepareMediaData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	BoxesWizard* self;
	BoxesInstallerMedia* install_media;
	BoxesActivityProgress* progress;
	BoxesInstallerMedia* _tmp0_;
	OsinfoOs* _tmp1_;
	GtkLabel* _tmp2_;
	BoxesInstallerMedia* _tmp3_;
	OsinfoOs* _tmp4_;
	const gchar* _tmp5_;
	const gchar* _tmp6_;
	GtkImage* _tmp7_;
	BoxesInstallerMedia* _tmp8_;
	OsinfoOs* _tmp9_;
	BoxesActivityProgress* prepare_media_progress;
	BoxesWizardSource* _tmp10_;
	gboolean _tmp11_;
	gboolean _tmp12_;
	BoxesActivityProgress* _tmp13_;
	BoxesActivityProgress* _tmp14_;
	BoxesActivityProgress* _tmp15_;
	BoxesActivityProgress* _tmp16_;
	BoxesActivityProgress* _tmp17_;
	GtkLabel* _tmp18_;
	BoxesInstallerMedia* _tmp19_;
	BoxesActivityProgress* _tmp20_;
	GCancellable* _tmp21_;
	gboolean _tmp22_;
	BoxesInstallerMedia* _tmp23_;
	BoxesVMCreator* _tmp24_;
	GtkProgressBar* _tmp25_;
};

struct _Block102Data {
	int _ref_count_;
	BoxesWizard* self;
	GVirConfigDomain* config;
};

struct _BoxesApp {
	GtkApplication parent_instance;
	BoxesAppPrivate * priv;
	BoxesCollection* collection;
	BoxesAsyncLauncher* async_launcher;
};

struct _BoxesAppClass {
	GtkApplicationClass parent_class;
};

typedef void (*BoxesWizardSummaryCustomizeFunc) (void* user_data);
struct _BoxesWizardDoReviewCancellableData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	BoxesWizard* self;
	gboolean result;
	GCancellable* _tmp0_;
	GtkInfoBar* _tmp1_;
	BoxesWizardSummary* _tmp2_;
	BoxesCollectionSource* _tmp3_;
	BoxesRemoteMachine* _tmp4_;
	BoxesCollectionSource* _tmp5_;
	BoxesRemoteMachine* _tmp6_;
	GError* _error_;
	GError* _tmp7_;
	const gchar* _tmp8_;
	gboolean _tmp9_;
	BoxesVMCreator* _tmp10_;
	BoxesLibvirtMachine* _tmp11_;
	BoxesLibvirtMachine* _tmp12_;
	BoxesLibvirtMachine* _tmp13_;
	BoxesVMCreator* _tmp14_;
	GCancellable* _tmp15_;
	BoxesLibvirtMachine* _tmp16_;
	GError* cancel_error;
	GError* _vala1__error_;
	BoxesAppWindow* _tmp17_;
	BoxesNotificationbar* _tmp18_;
	BoxesNotificationbar* _tmp19_;
	BoxesNotification* _tmp20_;
	BoxesNotification* _tmp21_;
	GError* _tmp22_;
	const gchar* _tmp23_;
	BoxesLibvirtMachine* _tmp24_;
	BoxesLibvirtMachine* _tmp25_;
	GCancellable* _tmp26_;
	gboolean _tmp27_;
	GtkLabel* _tmp28_;
	BoxesCollectionSource* _tmp29_;
	xmlURI* uri;
	BoxesCollectionSource* _tmp30_;
	gchar* _tmp31_;
	gchar* _tmp32_;
	gchar* _tmp33_;
	xmlURI* _tmp34_;
	xmlURI* _tmp35_;
	BoxesWizardSummary* _tmp36_;
	BoxesCollectionSource* _tmp37_;
	gchar* _tmp38_;
	gchar* _tmp39_;
	gchar* _tmp40_;
	gboolean _tmp41_;
	xmlURI* _tmp42_;
	xmlURI* _tmp43_;
	const gchar* _tmp44_;
	BoxesWizardSummary* _tmp45_;
	xmlURI* _tmp46_;
	const gchar* _tmp47_;
	gchar* _tmp48_;
	gchar* _tmp49_;
	BoxesWizardSummary* _tmp50_;
	BoxesCollectionSource* _tmp51_;
	gchar* _tmp52_;
	gchar* _tmp53_;
	gchar* _tmp54_;
	gchar* _tmp55_;
	gchar* _tmp56_;
	xmlURI* _tmp57_;
	const gchar* _tmp58_;
	const gchar* _tmp59_;
	GQuark _tmp61_;
	gint port;
	gint tls_port;
	BoxesCollectionSource* _tmp62_;
	gchar* _tmp63_;
	gchar* _tmp64_;
	gchar* _tmp65_;
	gint* _tmp66_;
	gint* _tmp67_;
	gint* _tmp68_;
	gint* _tmp69_;
	gint _tmp70_;
	BoxesWizardSummary* _tmp71_;
	gint _tmp72_;
	gchar* _tmp73_;
	gchar* _tmp74_;
	gint _tmp75_;
	BoxesWizardSummary* _tmp76_;
	gint _tmp77_;
	gchar* _tmp78_;
	gchar* _tmp79_;
	GError* _vala2__error_;
	GError* _tmp80_;
	const gchar* _tmp81_;
	xmlURI* _tmp82_;
	gint _tmp83_;
	BoxesWizardSummary* _tmp84_;
	xmlURI* _tmp85_;
	gint _tmp86_;
	gchar* _tmp87_;
	gchar* _tmp88_;
	BoxesApp* _tmp89_;
	BoxesCollectionSource* _tmp90_;
	gchar* _tmp91_;
	gchar* _tmp92_;
	gchar* _tmp93_;
	gboolean _tmp94_;
	gboolean _tmp95_;
	GtkLabel* _tmp96_;
	BoxesLibvirtMachine* _tmp97_;
	BoxesLibvirtMachine* _tmp98_;
	BoxesVMCreator* _tmp99_;
	BoxesInstallerMedia* _tmp100_;
	BoxesInstallerMedia* _tmp101_;
	GList* _tmp102_;
	GList* property_collection;
	GList* property_it;
	BoxesPair* _tmp103_;
	BoxesPair* property;
	BoxesWizardSummary* _tmp104_;
	BoxesPair* _tmp105_;
	gconstpointer _tmp106_;
	BoxesPair* _tmp107_;
	gconstpointer _tmp108_;
	Block102Data* _data102_;
	gpointer _tmp109_;
	GVirConfigDomain* _tmp110_;
	BoxesApp* _tmp111_;
	BoxesAsyncLauncher* _tmp112_;
	gchar* memory;
	GVirConfigDomain* _tmp113_;
	guint64 _tmp114_;
	guint64 _tmp115_;
	gchar* _tmp116_;
	BoxesWizardSummary* _tmp117_;
	const gchar* _tmp118_;
	GError* _vala3__error_;
	BoxesLibvirtMachine* _tmp119_;
	BoxesLibvirtMachine* _tmp120_;
	const gchar* _tmp121_;
	const gchar* _tmp122_;
	GError* _tmp123_;
	const gchar* _tmp124_;
	gboolean _tmp125_;
	BoxesLibvirtMachine* _tmp126_;
	BoxesLibvirtMachine* _tmp127_;
	gboolean _tmp128_;
	gboolean _tmp129_;
	BoxesLibvirtMachine* _tmp130_;
	BoxesLibvirtMachine* _tmp131_;
	GVirStorageVol* _tmp132_;
	GVirStorageVol* _tmp133_;
	GVirStorageVolInfo* volume_info;
	BoxesLibvirtMachine* _tmp134_;
	BoxesLibvirtMachine* _tmp135_;
	GVirStorageVol* _tmp136_;
	GVirStorageVol* _tmp137_;
	GVirStorageVolInfo* _tmp138_;
	gchar* capacity;
	GVirStorageVolInfo* _tmp139_;
	guint64 _tmp140_;
	gchar* _tmp141_;
	BoxesWizardSummary* _tmp142_;
	const gchar* _tmp143_;
	gchar* _tmp144_;
	gchar* _tmp145_;
	GError* _vala4__error_;
	BoxesLibvirtMachine* _tmp146_;
	BoxesLibvirtMachine* _tmp147_;
	GVirStorageVol* _tmp148_;
	GVirStorageVol* _tmp149_;
	const gchar* _tmp150_;
	GError* _tmp151_;
	const gchar* _tmp152_;
	GtkInfoBar* _tmp153_;
	BoxesLibvirtMachine* _tmp154_;
	BoxesLibvirtMachine* _tmp155_;
	GVirConfigDomain* _tmp156_;
	GVirConfigDomain* _tmp157_;
	GVirConfigDomainVirtType _tmp158_;
	BoxesWizardSource* _tmp159_;
	gboolean _tmp160_;
	GtkLabel* _tmp161_;
	BoxesWizardSource* _tmp162_;
	BoxesLibvirtSystemImporter* _tmp163_;
	BoxesLibvirtSystemImporter* _tmp164_;
	gchar* _tmp165_;
	gchar* _tmp166_;
	gchar* _tmp167_;
	BoxesLibvirtMachine* _tmp168_;
	BoxesLibvirtMachine* _tmp169_;
	BoxesWizardSummary* _tmp170_;
	GError * _inner_error_;
};

struct _BoxesWizardDownloadMediaData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	BoxesWizard* self;
	gchar* uri;
	BoxesActivityProgress* progress;
	BoxesActivityProgress* download_progress;
	BoxesActivityProgress* _tmp0_;
	BoxesActivityProgress* _tmp1_;
	GtkLabel* _tmp2_;
	gchar* cache_path;
	const gchar* _tmp3_;
	BoxesActivityProgress* _tmp4_;
	GCancellable* _tmp5_;
	gchar* _tmp6_;
	const gchar* _tmp7_;
	BoxesActivityProgress* _tmp8_;
	GError* e;
	const gchar* _tmp9_;
	GError* _vala1_e;
	const gchar* _tmp10_;
	GError* _tmp11_;
	const gchar* _tmp12_;
	BoxesAppWindow* _tmp13_;
	BoxesNotificationbar* _tmp14_;
	BoxesNotificationbar* _tmp15_;
	BoxesNotification* _tmp16_;
	BoxesNotification* _tmp17_;
	GError * _inner_error_;
};

struct _BoxesWizardWindow {
	GtkWindow parent_instance;
	BoxesWizardWindowPrivate * priv;
	GtkStack* view;
	BoxesWizard* wizard;
	GtkGrid* customization_grid;
	GtkFileChooserWidget* file_chooser;
	BoxesWizardToolbar* topbar;
	BoxesNotificationbar* notificationbar;
};

struct _BoxesWizardWindowClass {
	GtkWindowClass parent_class;
};

struct _BoxesWizardToolbar {
	GtkStack parent_instance;
	BoxesWizardToolbarPrivate * priv;
	GtkButton* cancel_btn;
	GtkButton* back_btn;
	GtkButton* continue_btn;
	GtkButton* create_btn;
};

struct _BoxesWizardToolbarClass {
	GtkStackClass parent_class;
};

struct _BoxesWizardSummary {
	GtkGrid parent_instance;
	BoxesWizardSummaryPrivate * priv;
};

struct _BoxesWizardSummaryClass {
	GtkGridClass parent_class;
};

struct _BoxesWizardSummaryPrivate {
	gint current_row;
};

struct _Block103Data {
	int _ref_count_;
	BoxesWizardSummary* self;
	BoxesWizardSummaryCustomizeFunc customize_func;
	gpointer customize_func_target;
};


static gpointer boxes_wizard_parent_class = NULL;
extern BoxesApp* boxes_app_app;
static BoxesUIIface * boxes_wizard_boxes_ui_parent_iface = NULL;
static gpointer boxes_wizard_summary_parent_class = NULL;

GType boxes_wizard_page_get_type (void) G_GNUC_CONST;
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_wizard_source_get_type (void) G_GNUC_CONST;
GType boxes_wizard_summary_get_type (void) G_GNUC_CONST;
GType boxes_app_window_get_type (void) G_GNUC_CONST;
GType boxes_wizard_window_get_type (void) G_GNUC_CONST;
GType boxes_media_manager_get_type (void) G_GNUC_CONST;
gpointer boxes_vm_creator_ref (gpointer instance);
void boxes_vm_creator_unref (gpointer instance);
GParamSpec* boxes_param_spec_vm_creator (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void boxes_value_set_vm_creator (GValue* value, gpointer v_object);
void boxes_value_take_vm_creator (GValue* value, gpointer v_object);
gpointer boxes_value_get_vm_creator (const GValue* value);
GType boxes_vm_creator_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_machine_get_type (void) G_GNUC_CONST;
#define BOXES_WIZARD_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_WIZARD, BoxesWizardPrivate))
#define BOXES_WIZARD_DOWNLOAD_PROGRESS_SCALE 0.95
#define BOXES_WIZARD_PREPARE_PROGRESS_SCALE 0.05
static BoxesActivityProgress* boxes_wizard_create_preparation_progress (BoxesWizard* self);
static Block99Data* block99_data_ref (Block99Data* _data99_);
static void block99_data_unref (void * _userdata_);
static void __lambda141_ (Block99Data* _data99_);
static void ___lambda141__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void boxes_wizard_wizard_source_update_next (BoxesWizard* self);
BoxesWizardPage boxes_wizard_get_page (BoxesWizard* self);
GType boxes_source_page_get_type (void) G_GNUC_CONST;
BoxesSourcePage boxes_wizard_source_get_page (BoxesWizardSource* self);
GtkWidget* boxes_wizard_source_get_selected (BoxesWizardSource* self);
const gchar* boxes_wizard_source_get_uri (BoxesWizardSource* self);
static void boxes_wizard_prepare_for_location (BoxesWizard* self, const gchar* location, gboolean probing, BoxesActivityProgress* progress, GError** error);
void boxes_wizard_cleanup (BoxesWizard* self);
static void boxes_wizard_destroy_machine (BoxesWizard* self);
void boxes_wizard_source_cleanup (BoxesWizardSource* self);
static void boxes_wizard_review_data_free (gpointer _data);
void boxes_wizard_review (BoxesWizard* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
gboolean boxes_wizard_review_finish (BoxesWizard* self, GAsyncResult* _res_);
static gboolean boxes_wizard_review_co (BoxesWizardReviewData* _data_);
static void boxes_wizard_do_review_cancellable (BoxesWizard* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean boxes_wizard_do_review_cancellable_finish (BoxesWizard* self, GAsyncResult* _res_);
static void boxes_wizard_review_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_wizard_create_data_free (gpointer _data);
static void boxes_wizard_create (BoxesWizard* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean boxes_wizard_create_finish (BoxesWizard* self, GAsyncResult* _res_);
static gboolean boxes_wizard_create_co (BoxesWizardCreateData* _data_);
static Block100Data* block100_data_ref (Block100Data* _data100_);
static void block100_data_unref (void * _userdata_);
GType boxes_libvirt_machine_get_type (void) G_GNUC_CONST;
static BoxesLibvirtMachine* boxes_wizard_get_libvirt_machine (BoxesWizard* self);
static void ____lambda145_ (Block100Data* _data100_);
static void _____lambda145__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
void boxes_vm_creator_launch_vm (BoxesVMCreator* self, BoxesLibvirtMachine* machine, gint64 access_last_time, GError** error);
GType boxes_installer_media_get_type (void) G_GNUC_CONST;
BoxesInstallerMedia* boxes_vm_creator_get_install_media (BoxesVMCreator* self);
void boxes_installer_media_clean_up_preparation_cache (BoxesInstallerMedia* self);
void boxes_wizard_source_set_uri (BoxesWizardSource* self, const gchar* value);
GType boxes_app_get_type (void) G_GNUC_CONST;
void boxes_app_add_collection_source (BoxesApp* self, BoxesCollectionSource* source, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_app_add_collection_source_finish (BoxesApp* self, GAsyncResult* _res_, GError** error);
GType boxes_libvirt_system_importer_get_type (void) G_GNUC_CONST;
BoxesLibvirtSystemImporter* boxes_wizard_source_get_libvirt_sys_importer (BoxesWizardSource* self);
void boxes_libvirt_system_importer_import (BoxesLibvirtSystemImporter* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_libvirt_system_importer_import_finish (BoxesLibvirtSystemImporter* self, GAsyncResult* _res_);
void boxes_wizard_set_machine (BoxesWizard* self, BoxesMachine* value);
static void boxes_wizard_prepare_for_installer (BoxesWizard* self, const gchar* path, BoxesActivityProgress* progress, GError** error);
static const gchar** _vala_array_dup6 (const gchar** self, int length);
static void _vala_array_add21 (const gchar** * array, int* length, int* size, const gchar* value);
static void boxes_wizard_prepare_for_uri (BoxesWizard* self, const gchar* uri_as_text, GError** error);
gboolean boxes_wizard_source_get_download_required (BoxesWizardSource* self);
void spice_validate_uri (const gchar* uri_as_text, gint** port, gint** tls_port, GError** error);
gboolean boxes_app_has_broker_for_source_type (BoxesApp* self, const gchar* type);
static Block101Data* block101_data_ref (Block101Data* _data101_);
static void block101_data_unref (void * _userdata_);
void boxes_media_manager_create_installer_media_for_path (BoxesMediaManager* self, const gchar* path, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
BoxesInstallerMedia* boxes_media_manager_create_installer_media_for_path_finish (BoxesMediaManager* self, GAsyncResult* _res_, GError** error);
static void __lambda142_ (Block101Data* _data101_, GObject* obj, GAsyncResult* res);
static void boxes_wizard_on_installer_media_instantiated (BoxesWizard* self, GAsyncResult* _result_, BoxesActivityProgress* progress);
static void ___lambda142__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void boxes_wizard_prepare_media (BoxesWizard* self, BoxesInstallerMedia* install_media, BoxesActivityProgress* progress, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_wizard_prepare_media_finish (BoxesWizard* self, GAsyncResult* _res_);
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
BoxesNotificationbar* boxes_app_window_get_notificationbar (BoxesAppWindow* self);
GType boxes_notification_get_type (void) G_GNUC_CONST;
BoxesNotification* boxes_notificationbar_display_error (BoxesNotificationbar* self, const gchar* message, gint timeout);
#define BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT 6
void boxes_wizard_set_page (BoxesWizard* self, BoxesWizardPage value);
static void boxes_wizard_prepare_media_data_free (gpointer _data);
static gboolean boxes_wizard_prepare_media_co (BoxesWizardPrepareMediaData* _data_);
void boxes_downloader_fetch_os_logo (GtkImage* image, OsinfoOs* os, gint size, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_downloader_fetch_os_logo_finish (GAsyncResult* _res_);
void boxes_installer_media_prepare (BoxesInstallerMedia* self, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
gboolean boxes_installer_media_prepare_finish (BoxesInstallerMedia* self, GAsyncResult* _res_);
static void boxes_wizard_prepare_media_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
BoxesVMCreator* boxes_installer_media_get_vm_creator (BoxesInstallerMedia* self);
static gboolean boxes_wizard_prepare (BoxesWizard* self, BoxesActivityProgress* progress);
static void boxes_wizard_download_media (BoxesWizard* self, const gchar* uri, BoxesActivityProgress* progress, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_wizard_download_media_finish (BoxesWizard* self, GAsyncResult* _res_);
BoxesInstallerMedia* boxes_wizard_source_get_install_media (BoxesWizardSource* self);
static gboolean boxes_wizard_setup (BoxesWizard* self);
void boxes_installer_media_populate_setup_box (BoxesInstallerMedia* self, GtkBox* setup_box);
static void __lambda143_ (BoxesWizard* self);
gboolean boxes_installer_media_get_ready_to_create (BoxesInstallerMedia* self);
static void ___lambda143__boxes_installer_media_user_wants_to_create (BoxesInstallerMedia* _sender, gpointer self);
static void boxes_wizard_do_review_cancellable_data_free (gpointer _data);
static gboolean boxes_wizard_do_review_cancellable_co (BoxesWizardDoReviewCancellableData* _data_);
void boxes_wizard_summary_clear (BoxesWizardSummary* self);
GType boxes_remote_machine_get_type (void) G_GNUC_CONST;
BoxesRemoteMachine* boxes_remote_machine_new (BoxesCollectionSource* source, GError** error);
BoxesRemoteMachine* boxes_remote_machine_construct (GType object_type, BoxesCollectionSource* source, GError** error);
void boxes_vm_creator_create_vm (BoxesVMCreator* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
BoxesLibvirtMachine* boxes_vm_creator_create_vm_finish (BoxesVMCreator* self, GAsyncResult* _res_, GError** error);
static void boxes_wizard_do_review_cancellable_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
void boxes_wizard_summary_add_property (BoxesWizardSummary* self, const gchar* name, const gchar* value);
GList* boxes_installer_media_get_vm_properties (BoxesInstallerMedia* self);
static void _boxes_pair_unref0_ (gpointer var);
static inline void _g_list_free__boxes_pair_unref0_ (GList* self);
static Block102Data* block102_data_ref (Block102Data* _data102_);
static void block102_data_unref (void * _userdata_);
GType boxes_collection_get_type (void) G_GNUC_CONST;
static void _____lambda102_ (Block102Data* _data102_, GError** error);
GVirDomain* boxes_libvirt_machine_get_domain (BoxesLibvirtMachine* self);
static void ______lambda102__boxes_async_launcher_run_in_thread_func (gpointer self, GError** error);
const gchar* boxes_collection_item_get_name (BoxesCollectionItem* self);
gboolean boxes_libvirt_machine_get_importing (BoxesLibvirtMachine* self);
GVirStorageVol* boxes_libvirt_machine_get_storage_volume (BoxesLibvirtMachine* self);
static void _vala_GVirStorageVolInfo_free (GVirStorageVolInfo* self);
GVirConfigDomain* boxes_libvirt_machine_get_domain_config (BoxesLibvirtMachine* self);
gchar* boxes_libvirt_system_importer_get_wizard_review_label (BoxesLibvirtSystemImporter* self);
void boxes_wizard_summary_append_customize_button (BoxesWizardSummary* self, BoxesWizardSummaryCustomizeFunc customize_func, void* customize_func_target);
static void ___lambda103_ (BoxesWizard* self);
void boxes_wizard_window_show_customization_page (BoxesWizardWindow* self, BoxesLibvirtMachine* machine);
static void ____lambda103__boxes_wizard_summary_customize_func (gpointer self);
static gboolean boxes_wizard_skip_page (BoxesWizard* self, BoxesWizardPage page);
gboolean boxes_installer_media_get_need_user_input_for_vm_creation (BoxesInstallerMedia* self);
gboolean boxes_installer_media_get_live (BoxesInstallerMedia* self);
static void boxes_wizard_download_media_data_free (gpointer _data);
static gboolean boxes_wizard_download_media_co (BoxesWizardDownloadMediaData* _data_);
void boxes_downloader_fetch_media (const gchar* uri, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
gchar* boxes_downloader_fetch_media_finish (GAsyncResult* _res_, GError** error);
static void boxes_wizard_download_media_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_wizard_prepare_downloaded_media (BoxesWizard* self, const gchar* cache_path, BoxesActivityProgress* progress);
void boxes_wizard_setup_ui (BoxesWizard* self, BoxesAppWindow* window, BoxesWizardWindow* wizard_window);
GType boxes_wizard_toolbar_get_type (void) G_GNUC_CONST;
void boxes_wizard_cancel (BoxesWizard* self);
static void _boxes_wizard_cancel_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void __lambda147_ (BoxesWizard* self);
static void ___lambda147__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void __lambda148_ (BoxesWizard* self);
static void ___lambda148__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void __lambda149_ (BoxesWizard* self);
static void ___lambda149__gtk_button_clicked (GtkButton* _sender, gpointer self);
void boxes_wizard_source_setup_ui (BoxesWizardSource* self, BoxesAppWindow* window);
void boxes_wizard_open_with_uri (BoxesWizard* self, const gchar* uri, gboolean skip_review_for_live);
void boxes_ui_set_state (BoxesUI* self, BoxesUIState new_state);
void boxes_wizard_source_set_page (BoxesWizardSource* self, BoxesSourcePage value);
static void boxes_wizard_ui_state_changed (BoxesWizard* self);
BoxesUIState boxes_ui_get_ui_state (BoxesUI* self);
BoxesMachine* boxes_wizard_get_machine (BoxesWizard* self);
void boxes_app_delete_machine (BoxesApp* self, BoxesMachine* machine, gboolean by_user);
BoxesWizard* boxes_wizard_new (void);
BoxesWizard* boxes_wizard_construct (GType object_type);
static void _boxes_wizard_page_____lambda144_ (BoxesWizard* self, GObject* obj, GAsyncResult* _result_);
static void __boxes_wizard_page_____lambda144__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void _boxes_wizard_page_____lambda146_ (BoxesWizard* self, GObject* obj, GAsyncResult* _result_);
static void __boxes_wizard_page_____lambda146__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
void boxes_wizard_toolbar_set_title_for_page (BoxesWizardToolbar* self, BoxesWizardPage page);
static GObject * boxes_wizard_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
BoxesMediaManager* boxes_media_manager_get_instance (void);
static void _boxes_wizard_wizard_source_update_next_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void _boxes_wizard_wizard_source_update_next_gtk_editable_changed (GtkEditable* _sender, gpointer self);
static void _boxes_wizard_ui_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void _boxes_wizard___lambda150_ (BoxesWizard* self);
static void __boxes_wizard___lambda150__boxes_wizard_source_activated (BoxesWizardSource* _sender, gpointer self);
static void boxes_wizard_finalize (GObject * obj);
BoxesUIState boxes_ui_get_previous_ui_state (BoxesUI* self);
static void _vala_boxes_wizard_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
void boxes_ui_set_previous_ui_state (BoxesUI* self, BoxesUIState value);
void boxes_ui_set_ui_state (BoxesUI* self, BoxesUIState value);
static void _vala_boxes_wizard_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
#define BOXES_WIZARD_SUMMARY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_WIZARD_SUMMARY, BoxesWizardSummaryPrivate))
static Block103Data* block103_data_ref (Block103Data* _data103_);
static void block103_data_unref (void * _userdata_);
static void __lambda72_ (Block103Data* _data103_);
static void ___lambda72__gtk_button_clicked (GtkButton* _sender, gpointer self);
BoxesWizardSummary* boxes_wizard_summary_new (void);
BoxesWizardSummary* boxes_wizard_summary_construct (GType object_type);
static GObject * boxes_wizard_summary_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void boxes_wizard_summary_finalize (GObject * obj);

static const gchar* BOXES_WIZARD_page_names[4] = {"source", "preparation", "setup", "review"};
extern const gchar* BOXES_INSTALLED_MEDIA_supported_extensions[16];

GType boxes_wizard_page_get_type (void) {
	static volatile gsize boxes_wizard_page_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_wizard_page_type_id__volatile)) {
		static const GEnumValue values[] = {{BOXES_WIZARD_PAGE_SOURCE, "BOXES_WIZARD_PAGE_SOURCE", "source"}, {BOXES_WIZARD_PAGE_PREPARATION, "BOXES_WIZARD_PAGE_PREPARATION", "preparation"}, {BOXES_WIZARD_PAGE_SETUP, "BOXES_WIZARD_PAGE_SETUP", "setup"}, {BOXES_WIZARD_PAGE_REVIEW, "BOXES_WIZARD_PAGE_REVIEW", "review"}, {BOXES_WIZARD_PAGE_LAST, "BOXES_WIZARD_PAGE_LAST", "last"}, {0, NULL, NULL}};
		GType boxes_wizard_page_type_id;
		boxes_wizard_page_type_id = g_enum_register_static ("BoxesWizardPage", values);
		g_once_init_leave (&boxes_wizard_page_type_id__volatile, boxes_wizard_page_type_id);
	}
	return boxes_wizard_page_type_id__volatile;
}


static Block99Data* block99_data_ref (Block99Data* _data99_) {
#line 144 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_atomic_int_inc (&_data99_->_ref_count_);
#line 144 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	return _data99_;
#line 999 "wizard.c"
}


static void block99_data_unref (void * _userdata_) {
	Block99Data* _data99_;
	_data99_ = (Block99Data*) _userdata_;
#line 144 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (g_atomic_int_dec_and_test (&_data99_->_ref_count_)) {
#line 1008 "wizard.c"
		BoxesWizard* self;
#line 144 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		self = _data99_->self;
#line 144 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (_data99_->progress);
#line 144 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (self);
#line 144 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		g_slice_free (Block99Data, _data99_);
#line 1018 "wizard.c"
	}
}


static void __lambda141_ (Block99Data* _data99_) {
	BoxesWizard* self;
	gdouble _tmp0_;
	gdouble _tmp1_;
	GtkProgressBar* _tmp2_;
	gdouble _tmp3_;
	gdouble _tmp4_;
#line 146 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	self = _data99_->self;
#line 147 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp0_ = boxes_activity_progress_get_progress (_data99_->progress);
#line 147 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp1_ = _tmp0_;
#line 147 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp2_ = self->priv->prep_progress;
#line 147 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp3_ = gtk_progress_bar_get_fraction (_tmp2_);
#line 147 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp4_ = _tmp3_;
#line 147 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if ((_tmp1_ - _tmp4_) >= 0.01) {
#line 1044 "wizard.c"
		GtkProgressBar* _tmp5_;
		gdouble _tmp6_;
		gdouble _tmp7_;
#line 148 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp5_ = self->priv->prep_progress;
#line 148 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp6_ = boxes_activity_progress_get_progress (_data99_->progress);
#line 148 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp7_ = _tmp6_;
#line 148 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		gtk_progress_bar_set_fraction (_tmp5_, _tmp7_);
#line 1056 "wizard.c"
	}
}


static void ___lambda141__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 146 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	__lambda141_ (self);
#line 1064 "wizard.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 152 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	return self ? g_object_ref (self) : NULL;
#line 1071 "wizard.c"
}


static BoxesActivityProgress* boxes_wizard_create_preparation_progress (BoxesWizard* self) {
	BoxesActivityProgress* result = NULL;
	Block99Data* _data99_;
	BoxesActivityProgress* _tmp0_;
	GtkProgressBar* _tmp1_;
	BoxesActivityProgress* _tmp2_;
#line 144 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 144 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data99_ = g_slice_new0 (Block99Data);
#line 144 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data99_->_ref_count_ = 1;
#line 144 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data99_->self = g_object_ref (self);
#line 145 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp0_ = boxes_activity_progress_new ();
#line 145 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data99_->progress = _tmp0_;
#line 146 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_signal_connect_data ((GObject*) _data99_->progress, "notify::progress", (GCallback) ___lambda141__g_object_notify, block99_data_ref (_data99_), (GClosureNotify) block99_data_unref, 0);
#line 150 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp1_ = self->priv->prep_progress;
#line 150 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	boxes_activity_progress_set_progress (_data99_->progress, (gdouble) 0);
#line 150 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	gtk_progress_bar_set_fraction (_tmp1_, (gdouble) 0);
#line 152 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp2_ = _g_object_ref0 (_data99_->progress);
#line 152 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	result = _tmp2_;
#line 152 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	block99_data_unref (_data99_);
#line 152 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data99_ = NULL;
#line 152 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	return result;
#line 1111 "wizard.c"
}


static void boxes_wizard_wizard_source_update_next (BoxesWizard* self) {
	BoxesWizardPage _tmp0_;
	BoxesWizardPage _tmp1_;
	GtkButton* _tmp2_;
	BoxesWizardSource* _tmp3_;
	BoxesSourcePage _tmp4_;
	BoxesSourcePage _tmp5_;
	GError * _inner_error_ = NULL;
#line 155 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 156 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp0_ = boxes_wizard_get_page (self);
#line 156 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp1_ = _tmp0_;
#line 156 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (_tmp1_ != BOXES_WIZARD_PAGE_SOURCE) {
#line 157 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		return;
#line 1133 "wizard.c"
	}
#line 159 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp2_ = self->priv->next_button;
#line 159 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp2_, FALSE);
#line 161 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp3_ = self->priv->wizard_source;
#line 161 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp4_ = boxes_wizard_source_get_page (_tmp3_);
#line 161 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp5_ = _tmp4_;
#line 161 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	switch (_tmp5_) {
#line 161 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		case BOXES_SOURCE_PAGE_MAIN:
#line 1149 "wizard.c"
		{
			GtkButton* _tmp6_;
			BoxesWizardSource* _tmp7_;
			GtkWidget* _tmp8_;
			GtkWidget* _tmp9_;
#line 163 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp6_ = self->priv->next_button;
#line 163 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp7_ = self->priv->wizard_source;
#line 163 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp8_ = boxes_wizard_source_get_selected (_tmp7_);
#line 163 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp9_ = _tmp8_;
#line 163 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			gtk_widget_set_sensitive ((GtkWidget*) _tmp6_, _tmp9_ != NULL);
#line 164 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_g_object_unref0 (self->priv->source);
#line 164 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			self->priv->source = NULL;
#line 165 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			break;
#line 1171 "wizard.c"
		}
#line 161 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		case BOXES_SOURCE_PAGE_URL:
#line 1175 "wizard.c"
		{
			GtkButton* _tmp10_;
			BoxesWizardSource* _tmp11_;
			const gchar* _tmp12_;
			const gchar* _tmp13_;
			gint _tmp14_;
			gint _tmp15_;
#line 168 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp10_ = self->priv->next_button;
#line 168 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			gtk_widget_set_sensitive ((GtkWidget*) _tmp10_, FALSE);
#line 169 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp11_ = self->priv->wizard_source;
#line 169 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp12_ = boxes_wizard_source_get_uri (_tmp11_);
#line 169 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp13_ = _tmp12_;
#line 169 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp14_ = strlen (_tmp13_);
#line 169 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp15_ = _tmp14_;
#line 169 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			if (_tmp15_ == 0) {
#line 170 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				return;
#line 1201 "wizard.c"
			}
			{
				BoxesWizardSource* _tmp16_;
				const gchar* _tmp17_;
				const gchar* _tmp18_;
				GtkButton* _tmp19_;
#line 173 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_tmp16_ = self->priv->wizard_source;
#line 173 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_tmp17_ = boxes_wizard_source_get_uri (_tmp16_);
#line 173 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_tmp18_ = _tmp17_;
#line 173 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				boxes_wizard_prepare_for_location (self, _tmp18_, TRUE, NULL, &_inner_error_);
#line 173 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1218 "wizard.c"
					goto __catch134_g_error;
				}
#line 175 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_tmp19_ = self->priv->next_button;
#line 175 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				gtk_widget_set_sensitive ((GtkWidget*) _tmp19_, TRUE);
#line 1225 "wizard.c"
			}
			goto __finally134;
			__catch134_g_error:
			{
				GError* _error_ = NULL;
#line 172 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_error_ = _inner_error_;
#line 172 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_inner_error_ = NULL;
#line 172 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_g_error_free0 (_error_);
#line 1237 "wizard.c"
			}
			__finally134:
#line 172 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 172 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 172 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				g_clear_error (&_inner_error_);
#line 172 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				return;
#line 1248 "wizard.c"
			}
#line 180 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			break;
#line 1252 "wizard.c"
		}
		default:
		{
#line 183 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			g_warn_if_reached ();
#line 184 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			break;
#line 1260 "wizard.c"
		}
	}
}


void boxes_wizard_cleanup (BoxesWizard* self) {
	GCancellable* _tmp0_;
	BoxesWizardSource* _tmp1_;
#line 203 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 204 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->prepare_cancellable;
#line 204 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_cancellable_cancel (_tmp0_);
#line 206 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	boxes_wizard_destroy_machine (self);
#line 207 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_boxes_vm_creator_unref0 (self->priv->vm_creator);
#line 207 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	self->priv->vm_creator = NULL;
#line 208 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->source);
#line 208 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	self->priv->source = NULL;
#line 209 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp1_ = self->priv->wizard_source;
#line 209 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	boxes_wizard_source_cleanup (_tmp1_);
#line 1289 "wizard.c"
}


static void boxes_wizard_review_data_free (gpointer _data) {
	BoxesWizardReviewData* _data_;
	_data_ = _data;
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data_->self);
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_slice_free (BoxesWizardReviewData, _data_);
#line 1300 "wizard.c"
}


void boxes_wizard_review (BoxesWizard* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesWizardReviewData* _data_;
	BoxesWizard* _tmp0_;
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_ = g_slice_new0 (BoxesWizardReviewData);
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_task_set_task_data (_data_->_async_result, _data_, boxes_wizard_review_data_free);
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->self = _tmp0_;
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	boxes_wizard_review_co (_data_);
#line 1319 "wizard.c"
}


gboolean boxes_wizard_review_finish (BoxesWizard* self, GAsyncResult* _res_) {
	gboolean result;
	BoxesWizardReviewData* _data_;
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	result = _data_->result;
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	return result;
#line 1332 "wizard.c"
}


static void boxes_wizard_review_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesWizardReviewData* _data_;
#line 217 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_ = _user_data_;
#line 217 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->_source_object_ = source_object;
#line 217 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->_res_ = _res_;
#line 217 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	boxes_wizard_review_co (_data_);
#line 1346 "wizard.c"
}


static gboolean boxes_wizard_review_co (BoxesWizardReviewData* _data_) {
#line 212 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	switch (_data_->_state_) {
#line 212 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		case 0:
#line 1355 "wizard.c"
		goto _state_0;
#line 212 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		case 1:
#line 1359 "wizard.c"
		goto _state_1;
		default:
#line 212 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		g_assert_not_reached ();
#line 1364 "wizard.c"
	}
	_state_0:
#line 214 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->_tmp0_ = _data_->self->priv->review_cancellable;
#line 214 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_return_val_if_fail (_data_->_tmp0_ == NULL, FALSE);
#line 216 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->_tmp1_ = g_cancellable_new ();
#line 216 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data_->self->priv->review_cancellable);
#line 216 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->self->priv->review_cancellable = _data_->_tmp1_;
#line 217 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->_state_ = 1;
#line 217 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	boxes_wizard_do_review_cancellable (_data_->self, boxes_wizard_review_ready, _data_);
#line 217 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	return FALSE;
#line 1383 "wizard.c"
	_state_1:
#line 217 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->_tmp2_ = boxes_wizard_do_review_cancellable_finish (_data_->self, _data_->_res_);
#line 217 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->_result_ = _data_->_tmp2_;
#line 218 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data_->self->priv->review_cancellable);
#line 218 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->self->priv->review_cancellable = NULL;
#line 220 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->self->priv->skip_review_for_live = FALSE;
#line 221 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->result = _data_->_result_;
#line 221 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 221 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (_data_->_state_ != 0) {
#line 221 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		while (g_task_get_completed (_data_->_async_result) != TRUE) {
#line 221 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 1405 "wizard.c"
		}
	}
#line 221 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_object_unref (_data_->_async_result);
#line 221 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	return FALSE;
#line 1412 "wizard.c"
}


static void boxes_wizard_create_data_free (gpointer _data) {
	BoxesWizardCreateData* _data_;
	_data_ = _data;
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data_->self);
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_slice_free (BoxesWizardCreateData, _data_);
#line 1423 "wizard.c"
}


static void boxes_wizard_create (BoxesWizard* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesWizardCreateData* _data_;
	BoxesWizard* _tmp0_;
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_ = g_slice_new0 (BoxesWizardCreateData);
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_task_set_task_data (_data_->_async_result, _data_, boxes_wizard_create_data_free);
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->self = _tmp0_;
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	boxes_wizard_create_co (_data_);
#line 1442 "wizard.c"
}


static gboolean boxes_wizard_create_finish (BoxesWizard* self, GAsyncResult* _res_) {
	gboolean result;
	BoxesWizardCreateData* _data_;
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	result = _data_->result;
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	return result;
#line 1455 "wizard.c"
}


static Block100Data* block100_data_ref (Block100Data* _data100_) {
#line 224 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_atomic_int_inc (&_data100_->_ref_count_);
#line 224 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	return _data100_;
#line 1464 "wizard.c"
}


static void block100_data_unref (void * _userdata_) {
	Block100Data* _data100_;
	_data100_ = (Block100Data*) _userdata_;
#line 224 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (g_atomic_int_dec_and_test (&_data100_->_ref_count_)) {
#line 1473 "wizard.c"
		BoxesWizard* self;
#line 224 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		self = _data100_->self;
#line 224 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (self);
#line 224 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		g_slice_free (Block100Data, _data100_);
#line 1481 "wizard.c"
	}
}


static void ____lambda145_ (Block100Data* _data100_) {
	BoxesWizard* self;
#line 229 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	self = _data100_->self;
#line 230 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	boxes_wizard_create_co (_data100_->_async_data_);
#line 1492 "wizard.c"
}


static void _____lambda145__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 229 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	____lambda145_ (self);
#line 1499 "wizard.c"
}


static gboolean boxes_wizard_create_co (BoxesWizardCreateData* _data_) {
#line 224 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	switch (_data_->_state_) {
#line 224 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		case 0:
#line 1508 "wizard.c"
		goto _state_0;
#line 224 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		case 1:
#line 1512 "wizard.c"
		goto _state_1;
		default:
#line 224 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		g_assert_not_reached ();
#line 1517 "wizard.c"
	}
	_state_0:
#line 224 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->_data100_ = g_slice_new0 (Block100Data);
#line 224 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->_data100_->_ref_count_ = 1;
#line 224 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->_data100_->self = g_object_ref (_data_->self);
#line 224 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->_data100_->_async_data_ = _data_;
#line 225 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->_tmp0_ = _data_->self->priv->vm_creator;
#line 225 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (_data_->_tmp0_ != NULL) {
#line 226 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp1_ = boxes_wizard_get_libvirt_machine (_data_->self);
#line 226 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp2_ = _data_->_tmp1_;
#line 226 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		if (_data_->_tmp2_ == NULL) {
#line 227 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp3_ = _data_->self->priv->review_cancellable;
#line 227 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			g_return_val_if_fail (_data_->_tmp3_ != NULL, FALSE);
#line 229 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp4_ = g_signal_connect_data ((GObject*) _data_->self, "notify::machine", (GCallback) _____lambda145__g_object_notify, block100_data_ref (_data_->_data100_), (GClosureNotify) block100_data_unref, 0);
#line 229 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->wait = _data_->_tmp4_;
#line 232 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_state_ = 1;
#line 232 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			return FALSE;
#line 1550 "wizard.c"
			_state_1:
			;
#line 233 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp5_ = _data_->wait;
#line 233 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			g_signal_handler_disconnect ((GObject*) _data_->self, _data_->_tmp5_);
#line 234 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp6_ = boxes_wizard_get_libvirt_machine (_data_->self);
#line 234 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp7_ = _data_->_tmp6_;
#line 234 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			if (_data_->_tmp7_ == NULL) {
#line 235 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->result = FALSE;
#line 235 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				block100_data_unref (_data_->_data100_);
#line 235 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_data100_ = NULL;
#line 235 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 235 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				if (_data_->_state_ != 0) {
#line 235 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					while (g_task_get_completed (_data_->_async_result) != TRUE) {
#line 235 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 1577 "wizard.c"
					}
				}
#line 235 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				g_object_unref (_data_->_async_result);
#line 235 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				return FALSE;
#line 1584 "wizard.c"
			}
		}
#line 237 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp8_ = _data_->self->priv->next_button;
#line 237 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		gtk_widget_set_sensitive ((GtkWidget*) _data_->_tmp8_, FALSE);
#line 1591 "wizard.c"
		{
#line 239 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp9_ = _data_->self->priv->vm_creator;
#line 239 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp10_ = boxes_wizard_get_libvirt_machine (_data_->self);
#line 239 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp11_ = _data_->_tmp10_;
#line 239 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			boxes_vm_creator_launch_vm (_data_->_tmp9_, _data_->_tmp11_, (gint64) -1, &_data_->_inner_error_);
#line 239 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 1603 "wizard.c"
				goto __catch135_g_error;
			}
		}
		goto __finally135;
		__catch135_g_error:
		{
#line 238 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_error_ = _data_->_inner_error_;
#line 238 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_inner_error_ = NULL;
#line 241 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp12_ = _data_->_error_;
#line 241 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp13_ = _data_->_tmp12_->message;
#line 241 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			g_warning ("wizard.vala:241: %s", _data_->_tmp13_);
#line 243 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->result = FALSE;
#line 243 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_g_error_free0 (_data_->_error_);
#line 243 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			block100_data_unref (_data_->_data100_);
#line 243 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_data100_ = NULL;
#line 243 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 243 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			if (_data_->_state_ != 0) {
#line 243 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				while (g_task_get_completed (_data_->_async_result) != TRUE) {
#line 243 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 1636 "wizard.c"
				}
			}
#line 243 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			g_object_unref (_data_->_async_result);
#line 243 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			return FALSE;
#line 1643 "wizard.c"
		}
		__finally135:
#line 238 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 238 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			block100_data_unref (_data_->_data100_);
#line 238 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_data100_ = NULL;
#line 238 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 238 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			g_clear_error (&_data_->_inner_error_);
#line 238 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			g_object_unref (_data_->_async_result);
#line 238 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			return FALSE;
#line 1660 "wizard.c"
		}
#line 246 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp14_ = _data_->self->priv->vm_creator;
#line 246 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp15_ = boxes_vm_creator_get_install_media (_data_->_tmp14_);
#line 246 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp16_ = _data_->_tmp15_;
#line 246 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		boxes_installer_media_clean_up_preparation_cache (_data_->_tmp16_);
#line 247 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_boxes_vm_creator_unref0 (_data_->self->priv->vm_creator);
#line 247 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->self->priv->vm_creator = NULL;
#line 248 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp17_ = _data_->self->priv->wizard_source;
#line 248 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		boxes_wizard_source_set_uri (_data_->_tmp17_, "");
#line 249 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp18_ = _data_->self->priv->wizard_source;
#line 249 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp18_->libvirt_sys_import = FALSE;
#line 1682 "wizard.c"
	} else {
#line 250 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp19_ = _data_->self->priv->source;
#line 250 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		if (_data_->_tmp19_ != NULL) {
#line 251 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp20_ = _data_->self->priv->source;
#line 251 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			boxes_iconfig_save ((BoxesIConfig*) _data_->_tmp20_);
#line 252 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp21_ = boxes_app_app;
#line 252 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp22_ = _data_->self->priv->source;
#line 252 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			boxes_app_add_collection_source (_data_->_tmp21_, _data_->_tmp22_, NULL, NULL);
#line 1698 "wizard.c"
		} else {
#line 253 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp23_ = _data_->self->priv->wizard_source;
#line 253 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp24_ = _data_->_tmp23_->libvirt_sys_import;
#line 253 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			if (_data_->_tmp24_) {
#line 254 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_tmp25_ = _data_->self->priv->wizard_source;
#line 254 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_tmp26_ = boxes_wizard_source_get_libvirt_sys_importer (_data_->_tmp25_);
#line 254 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_tmp27_ = _data_->_tmp26_;
#line 254 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				boxes_libvirt_system_importer_import (_data_->_tmp27_, NULL, NULL);
#line 1714 "wizard.c"
			} else {
#line 256 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				g_return_val_if_reached (FALSE);
#line 1718 "wizard.c"
			}
		}
	}
#line 259 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	boxes_wizard_set_machine (_data_->self, NULL);
#line 260 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->result = TRUE;
#line 260 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	block100_data_unref (_data_->_data100_);
#line 260 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->_data100_ = NULL;
#line 260 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 260 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (_data_->_state_ != 0) {
#line 260 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		while (g_task_get_completed (_data_->_async_result) != TRUE) {
#line 260 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 1738 "wizard.c"
		}
	}
#line 260 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_object_unref (_data_->_async_result);
#line 260 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	return FALSE;
#line 1745 "wizard.c"
}


static gboolean string_contains (const gchar* self, const gchar* needle) {
	gboolean result = FALSE;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 1411 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, FALSE);
#line 1411 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
	g_return_val_if_fail (needle != NULL, FALSE);
#line 1412 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
	_tmp0_ = needle;
#line 1412 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
	_tmp1_ = strstr ((gchar*) self, (gchar*) _tmp0_);
#line 1412 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
	result = _tmp1_ != NULL;
#line 1412 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
	return result;
#line 1765 "wizard.c"
}


static const gchar** _vala_array_dup6 (const gchar** self, int length) {
#line 279 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	return g_memdup (self, length * sizeof (const gchar*));
#line 1772 "wizard.c"
}


static void _vala_array_add21 (const gchar** * array, int* length, int* size, const gchar* value) {
#line 280 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if ((*length) == (*size)) {
#line 280 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 280 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		*array = g_renew (const gchar*, *array, (*size) + 1);
#line 1783 "wizard.c"
	}
#line 280 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	(*array)[(*length)++] = value;
#line 280 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	(*array)[*length] = NULL;
#line 1789 "wizard.c"
}


static void boxes_wizard_prepare_for_location (BoxesWizard* self, const gchar* location, gboolean probing, BoxesActivityProgress* progress, GError** error) {
	gboolean _tmp0_;
	BoxesActivityProgress* _tmp1_;
	const gchar* _tmp2_;
	GFile* _tmp4_ = NULL;
	const gchar* _tmp5_;
	gboolean _tmp6_;
	GFile* file = NULL;
	GFile* _tmp11_;
	gchar* path = NULL;
	GFile* _tmp12_;
	gchar* _tmp13_;
	gboolean _tmp14_ = FALSE;
	const gchar* _tmp15_;
	GFile* _tmp44_;
	gchar* _tmp45_;
	gchar* _tmp46_;
	GError * _inner_error_ = NULL;
#line 263 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 263 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_return_if_fail (location != NULL);
#line 263 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp0_ = probing;
#line 263 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp1_ = progress;
#line 263 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_vala_return_if_fail (_tmp0_ || (_tmp1_ != NULL), "probing || progress != null");
#line 268 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp2_ = location;
#line 268 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (g_strcmp0 (_tmp2_, "") == 0) {
#line 1825 "wizard.c"
		GError* _tmp3_;
#line 269 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp3_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, _ ("Empty location"));
#line 269 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_inner_error_ = _tmp3_;
#line 269 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		g_propagate_error (error, _inner_error_);
#line 269 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		return;
#line 1835 "wizard.c"
	}
#line 271 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp5_ = location;
#line 271 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp6_ = string_contains (_tmp5_, "://");
#line 271 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (_tmp6_) {
#line 1843 "wizard.c"
		const gchar* _tmp7_;
		GFile* _tmp8_;
#line 271 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp7_ = location;
#line 271 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp8_ = g_file_new_for_uri (_tmp7_);
#line 271 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (_tmp4_);
#line 271 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp4_ = _tmp8_;
#line 1854 "wizard.c"
	} else {
		const gchar* _tmp9_;
		GFile* _tmp10_;
#line 271 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp9_ = location;
#line 271 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp10_ = g_file_new_for_path (_tmp9_);
#line 271 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (_tmp4_);
#line 271 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp4_ = _tmp10_;
#line 1866 "wizard.c"
	}
#line 271 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp11_ = _g_object_ref0 (_tmp4_);
#line 271 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	file = _tmp11_;
#line 272 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp12_ = file;
#line 272 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp13_ = g_file_get_path (_tmp12_);
#line 272 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	path = _tmp13_;
#line 274 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp15_ = path;
#line 274 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (_tmp15_ != NULL) {
#line 1882 "wizard.c"
		gboolean _tmp16_ = FALSE;
		GFile* _tmp17_;
		gboolean _tmp18_;
#line 274 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp17_ = file;
#line 274 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp18_ = g_file_has_uri_scheme (_tmp17_, "file");
#line 274 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		if (_tmp18_) {
#line 274 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp16_ = TRUE;
#line 1894 "wizard.c"
		} else {
			GFile* _tmp19_;
			gboolean _tmp20_;
#line 274 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp19_ = file;
#line 274 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp20_ = g_file_has_uri_scheme (_tmp19_, "smb");
#line 274 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp16_ = _tmp20_;
#line 1904 "wizard.c"
		}
#line 274 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp14_ = _tmp16_;
#line 1908 "wizard.c"
	} else {
#line 274 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp14_ = FALSE;
#line 1912 "wizard.c"
	}
#line 274 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (_tmp14_) {
#line 1916 "wizard.c"
		gboolean _tmp21_;
#line 275 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp21_ = probing;
#line 275 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		if (!_tmp21_) {
#line 1922 "wizard.c"
			const gchar* _tmp22_;
			BoxesActivityProgress* _tmp23_;
#line 276 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp22_ = path;
#line 276 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp23_ = progress;
#line 276 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			boxes_wizard_prepare_for_installer (self, _tmp22_, _tmp23_, &_inner_error_);
#line 276 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 276 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				g_propagate_error (error, _inner_error_);
#line 276 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_g_free0 (path);
#line 276 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_g_object_unref0 (file);
#line 276 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_g_object_unref0 (_tmp4_);
#line 276 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				return;
#line 1943 "wizard.c"
			}
		} else {
			gboolean supported = FALSE;
			const gchar** extensions = NULL;
			const gchar** _tmp24_;
			gint _tmp24__length1;
			gint extensions_length1;
			gint _extensions_size_;
			const gchar** _tmp25_;
			gint _tmp25__length1;
			const gchar** _tmp26_;
			gint _tmp26__length1;
			gboolean _tmp34_;
			GFileInfo* info = NULL;
			GFile* _tmp36_;
			GFileInfo* _tmp37_;
			GFileType file_type = 0;
			GFileInfo* _tmp38_;
			GFileType _tmp39_;
			gboolean _tmp40_ = FALSE;
			GFileType _tmp41_;
#line 278 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			supported = FALSE;
#line 279 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp24_ = (BOXES_INSTALLED_MEDIA_supported_extensions != NULL) ? _vala_array_dup6 (BOXES_INSTALLED_MEDIA_supported_extensions, G_N_ELEMENTS (BOXES_INSTALLED_MEDIA_supported_extensions)) : ((gpointer) BOXES_INSTALLED_MEDIA_supported_extensions);
#line 279 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp24__length1 = G_N_ELEMENTS (BOXES_INSTALLED_MEDIA_supported_extensions);
#line 279 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			extensions = _tmp24_;
#line 279 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			extensions_length1 = _tmp24__length1;
#line 279 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_extensions_size_ = extensions_length1;
#line 280 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp25_ = extensions;
#line 280 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp25__length1 = extensions_length1;
#line 280 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_vala_array_add21 (&extensions, &extensions_length1, &_extensions_size_, "iso");
#line 281 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp26_ = extensions;
#line 281 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp26__length1 = extensions_length1;
#line 1987 "wizard.c"
			{
				const gchar** extension_collection = NULL;
				gint extension_collection_length1 = 0;
				gint _extension_collection_size_ = 0;
				gint extension_it = 0;
#line 281 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				extension_collection = _tmp26_;
#line 281 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				extension_collection_length1 = _tmp26__length1;
#line 281 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				for (extension_it = 0; extension_it < _tmp26__length1; extension_it = extension_it + 1) {
#line 1999 "wizard.c"
					const gchar* extension = NULL;
#line 281 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					extension = extension_collection[extension_it];
#line 2003 "wizard.c"
					{
						gchar* path_casefolded = NULL;
						const gchar* _tmp27_;
						gchar* _tmp28_;
						gchar* extension_casefolded = NULL;
						const gchar* _tmp29_;
						gchar* _tmp30_;
						const gchar* _tmp31_;
						const gchar* _tmp32_;
						gboolean _tmp33_;
#line 282 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						_tmp27_ = path;
#line 282 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						_tmp28_ = g_utf8_casefold (_tmp27_, (gssize) -1);
#line 282 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						path_casefolded = _tmp28_;
#line 283 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						_tmp29_ = extension;
#line 283 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						_tmp30_ = g_utf8_casefold (_tmp29_, (gssize) -1);
#line 283 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						extension_casefolded = _tmp30_;
#line 285 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						_tmp31_ = path_casefolded;
#line 285 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						_tmp32_ = extension_casefolded;
#line 285 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						_tmp33_ = g_str_has_suffix (_tmp31_, _tmp32_);
#line 285 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						if (_tmp33_) {
#line 286 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
							supported = TRUE;
#line 288 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
							_g_free0 (extension_casefolded);
#line 288 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
							_g_free0 (path_casefolded);
#line 288 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
							break;
#line 2042 "wizard.c"
						}
#line 281 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						_g_free0 (extension_casefolded);
#line 281 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						_g_free0 (path_casefolded);
#line 2048 "wizard.c"
					}
				}
			}
#line 291 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp34_ = supported;
#line 291 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			if (!_tmp34_) {
#line 2056 "wizard.c"
				GError* _tmp35_;
#line 292 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_tmp35_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, _ ("Unsupported file"));
#line 292 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_inner_error_ = _tmp35_;
#line 292 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				g_propagate_error (error, _inner_error_);
#line 292 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				extensions = (g_free (extensions), NULL);
#line 292 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_g_free0 (path);
#line 292 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_g_object_unref0 (file);
#line 292 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_g_object_unref0 (_tmp4_);
#line 292 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				return;
#line 2074 "wizard.c"
			}
#line 294 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp36_ = file;
#line 294 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp37_ = g_file_query_info (_tmp36_, G_FILE_ATTRIBUTE_STANDARD_TYPE, G_FILE_QUERY_INFO_NONE, NULL, &_inner_error_);
#line 294 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			info = _tmp37_;
#line 294 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 294 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				g_propagate_error (error, _inner_error_);
#line 294 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				extensions = (g_free (extensions), NULL);
#line 294 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_g_free0 (path);
#line 294 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_g_object_unref0 (file);
#line 294 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_g_object_unref0 (_tmp4_);
#line 294 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				return;
#line 2096 "wizard.c"
			}
#line 295 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp38_ = info;
#line 295 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp39_ = g_file_info_get_file_type (_tmp38_);
#line 295 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			file_type = _tmp39_;
#line 297 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp41_ = file_type;
#line 297 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			if (_tmp41_ != G_FILE_TYPE_REGULAR) {
#line 2108 "wizard.c"
				GFileType _tmp42_;
#line 297 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_tmp42_ = file_type;
#line 297 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_tmp40_ = _tmp42_ != G_FILE_TYPE_SYMBOLIC_LINK;
#line 2114 "wizard.c"
			} else {
#line 297 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_tmp40_ = FALSE;
#line 2118 "wizard.c"
			}
#line 297 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			if (_tmp40_) {
#line 2122 "wizard.c"
				GError* _tmp43_;
#line 298 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_tmp43_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, _ ("Invalid file"));
#line 298 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_inner_error_ = _tmp43_;
#line 298 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				g_propagate_error (error, _inner_error_);
#line 298 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_g_object_unref0 (info);
#line 298 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				extensions = (g_free (extensions), NULL);
#line 298 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_g_free0 (path);
#line 298 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_g_object_unref0 (file);
#line 298 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_g_object_unref0 (_tmp4_);
#line 298 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				return;
#line 2142 "wizard.c"
			}
#line 275 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_g_object_unref0 (info);
#line 275 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			extensions = (g_free (extensions), NULL);
#line 2148 "wizard.c"
		}
#line 301 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_g_free0 (path);
#line 301 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (file);
#line 301 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (_tmp4_);
#line 301 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		return;
#line 2158 "wizard.c"
	}
#line 304 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp44_ = file;
#line 304 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp45_ = g_file_get_uri (_tmp44_);
#line 304 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp46_ = _tmp45_;
#line 304 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	boxes_wizard_prepare_for_uri (self, _tmp46_, &_inner_error_);
#line 304 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_free0 (_tmp46_);
#line 304 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 304 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		g_propagate_error (error, _inner_error_);
#line 304 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_g_free0 (path);
#line 304 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (file);
#line 304 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (_tmp4_);
#line 304 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		return;
#line 2182 "wizard.c"
	}
#line 263 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_free0 (path);
#line 263 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (file);
#line 263 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_tmp4_);
#line 2190 "wizard.c"
}


static void boxes_wizard_prepare_for_uri (BoxesWizard* self, const gchar* uri_as_text, GError** error) {
	xmlURI* uri = NULL;
	const gchar* _tmp0_;
	xmlURI* _tmp1_;
	gboolean _tmp2_ = FALSE;
	xmlURI* _tmp3_;
	BoxesWizardSource* _tmp7_;
	gboolean _tmp8_;
	gboolean _tmp9_;
	const gchar* _tmp20_ = NULL;
	xmlURI* _tmp21_;
	const gchar* _tmp22_;
	xmlURI* _tmp24_;
	const gchar* _tmp25_;
	const gchar* _tmp26_;
	BoxesCollectionSource* _tmp27_;
	xmlURI* _tmp28_;
	const gchar* _tmp29_;
	gboolean _tmp30_;
	GError * _inner_error_ = NULL;
#line 307 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 307 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_return_if_fail (uri_as_text != NULL);
#line 308 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp0_ = uri_as_text;
#line 308 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp1_ = xmlParseURI (_tmp0_);
#line 308 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	uri = _tmp1_;
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp3_ = uri;
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (_tmp3_ == NULL) {
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp2_ = TRUE;
#line 2230 "wizard.c"
	} else {
		xmlURI* _tmp4_;
		const gchar* _tmp5_;
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp4_ = uri;
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp5_ = _tmp4_->scheme;
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp2_ = _tmp5_ == NULL;
#line 2240 "wizard.c"
	}
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (_tmp2_) {
#line 2244 "wizard.c"
		GError* _tmp6_;
#line 310 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp6_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, _ ("Invalid URL"));
#line 310 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_inner_error_ = _tmp6_;
#line 310 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		if (_inner_error_->domain == BOXES_ERROR) {
#line 310 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			g_propagate_error (error, _inner_error_);
#line 310 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_xmlFreeURI0 (uri);
#line 310 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			return;
#line 2258 "wizard.c"
		} else {
#line 310 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_xmlFreeURI0 (uri);
#line 310 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 310 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			g_clear_error (&_inner_error_);
#line 310 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			return;
#line 2268 "wizard.c"
		}
	}
#line 312 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp7_ = self->priv->wizard_source;
#line 312 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp8_ = boxes_wizard_source_get_download_required (_tmp7_);
#line 312 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp9_ = _tmp8_;
#line 312 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (_tmp9_) {
#line 2279 "wizard.c"
		GFile* file = NULL;
		const gchar* _tmp10_;
		GFile* _tmp11_;
		gchar* basename = NULL;
		GFile* _tmp12_;
		gchar* _tmp13_;
		gboolean _tmp14_ = FALSE;
		gboolean _tmp15_ = FALSE;
		const gchar* _tmp16_;
#line 313 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp10_ = uri_as_text;
#line 313 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp11_ = g_file_new_for_uri (_tmp10_);
#line 313 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		file = _tmp11_;
#line 314 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp12_ = file;
#line 314 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp13_ = g_file_get_basename (_tmp12_);
#line 314 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		basename = _tmp13_;
#line 316 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp16_ = basename;
#line 316 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		if (_tmp16_ == NULL) {
#line 316 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp15_ = TRUE;
#line 2307 "wizard.c"
		} else {
			const gchar* _tmp17_;
#line 316 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp17_ = basename;
#line 316 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp15_ = g_strcmp0 (_tmp17_, "") == 0;
#line 2314 "wizard.c"
		}
#line 316 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		if (_tmp15_) {
#line 316 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp14_ = TRUE;
#line 2320 "wizard.c"
		} else {
			const gchar* _tmp18_;
#line 316 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp18_ = basename;
#line 316 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp14_ = g_strcmp0 (_tmp18_, "/") == 0;
#line 2327 "wizard.c"
		}
#line 316 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		if (_tmp14_) {
#line 2331 "wizard.c"
			GError* _tmp19_;
#line 317 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp19_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, _ ("Invalid URL"));
#line 317 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_inner_error_ = _tmp19_;
#line 317 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			if (_inner_error_->domain == BOXES_ERROR) {
#line 317 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				g_propagate_error (error, _inner_error_);
#line 317 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_g_free0 (basename);
#line 317 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_g_object_unref0 (file);
#line 317 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_xmlFreeURI0 (uri);
#line 317 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				return;
#line 2349 "wizard.c"
			} else {
#line 317 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_g_free0 (basename);
#line 317 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_g_object_unref0 (file);
#line 317 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_xmlFreeURI0 (uri);
#line 317 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 317 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				g_clear_error (&_inner_error_);
#line 317 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				return;
#line 2363 "wizard.c"
			}
		}
#line 319 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_g_free0 (basename);
#line 319 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (file);
#line 319 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_xmlFreeURI0 (uri);
#line 319 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		return;
#line 2374 "wizard.c"
	}
#line 322 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp21_ = uri;
#line 322 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp22_ = _tmp21_->server;
#line 322 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp20_ = _tmp22_;
#line 322 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (_tmp20_ == NULL) {
#line 2384 "wizard.c"
		const gchar* _tmp23_;
#line 322 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp23_ = uri_as_text;
#line 322 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp20_ = _tmp23_;
#line 2390 "wizard.c"
	}
#line 322 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp24_ = uri;
#line 322 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp25_ = _tmp24_->scheme;
#line 322 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp26_ = uri_as_text;
#line 322 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp27_ = boxes_collection_source_new (_tmp20_, _tmp25_, _tmp26_);
#line 322 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->source);
#line 322 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	self->priv->source = _tmp27_;
#line 324 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp28_ = uri;
#line 324 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp29_ = _tmp28_->scheme;
#line 324 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp30_ = g_str_has_prefix (_tmp29_, "spice");
#line 324 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (_tmp30_) {
#line 2412 "wizard.c"
		const gchar* _tmp31_;
		BoxesCollectionSource* _tmp32_;
#line 325 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp31_ = uri_as_text;
#line 325 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		spice_validate_uri (_tmp31_, NULL, NULL, &_inner_error_);
#line 325 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 325 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			if (_inner_error_->domain == BOXES_ERROR) {
#line 325 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				g_propagate_error (error, _inner_error_);
#line 325 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_xmlFreeURI0 (uri);
#line 325 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				return;
#line 2429 "wizard.c"
			} else {
#line 325 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_xmlFreeURI0 (uri);
#line 325 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 325 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				g_clear_error (&_inner_error_);
#line 325 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				return;
#line 2439 "wizard.c"
			}
		}
#line 326 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp32_ = self->priv->source;
#line 326 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		boxes_collection_source_set_source_type (_tmp32_, "spice");
#line 2446 "wizard.c"
	} else {
		xmlURI* _tmp33_;
		const gchar* _tmp34_;
#line 327 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp33_ = uri;
#line 327 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp34_ = _tmp33_->scheme;
#line 327 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		if (g_strcmp0 (_tmp34_, "vnc") == 0) {
#line 2456 "wizard.c"
		} else {
			xmlURI* _tmp35_;
			const gchar* _tmp36_;
			gboolean _tmp37_;
#line 329 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp35_ = uri;
#line 329 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp36_ = _tmp35_->scheme;
#line 329 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp37_ = g_str_has_prefix (_tmp36_, "qemu");
#line 329 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			if (_tmp37_) {
#line 2469 "wizard.c"
				BoxesCollectionSource* _tmp38_;
#line 331 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_tmp38_ = self->priv->source;
#line 331 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				boxes_collection_source_set_source_type (_tmp38_, "libvirt");
#line 2475 "wizard.c"
			} else {
				BoxesApp* _tmp39_;
				xmlURI* _tmp40_;
				const gchar* _tmp41_;
				gboolean _tmp42_;
#line 332 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_tmp39_ = boxes_app_app;
#line 332 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_tmp40_ = uri;
#line 332 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_tmp41_ = _tmp40_->scheme;
#line 332 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_tmp42_ = boxes_app_has_broker_for_source_type (_tmp39_, _tmp41_);
#line 332 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				if (_tmp42_) {
#line 2491 "wizard.c"
					BoxesCollectionSource* _tmp43_;
					xmlURI* _tmp44_;
					const gchar* _tmp45_;
#line 333 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					_tmp43_ = self->priv->source;
#line 333 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					_tmp44_ = uri;
#line 333 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					_tmp45_ = _tmp44_->scheme;
#line 333 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					boxes_collection_source_set_source_type (_tmp43_, _tmp45_);
#line 2503 "wizard.c"
				} else {
					xmlURI* _tmp46_;
					const gchar* _tmp47_;
					gchar* _tmp48_;
					gchar* _tmp49_;
					GError* _tmp50_;
					GError* _tmp51_;
#line 335 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					_tmp46_ = uri;
#line 335 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					_tmp47_ = _tmp46_->scheme;
#line 335 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					_tmp48_ = g_strdup_printf (_ ("Unsupported protocol “%s”"), _tmp47_);
#line 335 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					_tmp49_ = _tmp48_;
#line 335 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					_tmp50_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, _tmp49_);
#line 335 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					_tmp51_ = _tmp50_;
#line 335 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					_g_free0 (_tmp49_);
#line 335 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					_inner_error_ = _tmp51_;
#line 335 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					if (_inner_error_->domain == BOXES_ERROR) {
#line 335 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						g_propagate_error (error, _inner_error_);
#line 335 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						_xmlFreeURI0 (uri);
#line 335 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						return;
#line 2535 "wizard.c"
					} else {
#line 335 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						_xmlFreeURI0 (uri);
#line 335 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 335 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						g_clear_error (&_inner_error_);
#line 335 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						return;
#line 2545 "wizard.c"
					}
				}
			}
		}
	}
#line 307 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_xmlFreeURI0 (uri);
#line 2553 "wizard.c"
}


static Block101Data* block101_data_ref (Block101Data* _data101_) {
#line 338 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_atomic_int_inc (&_data101_->_ref_count_);
#line 338 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	return _data101_;
#line 2562 "wizard.c"
}


static void block101_data_unref (void * _userdata_) {
	Block101Data* _data101_;
	_data101_ = (Block101Data*) _userdata_;
#line 338 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (g_atomic_int_dec_and_test (&_data101_->_ref_count_)) {
#line 2571 "wizard.c"
		BoxesWizard* self;
#line 338 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		self = _data101_->self;
#line 338 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (_data101_->progress);
#line 338 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (self);
#line 338 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		g_slice_free (Block101Data, _data101_);
#line 2581 "wizard.c"
	}
}


static void __lambda142_ (Block101Data* _data101_, GObject* obj, GAsyncResult* res) {
	BoxesWizard* self;
	GAsyncResult* _tmp0_;
	BoxesActivityProgress* _tmp1_;
#line 345 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	self = _data101_->self;
#line 345 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_return_if_fail (res != NULL);
#line 346 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp0_ = res;
#line 346 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp1_ = _data101_->progress;
#line 346 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	boxes_wizard_on_installer_media_instantiated (self, _tmp0_, _tmp1_);
#line 2600 "wizard.c"
}


static void ___lambda142__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 345 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	__lambda142_ (self, source_object, res);
#line 345 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	block101_data_unref (self);
#line 2609 "wizard.c"
}


static void boxes_wizard_prepare_for_installer (BoxesWizard* self, const gchar* path, BoxesActivityProgress* progress, GError** error) {
	Block101Data* _data101_;
	BoxesActivityProgress* _tmp0_;
	BoxesActivityProgress* _tmp1_;
	GtkButton* _tmp2_;
	GtkLabel* _tmp3_;
	GtkLabel* _tmp4_;
	BoxesMediaManager* _tmp5_;
	const gchar* _tmp6_;
#line 338 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 338 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_return_if_fail (path != NULL);
#line 338 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_return_if_fail (progress != NULL);
#line 338 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data101_ = g_slice_new0 (Block101Data);
#line 338 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data101_->_ref_count_ = 1;
#line 338 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data101_->self = g_object_ref (self);
#line 338 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp0_ = progress;
#line 338 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 338 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data101_->progress);
#line 338 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data101_->progress = _tmp1_;
#line 339 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp2_ = self->priv->next_button;
#line 339 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp2_, FALSE);
#line 341 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp3_ = self->priv->prep_media_label;
#line 341 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	gtk_label_set_label (_tmp3_, _ ("Unknown installer media"));
#line 343 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp4_ = self->priv->prep_status_label;
#line 343 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	gtk_label_set_label (_tmp4_, _ ("Analyzing…"));
#line 345 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp5_ = self->priv->media_manager;
#line 345 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp6_ = path;
#line 345 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	boxes_media_manager_create_installer_media_for_path (_tmp5_, _tmp6_, NULL, ___lambda142__gasync_ready_callback, block101_data_ref (_data101_));
#line 338 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	block101_data_unref (_data101_);
#line 338 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data101_ = NULL;
#line 2664 "wizard.c"
}


static void boxes_wizard_on_installer_media_instantiated (BoxesWizard* self, GAsyncResult* _result_, BoxesActivityProgress* progress) {
	GError * _inner_error_ = NULL;
#line 350 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 350 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_return_if_fail (_result_ != NULL);
#line 350 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_return_if_fail (progress != NULL);
#line 2676 "wizard.c"
	{
		BoxesInstallerMedia* install_media = NULL;
		BoxesMediaManager* _tmp0_;
		GAsyncResult* _tmp1_;
		BoxesInstallerMedia* _tmp2_;
		BoxesInstallerMedia* _tmp3_;
		BoxesActivityProgress* _tmp4_;
#line 352 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp0_ = self->priv->media_manager;
#line 352 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp1_ = _result_;
#line 352 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp2_ = boxes_media_manager_create_installer_media_for_path_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 352 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		install_media = _tmp2_;
#line 352 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 352 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			if (g_error_matches (_inner_error_, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
#line 2696 "wizard.c"
				goto __catch136_g_io_error_cancelled;
			}
			goto __catch136_g_error;
		}
#line 353 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp3_ = install_media;
#line 353 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp4_ = progress;
#line 353 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		boxes_wizard_prepare_media (self, _tmp3_, _tmp4_, NULL, NULL);
#line 351 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (install_media);
#line 2709 "wizard.c"
	}
	goto __finally136;
	__catch136_g_io_error_cancelled:
	{
		GError* cancel_error = NULL;
#line 351 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		cancel_error = _inner_error_;
#line 351 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_inner_error_ = NULL;
#line 351 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_g_error_free0 (cancel_error);
#line 2721 "wizard.c"
	}
	goto __finally136;
	__catch136_g_error:
	{
		GError* _error_ = NULL;
		GError* _tmp5_;
		const gchar* _tmp6_;
		gchar* msg = NULL;
		gchar* _tmp7_;
		BoxesAppWindow* _tmp8_;
		BoxesNotificationbar* _tmp9_;
		BoxesNotificationbar* _tmp10_;
		const gchar* _tmp11_;
		BoxesNotification* _tmp12_;
		BoxesNotification* _tmp13_;
#line 351 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_error_ = _inner_error_;
#line 351 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_inner_error_ = NULL;
#line 356 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp5_ = _error_;
#line 356 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp6_ = _tmp5_->message;
#line 356 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		g_debug ("wizard.vala:356: Failed to analyze installer image: %s", _tmp6_);
#line 357 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp7_ = g_strdup (_ ("Failed to analyze installer media. Corrupted or incomplete media?"));
#line 357 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		msg = _tmp7_;
#line 358 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp8_ = self->priv->window;
#line 358 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp9_ = boxes_app_window_get_notificationbar (_tmp8_);
#line 358 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp10_ = _tmp9_;
#line 358 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp11_ = msg;
#line 358 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp12_ = boxes_notificationbar_display_error (_tmp10_, _tmp11_, BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 358 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp13_ = _tmp12_;
#line 358 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (_tmp13_);
#line 359 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		boxes_wizard_set_page (self, BOXES_WIZARD_PAGE_SOURCE);
#line 351 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_g_free0 (msg);
#line 351 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_g_error_free0 (_error_);
#line 2771 "wizard.c"
	}
	__finally136:
#line 351 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 351 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 351 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		g_clear_error (&_inner_error_);
#line 351 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		return;
#line 2782 "wizard.c"
	}
}


static void boxes_wizard_prepare_media_data_free (gpointer _data) {
	BoxesWizardPrepareMediaData* _data_;
	_data_ = _data;
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data_->install_media);
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data_->progress);
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data_->self);
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_slice_free (BoxesWizardPrepareMediaData, _data_);
#line 2798 "wizard.c"
}


static void boxes_wizard_prepare_media (BoxesWizard* self, BoxesInstallerMedia* install_media, BoxesActivityProgress* progress, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesWizardPrepareMediaData* _data_;
	BoxesWizard* _tmp0_;
	BoxesInstallerMedia* _tmp1_;
	BoxesInstallerMedia* _tmp2_;
	BoxesActivityProgress* _tmp3_;
	BoxesActivityProgress* _tmp4_;
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_ = g_slice_new0 (BoxesWizardPrepareMediaData);
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_task_set_task_data (_data_->_async_result, _data_, boxes_wizard_prepare_media_data_free);
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->self = _tmp0_;
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp1_ = install_media;
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data_->install_media);
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->install_media = _tmp2_;
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp3_ = progress;
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data_->progress);
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->progress = _tmp4_;
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	boxes_wizard_prepare_media_co (_data_);
#line 2837 "wizard.c"
}


static void boxes_wizard_prepare_media_finish (BoxesWizard* self, GAsyncResult* _res_) {
	BoxesWizardPrepareMediaData* _data_;
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
#line 2845 "wizard.c"
}


static void boxes_wizard_prepare_media_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesWizardPrepareMediaData* _data_;
#line 375 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_ = _user_data_;
#line 375 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->_source_object_ = source_object;
#line 375 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->_res_ = _res_;
#line 375 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	boxes_wizard_prepare_media_co (_data_);
#line 2859 "wizard.c"
}


static gboolean boxes_wizard_prepare_media_co (BoxesWizardPrepareMediaData* _data_) {
#line 363 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	switch (_data_->_state_) {
#line 363 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		case 0:
#line 2868 "wizard.c"
		goto _state_0;
#line 363 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		case 1:
#line 2872 "wizard.c"
		goto _state_1;
		default:
#line 363 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		g_assert_not_reached ();
#line 2877 "wizard.c"
	}
	_state_0:
#line 364 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->_tmp0_ = _data_->install_media;
#line 364 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->_tmp1_ = _data_->_tmp0_->os;
#line 364 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (_data_->_tmp1_ != NULL) {
#line 365 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp2_ = _data_->self->priv->prep_media_label;
#line 365 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp3_ = _data_->install_media;
#line 365 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp4_ = _data_->_tmp3_->os;
#line 365 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp5_ = osinfo_product_get_name ((OsinfoProduct*) _data_->_tmp4_);
#line 365 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp6_ = _data_->_tmp5_;
#line 365 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		gtk_label_set_label (_data_->_tmp2_, _data_->_tmp6_);
#line 366 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp7_ = _data_->self->priv->installer_image;
#line 366 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp8_ = _data_->install_media;
#line 366 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp9_ = _data_->_tmp8_->os;
#line 366 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		boxes_downloader_fetch_os_logo (_data_->_tmp7_, _data_->_tmp9_, 128, NULL, NULL);
#line 2906 "wizard.c"
	}
#line 370 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->_tmp10_ = _data_->self->priv->wizard_source;
#line 370 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->_tmp11_ = boxes_wizard_source_get_download_required (_data_->_tmp10_);
#line 370 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->_tmp12_ = _data_->_tmp11_;
#line 370 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (_data_->_tmp12_) {
#line 371 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp13_ = _data_->progress;
#line 371 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp14_ = boxes_activity_progress_add_child_activity (_data_->_tmp13_, BOXES_WIZARD_PREPARE_PROGRESS_SCALE);
#line 371 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (_data_->prepare_media_progress);
#line 371 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->prepare_media_progress = _data_->_tmp14_;
#line 2924 "wizard.c"
	} else {
#line 373 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp15_ = _data_->progress;
#line 373 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp16_ = _g_object_ref0 (_data_->_tmp15_);
#line 373 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (_data_->prepare_media_progress);
#line 373 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->prepare_media_progress = _data_->_tmp16_;
#line 2934 "wizard.c"
	}
#line 374 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->_tmp17_ = _data_->prepare_media_progress;
#line 374 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->_tmp18_ = _data_->self->priv->prep_status_label;
#line 374 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_object_bind_property_with_closures ((GObject*) _data_->_tmp17_, "info", (GObject*) _data_->_tmp18_, "label", G_BINDING_DEFAULT, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)));
#line 375 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->_tmp19_ = _data_->install_media;
#line 375 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->_tmp20_ = _data_->prepare_media_progress;
#line 375 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->_tmp21_ = _data_->self->priv->prepare_cancellable;
#line 375 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->_state_ = 1;
#line 375 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	boxes_installer_media_prepare (_data_->_tmp19_, _data_->_tmp20_, _data_->_tmp21_, boxes_wizard_prepare_media_ready, _data_);
#line 375 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	return FALSE;
#line 2954 "wizard.c"
	_state_1:
#line 375 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->_tmp22_ = boxes_installer_media_prepare_finish (_data_->_tmp19_, _data_->_res_);
#line 375 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (!_data_->_tmp22_) {
#line 376 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (_data_->prepare_media_progress);
#line 376 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 376 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		if (_data_->_state_ != 0) {
#line 376 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			while (g_task_get_completed (_data_->_async_result) != TRUE) {
#line 376 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 2970 "wizard.c"
			}
		}
#line 376 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		g_object_unref (_data_->_async_result);
#line 376 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		return FALSE;
#line 2977 "wizard.c"
	}
#line 378 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->_tmp23_ = _data_->install_media;
#line 378 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->_tmp24_ = boxes_installer_media_get_vm_creator (_data_->_tmp23_);
#line 378 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_boxes_vm_creator_unref0 (_data_->self->priv->vm_creator);
#line 378 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->self->priv->vm_creator = _data_->_tmp24_;
#line 379 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->_tmp25_ = _data_->self->priv->prep_progress;
#line 379 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	gtk_progress_bar_set_fraction (_data_->_tmp25_, 1.0);
#line 380 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	boxes_wizard_set_page (_data_->self, BOXES_WIZARD_PAGE_SETUP);
#line 363 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data_->prepare_media_progress);
#line 363 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 363 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (_data_->_state_ != 0) {
#line 363 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		while (g_task_get_completed (_data_->_async_result) != TRUE) {
#line 363 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 3003 "wizard.c"
		}
	}
#line 363 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_object_unref (_data_->_async_result);
#line 363 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	return FALSE;
#line 3010 "wizard.c"
}


static gboolean boxes_wizard_prepare (BoxesWizard* self, BoxesActivityProgress* progress) {
	gboolean result = FALSE;
	BoxesWizardSource* _tmp0_;
	gboolean _tmp1_;
	GCancellable* _tmp14_;
	BoxesWizardSource* _tmp15_;
	gboolean _tmp16_;
	gboolean _tmp17_;
	GtkImage* _tmp23_;
	BoxesWizardSource* _tmp24_;
	BoxesInstallerMedia* _tmp25_;
	BoxesInstallerMedia* _tmp26_;
	GError * _inner_error_ = NULL;
#line 383 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 383 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_return_val_if_fail (progress != NULL, FALSE);
#line 384 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->wizard_source;
#line 384 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp1_ = _tmp0_->libvirt_sys_import;
#line 384 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (_tmp1_) {
#line 3037 "wizard.c"
		GCancellable* _tmp2_;
#line 385 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp2_ = self->priv->prepare_cancellable;
#line 385 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		g_cancellable_reset (_tmp2_);
#line 387 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		result = TRUE;
#line 387 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		return result;
#line 3047 "wizard.c"
	}
	{
		BoxesWizardSource* _tmp3_;
		const gchar* _tmp4_;
		const gchar* _tmp5_;
#line 392 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp3_ = self->priv->wizard_source;
#line 392 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp4_ = boxes_wizard_source_get_uri (_tmp3_);
#line 392 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp5_ = _tmp4_;
#line 392 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		boxes_wizard_prepare_for_location (self, _tmp5_, TRUE, NULL, &_inner_error_);
#line 392 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3063 "wizard.c"
			goto __catch137_g_error;
		}
	}
	goto __finally137;
	__catch137_g_error:
	{
		GError* _error_ = NULL;
		BoxesAppWindow* _tmp6_;
		BoxesNotificationbar* _tmp7_;
		BoxesNotificationbar* _tmp8_;
		GError* _tmp9_;
		const gchar* _tmp10_;
		BoxesNotification* _tmp11_;
		BoxesNotification* _tmp12_;
#line 390 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_error_ = _inner_error_;
#line 390 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_inner_error_ = NULL;
#line 394 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp6_ = self->priv->window;
#line 394 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp7_ = boxes_app_window_get_notificationbar (_tmp6_);
#line 394 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp8_ = _tmp7_;
#line 394 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp9_ = _error_;
#line 394 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp10_ = _tmp9_->message;
#line 394 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp11_ = boxes_notificationbar_display_error (_tmp8_, _tmp10_, BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 394 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp12_ = _tmp11_;
#line 394 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (_tmp12_);
#line 396 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		result = FALSE;
#line 396 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_g_error_free0 (_error_);
#line 396 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		return result;
#line 3104 "wizard.c"
	}
	__finally137:
#line 390 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3109 "wizard.c"
		gboolean _tmp13_ = FALSE;
#line 390 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 390 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		g_clear_error (&_inner_error_);
#line 390 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		return _tmp13_;
#line 3117 "wizard.c"
	}
#line 399 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp14_ = self->priv->prepare_cancellable;
#line 399 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_cancellable_reset (_tmp14_);
#line 401 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp15_ = self->priv->wizard_source;
#line 401 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp16_ = boxes_wizard_source_get_download_required (_tmp15_);
#line 401 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp17_ = _tmp16_;
#line 401 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (_tmp17_) {
#line 3131 "wizard.c"
		GtkButton* _tmp18_;
		BoxesWizardSource* _tmp19_;
		const gchar* _tmp20_;
		const gchar* _tmp21_;
		BoxesActivityProgress* _tmp22_;
#line 402 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp18_ = self->priv->continue_button;
#line 402 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		gtk_widget_set_sensitive ((GtkWidget*) _tmp18_, FALSE);
#line 403 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp19_ = self->priv->wizard_source;
#line 403 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp20_ = boxes_wizard_source_get_uri (_tmp19_);
#line 403 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp21_ = _tmp20_;
#line 403 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp22_ = progress;
#line 403 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		boxes_wizard_download_media (self, _tmp21_, _tmp22_, NULL, NULL);
#line 405 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		result = TRUE;
#line 405 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		return result;
#line 3155 "wizard.c"
	}
#line 408 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp23_ = self->priv->installer_image;
#line 408 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	gtk_image_set_from_icon_name (_tmp23_, "media-optical", 0);
#line 410 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp24_ = self->priv->wizard_source;
#line 410 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp25_ = boxes_wizard_source_get_install_media (_tmp24_);
#line 410 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp26_ = _tmp25_;
#line 410 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (_tmp26_ != NULL) {
#line 3169 "wizard.c"
		GtkLabel* _tmp27_;
		GtkLabel* _tmp28_;
		BoxesWizardSource* _tmp29_;
		BoxesInstallerMedia* _tmp30_;
		BoxesInstallerMedia* _tmp31_;
		BoxesActivityProgress* _tmp32_;
#line 411 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp27_ = self->priv->prep_media_label;
#line 411 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		gtk_label_set_label (_tmp27_, _ ("Unknown installer media"));
#line 412 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp28_ = self->priv->prep_status_label;
#line 412 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		gtk_label_set_label (_tmp28_, _ ("Analyzing…"));
#line 413 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp29_ = self->priv->wizard_source;
#line 413 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp30_ = boxes_wizard_source_get_install_media (_tmp29_);
#line 413 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp31_ = _tmp30_;
#line 413 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp32_ = progress;
#line 413 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		boxes_wizard_prepare_media (self, _tmp31_, _tmp32_, NULL, NULL);
#line 415 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		result = TRUE;
#line 415 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		return result;
#line 3198 "wizard.c"
	}
	{
		BoxesWizardSource* _tmp33_;
		const gchar* _tmp34_;
		const gchar* _tmp35_;
		BoxesActivityProgress* _tmp36_;
#line 419 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp33_ = self->priv->wizard_source;
#line 419 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp34_ = boxes_wizard_source_get_uri (_tmp33_);
#line 419 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp35_ = _tmp34_;
#line 419 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp36_ = progress;
#line 419 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		boxes_wizard_prepare_for_location (self, _tmp35_, FALSE, _tmp36_, &_inner_error_);
#line 419 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3217 "wizard.c"
			goto __catch138_g_error;
		}
	}
	goto __finally138;
	__catch138_g_error:
	{
		GError* _error_ = NULL;
		BoxesAppWindow* _tmp37_;
		BoxesNotificationbar* _tmp38_;
		BoxesNotificationbar* _tmp39_;
		GError* _tmp40_;
		const gchar* _tmp41_;
		BoxesNotification* _tmp42_;
		BoxesNotification* _tmp43_;
#line 418 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_error_ = _inner_error_;
#line 418 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_inner_error_ = NULL;
#line 421 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp37_ = self->priv->window;
#line 421 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp38_ = boxes_app_window_get_notificationbar (_tmp37_);
#line 421 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp39_ = _tmp38_;
#line 421 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp40_ = _error_;
#line 421 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp41_ = _tmp40_->message;
#line 421 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp42_ = boxes_notificationbar_display_error (_tmp39_, _tmp41_, BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 421 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp43_ = _tmp42_;
#line 421 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (_tmp43_);
#line 423 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		result = FALSE;
#line 423 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_g_error_free0 (_error_);
#line 423 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		return result;
#line 3258 "wizard.c"
	}
	__finally138:
#line 418 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3263 "wizard.c"
		gboolean _tmp44_ = FALSE;
#line 418 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 418 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		g_clear_error (&_inner_error_);
#line 418 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		return _tmp44_;
#line 3271 "wizard.c"
	}
#line 426 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	result = TRUE;
#line 426 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	return result;
#line 3277 "wizard.c"
}


static void __lambda143_ (BoxesWizard* self) {
	BoxesVMCreator* _tmp0_;
	BoxesInstallerMedia* _tmp1_;
	BoxesInstallerMedia* _tmp2_;
	gboolean _tmp3_;
	gboolean _tmp4_;
#line 441 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->vm_creator;
#line 441 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp1_ = boxes_vm_creator_get_install_media (_tmp0_);
#line 441 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp2_ = _tmp1_;
#line 441 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp3_ = boxes_installer_media_get_ready_to_create (_tmp2_);
#line 441 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp4_ = _tmp3_;
#line 441 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (_tmp4_) {
#line 3299 "wizard.c"
		BoxesWizardPage _tmp5_;
		BoxesWizardPage _tmp6_;
#line 442 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp5_ = boxes_wizard_get_page (self);
#line 442 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp6_ = _tmp5_;
#line 442 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		boxes_wizard_set_page (self, _tmp6_ + 1);
#line 3308 "wizard.c"
	}
}


static void ___lambda143__boxes_installer_media_user_wants_to_create (BoxesInstallerMedia* _sender, gpointer self) {
#line 440 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	__lambda143_ ((BoxesWizard*) self);
#line 3316 "wizard.c"
}


static gboolean boxes_wizard_setup (BoxesWizard* self) {
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	BoxesCollectionSource* _tmp1_;
	BoxesVMCreator* _tmp4_;
	BoxesVMCreator* _tmp5_;
	BoxesInstallerMedia* _tmp6_;
	BoxesInstallerMedia* _tmp7_;
	GtkButton* _tmp8_;
	BoxesVMCreator* _tmp9_;
	BoxesInstallerMedia* _tmp10_;
	BoxesInstallerMedia* _tmp11_;
	GtkBox* _tmp12_;
	BoxesVMCreator* _tmp13_;
	BoxesInstallerMedia* _tmp14_;
	BoxesInstallerMedia* _tmp15_;
#line 429 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 431 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp1_ = self->priv->source;
#line 431 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (_tmp1_ != NULL) {
#line 431 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp0_ = TRUE;
#line 3344 "wizard.c"
	} else {
		BoxesWizardSource* _tmp2_;
		gboolean _tmp3_;
#line 431 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp2_ = self->priv->wizard_source;
#line 431 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp3_ = _tmp2_->libvirt_sys_import;
#line 431 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp0_ = _tmp3_;
#line 3354 "wizard.c"
	}
#line 431 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (_tmp0_) {
#line 432 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		result = TRUE;
#line 432 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		return result;
#line 3362 "wizard.c"
	}
#line 434 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp4_ = self->priv->vm_creator;
#line 434 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_return_val_if_fail (_tmp4_ != NULL, FALSE);
#line 436 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp5_ = self->priv->vm_creator;
#line 436 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp6_ = boxes_vm_creator_get_install_media (_tmp5_);
#line 436 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp7_ = _tmp6_;
#line 436 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp8_ = self->priv->continue_button;
#line 436 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_object_bind_property_with_closures ((GObject*) _tmp7_, "ready-to-create", (GObject*) _tmp8_, "sensitive", G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)));
#line 439 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp9_ = self->priv->vm_creator;
#line 439 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp10_ = boxes_vm_creator_get_install_media (_tmp9_);
#line 439 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp11_ = _tmp10_;
#line 439 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp12_ = self->priv->setup_box;
#line 439 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	boxes_installer_media_populate_setup_box (_tmp11_, _tmp12_);
#line 440 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp13_ = self->priv->vm_creator;
#line 440 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp14_ = boxes_vm_creator_get_install_media (_tmp13_);
#line 440 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp15_ = _tmp14_;
#line 440 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_signal_connect_object (_tmp15_, "user-wants-to-create", (GCallback) ___lambda143__boxes_installer_media_user_wants_to_create, self, 0);
#line 445 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	result = TRUE;
#line 445 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	return result;
#line 3400 "wizard.c"
}


static void boxes_wizard_do_review_cancellable_data_free (gpointer _data) {
	BoxesWizardDoReviewCancellableData* _data_;
	_data_ = _data;
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data_->self);
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_slice_free (BoxesWizardDoReviewCancellableData, _data_);
#line 3411 "wizard.c"
}


static void boxes_wizard_do_review_cancellable (BoxesWizard* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesWizardDoReviewCancellableData* _data_;
	BoxesWizard* _tmp0_;
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_ = g_slice_new0 (BoxesWizardDoReviewCancellableData);
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_task_set_task_data (_data_->_async_result, _data_, boxes_wizard_do_review_cancellable_data_free);
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->self = _tmp0_;
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	boxes_wizard_do_review_cancellable_co (_data_);
#line 3430 "wizard.c"
}


static gboolean boxes_wizard_do_review_cancellable_finish (BoxesWizard* self, GAsyncResult* _res_) {
	gboolean result;
	BoxesWizardDoReviewCancellableData* _data_;
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	result = _data_->result;
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	return result;
#line 3443 "wizard.c"
}


static void boxes_wizard_do_review_cancellable_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesWizardDoReviewCancellableData* _data_;
#line 462 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_ = _user_data_;
#line 462 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->_source_object_ = source_object;
#line 462 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->_res_ = _res_;
#line 462 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	boxes_wizard_do_review_cancellable_co (_data_);
#line 3457 "wizard.c"
}


static gpointer _boxes_pair_ref0 (gpointer self) {
#line 517 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	return self ? boxes_pair_ref (self) : NULL;
#line 3464 "wizard.c"
}


static void _boxes_pair_unref0_ (gpointer var) {
#line 517 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	(var == NULL) ? NULL : (var = (boxes_pair_unref (var), NULL));
#line 3471 "wizard.c"
}


static inline void _g_list_free__boxes_pair_unref0_ (GList* self) {
#line 517 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_list_free_full (self, (GDestroyNotify) _boxes_pair_unref0_);
#line 3478 "wizard.c"
}


static Block102Data* block102_data_ref (Block102Data* _data102_) {
#line 520 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_atomic_int_inc (&_data102_->_ref_count_);
#line 520 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	return _data102_;
#line 3487 "wizard.c"
}


static void block102_data_unref (void * _userdata_) {
	Block102Data* _data102_;
	_data102_ = (Block102Data*) _userdata_;
#line 520 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (g_atomic_int_dec_and_test (&_data102_->_ref_count_)) {
#line 3496 "wizard.c"
		BoxesWizard* self;
#line 520 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		self = _data102_->self;
#line 520 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (_data102_->config);
#line 520 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (self);
#line 520 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		g_slice_free (Block102Data, _data102_);
#line 3506 "wizard.c"
	}
}


static void _____lambda102_ (Block102Data* _data102_, GError** error) {
	BoxesWizard* self;
	GVirConfigDomain* _tmp0_ = NULL;
	BoxesLibvirtMachine* _tmp1_;
	BoxesLibvirtMachine* _tmp2_;
	GVirDomain* _tmp3_;
	GVirDomain* _tmp4_;
	GVirConfigDomain* _tmp5_;
	GVirConfigDomain* _tmp6_;
	GError * _inner_error_ = NULL;
#line 522 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	self = _data102_->self;
#line 523 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp1_ = boxes_wizard_get_libvirt_machine (self);
#line 523 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp2_ = _tmp1_;
#line 523 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp3_ = boxes_libvirt_machine_get_domain (_tmp2_);
#line 523 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp4_ = _tmp3_;
#line 523 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp5_ = gvir_domain_get_config (_tmp4_, (guint) GVIR_DOMAIN_XML_INACTIVE, &_inner_error_);
#line 523 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp0_ = _tmp5_;
#line 523 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 523 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		g_propagate_error (error, _inner_error_);
#line 523 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		return;
#line 3541 "wizard.c"
	}
#line 523 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp6_ = _tmp0_;
#line 523 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp0_ = NULL;
#line 523 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data102_->config);
#line 523 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data102_->config = _tmp6_;
#line 522 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_tmp0_);
#line 3553 "wizard.c"
}


static void ______lambda102__boxes_async_launcher_run_in_thread_func (gpointer self, GError** error) {
#line 522 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_____lambda102_ (self, error);
#line 3560 "wizard.c"
}


static void _vala_GVirStorageVolInfo_free (GVirStorageVolInfo* self) {
#line 533 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_boxed_free (gvir_storage_vol_info_get_type (), self);
#line 3567 "wizard.c"
}


static void ___lambda103_ (BoxesWizard* self) {
	BoxesWizardWindow* _tmp0_;
	BoxesLibvirtMachine* _tmp1_;
	BoxesLibvirtMachine* _tmp2_;
#line 553 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->wizard_window;
#line 553 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp1_ = boxes_wizard_get_libvirt_machine (self);
#line 553 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp2_ = _tmp1_;
#line 553 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	boxes_wizard_window_show_customization_page (_tmp0_, _tmp2_);
#line 3583 "wizard.c"
}


static void ____lambda103__boxes_wizard_summary_customize_func (gpointer self) {
#line 552 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	___lambda103_ ((BoxesWizard*) self);
#line 3590 "wizard.c"
}


static gboolean boxes_wizard_do_review_cancellable_co (BoxesWizardDoReviewCancellableData* _data_) {
#line 448 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	switch (_data_->_state_) {
#line 448 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		case 0:
#line 3599 "wizard.c"
		goto _state_0;
#line 448 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		case 1:
#line 3603 "wizard.c"
		goto _state_1;
#line 448 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		case 2:
#line 3607 "wizard.c"
		goto _state_2;
		default:
#line 448 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		g_assert_not_reached ();
#line 3612 "wizard.c"
	}
	_state_0:
#line 449 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->_tmp0_ = _data_->self->priv->review_cancellable;
#line 449 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_return_val_if_fail (_data_->_tmp0_ != NULL, FALSE);
#line 451 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->_tmp1_ = _data_->self->priv->nokvm_infobar;
#line 451 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	gtk_widget_hide ((GtkWidget*) _data_->_tmp1_);
#line 452 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->_tmp2_ = _data_->self->priv->summary;
#line 452 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	boxes_wizard_summary_clear (_data_->_tmp2_);
#line 454 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->_tmp3_ = _data_->self->priv->source;
#line 454 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (_data_->_tmp3_ != NULL) {
#line 3631 "wizard.c"
		{
#line 456 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp5_ = _data_->self->priv->source;
#line 456 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp6_ = boxes_remote_machine_new (_data_->_tmp5_, &_data_->_inner_error_);
#line 456 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp4_ = _data_->_tmp6_;
#line 456 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 456 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				if (_data_->_inner_error_->domain == BOXES_ERROR) {
#line 3643 "wizard.c"
					goto __catch139_boxes_error;
				}
#line 456 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 456 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				g_clear_error (&_data_->_inner_error_);
#line 456 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				g_object_unref (_data_->_async_result);
#line 456 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				return FALSE;
#line 3654 "wizard.c"
			}
#line 456 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			boxes_wizard_set_machine (_data_->self, (BoxesMachine*) _data_->_tmp4_);
#line 455 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_g_object_unref0 (_data_->_tmp4_);
#line 3660 "wizard.c"
		}
		goto __finally139;
		__catch139_boxes_error:
		{
#line 455 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_error_ = _data_->_inner_error_;
#line 455 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_inner_error_ = NULL;
#line 458 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp7_ = _data_->_error_;
#line 458 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp8_ = _data_->_tmp7_->message;
#line 458 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			g_warning ("wizard.vala:458: %s", _data_->_tmp8_);
#line 455 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_g_error_free0 (_data_->_error_);
#line 3677 "wizard.c"
		}
		__finally139:
#line 455 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 455 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 455 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			g_clear_error (&_data_->_inner_error_);
#line 455 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			g_object_unref (_data_->_async_result);
#line 455 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			return FALSE;
#line 3690 "wizard.c"
		}
	} else {
#line 460 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp10_ = _data_->self->priv->vm_creator;
#line 460 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		if (_data_->_tmp10_ != NULL) {
#line 460 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp11_ = boxes_wizard_get_libvirt_machine (_data_->self);
#line 460 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp12_ = _data_->_tmp11_;
#line 460 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp9_ = _data_->_tmp12_ == NULL;
#line 3703 "wizard.c"
		} else {
#line 460 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp9_ = FALSE;
#line 3707 "wizard.c"
		}
#line 460 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		if (_data_->_tmp9_) {
#line 3711 "wizard.c"
			{
#line 462 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_tmp14_ = _data_->self->priv->vm_creator;
#line 462 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_tmp15_ = _data_->self->priv->review_cancellable;
#line 462 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_state_ = 1;
#line 462 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				boxes_vm_creator_create_vm (_data_->_tmp14_, _data_->_tmp15_, boxes_wizard_do_review_cancellable_ready, _data_);
#line 462 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				return FALSE;
#line 3723 "wizard.c"
				_state_1:
#line 462 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_tmp16_ = boxes_vm_creator_create_vm_finish (_data_->_tmp14_, _data_->_res_, &_data_->_inner_error_);
#line 462 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_tmp13_ = _data_->_tmp16_;
#line 462 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 462 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					if (g_error_matches (_data_->_inner_error_, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
#line 3733 "wizard.c"
						goto __catch140_g_io_error_cancelled;
					}
					goto __catch140_g_error;
				}
#line 462 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				boxes_wizard_set_machine (_data_->self, (BoxesMachine*) _data_->_tmp13_);
#line 461 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_g_object_unref0 (_data_->_tmp13_);
#line 3742 "wizard.c"
			}
			goto __finally140;
			__catch140_g_io_error_cancelled:
			{
#line 461 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->cancel_error = _data_->_inner_error_;
#line 461 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_inner_error_ = NULL;
#line 461 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_g_error_free0 (_data_->cancel_error);
#line 3753 "wizard.c"
			}
			goto __finally140;
			__catch140_g_error:
			{
#line 461 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_vala1__error_ = _data_->_inner_error_;
#line 461 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_inner_error_ = NULL;
#line 465 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_tmp17_ = _data_->self->priv->window;
#line 465 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_tmp18_ = boxes_app_window_get_notificationbar (_data_->_tmp17_);
#line 465 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_tmp19_ = _data_->_tmp18_;
#line 465 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_tmp20_ = boxes_notificationbar_display_error (_data_->_tmp19_, _ ("Box setup failed"), BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 465 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_tmp21_ = _data_->_tmp20_;
#line 465 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_g_object_unref0 (_data_->_tmp21_);
#line 466 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_tmp22_ = _data_->_vala1__error_;
#line 466 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_tmp23_ = _data_->_tmp22_->message;
#line 466 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				g_warning ("wizard.vala:466: %s", _data_->_tmp23_);
#line 461 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_g_error_free0 (_data_->_vala1__error_);
#line 3782 "wizard.c"
			}
			__finally140:
#line 461 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 461 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 461 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				g_clear_error (&_data_->_inner_error_);
#line 461 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				g_object_unref (_data_->_async_result);
#line 461 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				return FALSE;
#line 3795 "wizard.c"
			}
#line 469 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp24_ = boxes_wizard_get_libvirt_machine (_data_->self);
#line 469 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp25_ = _data_->_tmp24_;
#line 469 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			if (_data_->_tmp25_ == NULL) {
#line 471 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				g_object_notify ((GObject*) _data_->self, "machine");
#line 472 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->result = FALSE;
#line 472 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 472 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				if (_data_->_state_ != 0) {
#line 472 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					while (g_task_get_completed (_data_->_async_result) != TRUE) {
#line 472 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 3815 "wizard.c"
					}
				}
#line 472 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				g_object_unref (_data_->_async_result);
#line 472 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				return FALSE;
#line 3822 "wizard.c"
			}
		}
	}
#line 476 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->_tmp26_ = _data_->self->priv->review_cancellable;
#line 476 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->_tmp27_ = g_cancellable_is_cancelled (_data_->_tmp26_);
#line 476 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (_data_->_tmp27_) {
#line 477 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->result = FALSE;
#line 477 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 477 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		if (_data_->_state_ != 0) {
#line 477 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			while (g_task_get_completed (_data_->_async_result) != TRUE) {
#line 477 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 3842 "wizard.c"
			}
		}
#line 477 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		g_object_unref (_data_->_async_result);
#line 477 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		return FALSE;
#line 3849 "wizard.c"
	}
#line 479 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->_tmp28_ = _data_->self->priv->review_label;
#line 479 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	gtk_label_set_text (_data_->_tmp28_, _ ("Boxes will create a new box with the following properties:"));
#line 481 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->_tmp29_ = _data_->self->priv->source;
#line 481 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (_data_->_tmp29_ != NULL) {
#line 491 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		static GQuark _tmp60_label0 = 0;
#line 491 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		static GQuark _tmp60_label1 = 0;
#line 482 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp30_ = _data_->self->priv->source;
#line 482 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp31_ = boxes_collection_source_get_uri (_data_->_tmp30_);
#line 482 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp32_ = _data_->_tmp31_;
#line 482 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp33_ = _data_->_tmp32_;
#line 482 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp34_ = xmlParseURI (_data_->_tmp33_);
#line 482 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp35_ = _data_->_tmp34_;
#line 482 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_g_free0 (_data_->_tmp33_);
#line 482 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->uri = _data_->_tmp35_;
#line 484 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp36_ = _data_->self->priv->summary;
#line 484 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp37_ = _data_->self->priv->source;
#line 484 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp38_ = boxes_collection_source_get_source_type (_data_->_tmp37_);
#line 484 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp39_ = _data_->_tmp38_;
#line 484 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp40_ = _data_->_tmp39_;
#line 484 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		boxes_wizard_summary_add_property (_data_->_tmp36_, _ ("Type"), _data_->_tmp40_);
#line 484 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_g_free0 (_data_->_tmp40_);
#line 486 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp42_ = _data_->uri;
#line 486 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		if (_data_->_tmp42_ != NULL) {
#line 486 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp43_ = _data_->uri;
#line 486 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp44_ = _data_->_tmp43_->server;
#line 486 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp41_ = _data_->_tmp44_ != NULL;
#line 3903 "wizard.c"
		} else {
#line 486 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp41_ = FALSE;
#line 3907 "wizard.c"
		}
#line 486 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		if (_data_->_tmp41_) {
#line 487 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp45_ = _data_->self->priv->summary;
#line 487 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp46_ = _data_->uri;
#line 487 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp47_ = _data_->_tmp46_->server;
#line 487 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp48_ = g_utf8_strdown (_data_->_tmp47_, (gssize) -1);
#line 487 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp49_ = _data_->_tmp48_;
#line 487 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			boxes_wizard_summary_add_property (_data_->_tmp45_, _ ("Host"), _data_->_tmp49_);
#line 487 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_g_free0 (_data_->_tmp49_);
#line 3925 "wizard.c"
		} else {
#line 489 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp50_ = _data_->self->priv->summary;
#line 489 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp51_ = _data_->self->priv->source;
#line 489 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp52_ = boxes_collection_source_get_uri (_data_->_tmp51_);
#line 489 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp53_ = _data_->_tmp52_;
#line 489 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp54_ = _data_->_tmp53_;
#line 489 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp55_ = g_utf8_strdown (_data_->_tmp54_, (gssize) -1);
#line 489 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp56_ = _data_->_tmp55_;
#line 489 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			boxes_wizard_summary_add_property (_data_->_tmp50_, _ ("URL"), _data_->_tmp56_);
#line 489 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_g_free0 (_data_->_tmp56_);
#line 489 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_g_free0 (_data_->_tmp54_);
#line 3947 "wizard.c"
		}
#line 491 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp57_ = _data_->uri;
#line 491 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp58_ = _data_->_tmp57_->scheme;
#line 491 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp61_ = 0U;
#line 491 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp59_ = _data_->_tmp58_;
#line 491 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp61_ = (NULL == _data_->_tmp59_) ? 0 : g_quark_from_string (_data_->_tmp59_);
#line 491 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		if (_data_->_tmp61_ == ((0 != _tmp60_label0) ? _tmp60_label0 : (_tmp60_label0 = g_quark_from_static_string ("spice")))) {
#line 491 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			switch (0) {
#line 3963 "wizard.c"
				default:
				{
					{
#line 494 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						_data_->port = 0;
#line 494 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						_data_->tls_port = 0;
#line 496 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						_data_->_tmp62_ = _data_->self->priv->source;
#line 496 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						_data_->_tmp63_ = boxes_collection_source_get_uri (_data_->_tmp62_);
#line 496 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						_data_->_tmp64_ = _data_->_tmp63_;
#line 496 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						_data_->_tmp65_ = _data_->_tmp64_;
#line 496 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						_data_->_tmp66_ = NULL;
#line 496 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						_data_->_tmp67_ = NULL;
#line 496 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						spice_validate_uri (_data_->_tmp65_, &_data_->_tmp66_, &_data_->_tmp67_, &_data_->_inner_error_);
#line 496 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						_data_->_tmp68_ = _data_->_tmp66_;
#line 496 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						_data_->port = *_data_->_tmp68_;
#line 496 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						_data_->_tmp69_ = _data_->_tmp67_;
#line 496 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						_data_->tls_port = *_data_->_tmp69_;
#line 496 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						_g_free0 (_data_->_tmp69_);
#line 496 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						_g_free0 (_data_->_tmp68_);
#line 496 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						_g_free0 (_data_->_tmp65_);
#line 496 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 496 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
							if (_data_->_inner_error_->domain == BOXES_ERROR) {
#line 4003 "wizard.c"
								goto __catch141_boxes_error;
							}
#line 496 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
							_xmlFreeURI0 (_data_->uri);
#line 496 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
							g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 496 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
							g_clear_error (&_data_->_inner_error_);
#line 496 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
							g_object_unref (_data_->_async_result);
#line 496 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
							return FALSE;
#line 4016 "wizard.c"
						}
#line 497 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						_data_->_tmp70_ = _data_->port;
#line 497 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						if (_data_->_tmp70_ > 0) {
#line 498 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
							_data_->_tmp71_ = _data_->self->priv->summary;
#line 498 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
							_data_->_tmp72_ = _data_->port;
#line 498 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
							_data_->_tmp73_ = g_strdup_printf ("%i", _data_->_tmp72_);
#line 498 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
							_data_->_tmp74_ = _data_->_tmp73_;
#line 498 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
							boxes_wizard_summary_add_property (_data_->_tmp71_, _ ("Port"), _data_->_tmp74_);
#line 498 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
							_g_free0 (_data_->_tmp74_);
#line 4034 "wizard.c"
						}
#line 499 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						_data_->_tmp75_ = _data_->tls_port;
#line 499 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						if (_data_->_tmp75_ > 0) {
#line 500 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
							_data_->_tmp76_ = _data_->self->priv->summary;
#line 500 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
							_data_->_tmp77_ = _data_->tls_port;
#line 500 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
							_data_->_tmp78_ = g_strdup_printf ("%i", _data_->_tmp77_);
#line 500 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
							_data_->_tmp79_ = _data_->_tmp78_;
#line 500 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
							boxes_wizard_summary_add_property (_data_->_tmp76_, _ ("TLS Port"), _data_->_tmp79_);
#line 500 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
							_g_free0 (_data_->_tmp79_);
#line 4052 "wizard.c"
						}
					}
					goto __finally141;
					__catch141_boxes_error:
					{
#line 493 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						_data_->_vala2__error_ = _data_->_inner_error_;
#line 493 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						_data_->_inner_error_ = NULL;
#line 503 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						_data_->_tmp80_ = _data_->_vala2__error_;
#line 503 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						_data_->_tmp81_ = _data_->_tmp80_->message;
#line 503 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						g_critical ("wizard.vala:503: %s", _data_->_tmp81_);
#line 493 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						_g_error_free0 (_data_->_vala2__error_);
#line 4070 "wizard.c"
					}
					__finally141:
#line 493 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 493 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						_xmlFreeURI0 (_data_->uri);
#line 493 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 493 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						g_clear_error (&_data_->_inner_error_);
#line 493 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						g_object_unref (_data_->_async_result);
#line 493 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						return FALSE;
#line 4085 "wizard.c"
					}
#line 505 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					break;
#line 4089 "wizard.c"
				}
			}
		} else if (_data_->_tmp61_ == ((0 != _tmp60_label1) ? _tmp60_label1 : (_tmp60_label1 = g_quark_from_static_string ("vnc")))) {
#line 491 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			switch (0) {
#line 4095 "wizard.c"
				default:
				{
#line 508 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					_data_->_tmp82_ = _data_->uri;
#line 508 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					_data_->_tmp83_ = _data_->_tmp82_->port;
#line 508 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					if (_data_->_tmp83_ > 0) {
#line 509 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						_data_->_tmp84_ = _data_->self->priv->summary;
#line 509 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						_data_->_tmp85_ = _data_->uri;
#line 509 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						_data_->_tmp86_ = _data_->_tmp85_->port;
#line 509 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						_data_->_tmp87_ = g_strdup_printf ("%i", _data_->_tmp86_);
#line 509 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						_data_->_tmp88_ = _data_->_tmp87_;
#line 509 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						boxes_wizard_summary_add_property (_data_->_tmp84_, _ ("Port"), _data_->_tmp88_);
#line 509 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						_g_free0 (_data_->_tmp88_);
#line 4118 "wizard.c"
					}
#line 510 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					break;
#line 4122 "wizard.c"
				}
			}
		}
#line 513 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp89_ = boxes_app_app;
#line 513 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp90_ = _data_->self->priv->source;
#line 513 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp91_ = boxes_collection_source_get_source_type (_data_->_tmp90_);
#line 513 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp92_ = _data_->_tmp91_;
#line 513 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp93_ = _data_->_tmp92_;
#line 513 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp94_ = boxes_app_has_broker_for_source_type (_data_->_tmp89_, _data_->_tmp93_);
#line 513 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp95_ = _data_->_tmp94_;
#line 513 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_g_free0 (_data_->_tmp93_);
#line 513 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		if (_data_->_tmp95_) {
#line 514 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp96_ = _data_->self->priv->review_label;
#line 514 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			gtk_label_set_text (_data_->_tmp96_, _ ("Will add boxes for all systems available from this account:"));
#line 4148 "wizard.c"
		}
#line 481 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_xmlFreeURI0 (_data_->uri);
#line 4152 "wizard.c"
	} else {
#line 516 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp97_ = boxes_wizard_get_libvirt_machine (_data_->self);
#line 516 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp98_ = _data_->_tmp97_;
#line 516 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		if (_data_->_tmp98_ != NULL) {
#line 517 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp99_ = _data_->self->priv->vm_creator;
#line 517 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp100_ = boxes_vm_creator_get_install_media (_data_->_tmp99_);
#line 517 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp101_ = _data_->_tmp100_;
#line 517 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp102_ = boxes_installer_media_get_vm_properties (_data_->_tmp101_);
#line 4168 "wizard.c"
			{
#line 517 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->property_collection = _data_->_tmp102_;
#line 517 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				for (_data_->property_it = _data_->property_collection; _data_->property_it != NULL; _data_->property_it = _data_->property_it->next) {
#line 517 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					_data_->_tmp103_ = _boxes_pair_ref0 ((BoxesPair*) _data_->property_it->data);
#line 517 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					_data_->property = _data_->_tmp103_;
#line 4178 "wizard.c"
					{
#line 518 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						_data_->_tmp104_ = _data_->self->priv->summary;
#line 518 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						_data_->_tmp105_ = _data_->property;
#line 518 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						_data_->_tmp106_ = _data_->_tmp105_->first;
#line 518 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						_data_->_tmp107_ = _data_->property;
#line 518 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						_data_->_tmp108_ = _data_->_tmp107_->second;
#line 518 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						boxes_wizard_summary_add_property (_data_->_tmp104_, (const gchar*) _data_->_tmp106_, (const gchar*) _data_->_tmp108_);
#line 517 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						_boxes_pair_unref0 (_data_->property);
#line 4194 "wizard.c"
					}
				}
#line 517 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				__g_list_free__boxes_pair_unref0_0 (_data_->property_collection);
#line 4199 "wizard.c"
			}
			{
#line 520 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_data102_ = g_slice_new0 (Block102Data);
#line 520 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_data102_->_ref_count_ = 1;
#line 520 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_data102_->self = g_object_ref (_data_->self);
#line 521 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_tmp109_ = NULL;
#line 521 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_tmp110_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_data_->_tmp109_, gvir_config_domain_get_type ()) ? ((GVirConfigDomain*) _data_->_tmp109_) : NULL);
#line 521 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_data102_->config = _data_->_tmp110_;
#line 522 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_tmp111_ = boxes_app_app;
#line 522 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_tmp112_ = _data_->_tmp111_->async_launcher;
#line 522 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_state_ = 2;
#line 522 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				boxes_async_launcher_launch (_data_->_tmp112_, ______lambda102__boxes_async_launcher_run_in_thread_func, block102_data_ref (_data_->_data102_), block102_data_unref, boxes_wizard_do_review_cancellable_ready, _data_);
#line 522 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				return FALSE;
#line 4224 "wizard.c"
				_state_2:
#line 522 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				boxes_async_launcher_launch_finish (_data_->_tmp112_, _data_->_res_, &_data_->_inner_error_);
#line 522 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 522 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					block102_data_unref (_data_->_data102_);
#line 522 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					_data_->_data102_ = NULL;
#line 4234 "wizard.c"
					goto __catch142_g_error;
				}
#line 526 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_tmp113_ = _data_->_data102_->config;
#line 526 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_tmp114_ = gvir_config_domain_get_memory (_data_->_tmp113_);
#line 526 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_tmp115_ = _data_->_tmp114_;
#line 526 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_tmp116_ = g_format_size_full (_data_->_tmp115_ * OSINFO_KIBIBYTES, G_FORMAT_SIZE_IEC_UNITS);
#line 526 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->memory = _data_->_tmp116_;
#line 527 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_tmp117_ = _data_->self->priv->summary;
#line 527 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_tmp118_ = _data_->memory;
#line 527 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				boxes_wizard_summary_add_property (_data_->_tmp117_, _ ("Memory"), _data_->_tmp118_);
#line 520 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_g_free0 (_data_->memory);
#line 520 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				block102_data_unref (_data_->_data102_);
#line 520 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_data102_ = NULL;
#line 4259 "wizard.c"
			}
			goto __finally142;
			__catch142_g_error:
			{
#line 520 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_vala3__error_ = _data_->_inner_error_;
#line 520 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_inner_error_ = NULL;
#line 529 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_tmp119_ = boxes_wizard_get_libvirt_machine (_data_->self);
#line 529 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_tmp120_ = _data_->_tmp119_;
#line 529 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_tmp121_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _data_->_tmp120_);
#line 529 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_tmp122_ = _data_->_tmp121_;
#line 529 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_tmp123_ = _data_->_vala3__error_;
#line 529 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_tmp124_ = _data_->_tmp123_->message;
#line 529 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				g_warning ("wizard.vala:529: Failed to get configuration for machine '%s': %s", _data_->_tmp122_, _data_->_tmp124_);
#line 520 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_g_error_free0 (_data_->_vala3__error_);
#line 4284 "wizard.c"
			}
			__finally142:
#line 520 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 520 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 520 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				g_clear_error (&_data_->_inner_error_);
#line 520 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				g_object_unref (_data_->_async_result);
#line 520 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				return FALSE;
#line 4297 "wizard.c"
			}
#line 532 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp126_ = boxes_wizard_get_libvirt_machine (_data_->self);
#line 532 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp127_ = _data_->_tmp126_;
#line 532 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp128_ = boxes_libvirt_machine_get_importing (_data_->_tmp127_);
#line 532 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp129_ = _data_->_tmp128_;
#line 532 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			if (!_data_->_tmp129_) {
#line 532 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_tmp130_ = boxes_wizard_get_libvirt_machine (_data_->self);
#line 532 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_tmp131_ = _data_->_tmp130_;
#line 532 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_tmp132_ = boxes_libvirt_machine_get_storage_volume (_data_->_tmp131_);
#line 532 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_tmp133_ = _data_->_tmp132_;
#line 532 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_tmp125_ = _data_->_tmp133_ != NULL;
#line 4319 "wizard.c"
			} else {
#line 532 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_tmp125_ = FALSE;
#line 4323 "wizard.c"
			}
#line 532 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			if (_data_->_tmp125_) {
#line 4327 "wizard.c"
				{
#line 534 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					_data_->_tmp134_ = boxes_wizard_get_libvirt_machine (_data_->self);
#line 534 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					_data_->_tmp135_ = _data_->_tmp134_;
#line 534 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					_data_->_tmp136_ = boxes_libvirt_machine_get_storage_volume (_data_->_tmp135_);
#line 534 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					_data_->_tmp137_ = _data_->_tmp136_;
#line 534 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					_data_->_tmp138_ = gvir_storage_vol_get_info (_data_->_tmp137_, &_data_->_inner_error_);
#line 534 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					_data_->volume_info = _data_->_tmp138_;
#line 534 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 4343 "wizard.c"
						goto __catch143_g_error;
					}
#line 535 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					_data_->_tmp139_ = _data_->volume_info;
#line 535 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					_data_->_tmp140_ = _data_->_tmp139_->capacity;
#line 535 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					_data_->_tmp141_ = g_format_size_full (_data_->_tmp140_, G_FORMAT_SIZE_DEFAULT);
#line 535 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					_data_->capacity = _data_->_tmp141_;
#line 536 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					_data_->_tmp142_ = _data_->self->priv->summary;
#line 536 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					_data_->_tmp143_ = _data_->capacity;
#line 536 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					_data_->_tmp144_ = g_strdup_printf (_ ("%s maximum"), _data_->_tmp143_);
#line 536 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					_data_->_tmp145_ = _data_->_tmp144_;
#line 536 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					boxes_wizard_summary_add_property (_data_->_tmp142_, _ ("Disk"), _data_->_tmp145_);
#line 536 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					_g_free0 (_data_->_tmp145_);
#line 533 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					_g_free0 (_data_->capacity);
#line 533 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					__vala_GVirStorageVolInfo_free0 (_data_->volume_info);
#line 4370 "wizard.c"
				}
				goto __finally143;
				__catch143_g_error:
				{
#line 533 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					_data_->_vala4__error_ = _data_->_inner_error_;
#line 533 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					_data_->_inner_error_ = NULL;
#line 540 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					_data_->_tmp146_ = boxes_wizard_get_libvirt_machine (_data_->self);
#line 540 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					_data_->_tmp147_ = _data_->_tmp146_;
#line 540 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					_data_->_tmp148_ = boxes_libvirt_machine_get_storage_volume (_data_->_tmp147_);
#line 540 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					_data_->_tmp149_ = _data_->_tmp148_;
#line 540 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					_data_->_tmp150_ = gvir_storage_vol_get_name (_data_->_tmp149_);
#line 540 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					_data_->_tmp151_ = _data_->_vala4__error_;
#line 540 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					_data_->_tmp152_ = _data_->_tmp151_->message;
#line 540 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					g_warning ("wizard.vala:540: Failed to get information on volume '%s': %s", _data_->_tmp150_, _data_->_tmp152_);
#line 533 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					_g_error_free0 (_data_->_vala4__error_);
#line 4397 "wizard.c"
				}
				__finally143:
#line 533 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 533 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 533 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					g_clear_error (&_data_->_inner_error_);
#line 533 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					g_object_unref (_data_->_async_result);
#line 533 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					return FALSE;
#line 4410 "wizard.c"
				}
			}
#line 546 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp153_ = _data_->self->priv->nokvm_infobar;
#line 546 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp154_ = boxes_wizard_get_libvirt_machine (_data_->self);
#line 546 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp155_ = _data_->_tmp154_;
#line 546 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp156_ = boxes_libvirt_machine_get_domain_config (_data_->_tmp155_);
#line 546 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp157_ = _data_->_tmp156_;
#line 546 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp158_ = gvir_config_domain_get_virt_type (_data_->_tmp157_);
#line 546 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			gtk_widget_set_visible ((GtkWidget*) _data_->_tmp153_, _data_->_tmp158_ != GVIR_CONFIG_DOMAIN_VIRT_KVM);
#line 4427 "wizard.c"
		} else {
#line 547 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp159_ = _data_->self->priv->wizard_source;
#line 547 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_data_->_tmp160_ = _data_->_tmp159_->libvirt_sys_import;
#line 547 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			if (_data_->_tmp160_) {
#line 548 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_tmp161_ = _data_->self->priv->review_label;
#line 548 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_tmp162_ = _data_->self->priv->wizard_source;
#line 548 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_tmp163_ = boxes_wizard_source_get_libvirt_sys_importer (_data_->_tmp162_);
#line 548 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_tmp164_ = _data_->_tmp163_;
#line 548 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_tmp165_ = boxes_libvirt_system_importer_get_wizard_review_label (_data_->_tmp164_);
#line 548 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_tmp166_ = _data_->_tmp165_;
#line 548 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_data_->_tmp167_ = _data_->_tmp166_;
#line 548 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				gtk_label_set_text (_data_->_tmp161_, _data_->_tmp167_);
#line 548 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_g_free0 (_data_->_tmp167_);
#line 4453 "wizard.c"
			}
		}
	}
#line 551 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->_tmp168_ = boxes_wizard_get_libvirt_machine (_data_->self);
#line 551 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->_tmp169_ = _data_->_tmp168_;
#line 551 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (_data_->_tmp169_ != NULL) {
#line 552 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp170_ = _data_->self->priv->summary;
#line 552 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		boxes_wizard_summary_append_customize_button (_data_->_tmp170_, ____lambda103__boxes_wizard_summary_customize_func, _data_->self);
#line 4467 "wizard.c"
	}
#line 556 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->result = TRUE;
#line 556 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 556 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (_data_->_state_ != 0) {
#line 556 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		while (g_task_get_completed (_data_->_async_result) != TRUE) {
#line 556 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 4479 "wizard.c"
		}
	}
#line 556 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_object_unref (_data_->_async_result);
#line 556 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	return FALSE;
#line 4486 "wizard.c"
}


static gboolean boxes_wizard_skip_page (BoxesWizard* self, BoxesWizardPage page) {
	gboolean result = FALSE;
	gboolean forwards = FALSE;
	BoxesWizardPage _tmp0_;
	BoxesWizardPage _tmp1_;
	BoxesWizardPage _tmp2_;
	BoxesWizardPage skip_to = 0;
	BoxesWizardPage _tmp3_;
	gboolean _tmp4_ = FALSE;
	BoxesCollectionSource* _tmp5_;
	gboolean _tmp12_ = FALSE;
	gboolean _tmp13_;
	BoxesVMCreator* _tmp16_;
	BoxesWizardPage _tmp52_;
	BoxesWizardPage _tmp53_;
#line 559 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 560 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp0_ = page;
#line 560 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp1_ = boxes_wizard_get_page (self);
#line 560 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp2_ = _tmp1_;
#line 560 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	forwards = _tmp0_ > _tmp2_;
#line 561 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp3_ = page;
#line 561 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	skip_to = _tmp3_;
#line 564 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp5_ = self->priv->source;
#line 564 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (_tmp5_ != NULL) {
#line 4523 "wizard.c"
		BoxesWizardPage _tmp6_;
		BoxesWizardPage _tmp7_;
#line 565 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp6_ = page;
#line 565 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp7_ = _tmp6_;
#line 565 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp4_ = (BOXES_WIZARD_PAGE_SOURCE < _tmp7_) && (_tmp7_ < BOXES_WIZARD_PAGE_REVIEW);
#line 4532 "wizard.c"
	} else {
#line 564 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp4_ = FALSE;
#line 4536 "wizard.c"
	}
#line 564 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (_tmp4_) {
#line 4540 "wizard.c"
		BoxesWizardPage _tmp8_ = 0;
		gboolean _tmp9_;
#line 566 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp9_ = forwards;
#line 566 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		if (_tmp9_) {
#line 4547 "wizard.c"
			BoxesWizardPage _tmp10_;
#line 566 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp10_ = page;
#line 566 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp8_ = _tmp10_ + 1;
#line 4553 "wizard.c"
		} else {
			BoxesWizardPage _tmp11_;
#line 566 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp11_ = page;
#line 566 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp8_ = _tmp11_ - 1;
#line 4560 "wizard.c"
		}
#line 566 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		skip_to = _tmp8_;
#line 4564 "wizard.c"
	}
#line 569 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp13_ = forwards;
#line 569 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (!_tmp13_) {
#line 4570 "wizard.c"
		BoxesWizardPage _tmp14_;
#line 570 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp14_ = page;
#line 570 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp12_ = _tmp14_ == BOXES_WIZARD_PAGE_PREPARATION;
#line 4576 "wizard.c"
	} else {
#line 569 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp12_ = FALSE;
#line 4580 "wizard.c"
	}
#line 569 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (_tmp12_) {
#line 4584 "wizard.c"
		BoxesWizardPage _tmp15_;
#line 571 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp15_ = page;
#line 571 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		skip_to = _tmp15_ - 1;
#line 4590 "wizard.c"
	}
#line 573 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp16_ = self->priv->vm_creator;
#line 573 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (_tmp16_ != NULL) {
#line 4596 "wizard.c"
		gboolean _tmp17_ = FALSE;
		BoxesWizardPage _tmp18_;
		gboolean _tmp28_ = FALSE;
		gboolean _tmp29_ = FALSE;
		gboolean _tmp30_ = FALSE;
		BoxesWizardPage _tmp31_;
#line 575 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp18_ = page;
#line 575 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		if (_tmp18_ == BOXES_WIZARD_PAGE_SETUP) {
#line 4607 "wizard.c"
			BoxesVMCreator* _tmp19_;
			BoxesInstallerMedia* _tmp20_;
			BoxesInstallerMedia* _tmp21_;
			gboolean _tmp22_;
			gboolean _tmp23_;
#line 576 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp19_ = self->priv->vm_creator;
#line 576 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp20_ = boxes_vm_creator_get_install_media (_tmp19_);
#line 576 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp21_ = _tmp20_;
#line 576 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp22_ = boxes_installer_media_get_need_user_input_for_vm_creation (_tmp21_);
#line 576 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp23_ = _tmp22_;
#line 576 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp17_ = !_tmp23_;
#line 4625 "wizard.c"
		} else {
#line 575 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp17_ = FALSE;
#line 4629 "wizard.c"
		}
#line 575 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		if (_tmp17_) {
#line 4633 "wizard.c"
			BoxesWizardPage _tmp24_ = 0;
			gboolean _tmp25_;
#line 577 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp25_ = forwards;
#line 577 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			if (_tmp25_) {
#line 4640 "wizard.c"
				BoxesWizardPage _tmp26_;
#line 577 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_tmp26_ = page;
#line 577 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_tmp24_ = _tmp26_ + 1;
#line 4646 "wizard.c"
			} else {
				BoxesWizardPage _tmp27_;
#line 577 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_tmp27_ = page;
#line 577 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_tmp24_ = _tmp27_ - 1;
#line 4653 "wizard.c"
			}
#line 577 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			skip_to = _tmp24_;
#line 4657 "wizard.c"
		}
#line 580 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp31_ = page;
#line 580 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		if (_tmp31_ == BOXES_WIZARD_PAGE_REVIEW) {
#line 4663 "wizard.c"
			gboolean _tmp32_;
#line 580 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp32_ = forwards;
#line 580 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp30_ = _tmp32_;
#line 4669 "wizard.c"
		} else {
#line 580 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp30_ = FALSE;
#line 4673 "wizard.c"
		}
#line 580 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		if (_tmp30_) {
#line 4677 "wizard.c"
			BoxesVMCreator* _tmp33_;
			BoxesInstallerMedia* _tmp34_;
			BoxesInstallerMedia* _tmp35_;
			gboolean _tmp36_;
			gboolean _tmp37_;
#line 581 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp33_ = self->priv->vm_creator;
#line 581 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp34_ = boxes_vm_creator_get_install_media (_tmp33_);
#line 581 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp35_ = _tmp34_;
#line 581 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp36_ = boxes_installer_media_get_live (_tmp35_);
#line 581 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp37_ = _tmp36_;
#line 581 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp29_ = _tmp37_;
#line 4695 "wizard.c"
		} else {
#line 580 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp29_ = FALSE;
#line 4699 "wizard.c"
		}
#line 580 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		if (_tmp29_) {
#line 4703 "wizard.c"
			gboolean _tmp38_;
#line 582 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp38_ = self->priv->skip_review_for_live;
#line 582 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp28_ = _tmp38_;
#line 4709 "wizard.c"
		} else {
#line 580 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp28_ = FALSE;
#line 4713 "wizard.c"
		}
#line 580 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		if (_tmp28_) {
#line 4717 "wizard.c"
			BoxesWizardPage _tmp39_;
#line 583 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp39_ = skip_to;
#line 583 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			skip_to = _tmp39_ + 1;
#line 4723 "wizard.c"
		}
	} else {
		BoxesWizardSource* _tmp40_;
		gboolean _tmp41_;
#line 584 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp40_ = self->priv->wizard_source;
#line 584 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp41_ = _tmp40_->libvirt_sys_import;
#line 584 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		if (_tmp41_) {
#line 4734 "wizard.c"
			BoxesWizardPage _tmp42_;
#line 585 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp42_ = page;
#line 585 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			if (_tmp42_ == BOXES_WIZARD_PAGE_PREPARATION) {
#line 4740 "wizard.c"
				BoxesWizardPage _tmp43_ = 0;
				gboolean _tmp44_;
#line 586 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_tmp44_ = forwards;
#line 586 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				if (_tmp44_) {
#line 4747 "wizard.c"
					BoxesWizardPage _tmp45_;
#line 586 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					_tmp45_ = page;
#line 586 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					_tmp43_ = _tmp45_ + 2;
#line 4753 "wizard.c"
				} else {
					BoxesWizardPage _tmp46_;
#line 586 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					_tmp46_ = page;
#line 586 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					_tmp43_ = _tmp46_ - 1;
#line 4760 "wizard.c"
				}
#line 586 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				skip_to = _tmp43_;
#line 4764 "wizard.c"
			} else {
				BoxesWizardPage _tmp47_;
#line 587 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_tmp47_ = page;
#line 587 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				if (_tmp47_ == BOXES_WIZARD_PAGE_SETUP) {
#line 4771 "wizard.c"
					BoxesWizardPage _tmp48_ = 0;
					gboolean _tmp49_;
#line 588 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					_tmp49_ = forwards;
#line 588 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					if (_tmp49_) {
#line 4778 "wizard.c"
						BoxesWizardPage _tmp50_;
#line 588 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						_tmp50_ = page;
#line 588 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						_tmp48_ = _tmp50_ + 1;
#line 4784 "wizard.c"
					} else {
						BoxesWizardPage _tmp51_;
#line 588 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						_tmp51_ = page;
#line 588 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
						_tmp48_ = _tmp51_ - 2;
#line 4791 "wizard.c"
					}
#line 588 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					skip_to = _tmp48_;
#line 4795 "wizard.c"
				}
			}
		}
	}
#line 591 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp52_ = skip_to;
#line 591 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp53_ = page;
#line 591 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (_tmp52_ != _tmp53_) {
#line 4806 "wizard.c"
		BoxesWizardPage _tmp54_;
#line 592 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp54_ = skip_to;
#line 592 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		boxes_wizard_set_page (self, _tmp54_);
#line 593 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		result = TRUE;
#line 593 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		return result;
#line 4816 "wizard.c"
	}
#line 596 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	result = FALSE;
#line 596 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	return result;
#line 4822 "wizard.c"
}


static void boxes_wizard_download_media_data_free (gpointer _data) {
	BoxesWizardDownloadMediaData* _data_;
	_data_ = _data;
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_free0 (_data_->uri);
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data_->progress);
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data_->self);
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_slice_free (BoxesWizardDownloadMediaData, _data_);
#line 4837 "wizard.c"
}


static void boxes_wizard_download_media (BoxesWizard* self, const gchar* uri, BoxesActivityProgress* progress, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesWizardDownloadMediaData* _data_;
	BoxesWizard* _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_;
	BoxesActivityProgress* _tmp3_;
	BoxesActivityProgress* _tmp4_;
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_ = g_slice_new0 (BoxesWizardDownloadMediaData);
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_task_set_task_data (_data_->_async_result, _data_, boxes_wizard_download_media_data_free);
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->self = _tmp0_;
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp1_ = uri;
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_free0 (_data_->uri);
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->uri = _tmp2_;
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp3_ = progress;
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data_->progress);
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->progress = _tmp4_;
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	boxes_wizard_download_media_co (_data_);
#line 4876 "wizard.c"
}


static void boxes_wizard_download_media_finish (BoxesWizard* self, GAsyncResult* _res_) {
	BoxesWizardDownloadMediaData* _data_;
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
#line 4884 "wizard.c"
}


static void boxes_wizard_download_media_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesWizardDownloadMediaData* _data_;
#line 604 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_ = _user_data_;
#line 604 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->_source_object_ = source_object;
#line 604 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->_res_ = _res_;
#line 604 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	boxes_wizard_download_media_co (_data_);
#line 4898 "wizard.c"
}


static gboolean boxes_wizard_download_media_co (BoxesWizardDownloadMediaData* _data_) {
#line 599 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	switch (_data_->_state_) {
#line 599 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		case 0:
#line 4907 "wizard.c"
		goto _state_0;
#line 599 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		case 1:
#line 4911 "wizard.c"
		goto _state_1;
		default:
#line 599 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		g_assert_not_reached ();
#line 4916 "wizard.c"
	}
	_state_0:
#line 600 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->_tmp0_ = _data_->progress;
#line 600 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->_tmp1_ = boxes_activity_progress_add_child_activity (_data_->_tmp0_, BOXES_WIZARD_DOWNLOAD_PROGRESS_SCALE);
#line 600 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->download_progress = _data_->_tmp1_;
#line 601 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data_->_tmp2_ = _data_->self->priv->prep_status_label;
#line 601 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	gtk_label_set_label (_data_->_tmp2_, _ ("Downloading media…"));
#line 4929 "wizard.c"
	{
#line 604 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp3_ = _data_->uri;
#line 604 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp4_ = _data_->download_progress;
#line 604 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp5_ = _data_->self->priv->prepare_cancellable;
#line 604 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_state_ = 1;
#line 604 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		boxes_downloader_fetch_media (_data_->_tmp3_, _data_->_tmp4_, _data_->_tmp5_, boxes_wizard_download_media_ready, _data_);
#line 604 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		return FALSE;
#line 4943 "wizard.c"
		_state_1:
#line 604 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp6_ = boxes_downloader_fetch_media_finish (_data_->_res_, &_data_->_inner_error_);
#line 604 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->cache_path = _data_->_tmp6_;
#line 604 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 604 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			if (g_error_matches (_data_->_inner_error_, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
#line 4953 "wizard.c"
				goto __catch144_g_io_error_cancelled;
			}
			goto __catch144_g_error;
		}
#line 605 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp7_ = _data_->cache_path;
#line 605 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp8_ = _data_->progress;
#line 605 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		boxes_wizard_prepare_downloaded_media (_data_->self, _data_->_tmp7_, _data_->_tmp8_);
#line 603 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_g_free0 (_data_->cache_path);
#line 4966 "wizard.c"
	}
	goto __finally144;
	__catch144_g_io_error_cancelled:
	{
#line 603 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->e = _data_->_inner_error_;
#line 603 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_inner_error_ = NULL;
#line 607 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp9_ = _data_->uri;
#line 607 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		g_debug ("wizard.vala:607: Cancelled downloading media '%s'!", _data_->_tmp9_);
#line 608 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		boxes_wizard_set_page (_data_->self, BOXES_WIZARD_PAGE_SOURCE);
#line 603 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_g_error_free0 (_data_->e);
#line 4983 "wizard.c"
	}
	goto __finally144;
	__catch144_g_error:
	{
#line 603 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_vala1_e = _data_->_inner_error_;
#line 603 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_inner_error_ = NULL;
#line 610 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp10_ = _data_->uri;
#line 610 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp11_ = _data_->_vala1_e;
#line 610 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp12_ = _data_->_tmp11_->message;
#line 610 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		g_warning ("wizard.vala:610: Failed downloading media '%s'! %s", _data_->_tmp10_, _data_->_tmp12_);
#line 611 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp13_ = _data_->self->priv->window;
#line 611 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp14_ = boxes_app_window_get_notificationbar (_data_->_tmp13_);
#line 611 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp15_ = _data_->_tmp14_;
#line 611 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp16_ = boxes_notificationbar_display_error (_data_->_tmp15_, _ ("Download failed."), BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 611 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data_->_tmp17_ = _data_->_tmp16_;
#line 611 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (_data_->_tmp17_);
#line 612 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		boxes_wizard_set_page (_data_->self, BOXES_WIZARD_PAGE_SOURCE);
#line 603 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_g_error_free0 (_data_->_vala1_e);
#line 5016 "wizard.c"
	}
	__finally144:
#line 603 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 603 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (_data_->download_progress);
#line 603 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 603 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		g_clear_error (&_data_->_inner_error_);
#line 603 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		g_object_unref (_data_->_async_result);
#line 603 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		return FALSE;
#line 5031 "wizard.c"
	}
#line 599 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data_->download_progress);
#line 599 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 599 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (_data_->_state_ != 0) {
#line 599 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		while (g_task_get_completed (_data_->_async_result) != TRUE) {
#line 599 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 5043 "wizard.c"
		}
	}
#line 599 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_object_unref (_data_->_async_result);
#line 599 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	return FALSE;
#line 5050 "wizard.c"
}


static void boxes_wizard_prepare_downloaded_media (BoxesWizard* self, const gchar* cache_path, BoxesActivityProgress* progress) {
	BoxesWizardSource* _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	BoxesActivityProgress* _tmp4_;
#line 616 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 616 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_return_if_fail (cache_path != NULL);
#line 616 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_return_if_fail (progress != NULL);
#line 617 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	boxes_wizard_cleanup (self);
#line 620 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->wizard_source;
#line 620 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp1_ = cache_path;
#line 620 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp2_ = g_strconcat ("file://", _tmp1_, NULL);
#line 620 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp3_ = _tmp2_;
#line 620 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	boxes_wizard_source_set_uri (_tmp0_, _tmp3_);
#line 620 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_free0 (_tmp3_);
#line 621 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp4_ = progress;
#line 621 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	boxes_wizard_prepare (self, _tmp4_);
#line 5084 "wizard.c"
}


static void _boxes_wizard_cancel_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 629 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	boxes_wizard_cancel ((BoxesWizard*) self);
#line 5091 "wizard.c"
}


static void __lambda147_ (BoxesWizard* self) {
	GCancellable* _tmp0_;
	BoxesWizardPage _tmp1_;
	BoxesWizardPage _tmp2_;
#line 632 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->prepare_cancellable;
#line 632 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_cancellable_cancel (_tmp0_);
#line 634 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp1_ = boxes_wizard_get_page (self);
#line 634 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp2_ = _tmp1_;
#line 634 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	boxes_wizard_set_page (self, _tmp2_ - 1);
#line 5109 "wizard.c"
}


static void ___lambda147__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 631 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	__lambda147_ ((BoxesWizard*) self);
#line 5116 "wizard.c"
}


static void __lambda148_ (BoxesWizard* self) {
	BoxesWizardPage _tmp0_;
	BoxesWizardPage _tmp1_;
#line 638 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp0_ = boxes_wizard_get_page (self);
#line 638 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp1_ = _tmp0_;
#line 638 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	boxes_wizard_set_page (self, _tmp1_ + 1);
#line 5129 "wizard.c"
}


static void ___lambda148__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 637 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	__lambda148_ ((BoxesWizard*) self);
#line 5136 "wizard.c"
}


static void __lambda149_ (BoxesWizard* self) {
#line 643 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	boxes_wizard_set_page (self, BOXES_WIZARD_PAGE_LAST);
#line 5143 "wizard.c"
}


static void ___lambda149__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 642 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	__lambda149_ ((BoxesWizard*) self);
#line 5150 "wizard.c"
}


void boxes_wizard_setup_ui (BoxesWizard* self, BoxesAppWindow* window, BoxesWizardWindow* wizard_window) {
	BoxesAppWindow* _tmp0_;
	BoxesAppWindow* _tmp1_;
	BoxesWizardWindow* _tmp2_;
	BoxesWizardWindow* _tmp3_;
	BoxesWizardToolbar* _tmp4_;
	GtkButton* _tmp5_;
	GtkButton* _tmp6_;
	GtkButton* _tmp7_;
	BoxesWizardWindow* _tmp8_;
	BoxesWizardToolbar* _tmp9_;
	GtkButton* _tmp10_;
	GtkButton* _tmp11_;
	GtkButton* _tmp12_;
	BoxesWizardWindow* _tmp13_;
	BoxesWizardToolbar* _tmp14_;
	GtkButton* _tmp15_;
	GtkButton* _tmp16_;
	GtkButton* _tmp17_;
	GtkButton* _tmp18_;
	GtkButton* _tmp19_;
	BoxesWizardWindow* _tmp20_;
	BoxesWizardToolbar* _tmp21_;
	GtkButton* _tmp22_;
	GtkButton* _tmp23_;
	GtkButton* _tmp24_;
	BoxesWizardSource* _tmp25_;
	BoxesAppWindow* _tmp26_;
#line 624 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 624 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_return_if_fail (window != NULL);
#line 624 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_return_if_fail (wizard_window != NULL);
#line 625 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp0_ = window;
#line 625 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 625 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->window);
#line 625 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	self->priv->window = _tmp1_;
#line 626 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp2_ = wizard_window;
#line 626 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	self->priv->wizard_window = _tmp2_;
#line 628 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp3_ = wizard_window;
#line 628 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp4_ = _tmp3_->topbar;
#line 628 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp5_ = _tmp4_->cancel_btn;
#line 628 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp6_ = _g_object_ref0 (_tmp5_);
#line 628 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->cancel_button);
#line 628 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	self->priv->cancel_button = _tmp6_;
#line 629 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp7_ = self->priv->cancel_button;
#line 629 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_signal_connect_object (_tmp7_, "clicked", (GCallback) _boxes_wizard_cancel_gtk_button_clicked, self, 0);
#line 630 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp8_ = wizard_window;
#line 630 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp9_ = _tmp8_->topbar;
#line 630 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp10_ = _tmp9_->back_btn;
#line 630 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp11_ = _g_object_ref0 (_tmp10_);
#line 630 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->back_button);
#line 630 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	self->priv->back_button = _tmp11_;
#line 631 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp12_ = self->priv->back_button;
#line 631 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_signal_connect_object (_tmp12_, "clicked", (GCallback) ___lambda147__gtk_button_clicked, self, 0);
#line 636 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp13_ = wizard_window;
#line 636 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp14_ = _tmp13_->topbar;
#line 636 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp15_ = _tmp14_->continue_btn;
#line 636 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp16_ = _g_object_ref0 (_tmp15_);
#line 636 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->continue_button);
#line 636 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	self->priv->continue_button = _tmp16_;
#line 637 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp17_ = self->priv->continue_button;
#line 637 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_signal_connect_object (_tmp17_, "clicked", (GCallback) ___lambda148__gtk_button_clicked, self, 0);
#line 640 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp18_ = self->priv->continue_button;
#line 640 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp19_ = _g_object_ref0 (_tmp18_);
#line 640 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->next_button);
#line 640 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	self->priv->next_button = _tmp19_;
#line 641 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp20_ = wizard_window;
#line 641 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp21_ = _tmp20_->topbar;
#line 641 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp22_ = _tmp21_->create_btn;
#line 641 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp23_ = _g_object_ref0 (_tmp22_);
#line 641 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->create_button);
#line 641 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	self->priv->create_button = _tmp23_;
#line 642 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp24_ = self->priv->create_button;
#line 642 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_signal_connect_object (_tmp24_, "clicked", (GCallback) ___lambda149__gtk_button_clicked, self, 0);
#line 646 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp25_ = self->priv->wizard_source;
#line 646 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp26_ = window;
#line 646 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	boxes_wizard_source_setup_ui (_tmp25_, _tmp26_);
#line 5278 "wizard.c"
}


void boxes_wizard_open_with_uri (BoxesWizard* self, const gchar* uri, gboolean skip_review_for_live) {
	BoxesAppWindow* _tmp0_;
	gboolean _tmp1_;
	BoxesWizardSource* _tmp2_;
	BoxesWizardSource* _tmp3_;
	const gchar* _tmp4_;
#line 649 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 649 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_return_if_fail (uri != NULL);
#line 650 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->window;
#line 650 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	boxes_ui_set_state ((BoxesUI*) _tmp0_, BOXES_UI_STATE_WIZARD);
#line 651 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp1_ = skip_review_for_live;
#line 651 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	self->priv->skip_review_for_live = _tmp1_;
#line 653 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	boxes_wizard_set_page (self, BOXES_WIZARD_PAGE_SOURCE);
#line 654 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp2_ = self->priv->wizard_source;
#line 654 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	boxes_wizard_source_set_page (_tmp2_, BOXES_SOURCE_PAGE_URL);
#line 655 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp3_ = self->priv->wizard_source;
#line 655 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp4_ = uri;
#line 655 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	boxes_wizard_source_set_uri (_tmp3_, _tmp4_);
#line 656 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	boxes_wizard_set_page (self, BOXES_WIZARD_PAGE_PREPARATION);
#line 5314 "wizard.c"
}


void boxes_wizard_cancel (BoxesWizard* self) {
	BoxesWizardSource* _tmp0_;
	BoxesAppWindow* _tmp1_;
#line 659 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 660 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	boxes_wizard_cleanup (self);
#line 661 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->wizard_source;
#line 661 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	boxes_wizard_source_set_page (_tmp0_, BOXES_SOURCE_PAGE_MAIN);
#line 662 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp1_ = self->priv->window;
#line 662 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	boxes_ui_set_state ((BoxesUI*) _tmp1_, BOXES_UI_STATE_COLLECTION);
#line 5333 "wizard.c"
}


static void boxes_wizard_ui_state_changed (BoxesWizard* self) {
	BoxesUIState _tmp0_;
	BoxesUIState _tmp1_;
	BoxesWizardSource* _tmp2_;
	BoxesWizardSource* _tmp3_;
#line 665 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 666 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp0_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 666 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp1_ = _tmp0_;
#line 666 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (_tmp1_ != BOXES_UI_STATE_WIZARD) {
#line 667 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		return;
#line 5352 "wizard.c"
	}
#line 669 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp2_ = self->priv->wizard_source;
#line 669 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	boxes_wizard_source_set_uri (_tmp2_, "");
#line 670 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp3_ = self->priv->wizard_source;
#line 670 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp3_->libvirt_sys_import = FALSE;
#line 671 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	boxes_wizard_set_page (self, BOXES_WIZARD_PAGE_SOURCE);
#line 5364 "wizard.c"
}


static void boxes_wizard_destroy_machine (BoxesWizard* self) {
	GCancellable* _tmp0_;
	BoxesMachine* _tmp2_;
#line 674 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 675 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->review_cancellable;
#line 675 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (_tmp0_ != NULL) {
#line 5377 "wizard.c"
		GCancellable* _tmp1_;
#line 676 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp1_ = self->priv->review_cancellable;
#line 676 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		g_cancellable_cancel (_tmp1_);
#line 5383 "wizard.c"
	}
#line 678 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp2_ = self->priv->_machine;
#line 678 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (_tmp2_ != NULL) {
#line 5389 "wizard.c"
		BoxesApp* _tmp3_;
		BoxesMachine* _tmp4_;
#line 679 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp3_ = boxes_app_app;
#line 679 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp4_ = self->priv->_machine;
#line 679 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		boxes_app_delete_machine (_tmp3_, _tmp4_, TRUE);
#line 680 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		boxes_wizard_set_machine (self, NULL);
#line 5400 "wizard.c"
	}
}


BoxesWizard* boxes_wizard_construct (GType object_type) {
	BoxesWizard * self = NULL;
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	self = (BoxesWizard*) g_object_new (object_type, NULL);
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	return self;
#line 5411 "wizard.c"
}


BoxesWizard* boxes_wizard_new (void) {
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	return boxes_wizard_construct (BOXES_TYPE_WIZARD);
#line 5418 "wizard.c"
}


static BoxesUIState boxes_wizard_real_get_previous_ui_state (BoxesUI* base) {
	BoxesUIState result;
	BoxesWizard* self;
	BoxesUIState _tmp0_;
#line 18 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	self = (BoxesWizard*) base;
#line 18 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->_previous_ui_state;
#line 18 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	result = _tmp0_;
#line 18 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	return result;
#line 5434 "wizard.c"
}


static void boxes_wizard_real_set_previous_ui_state (BoxesUI* base, BoxesUIState value) {
	BoxesWizard* self;
#line 18 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	self = (BoxesWizard*) base;
#line 18 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (boxes_wizard_real_get_previous_ui_state (base) != value) {
#line 5444 "wizard.c"
		BoxesUIState _tmp0_;
#line 18 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp0_ = value;
#line 18 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		self->priv->_previous_ui_state = _tmp0_;
#line 18 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		g_object_notify_by_pspec ((GObject *) self, boxes_wizard_properties[BOXES_WIZARD_PREVIOUS_UI_STATE]);
#line 5452 "wizard.c"
	}
}


static BoxesUIState boxes_wizard_real_get_ui_state (BoxesUI* base) {
	BoxesUIState result;
	BoxesWizard* self;
	BoxesUIState _tmp0_;
#line 19 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	self = (BoxesWizard*) base;
#line 19 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->_ui_state;
#line 19 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	result = _tmp0_;
#line 19 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	return result;
#line 5469 "wizard.c"
}


static void boxes_wizard_real_set_ui_state (BoxesUI* base, BoxesUIState value) {
	BoxesWizard* self;
#line 19 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	self = (BoxesWizard*) base;
#line 19 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (boxes_wizard_real_get_ui_state (base) != value) {
#line 5479 "wizard.c"
		BoxesUIState _tmp0_;
#line 19 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp0_ = value;
#line 19 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		self->priv->_ui_state = _tmp0_;
#line 19 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		g_object_notify_by_pspec ((GObject *) self, boxes_wizard_properties[BOXES_WIZARD_UI_STATE]);
#line 5487 "wizard.c"
	}
}


BoxesMachine* boxes_wizard_get_machine (BoxesWizard* self) {
	BoxesMachine* result;
	BoxesMachine* _tmp0_;
#line 53 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 53 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->_machine;
#line 53 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	result = _tmp0_;
#line 53 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	return result;
#line 5503 "wizard.c"
}


void boxes_wizard_set_machine (BoxesWizard* self, BoxesMachine* value) {
#line 53 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 53 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (boxes_wizard_get_machine (self) != value) {
#line 5512 "wizard.c"
		BoxesMachine* _tmp0_;
		BoxesMachine* _tmp1_;
#line 53 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp0_ = value;
#line 53 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp1_ = _g_object_ref0 (_tmp0_);
#line 53 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (self->priv->_machine);
#line 53 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		self->priv->_machine = _tmp1_;
#line 53 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		g_object_notify_by_pspec ((GObject *) self, boxes_wizard_properties[BOXES_WIZARD_MACHINE]);
#line 5525 "wizard.c"
	}
}


static BoxesLibvirtMachine* boxes_wizard_get_libvirt_machine (BoxesWizard* self) {
	BoxesLibvirtMachine* result;
	BoxesMachine* _tmp0_;
#line 54 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 54 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->_machine;
#line 54 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	result = G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, BOXES_TYPE_LIBVIRT_MACHINE) ? ((BoxesLibvirtMachine*) _tmp0_) : NULL;
#line 54 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	return result;
#line 5541 "wizard.c"
}


BoxesWizardPage boxes_wizard_get_page (BoxesWizard* self) {
	BoxesWizardPage result;
	BoxesWizardPage _tmp0_;
#line 62 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 62 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->_page;
#line 62 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	result = _tmp0_;
#line 62 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	return result;
#line 5556 "wizard.c"
}


static void _boxes_wizard_page_____lambda144_ (BoxesWizard* self, GObject* obj, GAsyncResult* _result_) {
	GtkButton* _tmp0_;
	GtkButton* _tmp1_;
	GAsyncResult* _tmp2_;
	gboolean _tmp3_;
#line 101 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_return_if_fail (_result_ != NULL);
#line 102 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->next_button;
#line 102 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp0_, TRUE);
#line 103 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp1_ = self->priv->create_button;
#line 103 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	gtk_widget_grab_focus ((GtkWidget*) _tmp1_);
#line 104 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp2_ = _result_;
#line 104 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp3_ = boxes_wizard_review_finish (self, _tmp2_);
#line 104 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (!_tmp3_) {
#line 5581 "wizard.c"
		BoxesWizardPage _tmp4_;
		BoxesWizardPage _tmp5_;
#line 105 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp4_ = boxes_wizard_get_page (self);
#line 105 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp5_ = _tmp4_;
#line 105 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		boxes_wizard_set_page (self, _tmp5_ - 1);
#line 5590 "wizard.c"
	}
}


static void __boxes_wizard_page_____lambda144__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 101 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_boxes_wizard_page_____lambda144_ ((BoxesWizard*) self, source_object, res);
#line 101 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_object_unref (self);
#line 5600 "wizard.c"
}


static void _boxes_wizard_page_____lambda146_ (BoxesWizard* self, GObject* obj, GAsyncResult* _result_) {
	GAsyncResult* _tmp0_;
	gboolean _tmp1_;
#line 110 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_return_if_fail (_result_ != NULL);
#line 111 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp0_ = _result_;
#line 111 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp1_ = boxes_wizard_create_finish (self, _tmp0_);
#line 111 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (_tmp1_) {
#line 5615 "wizard.c"
		BoxesAppWindow* _tmp2_;
		BoxesWizardSource* _tmp3_;
#line 112 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp2_ = self->priv->window;
#line 112 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		boxes_ui_set_state ((BoxesUI*) _tmp2_, BOXES_UI_STATE_COLLECTION);
#line 113 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp3_ = self->priv->wizard_source;
#line 113 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		boxes_wizard_source_set_page (_tmp3_, BOXES_SOURCE_PAGE_MAIN);
#line 5626 "wizard.c"
	} else {
		BoxesAppWindow* _tmp4_;
		BoxesNotificationbar* _tmp5_;
		BoxesNotificationbar* _tmp6_;
		BoxesNotification* _tmp7_;
		BoxesNotification* _tmp8_;
#line 115 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp4_ = self->priv->window;
#line 115 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp5_ = boxes_app_window_get_notificationbar (_tmp4_);
#line 115 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp6_ = _tmp5_;
#line 115 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp7_ = boxes_notificationbar_display_error (_tmp6_, _ ("Box creation failed"), BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 115 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp8_ = _tmp7_;
#line 115 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (_tmp8_);
#line 5645 "wizard.c"
	}
}


static void __boxes_wizard_page_____lambda146__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 110 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_boxes_wizard_page_____lambda146_ ((BoxesWizard*) self, source_object, res);
#line 110 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_object_unref (self);
#line 5655 "wizard.c"
}


void boxes_wizard_set_page (BoxesWizard* self, BoxesWizardPage value) {
	gboolean forwards = FALSE;
	BoxesWizardPage _tmp0_;
	BoxesWizardPage _tmp1_;
	BoxesWizardPage _tmp2_;
	BoxesWizardPage _tmp3_;
	gboolean _tmp14_;
	BoxesWizardPage _tmp33_;
	gboolean _tmp34_;
	BoxesWizardPage _tmp35_;
	GtkButton* _tmp36_;
	BoxesWizardPage _tmp37_;
	BoxesWizardWindow* _tmp38_;
	BoxesWizardToolbar* _tmp39_;
	BoxesWizardPage _tmp40_;
	BoxesWizardPage _tmp41_;
	const gchar* _tmp42_;
	BoxesWizardPage _tmp43_;
#line 63 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 64 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp0_ = value;
#line 64 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp1_ = boxes_wizard_get_page (self);
#line 64 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp2_ = _tmp1_;
#line 64 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	forwards = _tmp0_ > _tmp2_;
#line 66 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp3_ = value;
#line 66 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	switch (_tmp3_) {
#line 66 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		case BOXES_WIZARD_PAGE_SOURCE:
#line 5693 "wizard.c"
		{
			GtkButton* _tmp4_;
			GtkButton* _tmp5_;
			GtkButton* _tmp6_;
			GtkButton* _tmp7_;
			GtkButton* _tmp8_;
			GtkButton* _tmp9_;
			BoxesWizardSource* _tmp10_;
			BoxesWizardSource* _tmp11_;
			BoxesSourcePage _tmp12_;
			BoxesSourcePage _tmp13_;
#line 69 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp4_ = self->priv->create_button;
#line 69 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			gtk_widget_set_visible ((GtkWidget*) _tmp4_, FALSE);
#line 70 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp5_ = self->priv->continue_button;
#line 70 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			gtk_widget_set_visible ((GtkWidget*) _tmp5_, TRUE);
#line 71 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp6_ = self->priv->continue_button;
#line 71 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp7_ = _g_object_ref0 (_tmp6_);
#line 71 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_g_object_unref0 (self->priv->next_button);
#line 71 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			self->priv->next_button = _tmp7_;
#line 72 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp8_ = self->priv->next_button;
#line 72 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			gtk_widget_set_sensitive ((GtkWidget*) _tmp8_, TRUE);
#line 73 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp9_ = self->priv->next_button;
#line 73 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			gtk_widget_grab_focus ((GtkWidget*) _tmp9_);
#line 74 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp10_ = self->priv->wizard_source;
#line 74 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp11_ = self->priv->wizard_source;
#line 74 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp12_ = boxes_wizard_source_get_page (_tmp11_);
#line 74 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			_tmp13_ = _tmp12_;
#line 74 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			boxes_wizard_source_set_page (_tmp10_, _tmp13_);
#line 75 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			boxes_wizard_cleanup (self);
#line 76 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			break;
#line 5743 "wizard.c"
		}
		default:
#line 66 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		break;
#line 5748 "wizard.c"
	}
#line 79 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp14_ = forwards;
#line 79 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (_tmp14_) {
#line 5754 "wizard.c"
		BoxesWizardPage _tmp15_;
#line 80 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp15_ = value;
#line 80 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		switch (_tmp15_) {
#line 80 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			case BOXES_WIZARD_PAGE_SOURCE:
#line 5762 "wizard.c"
			{
				BoxesWizardSource* _tmp16_;
#line 82 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_tmp16_ = self->priv->wizard_source;
#line 82 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				boxes_wizard_source_set_page (_tmp16_, BOXES_SOURCE_PAGE_MAIN);
#line 83 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				break;
#line 5771 "wizard.c"
			}
#line 80 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			case BOXES_WIZARD_PAGE_PREPARATION:
#line 5775 "wizard.c"
			{
				BoxesActivityProgress* _tmp17_;
				BoxesActivityProgress* _tmp18_;
				gboolean _tmp19_;
				gboolean _tmp20_;
#line 86 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_tmp17_ = boxes_wizard_create_preparation_progress (self);
#line 86 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_tmp18_ = _tmp17_;
#line 86 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_tmp19_ = boxes_wizard_prepare (self, _tmp18_);
#line 86 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_tmp20_ = !_tmp19_;
#line 86 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_g_object_unref0 (_tmp18_);
#line 86 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				if (_tmp20_) {
#line 87 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					return;
#line 5795 "wizard.c"
				}
#line 88 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				break;
#line 5799 "wizard.c"
			}
#line 80 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			case BOXES_WIZARD_PAGE_SETUP:
#line 5803 "wizard.c"
			{
				gboolean _tmp21_;
#line 91 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_tmp21_ = boxes_wizard_setup (self);
#line 91 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				if (!_tmp21_) {
#line 92 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
					return;
#line 5812 "wizard.c"
				}
#line 93 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				break;
#line 5816 "wizard.c"
			}
#line 80 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			case BOXES_WIZARD_PAGE_REVIEW:
#line 5820 "wizard.c"
			{
				GtkButton* _tmp22_;
				GtkButton* _tmp23_;
				GtkButton* _tmp24_;
				GtkButton* _tmp25_;
				GtkButton* _tmp26_;
#line 96 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_tmp22_ = self->priv->continue_button;
#line 96 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				gtk_widget_set_visible ((GtkWidget*) _tmp22_, FALSE);
#line 97 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_tmp23_ = self->priv->create_button;
#line 97 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				gtk_widget_set_visible ((GtkWidget*) _tmp23_, TRUE);
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_tmp24_ = self->priv->create_button;
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_tmp25_ = _g_object_ref0 (_tmp24_);
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_g_object_unref0 (self->priv->next_button);
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				self->priv->next_button = _tmp25_;
#line 99 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_tmp26_ = self->priv->next_button;
#line 99 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				gtk_widget_set_sensitive ((GtkWidget*) _tmp26_, FALSE);
#line 101 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				boxes_wizard_review (self, __boxes_wizard_page_____lambda144__gasync_ready_callback, g_object_ref (self));
#line 107 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				break;
#line 5851 "wizard.c"
			}
#line 80 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			case BOXES_WIZARD_PAGE_LAST:
#line 5855 "wizard.c"
			{
#line 110 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				boxes_wizard_create (self, __boxes_wizard_page_____lambda146__gasync_ready_callback, g_object_ref (self));
#line 118 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				return;
#line 5861 "wizard.c"
			}
			default:
#line 80 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			break;
#line 5866 "wizard.c"
		}
	} else {
		BoxesWizardPage _tmp27_;
		BoxesWizardPage _tmp28_;
#line 121 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp27_ = boxes_wizard_get_page (self);
#line 121 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_tmp28_ = _tmp27_;
#line 121 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		switch (_tmp28_) {
#line 121 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			case BOXES_WIZARD_PAGE_REVIEW:
#line 5879 "wizard.c"
			{
				GtkButton* _tmp29_;
				GtkButton* _tmp30_;
				GtkButton* _tmp31_;
				GtkButton* _tmp32_;
#line 123 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_tmp29_ = self->priv->create_button;
#line 123 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				gtk_widget_set_visible ((GtkWidget*) _tmp29_, FALSE);
#line 124 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_tmp30_ = self->priv->continue_button;
#line 124 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				gtk_widget_set_visible ((GtkWidget*) _tmp30_, TRUE);
#line 125 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_tmp31_ = self->priv->continue_button;
#line 125 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_tmp32_ = _g_object_ref0 (_tmp31_);
#line 125 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_g_object_unref0 (self->priv->next_button);
#line 125 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				self->priv->next_button = _tmp32_;
#line 126 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				boxes_wizard_destroy_machine (self);
#line 127 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				break;
#line 5905 "wizard.c"
			}
			default:
#line 121 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			break;
#line 5910 "wizard.c"
		}
	}
#line 131 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp33_ = value;
#line 131 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp34_ = boxes_wizard_skip_page (self, _tmp33_);
#line 131 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (_tmp34_) {
#line 132 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		return;
#line 5921 "wizard.c"
	}
#line 134 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp35_ = value;
#line 134 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	self->priv->_page = _tmp35_;
#line 135 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp36_ = self->priv->back_button;
#line 135 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp37_ = value;
#line 135 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp36_, _tmp37_ != BOXES_WIZARD_PAGE_SOURCE);
#line 136 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp38_ = self->priv->wizard_window;
#line 136 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp39_ = _tmp38_->topbar;
#line 136 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp40_ = value;
#line 136 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	boxes_wizard_toolbar_set_title_for_page (_tmp39_, _tmp40_);
#line 137 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp41_ = value;
#line 137 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp42_ = BOXES_WIZARD_page_names[_tmp41_];
#line 137 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	gtk_stack_set_visible_child_name ((GtkStack*) self, _tmp42_);
#line 139 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp43_ = value;
#line 139 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (_tmp43_ == BOXES_WIZARD_PAGE_SOURCE) {
#line 140 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		boxes_wizard_wizard_source_update_next (self);
#line 5953 "wizard.c"
	}
#line 63 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_object_notify_by_pspec ((GObject *) self, boxes_wizard_properties[BOXES_WIZARD_PAGE]);
#line 5957 "wizard.c"
}


static void _boxes_wizard_wizard_source_update_next_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 190 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	boxes_wizard_wizard_source_update_next ((BoxesWizard*) self);
#line 5964 "wizard.c"
}


static void _boxes_wizard_wizard_source_update_next_gtk_editable_changed (GtkEditable* _sender, gpointer self) {
#line 192 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	boxes_wizard_wizard_source_update_next ((BoxesWizard*) self);
#line 5971 "wizard.c"
}


static void _boxes_wizard_ui_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 193 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	boxes_wizard_ui_state_changed ((BoxesWizard*) self);
#line 5978 "wizard.c"
}


static void _boxes_wizard___lambda150_ (BoxesWizard* self) {
#line 196 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	boxes_wizard_set_page (self, BOXES_WIZARD_PAGE_PREPARATION);
#line 5985 "wizard.c"
}


static void __boxes_wizard___lambda150__boxes_wizard_source_activated (BoxesWizardSource* _sender, gpointer self) {
#line 195 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_boxes_wizard___lambda150_ ((BoxesWizard*) self);
#line 5992 "wizard.c"
}


static GObject * boxes_wizard_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	BoxesWizard * self;
	BoxesMediaManager* _tmp0_;
	BoxesWizardSource* _tmp1_;
	BoxesWizardSource* _tmp2_;
	BoxesWizardSource* _tmp3_;
	GtkEntry* _tmp4_;
	BoxesWizardSource* _tmp5_;
#line 188 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	parent_class = G_OBJECT_CLASS (boxes_wizard_parent_class);
#line 188 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 188 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_WIZARD, BoxesWizard);
#line 189 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp0_ = boxes_media_manager_get_instance ();
#line 189 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->media_manager);
#line 189 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	self->priv->media_manager = _tmp0_;
#line 190 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp1_ = self->priv->wizard_source;
#line 190 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_signal_connect_object ((GObject*) _tmp1_, "notify::page", (GCallback) _boxes_wizard_wizard_source_update_next_g_object_notify, self, 0);
#line 191 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp2_ = self->priv->wizard_source;
#line 191 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_signal_connect_object ((GObject*) _tmp2_, "notify::selected", (GCallback) _boxes_wizard_wizard_source_update_next_g_object_notify, self, 0);
#line 192 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp3_ = self->priv->wizard_source;
#line 192 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp4_ = _tmp3_->url_entry;
#line 192 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_signal_connect_object ((GtkEditable*) _tmp4_, "changed", (GCallback) _boxes_wizard_wizard_source_update_next_gtk_editable_changed, self, 0);
#line 193 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_signal_connect_object ((GObject*) self, "notify::ui-state", (GCallback) _boxes_wizard_ui_state_changed_g_object_notify, self, 0);
#line 195 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp5_ = self->priv->wizard_source;
#line 195 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_signal_connect_object (_tmp5_, "activated", (GCallback) __boxes_wizard___lambda150__boxes_wizard_source_activated, self, 0);
#line 200 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	gtk_stack_set_transition_type ((GtkStack*) self, GTK_STACK_TRANSITION_TYPE_SLIDE_LEFT_RIGHT);
#line 188 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	return obj;
#line 6042 "wizard.c"
}


static void boxes_wizard_class_init (BoxesWizardClass * klass) {
	gint BoxesWizard_private_offset;
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	boxes_wizard_parent_class = g_type_class_peek_parent (klass);
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_type_class_add_private (klass, sizeof (BoxesWizardPrivate));
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_wizard_get_property;
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_wizard_set_property;
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	G_OBJECT_CLASS (klass)->constructor = boxes_wizard_constructor;
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_wizard_finalize;
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_WIZARD_PREVIOUS_UI_STATE, boxes_wizard_properties[BOXES_WIZARD_PREVIOUS_UI_STATE] = g_param_spec_enum ("previous-ui-state", "previous-ui-state", "previous-ui-state", BOXES_TYPE_UI_STATE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_WIZARD_UI_STATE, boxes_wizard_properties[BOXES_WIZARD_UI_STATE] = g_param_spec_enum ("ui-state", "ui-state", "ui-state", BOXES_TYPE_UI_STATE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_WIZARD_MACHINE, boxes_wizard_properties[BOXES_WIZARD_MACHINE] = g_param_spec_object ("machine", "machine", "machine", BOXES_TYPE_MACHINE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_WIZARD_PAGE, boxes_wizard_properties[BOXES_WIZARD_PAGE] = g_param_spec_enum ("page", "page", "page", BOXES_TYPE_WIZARD_PAGE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	BoxesWizard_private_offset = g_type_class_get_instance_private_offset (klass);
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Boxes/ui/wizard.ui");
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "wizard_source", FALSE, BoxesWizard_private_offset + G_STRUCT_OFFSET (BoxesWizardPrivate, wizard_source));
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "summary", FALSE, BoxesWizard_private_offset + G_STRUCT_OFFSET (BoxesWizardPrivate, summary));
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "prep_progress", FALSE, BoxesWizard_private_offset + G_STRUCT_OFFSET (BoxesWizardPrivate, prep_progress));
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "prep_media_label", FALSE, BoxesWizard_private_offset + G_STRUCT_OFFSET (BoxesWizardPrivate, prep_media_label));
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "prep_status_label", FALSE, BoxesWizard_private_offset + G_STRUCT_OFFSET (BoxesWizardPrivate, prep_status_label));
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "setup_box", FALSE, BoxesWizard_private_offset + G_STRUCT_OFFSET (BoxesWizardPrivate, setup_box));
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "review_label", FALSE, BoxesWizard_private_offset + G_STRUCT_OFFSET (BoxesWizardPrivate, review_label));
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "nokvm_infobar", FALSE, BoxesWizard_private_offset + G_STRUCT_OFFSET (BoxesWizardPrivate, nokvm_infobar));
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "installer_image", FALSE, BoxesWizard_private_offset + G_STRUCT_OFFSET (BoxesWizardPrivate, installer_image));
#line 6090 "wizard.c"
}


static void boxes_wizard_boxes_ui_interface_init (BoxesUIIface * iface) {
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	boxes_wizard_boxes_ui_parent_iface = g_type_interface_peek_parent (iface);
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	iface->get_previous_ui_state = boxes_wizard_real_get_previous_ui_state;
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	iface->set_previous_ui_state = boxes_wizard_real_set_previous_ui_state;
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	iface->get_ui_state = boxes_wizard_real_get_ui_state;
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	iface->set_ui_state = boxes_wizard_real_set_ui_state;
#line 6105 "wizard.c"
}


static void boxes_wizard_instance_init (BoxesWizard * self) {
	GCancellable* _tmp0_;
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	self->priv = BOXES_WIZARD_GET_PRIVATE (self);
#line 56 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp0_ = g_cancellable_new ();
#line 56 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	self->priv->prepare_cancellable = _tmp0_;
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_type_ensure (BOXES_TYPE_WIZARD_SOURCE);
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_type_ensure (BOXES_TYPE_WIZARD_SUMMARY);
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 6123 "wizard.c"
}


static void boxes_wizard_finalize (GObject * obj) {
	BoxesWizard * self;
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_WIZARD, BoxesWizard);
#line 21 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->cancel_button);
#line 22 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->back_button);
#line 23 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->next_button);
#line 24 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->continue_button);
#line 25 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->create_button);
#line 26 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->source);
#line 29 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->wizard_source);
#line 31 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->summary);
#line 33 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->prep_progress);
#line 35 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->prep_media_label);
#line 37 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->prep_status_label);
#line 39 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->setup_box);
#line 41 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->review_label);
#line 43 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->nokvm_infobar);
#line 45 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->installer_image);
#line 47 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->window);
#line 50 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->media_manager);
#line 52 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_boxes_vm_creator_unref0 (self->priv->vm_creator);
#line 53 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->_machine);
#line 56 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->prepare_cancellable);
#line 57 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->review_cancellable);
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	G_OBJECT_CLASS (boxes_wizard_parent_class)->finalize (obj);
#line 6175 "wizard.c"
}


GType boxes_wizard_get_type (void) {
	static volatile gsize boxes_wizard_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_wizard_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesWizardClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_wizard_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesWizard), 0, (GInstanceInitFunc) boxes_wizard_instance_init, NULL };
		static const GInterfaceInfo boxes_ui_info = { (GInterfaceInitFunc) boxes_wizard_boxes_ui_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType boxes_wizard_type_id;
		boxes_wizard_type_id = g_type_register_static (gtk_stack_get_type (), "BoxesWizard", &g_define_type_info, 0);
		g_type_add_interface_static (boxes_wizard_type_id, BOXES_TYPE_UI, &boxes_ui_info);
		g_once_init_leave (&boxes_wizard_type_id__volatile, boxes_wizard_type_id);
	}
	return boxes_wizard_type_id__volatile;
}


static void _vala_boxes_wizard_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesWizard * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_WIZARD, BoxesWizard);
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	switch (property_id) {
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		case BOXES_WIZARD_PREVIOUS_UI_STATE:
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		g_value_set_enum (value, boxes_ui_get_previous_ui_state ((BoxesUI*) self));
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		break;
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		case BOXES_WIZARD_UI_STATE:
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		g_value_set_enum (value, boxes_ui_get_ui_state ((BoxesUI*) self));
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		break;
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		case BOXES_WIZARD_MACHINE:
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		g_value_set_object (value, boxes_wizard_get_machine (self));
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		break;
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		case BOXES_WIZARD_PAGE:
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		g_value_set_enum (value, boxes_wizard_get_page (self));
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		break;
#line 6222 "wizard.c"
		default:
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		break;
#line 6228 "wizard.c"
	}
}


static void _vala_boxes_wizard_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesWizard * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_WIZARD, BoxesWizard);
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	switch (property_id) {
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		case BOXES_WIZARD_PREVIOUS_UI_STATE:
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		boxes_ui_set_previous_ui_state ((BoxesUI*) self, g_value_get_enum (value));
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		break;
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		case BOXES_WIZARD_UI_STATE:
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		boxes_ui_set_ui_state ((BoxesUI*) self, g_value_get_enum (value));
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		break;
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		case BOXES_WIZARD_MACHINE:
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		boxes_wizard_set_machine (self, g_value_get_object (value));
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		break;
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		case BOXES_WIZARD_PAGE:
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		boxes_wizard_set_page (self, g_value_get_enum (value));
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		break;
#line 6262 "wizard.c"
		default:
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 13 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		break;
#line 6268 "wizard.c"
	}
}


void boxes_wizard_summary_add_property (BoxesWizardSummary* self, const gchar* name, const gchar* value) {
	const gchar* _tmp0_;
	GtkLabel* label_name = NULL;
	const gchar* _tmp1_;
	GtkLabel* _tmp2_;
	GtkLabel* _tmp3_;
	GtkStyleContext* _tmp4_;
	GtkLabel* _tmp5_;
	GtkLabel* _tmp6_;
	gint _tmp7_;
	GtkLabel* label_value = NULL;
	const gchar* _tmp8_;
	GtkLabel* _tmp9_;
	GtkLabel* _tmp10_;
	GtkLabel* _tmp11_;
	GtkLabel* _tmp12_;
	GtkLabel* _tmp13_;
	gint _tmp14_;
	gint _tmp15_;
#line 695 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 695 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_return_if_fail (name != NULL);
#line 696 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp0_ = value;
#line 696 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (_tmp0_ == NULL) {
#line 697 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		return;
#line 6302 "wizard.c"
	}
#line 699 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp1_ = name;
#line 699 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp2_ = (GtkLabel*) gtk_label_new (_tmp1_);
#line 699 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp2_);
#line 699 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	label_name = _tmp2_;
#line 700 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp3_ = label_name;
#line 700 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp4_ = gtk_widget_get_style_context ((GtkWidget*) _tmp3_);
#line 700 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	gtk_style_context_add_class (_tmp4_, "dim-label");
#line 701 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp5_ = label_name;
#line 701 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	gtk_widget_set_halign ((GtkWidget*) _tmp5_, GTK_ALIGN_END);
#line 702 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp6_ = label_name;
#line 702 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp7_ = self->priv->current_row;
#line 702 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	gtk_grid_attach ((GtkGrid*) self, (GtkWidget*) _tmp6_, 0, _tmp7_, 1, 1);
#line 704 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp8_ = value;
#line 704 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp9_ = (GtkLabel*) gtk_label_new (_tmp8_);
#line 704 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp9_);
#line 704 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	label_value = _tmp9_;
#line 705 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp10_ = label_value;
#line 705 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	gtk_label_set_ellipsize (_tmp10_, PANGO_ELLIPSIZE_END);
#line 706 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp11_ = label_value;
#line 706 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	gtk_label_set_max_width_chars (_tmp11_, 32);
#line 707 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp12_ = label_value;
#line 707 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	gtk_widget_set_halign ((GtkWidget*) _tmp12_, GTK_ALIGN_START);
#line 708 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp13_ = label_value;
#line 708 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp14_ = self->priv->current_row;
#line 708 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	gtk_grid_attach ((GtkGrid*) self, (GtkWidget*) _tmp13_, 1, _tmp14_, 1, 1);
#line 710 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp15_ = self->priv->current_row;
#line 710 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	self->priv->current_row = _tmp15_ + 1;
#line 711 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	gtk_widget_show_all ((GtkWidget*) self);
#line 695 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (label_value);
#line 695 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (label_name);
#line 6364 "wizard.c"
}


static Block103Data* block103_data_ref (Block103Data* _data103_) {
#line 714 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_atomic_int_inc (&_data103_->_ref_count_);
#line 714 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	return _data103_;
#line 6373 "wizard.c"
}


static void block103_data_unref (void * _userdata_) {
	Block103Data* _data103_;
	_data103_ = (Block103Data*) _userdata_;
#line 714 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (g_atomic_int_dec_and_test (&_data103_->_ref_count_)) {
#line 6382 "wizard.c"
		BoxesWizardSummary* self;
#line 714 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		self = _data103_->self;
#line 714 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (self);
#line 714 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		g_slice_free (Block103Data, _data103_);
#line 6390 "wizard.c"
	}
}


static void __lambda72_ (Block103Data* _data103_) {
	BoxesWizardSummary* self;
	BoxesWizardSummaryCustomizeFunc _tmp0_;
	void* _tmp0__target;
#line 723 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	self = _data103_->self;
#line 723 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp0_ = _data103_->customize_func;
#line 723 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp0__target = _data103_->customize_func_target;
#line 723 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp0_ (_tmp0__target);
#line 6407 "wizard.c"
}


static void ___lambda72__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 723 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	__lambda72_ (self);
#line 6414 "wizard.c"
}


void boxes_wizard_summary_append_customize_button (BoxesWizardSummary* self, BoxesWizardSummaryCustomizeFunc customize_func, void* customize_func_target) {
	Block103Data* _data103_;
	BoxesWizardSummaryCustomizeFunc _tmp0_;
	void* _tmp0__target;
	gint _tmp1_;
	GtkButton* button = NULL;
	GtkButton* _tmp2_;
	GtkButton* _tmp3_;
	gint _tmp4_;
	GtkButton* _tmp5_;
	GtkButton* _tmp6_;
#line 714 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 714 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data103_ = g_slice_new0 (Block103Data);
#line 714 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data103_->_ref_count_ = 1;
#line 714 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data103_->self = g_object_ref (self);
#line 714 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp0_ = customize_func;
#line 714 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp0__target = customize_func_target;
#line 714 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data103_->customize_func = _tmp0_;
#line 714 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data103_->customize_func_target = _tmp0__target;
#line 716 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp1_ = self->priv->current_row;
#line 716 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	if (_tmp1_ == 0) {
#line 717 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		block103_data_unref (_data103_);
#line 717 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_data103_ = NULL;
#line 717 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		return;
#line 6455 "wizard.c"
	}
#line 719 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp2_ = (GtkButton*) gtk_button_new_with_mnemonic (_ ("C_ustomize…"));
#line 719 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp2_);
#line 719 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	button = _tmp2_;
#line 720 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp3_ = button;
#line 720 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp4_ = self->priv->current_row;
#line 720 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	gtk_grid_attach ((GtkGrid*) self, (GtkWidget*) _tmp3_, 2, _tmp4_ - 1, 1, 1);
#line 721 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp5_ = button;
#line 721 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	gtk_widget_show ((GtkWidget*) _tmp5_);
#line 723 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp6_ = button;
#line 723 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_signal_connect_data (_tmp6_, "clicked", (GCallback) ___lambda72__gtk_button_clicked, block103_data_ref (_data103_), (GClosureNotify) block103_data_unref, 0);
#line 714 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (button);
#line 714 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	block103_data_unref (_data103_);
#line 714 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_data103_ = NULL;
#line 6483 "wizard.c"
}


void boxes_wizard_summary_clear (BoxesWizardSummary* self) {
	GList* _tmp0_;
#line 726 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 727 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	_tmp0_ = gtk_container_get_children ((GtkContainer*) self);
#line 6493 "wizard.c"
	{
		GList* child_collection = NULL;
		GList* child_it = NULL;
#line 727 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		child_collection = _tmp0_;
#line 727 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		for (child_it = child_collection; child_it != NULL; child_it = child_it->next) {
#line 6501 "wizard.c"
			GtkWidget* child = NULL;
#line 727 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
			child = (GtkWidget*) child_it->data;
#line 6505 "wizard.c"
			{
				GtkWidget* _tmp1_;
#line 728 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				_tmp1_ = child;
#line 728 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
				gtk_container_remove ((GtkContainer*) self, _tmp1_);
#line 6512 "wizard.c"
			}
		}
#line 727 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
		_g_list_free0 (child_collection);
#line 6517 "wizard.c"
	}
#line 731 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	self->priv->current_row = 0;
#line 6521 "wizard.c"
}


BoxesWizardSummary* boxes_wizard_summary_construct (GType object_type) {
	BoxesWizardSummary * self = NULL;
#line 686 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	self = (BoxesWizardSummary*) g_object_new (object_type, NULL);
#line 686 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	return self;
#line 6531 "wizard.c"
}


BoxesWizardSummary* boxes_wizard_summary_new (void) {
#line 686 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	return boxes_wizard_summary_construct (BOXES_TYPE_WIZARD_SUMMARY);
#line 6538 "wizard.c"
}


static GObject * boxes_wizard_summary_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	BoxesWizardSummary * self;
#line 691 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	parent_class = G_OBJECT_CLASS (boxes_wizard_summary_parent_class);
#line 691 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 691 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_WIZARD_SUMMARY, BoxesWizardSummary);
#line 692 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	self->priv->current_row = 0;
#line 691 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	return obj;
#line 6556 "wizard.c"
}


static void boxes_wizard_summary_class_init (BoxesWizardSummaryClass * klass) {
	gint BoxesWizardSummary_private_offset;
#line 686 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	boxes_wizard_summary_parent_class = g_type_class_peek_parent (klass);
#line 686 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	g_type_class_add_private (klass, sizeof (BoxesWizardSummaryPrivate));
#line 686 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	G_OBJECT_CLASS (klass)->constructor = boxes_wizard_summary_constructor;
#line 686 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_wizard_summary_finalize;
#line 686 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	BoxesWizardSummary_private_offset = g_type_class_get_instance_private_offset (klass);
#line 686 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Boxes/ui/wizard-summary.ui");
#line 6574 "wizard.c"
}


static void boxes_wizard_summary_instance_init (BoxesWizardSummary * self) {
#line 686 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	self->priv = BOXES_WIZARD_SUMMARY_GET_PRIVATE (self);
#line 686 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 6583 "wizard.c"
}


static void boxes_wizard_summary_finalize (GObject * obj) {
	BoxesWizardSummary * self;
#line 686 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_WIZARD_SUMMARY, BoxesWizardSummary);
#line 686 "/home/fborges/checkout/gnome-boxes/src/wizard.vala"
	G_OBJECT_CLASS (boxes_wizard_summary_parent_class)->finalize (obj);
#line 6593 "wizard.c"
}


GType boxes_wizard_summary_get_type (void) {
	static volatile gsize boxes_wizard_summary_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_wizard_summary_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesWizardSummaryClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_wizard_summary_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesWizardSummary), 0, (GInstanceInitFunc) boxes_wizard_summary_instance_init, NULL };
		GType boxes_wizard_summary_type_id;
		boxes_wizard_summary_type_id = g_type_register_static (gtk_grid_get_type (), "BoxesWizardSummary", &g_define_type_info, 0);
		g_once_init_leave (&boxes_wizard_summary_type_id__volatile, boxes_wizard_summary_type_id);
	}
	return boxes_wizard_summary_type_id__volatile;
}



