/* spice-display.c generated by valac 0.37.1.4-3591e, the Vala compiler
 * generated from spice-display.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <libcommon.h>
#include <stdlib.h>
#include <string.h>
#include <spice-client.h>
#include <spice-widget.h>
#include <gio/gio.h>
#include <glib/gi18n-lib.h>
#include <glib/gstdio.h>
#include <unistd.h>
#include <sys/stat.h>
#include <sys/types.h>
#include <errno.h>
#include <libusb.h>
#include <libxml/uri.h>


#define BOXES_TYPE_IPROPERTIES_PROVIDER (boxes_iproperties_provider_get_type ())
#define BOXES_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProvider))
#define BOXES_IS_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER))
#define BOXES_IPROPERTIES_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProviderIface))

typedef struct _BoxesIPropertiesProvider BoxesIPropertiesProvider;
typedef struct _BoxesIPropertiesProviderIface BoxesIPropertiesProviderIface;

#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())

#define BOXES_TYPE_PROPERTY (boxes_property_get_type ())
#define BOXES_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTY, BoxesProperty))
#define BOXES_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTY, BoxesPropertyClass))
#define BOXES_IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTY))
#define BOXES_IS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTY))
#define BOXES_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTY, BoxesPropertyClass))

typedef struct _BoxesProperty BoxesProperty;
typedef struct _BoxesPropertyClass BoxesPropertyClass;

#define BOXES_TYPE_DISPLAY (boxes_display_get_type ())
#define BOXES_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY, BoxesDisplay))
#define BOXES_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY, BoxesDisplayClass))
#define BOXES_IS_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY))
#define BOXES_IS_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY))
#define BOXES_DISPLAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY, BoxesDisplayClass))

typedef struct _BoxesDisplay BoxesDisplay;
typedef struct _BoxesDisplayClass BoxesDisplayClass;
typedef struct _BoxesDisplayPrivate BoxesDisplayPrivate;

#define BOXES_TYPE_SPICE_DISPLAY (boxes_spice_display_get_type ())
#define BOXES_SPICE_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SPICE_DISPLAY, BoxesSpiceDisplay))
#define BOXES_SPICE_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SPICE_DISPLAY, BoxesSpiceDisplayClass))
#define BOXES_IS_SPICE_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SPICE_DISPLAY))
#define BOXES_IS_SPICE_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SPICE_DISPLAY))
#define BOXES_SPICE_DISPLAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SPICE_DISPLAY, BoxesSpiceDisplayClass))

typedef struct _BoxesSpiceDisplay BoxesSpiceDisplay;
typedef struct _BoxesSpiceDisplayClass BoxesSpiceDisplayClass;
typedef struct _BoxesSpiceDisplayPrivate BoxesSpiceDisplayPrivate;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;

#define BOXES_TYPE_SPICE_CHANNEL_HANDLER (boxes_spice_channel_handler_get_type ())
#define BOXES_SPICE_CHANNEL_HANDLER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SPICE_CHANNEL_HANDLER, BoxesSpiceChannelHandler))
#define BOXES_SPICE_CHANNEL_HANDLER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SPICE_CHANNEL_HANDLER, BoxesSpiceChannelHandlerClass))
#define BOXES_IS_SPICE_CHANNEL_HANDLER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SPICE_CHANNEL_HANDLER))
#define BOXES_IS_SPICE_CHANNEL_HANDLER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SPICE_CHANNEL_HANDLER))
#define BOXES_SPICE_CHANNEL_HANDLER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SPICE_CHANNEL_HANDLER, BoxesSpiceChannelHandlerClass))

typedef struct _BoxesSpiceChannelHandler BoxesSpiceChannelHandler;
typedef struct _BoxesSpiceChannelHandlerClass BoxesSpiceChannelHandlerClass;
enum  {
	BOXES_SPICE_DISPLAY_DUMMY_PROPERTY,
	BOXES_SPICE_DISPLAY_PROTOCOL,
	BOXES_SPICE_DISPLAY_URI,
	BOXES_SPICE_DISPLAY_CA_CERT,
	BOXES_SPICE_DISPLAY_MAIN_CHANNEL,
	BOXES_SPICE_DISPLAY_LAST_PROPERTY
};
static GParamSpec* boxes_spice_display_properties[BOXES_SPICE_DISPLAY_LAST_PROPERTY];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_hash_table_unref0(var) ((var == NULL) ? NULL : (var = (g_hash_table_unref (var), NULL)))

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())
#define _g_ptr_array_unref0(var) ((var == NULL) ? NULL : (var = (g_ptr_array_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define __vala_SpiceUsbDevice_free0(var) ((var == NULL) ? NULL : (var = (_vala_SpiceUsbDevice_free (var), NULL)))
#define _g_dir_close0(var) ((var == NULL) ? NULL : (var = (g_dir_close (var), NULL)))
typedef struct _BoxesCollectionItemPrivate BoxesCollectionItemPrivate;
typedef struct _BoxesMachinePrivate BoxesMachinePrivate;

#define BOXES_MACHINE_TYPE_CONNECT_FLAGS (boxes_machine_connect_flags_get_type ())
#define _g_list_free0(var) ((var == NULL) ? NULL : (var = (g_list_free (var), NULL)))
#define _g_variant_type_free0(var) ((var == NULL) ? NULL : (var = (g_variant_type_free (var), NULL)))
#define _g_variant_unref0(var) ((var == NULL) ? NULL : (var = (g_variant_unref (var), NULL)))
#define _g_variant_iter_free0(var) ((var == NULL) ? NULL : (var = (g_variant_iter_free (var), NULL)))
#define _g_variant_builder_unref0(var) ((var == NULL) ? NULL : (var = (g_variant_builder_unref (var), NULL)))
typedef struct _Block79Data Block79Data;
typedef struct _Block80Data Block80Data;
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))
#define _libusb_unref_device0(var) ((var == NULL) ? NULL : (var = (libusb_unref_device (var), NULL)))
#define _libusb_free_config_descriptor0(var) ((var == NULL) ? NULL : (var = (libusb_free_config_descriptor (var), NULL)))
typedef struct _Block81Data Block81Data;
typedef struct _Block82Data Block82Data;

#define BOXES_TYPE_SHARED_FOLDER_POPOVER (boxes_shared_folder_popover_get_type ())
#define BOXES_SHARED_FOLDER_POPOVER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SHARED_FOLDER_POPOVER, BoxesSharedFolderPopover))
#define BOXES_SHARED_FOLDER_POPOVER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SHARED_FOLDER_POPOVER, BoxesSharedFolderPopoverClass))
#define BOXES_IS_SHARED_FOLDER_POPOVER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SHARED_FOLDER_POPOVER))
#define BOXES_IS_SHARED_FOLDER_POPOVER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SHARED_FOLDER_POPOVER))
#define BOXES_SHARED_FOLDER_POPOVER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SHARED_FOLDER_POPOVER, BoxesSharedFolderPopoverClass))

typedef struct _BoxesSharedFolderPopover BoxesSharedFolderPopover;
typedef struct _BoxesSharedFolderPopoverClass BoxesSharedFolderPopoverClass;
typedef struct _Block83Data Block83Data;
typedef struct _BoxesSharedFolderPopoverPrivate BoxesSharedFolderPopoverPrivate;

#define BOXES_TYPE_SHARED_FOLDER_ROW (boxes_shared_folder_row_get_type ())
#define BOXES_SHARED_FOLDER_ROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SHARED_FOLDER_ROW, BoxesSharedFolderRow))
#define BOXES_SHARED_FOLDER_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SHARED_FOLDER_ROW, BoxesSharedFolderRowClass))
#define BOXES_IS_SHARED_FOLDER_ROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SHARED_FOLDER_ROW))
#define BOXES_IS_SHARED_FOLDER_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SHARED_FOLDER_ROW))
#define BOXES_SHARED_FOLDER_ROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SHARED_FOLDER_ROW, BoxesSharedFolderRowClass))

typedef struct _BoxesSharedFolderRow BoxesSharedFolderRow;
typedef struct _BoxesSharedFolderRowClass BoxesSharedFolderRowClass;
typedef struct _Block84Data Block84Data;
typedef struct _BoxesSpiceChannelHandlerPrivate BoxesSpiceChannelHandlerPrivate;
enum  {
	BOXES_SPICE_CHANNEL_HANDLER_DUMMY_PROPERTY,
	BOXES_SPICE_CHANNEL_HANDLER_LAST_PROPERTY
};
static GParamSpec* boxes_spice_channel_handler_properties[BOXES_SPICE_CHANNEL_HANDLER_LAST_PROPERTY];
#define _xmlFreeURI0(var) ((var == NULL) ? NULL : (var = (xmlFreeURI (var), NULL)))
typedef struct _BoxesSharedFolderRowPrivate BoxesSharedFolderRowPrivate;
enum  {
	BOXES_SHARED_FOLDER_ROW_DUMMY_PROPERTY,
	BOXES_SHARED_FOLDER_ROW_FOLDER_PATH,
	BOXES_SHARED_FOLDER_ROW_FOLDER_NAME,
	BOXES_SHARED_FOLDER_ROW_LAST_PROPERTY
};
static GParamSpec* boxes_shared_folder_row_properties[BOXES_SHARED_FOLDER_ROW_LAST_PROPERTY];
enum  {
	BOXES_SHARED_FOLDER_ROW_REMOVED_SIGNAL,
	BOXES_SHARED_FOLDER_ROW_LAST_SIGNAL
};
static guint boxes_shared_folder_row_signals[BOXES_SHARED_FOLDER_ROW_LAST_SIGNAL] = {0};
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

typedef enum  {
	BOXES_PROPERTIES_PAGE_GENERAL,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_SNAPSHOTS,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

struct _BoxesIPropertiesProviderIface {
	GTypeInterface parent_iface;
	GList* (*get_properties) (BoxesIPropertiesProvider* self, BoxesPropertiesPage page);
};

typedef gint (*BoxesDisplayOpenFDFunc) (void* user_data);
struct _BoxesDisplay {
	GObject parent_instance;
	BoxesDisplayPrivate * priv;
	gboolean connected;
	GHashTable* displays;
};

struct _BoxesDisplayClass {
	GObjectClass parent_class;
	GtkWidget* (*get_display) (BoxesDisplay* self, gint n);
	GdkPixbuf* (*get_pixbuf) (BoxesDisplay* self, gint n, GError** error);
	void (*set_enable_audio) (BoxesDisplay* self, gboolean enable);
	gboolean (*should_keep_alive) (BoxesDisplay* self);
	void (*connect_it) (BoxesDisplay* self, BoxesDisplayOpenFDFunc open_fd, void* open_fd_target, GDestroyNotify open_fd_target_destroy_notify, GError** error);
	void (*disconnect_it) (BoxesDisplay* self);
	void (*collect_logs) (BoxesDisplay* self, GString* builder);
	void (*send_keys) (BoxesDisplay* self, guint* keyvals, int keyvals_length1);
	GList* (*get_properties) (BoxesDisplay* self, BoxesPropertiesPage page);
	const gchar* (*get_protocol) (BoxesDisplay* self);
	gchar* (*get_uri) (BoxesDisplay* self);
};

struct _BoxesSpiceDisplay {
	BoxesDisplay parent_instance;
	BoxesSpiceDisplayPrivate * priv;
};

struct _BoxesSpiceDisplayClass {
	BoxesDisplayClass parent_class;
};

struct _BoxesSpiceDisplayPrivate {
	BoxesMachine* machine;
	SpiceSession* session;
	SpiceGtkSession* gtk_session;
	SpiceAudio* audio;
	gulong channel_new_id;
	gulong channel_destroy_id;
	BoxesBoxConfigSavedProperty* display_saved_properties;
	gint display_saved_properties_length1;
	gint _display_saved_properties_size_;
	BoxesBoxConfigSavedProperty* gtk_session_saved_properties;
	gint gtk_session_saved_properties_length1;
	gint _gtk_session_saved_properties_size_;
	gboolean closed;
	SpicePortChannel* webdav_channel;
	gchar* shared_folder;
	GSettings* shared_folder_settings;
	GHashTable* channel_handlers;
	BoxesDisplayOpenFDFunc open_fd;
	gpointer open_fd_target;
	GDestroyNotify open_fd_target_destroy_notify;
	SpiceMainChannel* _main_channel;
	gulong main_event_id;
	gulong main_mouse_mode_id;
};

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesCollectionItem {
	GObject parent_instance;
	BoxesCollectionItemPrivate * priv;
};

struct _BoxesCollectionItemClass {
	GObjectClass parent_class;
	gint (*compare) (BoxesCollectionItem* self, BoxesCollectionItem* other);
};

typedef enum  {
	BOXES_MACHINE_CONNECT_FLAGS_NONE = 0,
	BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE = 1 << 0
} BoxesMachineConnectFlags;

struct _BoxesMachine {
	BoxesCollectionItem parent_instance;
	BoxesMachinePrivate * priv;
	BoxesCollectionSource* source;
	BoxesBoxConfig* config;
	gboolean stay_on_display;
};

struct _BoxesMachineClass {
	BoxesCollectionItemClass parent_class;
	void (*save_real) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*save_real_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*take_screenshot) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GdkPixbuf* (*take_screenshot_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	GList* (*get_properties) (BoxesMachine* self, BoxesPropertiesPage page);
	void (*connect_display) (BoxesMachine* self, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*connect_display_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*restart) (BoxesMachine* self);
	void (*clone) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*clone_finish) (BoxesMachine* self, GAsyncResult* _res_);
	void (*disconnect_display) (BoxesMachine* self);
	void (*update_status) (BoxesMachine* self);
	void (*delete) (BoxesMachine* self, gboolean by_user);
	gboolean (*get_suspend_at_exit) (BoxesMachine* self);
	gboolean (*get_can_save) (BoxesMachine* self);
	gboolean (*get_can_restart) (BoxesMachine* self);
	gboolean (*get_can_clone) (BoxesMachine* self);
	gboolean (*get_should_autosave) (BoxesMachine* self);
	gboolean (*get_is_local) (BoxesMachine* self);
};

struct _Block79Data {
	int _ref_count_;
	BoxesSpiceDisplay* self;
	BoxesProperty* usb_property;
};

struct _Block80Data {
	int _ref_count_;
	GPtrArray* self;
	GCompareFunc compare_func;
};

struct _Block81Data {
	int _ref_count_;
	BoxesSpiceDisplay* self;
	SpiceUsbDeviceManager* manager;
};

struct _Block82Data {
	int _ref_count_;
	Block81Data * _data81_;
	SpiceUsbDevice* dev;
	GtkSwitch* dev_toggle;
};

struct _Block83Data {
	int _ref_count_;
	BoxesSpiceDisplay* self;
	GtkListBox* listbox;
	GtkButton* button_plus;
	BoxesSharedFolderPopover* popover;
};

struct _BoxesSharedFolderPopover {
	GtkPopover parent_instance;
	BoxesSharedFolderPopoverPrivate * priv;
	GtkFileChooserButton* file_chooser_button;
	GtkEntry* name_entry;
	gint target_position;
};

struct _BoxesSharedFolderPopoverClass {
	GtkPopoverClass parent_class;
};

struct _Block84Data {
	int _ref_count_;
	BoxesSpiceDisplay* self;
	BoxesSharedFolderRow* listboxrow;
	GtkListBox* listbox;
	gchar* name;
};

struct _BoxesSpiceChannelHandler {
	GObject parent_instance;
	BoxesSpiceChannelHandlerPrivate * priv;
};

struct _BoxesSpiceChannelHandlerClass {
	GObjectClass parent_class;
};

struct _BoxesSpiceChannelHandlerPrivate {
	BoxesSpiceDisplay* display;
	SpiceChannel* channel;
	BoxesDisplayOpenFDFunc open_fd;
	gpointer open_fd_target;
	GDestroyNotify open_fd_target_destroy_notify;
};

struct _BoxesSharedFolderRow {
	GtkListBoxRow parent_instance;
	BoxesSharedFolderRowPrivate * priv;
};

struct _BoxesSharedFolderRowClass {
	GtkListBoxRowClass parent_class;
};

struct _BoxesSharedFolderRowPrivate {
	gchar* _folder_path;
	gchar* _folder_name;
	GtkLabel* folder_path_label;
	GtkLabel* folder_name_label;
};


static gpointer boxes_spice_display_parent_class = NULL;
static gpointer boxes_spice_channel_handler_parent_class = NULL;
static gpointer boxes_shared_folder_row_parent_class = NULL;

GType boxes_properties_page_get_type (void) G_GNUC_CONST;
GType boxes_property_get_type (void) G_GNUC_CONST;
GType boxes_iproperties_provider_get_type (void) G_GNUC_CONST;
GType boxes_display_get_type (void) G_GNUC_CONST;
GType boxes_spice_display_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_machine_get_type (void) G_GNUC_CONST;
GType boxes_spice_channel_handler_get_type (void) G_GNUC_CONST;
#define BOXES_SPICE_DISPLAY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_SPICE_DISPLAY, BoxesSpiceDisplayPrivate))
static void boxes_spice_display_main_cleanup (BoxesSpiceDisplay* self);
static void _vala_BoxesBoxConfigSavedProperty_array_free (BoxesBoxConfigSavedProperty * array, gint array_length);
static void boxes_spice_display_ui_state_changed (BoxesSpiceDisplay* self);
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
BoxesUIState boxes_ui_get_ui_state (BoxesUI* self);
GtkWidget* boxes_display_get_display (BoxesDisplay* self, gint n);
static gchar* boxes_spice_display_get_box_name (BoxesSpiceDisplay* self);
BoxesBoxConfig* boxes_display_get_config (BoxesDisplay* self);
SpiceMainChannel* boxes_spice_display_get_main_channel (BoxesSpiceDisplay* self);
void boxes_spice_display_set_main_channel (BoxesSpiceDisplay* self, SpiceMainChannel* value);
BoxesSpiceDisplay* boxes_spice_display_new (BoxesMachine* machine, BoxesBoxConfig* config, const gchar* host, gint port, gint tls_port, const gchar* host_subject);
BoxesSpiceDisplay* boxes_spice_display_construct (GType object_type, BoxesMachine* machine, BoxesBoxConfig* config, const gchar* host, gint port, gint tls_port, const gchar* host_subject);
BoxesDisplay* boxes_display_construct (GType object_type);
static void _boxes_spice_display_ui_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
void boxes_display_set_config (BoxesDisplay* self, BoxesBoxConfig* value);
static void boxes_spice_display_init_shared_folders (BoxesSpiceDisplay* self);
BoxesSpiceDisplay* boxes_spice_display_new_with_uri (BoxesMachine* machine, BoxesBoxConfig* config, const gchar* uri);
BoxesSpiceDisplay* boxes_spice_display_construct_with_uri (GType object_type, BoxesMachine* machine, BoxesBoxConfig* config, const gchar* uri);
BoxesSpiceDisplay* boxes_spice_display_new_priv (BoxesMachine* machine, BoxesBoxConfig* config);
BoxesSpiceDisplay* boxes_spice_display_construct_priv (GType object_type, BoxesMachine* machine, BoxesBoxConfig* config);
static GtkWidget* boxes_spice_display_real_get_display (BoxesDisplay* base, gint n);
static void ___lambda74_ (BoxesSpiceDisplay* self, gint status);
void boxes_display_set_mouse_grabbed (BoxesDisplay* self, gboolean value);
static void ____lambda74__spice_display_mouse_grab (SpiceDisplay* _sender, gint status, gpointer self);
static void ___lambda75_ (BoxesSpiceDisplay* self, gint status);
void boxes_display_set_keyboard_grabbed (BoxesDisplay* self, gboolean value);
static void ____lambda75__spice_display_keyboard_grab (SpiceDisplay* _sender, gint status, gpointer self);
static gboolean boxes_spice_display_real_should_keep_alive (BoxesDisplay* base);
static GPtrArray* boxes_spice_display_get_usb_devices (BoxesSpiceDisplay* self, SpiceUsbDeviceManager* manager);
static void boxes_spice_display_real_set_enable_audio (BoxesDisplay* base, gboolean enable);
static GdkPixbuf* boxes_spice_display_real_get_pixbuf (BoxesDisplay* base, gint n, GError** error);
static void boxes_spice_display_real_collect_logs (BoxesDisplay* base, GString* builder);
gchar* boxes_display_get_uri (BoxesDisplay* self);
static SpiceUsbDevice* _vala_SpiceUsbDevice_copy (SpiceUsbDevice* self);
static void _vala_SpiceUsbDevice_free (SpiceUsbDevice* self);
static void boxes_spice_display_real_connect_it (BoxesDisplay* base, BoxesDisplayOpenFDFunc open_fd, void* open_fd_target, GDestroyNotify open_fd_target_destroy_notify, GError** error);
static void _g_object_unref0_ (gpointer var);
static void boxes_spice_display_on_channel_new (BoxesSpiceDisplay* self, SpiceSession* session, SpiceChannel* channel);
static void _boxes_spice_display_on_channel_new_spice_session_channel_new (SpiceSession* _sender, SpiceChannel* channel, gpointer self);
static void boxes_spice_display_on_channel_destroy (BoxesSpiceDisplay* self, SpiceSession* session, SpiceChannel* channel);
static void _boxes_spice_display_on_channel_destroy_spice_session_channel_destroy (SpiceSession* _sender, SpiceChannel* channel, gpointer self);
const gchar* boxes_display_get_password (BoxesDisplay* self);
static void boxes_spice_display_real_disconnect_it (BoxesDisplay* base);
BoxesSpiceChannelHandler* boxes_spice_channel_handler_new (BoxesSpiceDisplay* display, SpiceChannel* channel, BoxesDisplayOpenFDFunc open_fd, void* open_fd_target);
BoxesSpiceChannelHandler* boxes_spice_channel_handler_construct (GType object_type, BoxesSpiceDisplay* display, SpiceChannel* channel, BoxesDisplayOpenFDFunc open_fd, void* open_fd_target);
void boxes_display_access_start (BoxesDisplay* self);
void boxes_display_access_finish (BoxesDisplay* self);
static gboolean boxes_spice_display_add_shared_folder (BoxesSpiceDisplay* self, const gchar* path, const gchar* name);
static void boxes_spice_display_add_gsetting_shared_folder (BoxesSpiceDisplay* self, const gchar* path, const gchar* name);
static void boxes_spice_display_remove_shared_folder (BoxesSpiceDisplay* self, const gchar* name);
static void boxes_spice_display_remove_gsetting_shared_folder (BoxesSpiceDisplay* self, const gchar* name);
static GHashTable* boxes_spice_display_get_shared_folders (BoxesSpiceDisplay* self);
static void _g_free0_ (gpointer var);
GType boxes_machine_connect_flags_get_type (void) G_GNUC_CONST;
static GHashTable* boxes_spice_display_parse_shared_folders (BoxesSpiceDisplay* self);
static void boxes_spice_display_main_event (BoxesSpiceDisplay* self, SpiceChannelEvent event);
void boxes_display_set_need_password (BoxesDisplay* self, gboolean value);
static GList* boxes_spice_display_real_get_properties (BoxesDisplay* base, BoxesPropertiesPage page);
BoxesProperty* boxes_iproperties_provider_add_property (BoxesIPropertiesProvider* self, GList* * list, const gchar* name, GtkWidget* widget, GtkWidget* extra_widget);
static Block79Data* block79_data_ref (Block79Data* _data79_);
static void block79_data_unref (void * _userdata_);
static Block80Data* block80_data_ref (Block80Data* _data80_);
static void block80_data_unref (void * _userdata_);
static gint ___lambda1__gcompare_data_func (gconstpointer a, gconstpointer b, gpointer self);
static gint _____lambda76_ (SpiceUsbDevice* a, SpiceUsbDevice* b);
static gint ______lambda76__gcompare_func (gconstpointer a, gconstpointer b);
static GtkFrame* boxes_spice_display_create_usb_frame (BoxesSpiceDisplay* self, SpiceUsbDeviceManager* manager, GPtrArray* devs);
static void _____lambda79_ (Block79Data* _data79_, SpiceUsbDeviceManager* manager, SpiceUsbDevice* dev);
static void ______lambda79__spice_usb_device_manager_device_added (SpiceUsbDeviceManager* _sender, SpiceUsbDevice* device, gpointer self);
static void _____lambda80_ (Block79Data* _data79_, SpiceUsbDeviceManager* manager, SpiceUsbDevice* dev);
static void ______lambda80__spice_usb_device_manager_device_removed (SpiceUsbDeviceManager* _sender, SpiceUsbDevice* device, gpointer self);
static inline void _g_list_free__g_object_unref0_ (GList* self);
static GtkFrame* boxes_spice_display_create_shared_folders_frame (BoxesSpiceDisplay* self);
static void boxes_spice_display_real_send_keys (BoxesDisplay* base, guint* keyvals, int keyvals_length1);
static void __vala_SpiceUsbDevice_free0_ (gpointer var);
static gboolean boxes_spice_display_is_usb_kbd_or_mouse (BoxesSpiceDisplay* self, guint8 class, guint8 subclass, guint8 protocol);
static Block81Data* block81_data_ref (Block81Data* _data81_);
static void block81_data_unref (void * _userdata_);
static Block82Data* block82_data_ref (Block82Data* _data82_);
static void block82_data_unref (void * _userdata_);
static void _____lambda77_ (Block82Data* _data82_);
static void ___lambda78_ (Block82Data* _data82_, GObject* obj, GAsyncResult* res);
static void ____lambda78__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void ______lambda77__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
GType boxes_shared_folder_popover_get_type (void) G_GNUC_CONST;
static Block83Data* block83_data_ref (Block83Data* _data83_);
static void block83_data_unref (void * _userdata_);
BoxesSharedFolderPopover* boxes_shared_folder_popover_new (void);
BoxesSharedFolderPopover* boxes_shared_folder_popover_construct (GType object_type);
static void __lambda81_ (Block83Data* _data83_);
static void ___lambda81__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void __lambda82_ (Block83Data* _data83_, GtkListBoxRow* row);
GType boxes_shared_folder_row_get_type (void) G_GNUC_CONST;
const gchar* boxes_shared_folder_row_get_folder_path (BoxesSharedFolderRow* self);
const gchar* boxes_shared_folder_row_get_folder_name (BoxesSharedFolderRow* self);
static void ___lambda82__gtk_list_box_row_activated (GtkListBox* _sender, GtkListBoxRow* row, gpointer self);
static void boxes_spice_display_add_listbox_row (BoxesSpiceDisplay* self, GtkListBox* listbox, const gchar* path, const gchar* name, gint target_position);
static void __lambda84_ (Block83Data* _data83_, const gchar* path, const gchar* name, gint target_position);
static void ___lambda84__boxes_shared_folder_popover_saved (BoxesSharedFolderPopover* _sender, const gchar* local_folder, const gchar* name, gint target_position, gpointer self);
static Block84Data* block84_data_ref (Block84Data* _data84_);
static void block84_data_unref (void * _userdata_);
BoxesSharedFolderRow* boxes_shared_folder_row_new (const gchar* path, const gchar* name);
BoxesSharedFolderRow* boxes_shared_folder_row_construct (GType object_type, const gchar* path, const gchar* name);
static void __lambda83_ (Block84Data* _data84_);
static void ___lambda83__boxes_shared_folder_row_removed (BoxesSharedFolderRow* _sender, gpointer self);
GByteArray* boxes_spice_display_get_ca_cert (BoxesSpiceDisplay* self);
void boxes_spice_display_set_ca_cert (BoxesSpiceDisplay* self, GByteArray* value);
static void _boxes_spice_display_main_event_spice_channel_channel_event (SpiceChannel* _sender, SpiceChannelEvent event, gpointer self);
static void _boxes_spice_display_main_channel___lambda73_ (BoxesSpiceDisplay* self);
void boxes_display_set_can_grab_mouse (BoxesDisplay* self, gboolean value);
static void __boxes_spice_display_main_channel___lambda73__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static GObject * boxes_spice_display_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void _boxes_spice_display____lambda85_ (BoxesSpiceDisplay* self, SpiceUsbDevice* dev, GError* err);
static void __boxes_spice_display____lambda85__spice_usb_device_manager_device_error (SpiceUsbDeviceManager* _sender, SpiceUsbDevice* device, GError* _error_, gpointer self);
static void boxes_spice_display_finalize (GObject * obj);
const gchar* boxes_display_get_protocol (BoxesDisplay* self);
static void _vala_boxes_spice_display_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_spice_display_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
#define BOXES_SPICE_CHANNEL_HANDLER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_SPICE_CHANNEL_HANDLER, BoxesSpiceChannelHandlerPrivate))
static void boxes_spice_channel_handler_on_open_fd (BoxesSpiceChannelHandler* self, SpiceChannel* channel, gint with_tls);
static void _boxes_spice_channel_handler_on_open_fd_spice_channel_open_fd (SpiceChannel* _sender, gint with_tls, gpointer self);
static void boxes_spice_channel_handler_on_display_ready (BoxesSpiceChannelHandler* self, GObject* object, GParamSpec* param_spec);
static void _boxes_spice_channel_handler_on_display_ready_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void boxes_spice_channel_handler_finalize (GObject * obj);
void spice_validate_uri (const gchar* uri_as_text, gint** port, gint** tls_port, GError** error);
static gint* _int_dup (gint* self);
#define BOXES_SHARED_FOLDER_ROW_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_SHARED_FOLDER_ROW, BoxesSharedFolderRowPrivate))
void boxes_shared_folder_row_set_folder_path (BoxesSharedFolderRow* self, const gchar* value);
void boxes_shared_folder_row_set_folder_name (BoxesSharedFolderRow* self, const gchar* value);
static void boxes_shared_folder_row_on_delete_button_clicked (BoxesSharedFolderRow* self);
static void _boxes_shared_folder_row_on_delete_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void boxes_shared_folder_row_finalize (GObject * obj);
static void _vala_boxes_shared_folder_row_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_shared_folder_row_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);


static void _vala_BoxesBoxConfigSavedProperty_array_free (BoxesBoxConfigSavedProperty * array, gint array_length) {
#line 25 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (array != NULL) {
#line 562 "spice-display.c"
		int i;
#line 25 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		for (i = 0; i < array_length; i = i + 1) {
#line 25 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			boxes_box_config_saved_property_destroy (&array[i]);
#line 568 "spice-display.c"
		}
	}
#line 25 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_free (array);
#line 573 "spice-display.c"
}


static void boxes_spice_display_ui_state_changed (BoxesSpiceDisplay* self) {
	BoxesMachine* _tmp0_;
	BoxesUIState _tmp1_;
	BoxesUIState _tmp2_;
#line 36 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (self != NULL);
#line 38 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp0_ = self->priv->machine;
#line 38 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp1_ = boxes_ui_get_ui_state ((BoxesUI*) _tmp0_);
#line 38 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp2_ = _tmp1_;
#line 38 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (_tmp2_ == BOXES_UI_STATE_DISPLAY) {
#line 591 "spice-display.c"
		SpiceDisplay* display = NULL;
		GtkWidget* _tmp3_;
		SpiceDisplay* _tmp4_;
		SpiceDisplay* _tmp5_;
#line 40 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp3_ = boxes_display_get_display ((BoxesDisplay*) self, 0);
#line 40 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp4_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, spice_display_get_type ()) ? ((SpiceDisplay*) _tmp3_) : NULL;
#line 40 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		if (_tmp4_ == NULL) {
#line 40 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_g_object_unref0 (_tmp3_);
#line 604 "spice-display.c"
		}
#line 40 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		display = _tmp4_;
#line 41 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp5_ = display;
#line 41 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_object_set (_tmp5_, "resize-guest", TRUE, NULL);
#line 38 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (display);
#line 614 "spice-display.c"
	}
}


static gchar* boxes_spice_display_get_box_name (BoxesSpiceDisplay* self) {
	gchar* result = NULL;
	gchar* _tmp0_ = NULL;
	BoxesBoxConfig* _tmp1_;
	BoxesBoxConfig* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp6_;
#line 45 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 47 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp1_ = boxes_display_get_config ((BoxesDisplay*) self);
#line 47 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp2_ = _tmp1_;
#line 47 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp3_ = boxes_box_config_get_last_seen_name (_tmp2_);
#line 47 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp4_ = _tmp3_;
#line 47 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp0_ = _tmp4_;
#line 47 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (_tmp0_ == NULL) {
#line 641 "spice-display.c"
		gchar* _tmp5_;
#line 47 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp5_ = g_strdup (_ ("Unknown"));
#line 47 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_free0 (_tmp0_);
#line 47 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp0_ = _tmp5_;
#line 649 "spice-display.c"
	}
#line 47 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp6_ = _tmp0_;
#line 47 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp0_ = NULL;
#line 47 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	result = _tmp6_;
#line 47 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_free0 (_tmp0_);
#line 47 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	return result;
#line 661 "spice-display.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 100 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	return self ? g_object_ref (self) : NULL;
#line 668 "spice-display.c"
}


static void boxes_spice_display_main_cleanup (BoxesSpiceDisplay* self) {
	SpiceMainChannel* _tmp0_;
	SpiceMainChannel* _tmp1_;
	GObject* o = NULL;
	SpiceMainChannel* _tmp2_;
	SpiceMainChannel* _tmp3_;
	GObject* _tmp4_;
	GObject* _tmp5_;
	gulong _tmp6_;
	GObject* _tmp7_;
	gulong _tmp8_;
#line 96 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (self != NULL);
#line 97 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp0_ = boxes_spice_display_get_main_channel (self);
#line 97 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp1_ = _tmp0_;
#line 97 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (_tmp1_ == NULL) {
#line 98 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		return;
#line 693 "spice-display.c"
	}
#line 100 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp2_ = boxes_spice_display_get_main_channel (self);
#line 100 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp3_ = _tmp2_;
#line 100 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp4_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, G_TYPE_OBJECT) ? ((GObject*) _tmp3_) : NULL);
#line 100 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	o = _tmp4_;
#line 101 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp5_ = o;
#line 101 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp6_ = self->priv->main_event_id;
#line 101 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_signal_handler_disconnect (_tmp5_, _tmp6_);
#line 102 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self->priv->main_event_id = (gulong) 0;
#line 103 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp7_ = o;
#line 103 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp8_ = self->priv->main_mouse_mode_id;
#line 103 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_signal_handler_disconnect (_tmp7_, _tmp8_);
#line 104 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self->priv->main_mouse_mode_id = (gulong) 0;
#line 105 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	boxes_spice_display_set_main_channel (self, NULL);
#line 96 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_object_unref0 (o);
#line 723 "spice-display.c"
}


static void _boxes_spice_display_ui_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 115 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	boxes_spice_display_ui_state_changed ((BoxesSpiceDisplay*) self);
#line 730 "spice-display.c"
}


BoxesSpiceDisplay* boxes_spice_display_construct (GType object_type, BoxesMachine* machine, BoxesBoxConfig* config, const gchar* host, gint port, gint tls_port, const gchar* host_subject) {
	BoxesSpiceDisplay * self = NULL;
	gint _tmp0_;
	gint _tmp1_;
	BoxesMachine* _tmp2_;
	BoxesMachine* _tmp3_;
	BoxesBoxConfig* _tmp4_;
	SpiceSession* _tmp5_;
	const gchar* _tmp6_;
	gint _tmp7_;
	gint _tmp12_;
	const gchar* _tmp17_;
	BoxesBoxConfig* _tmp22_;
	SpiceGtkSession* _tmp23_;
	BoxesBoxConfigSavedProperty* _tmp24_;
	gint _tmp24__length1;
#line 112 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (machine != NULL, NULL);
#line 112 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (config != NULL, NULL);
#line 112 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (host != NULL, NULL);
#line 112 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp0_ = port;
#line 112 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp1_ = tls_port;
#line 112 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_vala_return_val_if_fail ((_tmp0_ != 0) || (_tmp1_ != 0), "port != 0 || tls_port != 0", NULL);
#line 112 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) boxes_display_construct (object_type);
#line 114 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp2_ = machine;
#line 114 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self->priv->machine = _tmp2_;
#line 115 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp3_ = machine;
#line 115 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_signal_connect_object ((GObject*) _tmp3_, "notify::ui-state", (GCallback) _boxes_spice_display_ui_state_changed_g_object_notify, self, 0);
#line 117 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp4_ = config;
#line 117 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	boxes_display_set_config ((BoxesDisplay*) self, _tmp4_);
#line 119 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp5_ = self->priv->session;
#line 119 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp6_ = host;
#line 119 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_object_set (_tmp5_, "host", _tmp6_, NULL);
#line 120 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp7_ = port;
#line 120 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (_tmp7_ != 0) {
#line 786 "spice-display.c"
		SpiceSession* _tmp8_;
		gint _tmp9_;
		gchar* _tmp10_;
		gchar* _tmp11_;
#line 121 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp8_ = self->priv->session;
#line 121 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp9_ = port;
#line 121 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp10_ = g_strdup_printf ("%i", _tmp9_);
#line 121 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp11_ = _tmp10_;
#line 121 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_object_set (_tmp8_, "port", _tmp11_, NULL);
#line 121 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_free0 (_tmp11_);
#line 803 "spice-display.c"
	}
#line 123 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp12_ = tls_port;
#line 123 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (_tmp12_ != 0) {
#line 809 "spice-display.c"
		SpiceSession* _tmp13_;
		gint _tmp14_;
		gchar* _tmp15_;
		gchar* _tmp16_;
#line 124 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp13_ = self->priv->session;
#line 124 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp14_ = tls_port;
#line 124 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp15_ = g_strdup_printf ("%i", _tmp14_);
#line 124 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp16_ = _tmp15_;
#line 124 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_object_set (_tmp13_, "tls-port", _tmp16_, NULL);
#line 124 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_free0 (_tmp16_);
#line 826 "spice-display.c"
	}
#line 130 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp17_ = host_subject;
#line 130 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (_tmp17_ != NULL) {
#line 832 "spice-display.c"
		SpiceSession* _tmp18_;
		const gchar* _tmp19_;
#line 131 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp18_ = self->priv->session;
#line 131 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp19_ = host_subject;
#line 131 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_object_set (_tmp18_, "cert-subject", _tmp19_, NULL);
#line 841 "spice-display.c"
	} else {
		SpiceSession* _tmp20_;
		const gchar* _tmp21_;
#line 133 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp20_ = self->priv->session;
#line 133 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp21_ = g_getenv ("BOXES_SPICE_HOST_SUBJECT");
#line 133 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_object_set (_tmp20_, "cert-subject", _tmp21_, NULL);
#line 851 "spice-display.c"
	}
#line 135 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp22_ = config;
#line 135 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp23_ = self->priv->gtk_session;
#line 135 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp24_ = self->priv->gtk_session_saved_properties;
#line 135 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp24__length1 = self->priv->gtk_session_saved_properties_length1;
#line 135 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	boxes_box_config_save_properties (_tmp22_, (GObject*) _tmp23_, _tmp24_, _tmp24__length1);
#line 137 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	boxes_spice_display_init_shared_folders (self);
#line 112 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	return self;
#line 867 "spice-display.c"
}


BoxesSpiceDisplay* boxes_spice_display_new (BoxesMachine* machine, BoxesBoxConfig* config, const gchar* host, gint port, gint tls_port, const gchar* host_subject) {
#line 112 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	return boxes_spice_display_construct (BOXES_TYPE_SPICE_DISPLAY, machine, config, host, port, tls_port, host_subject);
#line 874 "spice-display.c"
}


BoxesSpiceDisplay* boxes_spice_display_construct_with_uri (GType object_type, BoxesMachine* machine, BoxesBoxConfig* config, const gchar* uri) {
	BoxesSpiceDisplay * self = NULL;
	BoxesMachine* _tmp0_;
	BoxesMachine* _tmp1_;
	BoxesBoxConfig* _tmp2_;
	SpiceSession* _tmp3_;
	const gchar* _tmp4_;
	BoxesBoxConfig* _tmp5_;
	SpiceGtkSession* _tmp6_;
	BoxesBoxConfigSavedProperty* _tmp7_;
	gint _tmp7__length1;
#line 140 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (machine != NULL, NULL);
#line 140 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (config != NULL, NULL);
#line 140 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (uri != NULL, NULL);
#line 140 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) boxes_display_construct (object_type);
#line 141 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp0_ = machine;
#line 141 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self->priv->machine = _tmp0_;
#line 142 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp1_ = machine;
#line 142 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_signal_connect_object ((GObject*) _tmp1_, "notify::ui-state", (GCallback) _boxes_spice_display_ui_state_changed_g_object_notify, self, 0);
#line 144 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp2_ = config;
#line 144 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	boxes_display_set_config ((BoxesDisplay*) self, _tmp2_);
#line 146 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp3_ = self->priv->session;
#line 146 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp4_ = uri;
#line 146 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_object_set (_tmp3_, "uri", _tmp4_, NULL);
#line 148 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp5_ = config;
#line 148 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp6_ = self->priv->gtk_session;
#line 148 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp7_ = self->priv->gtk_session_saved_properties;
#line 148 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp7__length1 = self->priv->gtk_session_saved_properties_length1;
#line 148 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	boxes_box_config_save_properties (_tmp5_, (GObject*) _tmp6_, _tmp7_, _tmp7__length1);
#line 150 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	boxes_spice_display_init_shared_folders (self);
#line 140 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	return self;
#line 929 "spice-display.c"
}


BoxesSpiceDisplay* boxes_spice_display_new_with_uri (BoxesMachine* machine, BoxesBoxConfig* config, const gchar* uri) {
#line 140 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	return boxes_spice_display_construct_with_uri (BOXES_TYPE_SPICE_DISPLAY, machine, config, uri);
#line 936 "spice-display.c"
}


BoxesSpiceDisplay* boxes_spice_display_construct_priv (GType object_type, BoxesMachine* machine, BoxesBoxConfig* config) {
	BoxesSpiceDisplay * self = NULL;
	BoxesMachine* _tmp0_;
	BoxesMachine* _tmp1_;
	BoxesBoxConfig* _tmp2_;
	BoxesBoxConfig* _tmp3_;
	SpiceGtkSession* _tmp4_;
	BoxesBoxConfigSavedProperty* _tmp5_;
	gint _tmp5__length1;
#line 153 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (machine != NULL, NULL);
#line 153 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (config != NULL, NULL);
#line 153 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) boxes_display_construct (object_type);
#line 154 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp0_ = machine;
#line 154 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self->priv->machine = _tmp0_;
#line 155 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp1_ = machine;
#line 155 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_signal_connect_object ((GObject*) _tmp1_, "notify::ui-state", (GCallback) _boxes_spice_display_ui_state_changed_g_object_notify, self, 0);
#line 157 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp2_ = config;
#line 157 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	boxes_display_set_config ((BoxesDisplay*) self, _tmp2_);
#line 159 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp3_ = config;
#line 159 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp4_ = self->priv->gtk_session;
#line 159 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp5_ = self->priv->gtk_session_saved_properties;
#line 159 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp5__length1 = self->priv->gtk_session_saved_properties_length1;
#line 159 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	boxes_box_config_save_properties (_tmp3_, (GObject*) _tmp4_, _tmp5_, _tmp5__length1);
#line 161 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	boxes_spice_display_init_shared_folders (self);
#line 153 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	return self;
#line 981 "spice-display.c"
}


BoxesSpiceDisplay* boxes_spice_display_new_priv (BoxesMachine* machine, BoxesBoxConfig* config) {
#line 153 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	return boxes_spice_display_construct_priv (BOXES_TYPE_SPICE_DISPLAY, machine, config);
#line 988 "spice-display.c"
}


static void ___lambda74_ (BoxesSpiceDisplay* self, gint status) {
	gint _tmp0_;
#line 171 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp0_ = status;
#line 171 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	boxes_display_set_mouse_grabbed ((BoxesDisplay*) self, _tmp0_ != 0);
#line 998 "spice-display.c"
}


static void ____lambda74__spice_display_mouse_grab (SpiceDisplay* _sender, gint status, gpointer self) {
#line 170 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	___lambda74_ ((BoxesSpiceDisplay*) self, status);
#line 1005 "spice-display.c"
}


static void ___lambda75_ (BoxesSpiceDisplay* self, gint status) {
	gint _tmp0_;
#line 174 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp0_ = status;
#line 174 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	boxes_display_set_keyboard_grabbed ((BoxesDisplay*) self, _tmp0_ != 0);
#line 1015 "spice-display.c"
}


static void ____lambda75__spice_display_keyboard_grab (SpiceDisplay* _sender, gint status, gpointer self) {
#line 173 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	___lambda75_ ((BoxesSpiceDisplay*) self, status);
#line 1022 "spice-display.c"
}


static GtkWidget* boxes_spice_display_real_get_display (BoxesDisplay* base, gint n) {
	BoxesSpiceDisplay * self;
	GtkWidget* result = NULL;
	SpiceDisplay* display = NULL;
	GHashTable* _tmp0_;
	gint _tmp1_;
	gconstpointer _tmp2_;
	GtkWidget* _tmp3_;
	SpiceDisplay* _tmp4_;
	SpiceDisplay* _tmp5_;
#line 164 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) base;
#line 165 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp0_ = ((BoxesDisplay*) self)->displays;
#line 165 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp1_ = n;
#line 165 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp2_ = g_hash_table_lookup (_tmp0_, (gpointer) ((gintptr) _tmp1_));
#line 165 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp3_ = (GtkWidget*) _tmp2_;
#line 165 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp4_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, spice_display_get_type ()) ? ((SpiceDisplay*) _tmp3_) : NULL);
#line 165 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	display = _tmp4_;
#line 167 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp5_ = display;
#line 167 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (_tmp5_ == NULL) {
#line 1054 "spice-display.c"
		SpiceSession* _tmp6_;
		gint _tmp7_;
		SpiceDisplay* _tmp8_;
		SpiceDisplay* _tmp9_;
		SpiceDisplay* _tmp10_;
		BoxesBoxConfig* _tmp11_;
		BoxesBoxConfig* _tmp12_;
		BoxesBoxConfigSavedProperty* _tmp13_;
		gint _tmp13__length1;
		SpiceDisplay* _tmp14_;
		GHashTable* _tmp15_;
		gint _tmp16_;
		SpiceDisplay* _tmp17_;
		GtkWidget* _tmp18_;
#line 168 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp6_ = self->priv->session;
#line 168 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp7_ = n;
#line 168 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp8_ = spice_display_new (_tmp6_, _tmp7_);
#line 168 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_object_ref_sink (_tmp8_);
#line 168 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (display);
#line 168 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		display = _tmp8_;
#line 170 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp9_ = display;
#line 170 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_signal_connect_object (_tmp9_, "mouse-grab", (GCallback) ____lambda74__spice_display_mouse_grab, self, 0);
#line 173 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp10_ = display;
#line 173 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_signal_connect_object (_tmp10_, "keyboard-grab", (GCallback) ____lambda75__spice_display_keyboard_grab, self, 0);
#line 176 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp11_ = boxes_display_get_config ((BoxesDisplay*) self);
#line 176 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp12_ = _tmp11_;
#line 176 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp13_ = self->priv->display_saved_properties;
#line 176 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp13__length1 = self->priv->display_saved_properties_length1;
#line 176 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		boxes_box_config_save_properties (_tmp12_, (GObject*) self, _tmp13_, _tmp13__length1);
#line 177 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp14_ = display;
#line 177 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_object_set (_tmp14_, "scaling", TRUE, NULL);
#line 179 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp15_ = ((BoxesDisplay*) self)->displays;
#line 179 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp16_ = n;
#line 179 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp17_ = display;
#line 179 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp18_ = _g_object_ref0 ((GtkWidget*) _tmp17_);
#line 179 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_hash_table_replace (_tmp15_, (gpointer) ((gintptr) _tmp16_), _tmp18_);
#line 1113 "spice-display.c"
	}
#line 182 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	result = (GtkWidget*) display;
#line 182 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	return result;
#line 1119 "spice-display.c"
}


static gint g_ptr_array_get_length (GPtrArray* self) {
	gint result;
	guint _tmp0_;
#line 4981 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, 0);
#line 4981 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
	_tmp0_ = self->len;
#line 4981 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
	result = (gint) _tmp0_;
#line 4981 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
	return result;
#line 1134 "spice-display.c"
}


static void g_ptr_array_set_length (GPtrArray* self, gint value) {
	gint _tmp0_;
#line 4982 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
	g_return_if_fail (self != NULL);
#line 4982 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
	_tmp0_ = value;
#line 4982 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
	g_ptr_array_set_size (self, _tmp0_);
#line 1146 "spice-display.c"
}


static gboolean boxes_spice_display_real_should_keep_alive (BoxesDisplay* base) {
	BoxesSpiceDisplay * self;
	gboolean result = FALSE;
	gboolean _tmp9_ = FALSE;
	GError * _inner_error_ = NULL;
#line 185 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) base;
#line 1157 "spice-display.c"
	{
		SpiceUsbDeviceManager* manager = NULL;
		SpiceSession* _tmp0_;
		SpiceUsbDeviceManager* _tmp1_;
		SpiceUsbDeviceManager* _tmp2_;
		GPtrArray* devs = NULL;
		GPtrArray* _tmp3_;
		gboolean _tmp4_ = FALSE;
		gboolean _tmp5_;
#line 187 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp0_ = self->priv->session;
#line 187 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp1_ = spice_usb_device_manager_get (_tmp0_, &_inner_error_);
#line 187 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp2_ = _g_object_ref0 (_tmp1_);
#line 187 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		manager = _tmp2_;
#line 187 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1177 "spice-display.c"
			goto __catch75_g_error;
		}
#line 188 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp3_ = boxes_spice_display_get_usb_devices (self, manager);
#line 188 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		devs = _tmp3_;
#line 190 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp5_ = self->priv->closed;
#line 190 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		if (!_tmp5_) {
#line 1188 "spice-display.c"
			GPtrArray* _tmp6_;
			gint _tmp7_;
			gint _tmp8_;
#line 190 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp6_ = devs;
#line 190 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp7_ = g_ptr_array_get_length (_tmp6_);
#line 190 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp8_ = _tmp7_;
#line 190 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp4_ = _tmp8_ > 0;
#line 1200 "spice-display.c"
		} else {
#line 190 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp4_ = FALSE;
#line 1204 "spice-display.c"
		}
#line 190 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		result = _tmp4_;
#line 190 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_ptr_array_unref0 (devs);
#line 190 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (manager);
#line 190 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		return result;
#line 1214 "spice-display.c"
	}
	goto __finally75;
	__catch75_g_error:
	{
		GError* _error_ = NULL;
#line 186 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_error_ = _inner_error_;
#line 186 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_inner_error_ = NULL;
#line 192 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		result = FALSE;
#line 192 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_error_free0 (_error_);
#line 192 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		return result;
#line 1230 "spice-display.c"
	}
	__finally75:
#line 186 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 186 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_clear_error (&_inner_error_);
#line 186 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	return _tmp9_;
#line 1239 "spice-display.c"
}


static void boxes_spice_display_real_set_enable_audio (BoxesDisplay* base, gboolean enable) {
	BoxesSpiceDisplay * self;
	SpiceSession* _tmp0_;
	gboolean _tmp1_;
#line 196 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) base;
#line 197 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp0_ = self->priv->session;
#line 197 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp1_ = enable;
#line 197 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_object_set (_tmp0_, "enable-audio", _tmp1_, NULL);
#line 1255 "spice-display.c"
}


static GdkPixbuf* boxes_spice_display_real_get_pixbuf (BoxesDisplay* base, gint n, GError** error) {
	BoxesSpiceDisplay * self;
	GdkPixbuf* result = NULL;
	SpiceDisplay* display = NULL;
	gint _tmp0_;
	GtkWidget* _tmp1_;
	SpiceDisplay* _tmp2_;
	SpiceDisplay* _tmp3_;
	gboolean _tmp4_;
	gboolean _tmp5_;
	SpiceDisplay* _tmp6_;
	GdkPixbuf* _tmp7_;
#line 200 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) base;
#line 201 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp0_ = n;
#line 201 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp1_ = boxes_display_get_display ((BoxesDisplay*) self, _tmp0_);
#line 201 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp2_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, spice_display_get_type ()) ? ((SpiceDisplay*) _tmp1_) : NULL;
#line 201 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (_tmp2_ == NULL) {
#line 201 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (_tmp1_);
#line 1283 "spice-display.c"
	}
#line 201 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	display = _tmp2_;
#line 203 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp3_ = display;
#line 203 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_object_get (_tmp3_, "ready", &_tmp4_, NULL);
#line 203 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp5_ = _tmp4_;
#line 203 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (!_tmp5_) {
#line 204 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		result = NULL;
#line 204 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (display);
#line 204 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		return result;
#line 1301 "spice-display.c"
	}
#line 206 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp6_ = display;
#line 206 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp7_ = spice_display_get_pixbuf (_tmp6_);
#line 206 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	result = _tmp7_;
#line 206 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_object_unref0 (display);
#line 206 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	return result;
#line 1313 "spice-display.c"
}


static SpiceUsbDevice* _vala_SpiceUsbDevice_copy (SpiceUsbDevice* self) {
#line 224 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	return g_boxed_copy (spice_usb_device_get_type (), self);
#line 1320 "spice-display.c"
}


static gpointer __vala_SpiceUsbDevice_copy0 (gpointer self) {
#line 224 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	return self ? _vala_SpiceUsbDevice_copy (self) : NULL;
#line 1327 "spice-display.c"
}


static void _vala_SpiceUsbDevice_free (SpiceUsbDevice* self) {
#line 223 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_boxed_free (spice_usb_device_get_type (), self);
#line 1334 "spice-display.c"
}


static void boxes_spice_display_real_collect_logs (BoxesDisplay* base, GString* builder) {
	BoxesSpiceDisplay * self;
	GString* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	SpiceGtkSession* _tmp4_;
	SpiceMainChannel* _tmp10_;
	SpiceMainChannel* _tmp11_;
	GError * _inner_error_ = NULL;
#line 209 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) base;
#line 209 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (builder != NULL);
#line 210 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp0_ = builder;
#line 210 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp1_ = boxes_display_get_uri ((BoxesDisplay*) self);
#line 210 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp2_ = _tmp1_;
#line 210 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp3_ = _tmp2_;
#line 210 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_string_append_printf (_tmp0_, "URL: %s\n", _tmp3_);
#line 210 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_free0 (_tmp3_);
#line 211 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp4_ = self->priv->gtk_session;
#line 211 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (_tmp4_ != NULL) {
#line 1368 "spice-display.c"
		const gchar* _tmp5_ = NULL;
		SpiceGtkSession* _tmp6_;
		gboolean _tmp7_;
		gboolean _tmp8_;
		GString* _tmp9_;
#line 212 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp6_ = self->priv->gtk_session;
#line 212 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_object_get (_tmp6_, "auto-clipboard", &_tmp7_, NULL);
#line 212 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp8_ = _tmp7_;
#line 212 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		if (_tmp8_) {
#line 212 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp5_ = "yes";
#line 1384 "spice-display.c"
		} else {
#line 212 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp5_ = "no";
#line 1388 "spice-display.c"
		}
#line 212 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp9_ = builder;
#line 212 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_string_append_printf (_tmp9_, "Auto clipboard sync: %s\n", _tmp5_);
#line 1394 "spice-display.c"
	}
#line 214 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp10_ = boxes_spice_display_get_main_channel (self);
#line 214 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp11_ = _tmp10_;
#line 214 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (_tmp11_ != NULL) {
#line 1402 "spice-display.c"
		GString* _tmp12_;
		const gchar* _tmp13_;
		const gchar* _tmp14_ = NULL;
		SpiceMainChannel* _tmp15_;
		SpiceMainChannel* _tmp16_;
		gint _tmp17_;
		gint _tmp18_;
		GString* _tmp19_;
		const gchar* _tmp20_ = NULL;
		SpiceMainChannel* _tmp21_;
		SpiceMainChannel* _tmp22_;
		gboolean _tmp23_;
		gboolean _tmp24_;
		GString* _tmp25_;
#line 215 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp12_ = builder;
#line 215 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp13_ = spice_util_get_version_string ();
#line 215 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_string_append_printf (_tmp12_, "Spice-gtk version %s\n", _tmp13_);
#line 216 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp15_ = boxes_spice_display_get_main_channel (self);
#line 216 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp16_ = _tmp15_;
#line 216 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_object_get (_tmp16_, "mouse-mode", &_tmp17_, NULL);
#line 216 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp18_ = _tmp17_;
#line 216 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		if (_tmp18_ == 1) {
#line 216 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp14_ = "server";
#line 1435 "spice-display.c"
		} else {
#line 216 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp14_ = "client";
#line 1439 "spice-display.c"
		}
#line 216 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp19_ = builder;
#line 216 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_string_append_printf (_tmp19_, "Mouse mode: %s\n", _tmp14_);
#line 217 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp21_ = boxes_spice_display_get_main_channel (self);
#line 217 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp22_ = _tmp21_;
#line 217 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_object_get (_tmp22_, "agent-connected", &_tmp23_, NULL);
#line 217 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp24_ = _tmp23_;
#line 217 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		if (_tmp24_) {
#line 217 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp20_ = "connected";
#line 1457 "spice-display.c"
		} else {
#line 217 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp20_ = "disconnected";
#line 1461 "spice-display.c"
		}
#line 217 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp25_ = builder;
#line 217 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_string_append_printf (_tmp25_, "Agent: %s\n", _tmp20_);
#line 1467 "spice-display.c"
	}
	{
		SpiceUsbDeviceManager* manager = NULL;
		SpiceSession* _tmp26_;
		SpiceUsbDeviceManager* _tmp27_;
		SpiceUsbDeviceManager* _tmp28_;
		GPtrArray* devs = NULL;
		SpiceUsbDeviceManager* _tmp29_;
		GPtrArray* _tmp30_;
#line 221 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp26_ = self->priv->session;
#line 221 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp27_ = spice_usb_device_manager_get (_tmp26_, &_inner_error_);
#line 221 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp28_ = _g_object_ref0 (_tmp27_);
#line 221 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		manager = _tmp28_;
#line 221 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1487 "spice-display.c"
			goto __catch76_g_error;
		}
#line 222 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp29_ = manager;
#line 222 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp30_ = spice_usb_device_manager_get_devices (_tmp29_);
#line 222 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		devs = _tmp30_;
#line 1496 "spice-display.c"
		{
			gint i = 0;
#line 223 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			i = 0;
#line 1501 "spice-display.c"
			{
				gboolean _tmp31_ = FALSE;
#line 223 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp31_ = TRUE;
#line 223 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				while (TRUE) {
#line 1508 "spice-display.c"
					gint _tmp33_;
					GPtrArray* _tmp34_;
					gint _tmp35_;
					gint _tmp36_;
					SpiceUsbDevice* dev = NULL;
					GPtrArray* _tmp37_;
					gint _tmp38_;
					gconstpointer _tmp39_;
					SpiceUsbDevice* _tmp40_;
					SpiceUsbDeviceManager* _tmp41_;
					SpiceUsbDevice* _tmp42_;
					gboolean _tmp43_;
#line 223 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					if (!_tmp31_) {
#line 1523 "spice-display.c"
						gint _tmp32_;
#line 223 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
						_tmp32_ = i;
#line 223 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
						i = _tmp32_ + 1;
#line 1529 "spice-display.c"
					}
#line 223 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_tmp31_ = FALSE;
#line 223 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_tmp33_ = i;
#line 223 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_tmp34_ = devs;
#line 223 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_tmp35_ = g_ptr_array_get_length (_tmp34_);
#line 223 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_tmp36_ = _tmp35_;
#line 223 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					if (!(_tmp33_ < _tmp36_)) {
#line 223 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
						break;
#line 1545 "spice-display.c"
					}
#line 224 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_tmp37_ = devs;
#line 224 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_tmp38_ = i;
#line 224 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_tmp39_ = g_ptr_array_index (_tmp37_, (guint) _tmp38_);
#line 224 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_tmp40_ = __vala_SpiceUsbDevice_copy0 ((SpiceUsbDevice*) _tmp39_);
#line 224 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					dev = _tmp40_;
#line 225 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_tmp41_ = manager;
#line 225 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_tmp42_ = dev;
#line 225 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_tmp43_ = spice_usb_device_manager_is_device_connected (_tmp41_, _tmp42_);
#line 225 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					if (_tmp43_) {
#line 1565 "spice-display.c"
						GString* _tmp44_;
						SpiceUsbDevice* _tmp45_;
						gchar* _tmp46_;
						gchar* _tmp47_;
#line 226 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
						_tmp44_ = builder;
#line 226 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
						_tmp45_ = dev;
#line 226 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
						_tmp46_ = spice_usb_device_get_description (_tmp45_, "%s %s %s at %d-%d");
#line 226 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
						_tmp47_ = _tmp46_;
#line 226 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
						g_string_append_printf (_tmp44_, "USB device redirected: %s\n", _tmp47_);
#line 226 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
						_g_free0 (_tmp47_);
#line 1582 "spice-display.c"
					}
#line 223 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					__vala_SpiceUsbDevice_free0 (dev);
#line 1586 "spice-display.c"
				}
			}
		}
#line 220 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_ptr_array_unref0 (devs);
#line 220 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (manager);
#line 1594 "spice-display.c"
	}
	goto __finally76;
	__catch76_g_error:
	{
		GError* _error_ = NULL;
#line 220 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_error_ = _inner_error_;
#line 220 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_inner_error_ = NULL;
#line 220 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_error_free0 (_error_);
#line 1606 "spice-display.c"
	}
	__finally76:
#line 220 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 220 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 220 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_clear_error (&_inner_error_);
#line 220 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		return;
#line 1617 "spice-display.c"
	}
}


static void _g_object_unref0_ (gpointer var) {
#line 240 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 1625 "spice-display.c"
}


static void _boxes_spice_display_on_channel_new_spice_session_channel_new (SpiceSession* _sender, SpiceChannel* channel, gpointer self) {
#line 244 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	boxes_spice_display_on_channel_new ((BoxesSpiceDisplay*) self, _sender, channel);
#line 1632 "spice-display.c"
}


static void _boxes_spice_display_on_channel_destroy_spice_session_channel_destroy (SpiceSession* _sender, SpiceChannel* channel, gpointer self) {
#line 246 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	boxes_spice_display_on_channel_destroy ((BoxesSpiceDisplay*) self, _sender, channel);
#line 1639 "spice-display.c"
}


static void boxes_spice_display_real_connect_it (BoxesDisplay* base, BoxesDisplayOpenFDFunc open_fd, void* open_fd_target, GDestroyNotify open_fd_target_destroy_notify, GError** error) {
	BoxesSpiceDisplay * self;
	gboolean _tmp0_;
	BoxesDisplayOpenFDFunc _tmp1_;
	void* _tmp1__target;
	GDestroyNotify _tmp1__target_destroy_notify;
	GHashFunc _tmp2_;
	GEqualFunc _tmp3_;
	GHashTable* _tmp4_;
	gulong _tmp5_;
	gulong _tmp8_;
	SpiceSession* _tmp11_;
	const gchar* _tmp12_;
	const gchar* _tmp13_;
	BoxesDisplayOpenFDFunc _tmp14_;
	void* _tmp14__target;
#line 232 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) base;
#line 234 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp0_ = ((BoxesDisplay*) self)->connected;
#line 234 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (_tmp0_) {
#line 235 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		(open_fd_target_destroy_notify == NULL) ? NULL : (open_fd_target_destroy_notify (open_fd_target), NULL);
#line 235 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		open_fd = NULL;
#line 235 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		open_fd_target = NULL;
#line 235 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		open_fd_target_destroy_notify = NULL;
#line 235 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		return;
#line 1675 "spice-display.c"
	}
#line 236 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	((BoxesDisplay*) self)->connected = TRUE;
#line 237 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp1_ = open_fd;
#line 237 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp1__target = open_fd_target;
#line 237 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp1__target_destroy_notify = open_fd_target_destroy_notify;
#line 237 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	open_fd = NULL;
#line 237 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	open_fd_target = NULL;
#line 237 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	open_fd_target_destroy_notify = NULL;
#line 237 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	(self->priv->open_fd_target_destroy_notify == NULL) ? NULL : (self->priv->open_fd_target_destroy_notify (self->priv->open_fd_target), NULL);
#line 237 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self->priv->open_fd = NULL;
#line 237 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self->priv->open_fd_target = NULL;
#line 237 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self->priv->open_fd_target_destroy_notify = NULL;
#line 237 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self->priv->open_fd = _tmp1_;
#line 237 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self->priv->open_fd_target = _tmp1__target;
#line 237 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self->priv->open_fd_target_destroy_notify = _tmp1__target_destroy_notify;
#line 239 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	boxes_spice_display_main_cleanup (self);
#line 240 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp2_ = g_direct_hash;
#line 240 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp3_ = g_direct_equal;
#line 240 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp4_ = g_hash_table_new_full (_tmp2_, _tmp3_, _g_object_unref0_, _g_object_unref0_);
#line 240 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_hash_table_unref0 (self->priv->channel_handlers);
#line 240 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self->priv->channel_handlers = _tmp4_;
#line 243 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp5_ = self->priv->channel_new_id;
#line 243 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (_tmp5_ == ((gulong) 0)) {
#line 1721 "spice-display.c"
		SpiceSession* _tmp6_;
		gulong _tmp7_;
#line 244 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp6_ = self->priv->session;
#line 244 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp7_ = g_signal_connect_object (_tmp6_, "channel-new", (GCallback) _boxes_spice_display_on_channel_new_spice_session_channel_new, self, 0);
#line 244 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		self->priv->channel_new_id = _tmp7_;
#line 1730 "spice-display.c"
	}
#line 245 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp8_ = self->priv->channel_destroy_id;
#line 245 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (_tmp8_ == ((gulong) 0)) {
#line 1736 "spice-display.c"
		SpiceSession* _tmp9_;
		gulong _tmp10_;
#line 246 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp9_ = self->priv->session;
#line 246 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp10_ = g_signal_connect_object (_tmp9_, "channel-destroy", (GCallback) _boxes_spice_display_on_channel_destroy_spice_session_channel_destroy, self, 0);
#line 246 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		self->priv->channel_destroy_id = _tmp10_;
#line 1745 "spice-display.c"
	}
#line 248 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp11_ = self->priv->session;
#line 248 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp12_ = boxes_display_get_password ((BoxesDisplay*) self);
#line 248 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp13_ = _tmp12_;
#line 248 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_object_set (_tmp11_, "password", _tmp13_, NULL);
#line 249 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp14_ = self->priv->open_fd;
#line 249 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp14__target = self->priv->open_fd_target;
#line 249 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (_tmp14_ != NULL) {
#line 1761 "spice-display.c"
		SpiceSession* _tmp15_;
#line 250 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp15_ = self->priv->session;
#line 250 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		spice_session_open_fd (_tmp15_, -1);
#line 1767 "spice-display.c"
	} else {
		SpiceSession* _tmp16_;
#line 252 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp16_ = self->priv->session;
#line 252 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		spice_session_connect (_tmp16_);
#line 1774 "spice-display.c"
	}
#line 232 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	(open_fd_target_destroy_notify == NULL) ? NULL : (open_fd_target_destroy_notify (open_fd_target), NULL);
#line 232 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	open_fd = NULL;
#line 232 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	open_fd_target = NULL;
#line 232 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	open_fd_target_destroy_notify = NULL;
#line 1784 "spice-display.c"
}


static void boxes_spice_display_real_disconnect_it (BoxesDisplay* base) {
	BoxesSpiceDisplay * self;
	gulong _tmp0_;
	gulong _tmp3_;
	SpiceSession* _tmp6_;
	GHashTable* _tmp7_;
#line 255 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) base;
#line 256 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp0_ = self->priv->channel_new_id;
#line 256 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (_tmp0_ > ((gulong) 0)) {
#line 1800 "spice-display.c"
		SpiceSession* _tmp1_;
		gulong _tmp2_;
#line 257 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp1_ = self->priv->session;
#line 257 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp2_ = self->priv->channel_new_id;
#line 257 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_signal_handler_disconnect (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, G_TYPE_OBJECT) ? ((GObject*) _tmp1_) : NULL, _tmp2_);
#line 258 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		self->priv->channel_new_id = (gulong) 0;
#line 1811 "spice-display.c"
	}
#line 260 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp3_ = self->priv->channel_destroy_id;
#line 260 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (_tmp3_ > ((gulong) 0)) {
#line 1817 "spice-display.c"
		SpiceSession* _tmp4_;
		gulong _tmp5_;
#line 261 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp4_ = self->priv->session;
#line 261 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp5_ = self->priv->channel_destroy_id;
#line 261 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_signal_handler_disconnect (G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, G_TYPE_OBJECT) ? ((GObject*) _tmp4_) : NULL, _tmp5_);
#line 262 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		self->priv->channel_destroy_id = (gulong) 0;
#line 1828 "spice-display.c"
	}
#line 264 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp6_ = self->priv->session;
#line 264 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	spice_session_disconnect (_tmp6_);
#line 265 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	boxes_spice_display_main_cleanup (self);
#line 266 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_hash_table_unref0 (self->priv->channel_handlers);
#line 266 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self->priv->channel_handlers = NULL;
#line 267 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	(self->priv->open_fd_target_destroy_notify == NULL) ? NULL : (self->priv->open_fd_target_destroy_notify (self->priv->open_fd_target), NULL);
#line 267 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self->priv->open_fd = NULL;
#line 267 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self->priv->open_fd_target = NULL;
#line 267 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self->priv->open_fd_target_destroy_notify = NULL;
#line 267 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self->priv->open_fd = NULL;
#line 267 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self->priv->open_fd_target = NULL;
#line 267 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self->priv->open_fd_target_destroy_notify = NULL;
#line 268 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp7_ = ((BoxesDisplay*) self)->displays;
#line 268 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_hash_table_remove_all (_tmp7_);
#line 1858 "spice-display.c"
}


static void boxes_spice_display_on_channel_new (BoxesSpiceDisplay* self, SpiceSession* session, SpiceChannel* channel) {
	BoxesSpiceChannelHandler* handler = NULL;
	SpiceChannel* _tmp0_;
	BoxesDisplayOpenFDFunc _tmp1_;
	void* _tmp1__target;
	BoxesSpiceChannelHandler* _tmp2_;
	GHashTable* _tmp3_;
	SpiceChannel* _tmp4_;
	SpiceChannel* _tmp5_;
	BoxesSpiceChannelHandler* _tmp6_;
	BoxesSpiceChannelHandler* _tmp7_;
	SpiceChannel* _tmp8_;
	SpiceChannel* _tmp12_;
#line 271 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (self != NULL);
#line 271 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (session != NULL);
#line 271 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (channel != NULL);
#line 272 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp0_ = channel;
#line 272 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp1_ = self->priv->open_fd;
#line 272 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp1__target = self->priv->open_fd_target;
#line 272 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp2_ = boxes_spice_channel_handler_new (self, _tmp0_, _tmp1_, _tmp1__target);
#line 272 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	handler = _tmp2_;
#line 273 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp3_ = self->priv->channel_handlers;
#line 273 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp4_ = channel;
#line 273 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp5_ = _g_object_ref0 (_tmp4_);
#line 273 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp6_ = handler;
#line 273 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp7_ = _g_object_ref0 (_tmp6_);
#line 273 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_hash_table_insert (_tmp3_, _tmp5_, _tmp7_);
#line 275 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp8_ = channel;
#line 275 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp8_, spice_display_channel_get_type ())) {
#line 1907 "spice-display.c"
		SpiceChannel* _tmp9_;
		gint _tmp10_;
		gint _tmp11_;
#line 276 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp9_ = channel;
#line 276 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_object_get (_tmp9_, "channel-id", &_tmp10_, NULL);
#line 276 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp11_ = _tmp10_;
#line 276 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		if (_tmp11_ != 0) {
#line 277 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_g_object_unref0 (handler);
#line 277 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			return;
#line 1923 "spice-display.c"
		}
#line 279 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		boxes_display_access_start ((BoxesDisplay*) self);
#line 1927 "spice-display.c"
	}
#line 282 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp12_ = channel;
#line 282 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp12_, spice_webdav_channel_get_type ())) {
#line 1933 "spice-display.c"
		SpiceChannel* _tmp13_;
		SpicePortChannel* _tmp14_;
#line 283 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp13_ = channel;
#line 283 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp14_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp13_, spice_port_channel_get_type ()) ? ((SpicePortChannel*) _tmp13_) : NULL);
#line 283 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (self->priv->webdav_channel);
#line 283 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		self->priv->webdav_channel = _tmp14_;
#line 1944 "spice-display.c"
	}
#line 271 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_object_unref0 (handler);
#line 1948 "spice-display.c"
}


static void boxes_spice_display_on_channel_destroy (BoxesSpiceDisplay* self, SpiceSession* session, SpiceChannel* channel) {
	SpiceChannel* _tmp0_;
	SpiceDisplayChannel* display = NULL;
	SpiceChannel* _tmp1_;
	SpiceDisplayChannel* _tmp2_;
	SpiceDisplayChannel* _tmp3_;
	gint _tmp4_;
	gint _tmp5_;
#line 286 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (self != NULL);
#line 286 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (session != NULL);
#line 286 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (channel != NULL);
#line 287 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp0_ = channel;
#line 287 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, spice_display_channel_get_type ())) {
#line 288 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		return;
#line 1972 "spice-display.c"
	}
#line 290 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp1_ = channel;
#line 290 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, spice_display_channel_get_type ()) ? ((SpiceDisplayChannel*) _tmp1_) : NULL);
#line 290 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	display = _tmp2_;
#line 291 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp3_ = display;
#line 291 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_object_get ((SpiceChannel*) _tmp3_, "channel-id", &_tmp4_, NULL);
#line 291 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp5_ = _tmp4_;
#line 291 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_signal_emit_by_name ((BoxesDisplay*) self, "hide", _tmp5_);
#line 292 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	boxes_display_access_finish ((BoxesDisplay*) self);
#line 286 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_object_unref0 (display);
#line 1992 "spice-display.c"
}


static gboolean boxes_spice_display_add_shared_folder (BoxesSpiceDisplay* self, const gchar* path, const gchar* name) {
	gboolean result = FALSE;
	const gchar* _tmp0_;
	gboolean _tmp1_;
	const gchar* _tmp3_;
	gboolean _tmp4_;
	gchar* link_path = NULL;
	const gchar* _tmp10_;
	const gchar* _tmp11_;
	gchar* _tmp12_;
	gint ret = 0;
	const gchar* _tmp13_;
	const gchar* _tmp14_;
	gint _tmp15_;
	gint _tmp16_;
	const gchar* _tmp19_;
	const gchar* _tmp20_;
#line 295 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 295 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (path != NULL, FALSE);
#line 295 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (name != NULL, FALSE);
#line 296 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp0_ = self->priv->shared_folder;
#line 296 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp1_ = g_file_test (_tmp0_, G_FILE_TEST_IS_DIR);
#line 296 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (!_tmp1_) {
#line 2025 "spice-display.c"
		const gchar* _tmp2_;
#line 297 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp2_ = self->priv->shared_folder;
#line 297 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		unlink (_tmp2_);
#line 2031 "spice-display.c"
	}
#line 299 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp3_ = self->priv->shared_folder;
#line 299 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp4_ = g_file_test (_tmp3_, G_FILE_TEST_EXISTS);
#line 299 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (!_tmp4_) {
#line 2039 "spice-display.c"
		gint ret = 0;
		const gchar* _tmp5_;
		gint _tmp6_;
		gint _tmp7_;
#line 300 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp5_ = self->priv->shared_folder;
#line 300 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp6_ = mkdir (_tmp5_, (mode_t) 0755);
#line 300 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		ret = _tmp6_;
#line 302 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp7_ = ret;
#line 302 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		if (_tmp7_ == -1) {
#line 2054 "spice-display.c"
			gint _tmp8_;
			const gchar* _tmp9_;
#line 303 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp8_ = errno;
#line 303 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp9_ = g_strerror (_tmp8_);
#line 303 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			g_warning ("spice-display.vala:303: %s", _tmp9_);
#line 305 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			result = FALSE;
#line 305 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			return result;
#line 2067 "spice-display.c"
		}
	}
#line 309 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp10_ = self->priv->shared_folder;
#line 309 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp11_ = name;
#line 309 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp12_ = g_build_filename (_tmp10_, _tmp11_, NULL);
#line 309 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	link_path = _tmp12_;
#line 311 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp13_ = path;
#line 311 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp14_ = link_path;
#line 311 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp15_ = symlink (_tmp13_, _tmp14_);
#line 311 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	ret = _tmp15_;
#line 312 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp16_ = ret;
#line 312 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (_tmp16_ == -1) {
#line 2090 "spice-display.c"
		gint _tmp17_;
		const gchar* _tmp18_;
#line 313 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp17_ = errno;
#line 313 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp18_ = g_strerror (_tmp17_);
#line 313 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_warning ("spice-display.vala:313: %s", _tmp18_);
#line 315 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		result = FALSE;
#line 315 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_free0 (link_path);
#line 315 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		return result;
#line 2105 "spice-display.c"
	}
#line 317 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp19_ = path;
#line 317 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp20_ = name;
#line 317 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	boxes_spice_display_add_gsetting_shared_folder (self, _tmp19_, _tmp20_);
#line 319 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	result = TRUE;
#line 319 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_free0 (link_path);
#line 319 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	return result;
#line 2119 "spice-display.c"
}


static void boxes_spice_display_remove_shared_folder (BoxesSpiceDisplay* self, const gchar* name) {
	gboolean _tmp0_ = FALSE;
	const gchar* _tmp1_;
	gboolean _tmp2_;
	gchar* to_remove = NULL;
	const gchar* _tmp5_;
	const gchar* _tmp6_;
	gchar* _tmp7_;
	const gchar* _tmp8_;
	const gchar* _tmp9_;
#line 322 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (self != NULL);
#line 322 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (name != NULL);
#line 323 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp1_ = self->priv->shared_folder;
#line 323 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp2_ = g_file_test (_tmp1_, G_FILE_TEST_EXISTS);
#line 323 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (!_tmp2_) {
#line 323 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp0_ = TRUE;
#line 2145 "spice-display.c"
	} else {
		const gchar* _tmp3_;
		gboolean _tmp4_;
#line 323 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp3_ = self->priv->shared_folder;
#line 323 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp4_ = g_file_test (_tmp3_, G_FILE_TEST_IS_DIR);
#line 323 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp0_ = !_tmp4_;
#line 2155 "spice-display.c"
	}
#line 323 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (_tmp0_) {
#line 324 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		return;
#line 2161 "spice-display.c"
	}
#line 326 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp5_ = self->priv->shared_folder;
#line 326 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp6_ = name;
#line 326 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp7_ = g_build_filename (_tmp5_, _tmp6_, NULL);
#line 326 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	to_remove = _tmp7_;
#line 327 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp8_ = to_remove;
#line 327 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	unlink (_tmp8_);
#line 329 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp9_ = name;
#line 329 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	boxes_spice_display_remove_gsetting_shared_folder (self, _tmp9_);
#line 322 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_free0 (to_remove);
#line 2181 "spice-display.c"
}


static void _g_free0_ (gpointer var) {
#line 336 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	var = (g_free (var), NULL);
#line 2188 "spice-display.c"
}


static GHashTable* boxes_spice_display_get_shared_folders (BoxesSpiceDisplay* self) {
	GHashTable* result = NULL;
	gboolean _tmp0_ = FALSE;
	const gchar* _tmp1_;
	gboolean _tmp2_;
	GHashTable* hash = NULL;
	GHashFunc _tmp5_;
	GEqualFunc _tmp6_;
	GHashTable* _tmp7_;
	GError * _inner_error_ = NULL;
#line 332 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 333 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp1_ = self->priv->shared_folder;
#line 333 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp2_ = g_file_test (_tmp1_, G_FILE_TEST_EXISTS);
#line 333 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (!_tmp2_) {
#line 333 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp0_ = TRUE;
#line 2212 "spice-display.c"
	} else {
		const gchar* _tmp3_;
		gboolean _tmp4_;
#line 333 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp3_ = self->priv->shared_folder;
#line 333 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp4_ = g_file_test (_tmp3_, G_FILE_TEST_IS_DIR);
#line 333 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp0_ = !_tmp4_;
#line 2222 "spice-display.c"
	}
#line 333 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (_tmp0_) {
#line 334 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		result = NULL;
#line 334 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		return result;
#line 2230 "spice-display.c"
	}
#line 336 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp5_ = g_str_hash;
#line 336 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp6_ = g_str_equal;
#line 336 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp7_ = g_hash_table_new_full (_tmp5_, _tmp6_, _g_free0_, _g_free0_);
#line 336 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	hash = _tmp7_;
#line 2240 "spice-display.c"
	{
		GDir* dir = NULL;
		const gchar* _tmp8_;
		GDir* _tmp9_;
		gchar* name = NULL;
#line 338 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp8_ = self->priv->shared_folder;
#line 338 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp9_ = g_dir_open (_tmp8_, (guint) 0, &_inner_error_);
#line 338 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		dir = _tmp9_;
#line 338 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 338 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			if (_inner_error_->domain == G_FILE_ERROR) {
#line 2256 "spice-display.c"
				goto __catch77_g_file_error;
			}
#line 338 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_g_hash_table_unref0 (hash);
#line 338 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 338 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			g_clear_error (&_inner_error_);
#line 338 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			return NULL;
#line 2267 "spice-display.c"
		}
#line 339 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		name = NULL;
#line 341 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		while (TRUE) {
#line 2273 "spice-display.c"
			GDir* _tmp10_;
			const gchar* _tmp11_;
			gchar* _tmp12_;
			const gchar* _tmp13_;
			gchar* path = NULL;
			const gchar* _tmp14_;
			const gchar* _tmp15_;
			gchar* _tmp16_;
			const gchar* _tmp17_;
			gboolean _tmp18_;
#line 341 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp10_ = dir;
#line 341 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp11_ = g_dir_read_name (_tmp10_);
#line 341 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp12_ = g_strdup (_tmp11_);
#line 341 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_g_free0 (name);
#line 341 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			name = _tmp12_;
#line 341 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp13_ = name;
#line 341 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			if (!(_tmp13_ != NULL)) {
#line 341 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				break;
#line 2300 "spice-display.c"
			}
#line 342 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp14_ = self->priv->shared_folder;
#line 342 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp15_ = name;
#line 342 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp16_ = g_build_filename (_tmp14_, _tmp15_, NULL);
#line 342 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			path = _tmp16_;
#line 343 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp17_ = path;
#line 343 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp18_ = g_file_test (_tmp17_, G_FILE_TEST_IS_SYMLINK);
#line 343 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			if (_tmp18_) {
#line 2316 "spice-display.c"
				gchar* folder = NULL;
				const gchar* _tmp19_;
				gchar* _tmp20_;
				GHashTable* _tmp21_;
				const gchar* _tmp22_;
				gchar* _tmp23_;
				const gchar* _tmp24_;
				gchar* _tmp25_;
#line 344 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp19_ = path;
#line 344 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp20_ = g_file_read_link (_tmp19_, &_inner_error_);
#line 344 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				folder = _tmp20_;
#line 344 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 344 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_g_free0 (path);
#line 344 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_g_free0 (name);
#line 344 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_g_dir_close0 (dir);
#line 344 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					if (_inner_error_->domain == G_FILE_ERROR) {
#line 2341 "spice-display.c"
						goto __catch77_g_file_error;
					}
#line 344 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_g_free0 (path);
#line 344 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_g_free0 (name);
#line 344 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_g_dir_close0 (dir);
#line 344 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_g_hash_table_unref0 (hash);
#line 344 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 344 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					g_clear_error (&_inner_error_);
#line 344 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					return NULL;
#line 2358 "spice-display.c"
				}
#line 346 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp21_ = hash;
#line 346 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp22_ = name;
#line 346 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp23_ = g_strdup (_tmp22_);
#line 346 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp24_ = folder;
#line 346 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp25_ = g_strdup (_tmp24_);
#line 346 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				g_hash_table_insert (_tmp21_, _tmp23_, _tmp25_);
#line 343 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_g_free0 (folder);
#line 2374 "spice-display.c"
			}
#line 341 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_g_free0 (path);
#line 2378 "spice-display.c"
		}
#line 337 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_free0 (name);
#line 337 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_dir_close0 (dir);
#line 2384 "spice-display.c"
	}
	goto __finally77;
	__catch77_g_file_error:
	{
		GError* err = NULL;
		GError* _tmp26_;
		const gchar* _tmp27_;
#line 337 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		err = _inner_error_;
#line 337 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_inner_error_ = NULL;
#line 350 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp26_ = err;
#line 350 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp27_ = _tmp26_->message;
#line 350 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_warning ("spice-display.vala:350: %s", _tmp27_);
#line 337 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_error_free0 (err);
#line 2404 "spice-display.c"
	}
	__finally77:
#line 337 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 337 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_hash_table_unref0 (hash);
#line 337 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 337 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_clear_error (&_inner_error_);
#line 337 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		return NULL;
#line 2417 "spice-display.c"
	}
#line 353 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	result = hash;
#line 353 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	return result;
#line 2423 "spice-display.c"
}


static void boxes_spice_display_init_shared_folders (BoxesSpiceDisplay* self) {
	const gchar* _tmp0_;
	BoxesMachine* _tmp1_;
	BoxesBoxConfig* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	GSettings* _tmp7_;
	GHashTable* hash = NULL;
	GHashTable* _tmp8_;
	GList* names = NULL;
	GHashTable* _tmp9_;
	GList* _tmp10_;
	GList* _tmp11_;
#line 356 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (self != NULL);
#line 357 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp0_ = g_get_user_config_dir ();
#line 357 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp1_ = self->priv->machine;
#line 357 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp2_ = _tmp1_->config;
#line 357 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp3_ = boxes_box_config_get_uuid (_tmp2_);
#line 357 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp4_ = _tmp3_;
#line 357 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp5_ = _tmp4_;
#line 357 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp6_ = g_build_filename (_tmp0_, "gnome-boxes", _tmp5_, NULL);
#line 357 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_free0 (self->priv->shared_folder);
#line 357 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self->priv->shared_folder = _tmp6_;
#line 357 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_free0 (_tmp5_);
#line 359 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp7_ = g_settings_new ("org.gnome.boxes");
#line 359 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_object_unref0 (self->priv->shared_folder_settings);
#line 359 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self->priv->shared_folder_settings = _tmp7_;
#line 360 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp8_ = boxes_spice_display_parse_shared_folders (self);
#line 360 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	hash = _tmp8_;
#line 361 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp9_ = hash;
#line 361 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp10_ = g_hash_table_get_keys (_tmp9_);
#line 361 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	names = _tmp10_;
#line 362 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp11_ = names;
#line 2482 "spice-display.c"
	{
		GList* name_collection = NULL;
		GList* name_it = NULL;
#line 362 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		name_collection = _tmp11_;
#line 362 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		for (name_it = name_collection; name_it != NULL; name_it = name_it->next) {
#line 2490 "spice-display.c"
			const gchar* name = NULL;
#line 362 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			name = (const gchar*) name_it->data;
#line 2494 "spice-display.c"
			{
				GHashTable* _tmp12_;
				const gchar* _tmp13_;
				gconstpointer _tmp14_;
				const gchar* _tmp15_;
#line 363 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp12_ = hash;
#line 363 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp13_ = name;
#line 363 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp14_ = g_hash_table_lookup (_tmp12_, _tmp13_);
#line 363 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp15_ = name;
#line 363 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				boxes_spice_display_add_shared_folder (self, (const gchar*) _tmp14_, _tmp15_);
#line 2510 "spice-display.c"
			}
		}
	}
#line 356 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_list_free0 (names);
#line 356 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_hash_table_unref0 (hash);
#line 2518 "spice-display.c"
}


static GHashTable* boxes_spice_display_parse_shared_folders (BoxesSpiceDisplay* self) {
	GHashTable* result = NULL;
	GHashTable* hash = NULL;
	GHashFunc _tmp0_;
	GEqualFunc _tmp1_;
	GHashTable* _tmp2_;
	gchar* shared_folders = NULL;
	GSettings* _tmp3_;
	gchar* _tmp4_;
	const gchar* _tmp5_;
	GError * _inner_error_ = NULL;
#line 367 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 368 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp0_ = g_str_hash;
#line 368 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp1_ = g_str_equal;
#line 368 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp2_ = g_hash_table_new_full (_tmp0_, _tmp1_, _g_free0_, _g_free0_);
#line 368 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	hash = _tmp2_;
#line 370 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp3_ = self->priv->shared_folder_settings;
#line 370 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp4_ = g_settings_get_string (_tmp3_, "shared-folders");
#line 370 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	shared_folders = _tmp4_;
#line 371 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp5_ = shared_folders;
#line 371 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (g_strcmp0 (_tmp5_, "") == 0) {
#line 372 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		result = hash;
#line 372 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_free0 (shared_folders);
#line 372 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		return result;
#line 2559 "spice-display.c"
	}
	{
		GVariant* entry = NULL;
		gchar* uuid_str = NULL;
		gchar* path_str = NULL;
		gchar* name_str = NULL;
		GVariant* variant = NULL;
		const GVariantType* _tmp6_;
		GVariantType* _tmp7_;
		GVariantType* _tmp8_;
		const gchar* _tmp9_;
		GVariant* _tmp10_;
		GVariant* _tmp11_;
		GVariantIter* iter = NULL;
		GVariant* _tmp12_;
		GVariantIter* _tmp13_;
#line 375 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		entry = NULL;
#line 380 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp6_ = G_VARIANT_TYPE_VARIANT;
#line 380 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp7_ = g_variant_type_new_array (_tmp6_);
#line 380 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp8_ = _tmp7_;
#line 380 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp9_ = shared_folders;
#line 380 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp10_ = g_variant_parse (_tmp8_, _tmp9_, NULL, NULL, &_inner_error_);
#line 380 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp11_ = _tmp10_;
#line 380 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_variant_type_free0 (_tmp8_);
#line 380 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		variant = _tmp11_;
#line 380 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 380 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_g_free0 (name_str);
#line 380 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_g_free0 (path_str);
#line 380 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_g_free0 (uuid_str);
#line 380 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_g_variant_unref0 (entry);
#line 380 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			if (_inner_error_->domain == G_VARIANT_PARSE_ERROR) {
#line 2606 "spice-display.c"
				goto __catch78_g_variant_parse_error;
			}
#line 380 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_g_free0 (name_str);
#line 380 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_g_free0 (path_str);
#line 380 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_g_free0 (uuid_str);
#line 380 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_g_variant_unref0 (entry);
#line 380 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_g_free0 (shared_folders);
#line 380 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_g_hash_table_unref0 (hash);
#line 380 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 380 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			g_clear_error (&_inner_error_);
#line 380 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			return NULL;
#line 2627 "spice-display.c"
		}
#line 381 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp12_ = variant;
#line 381 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp13_ = g_variant_iter_new (_tmp12_);
#line 381 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		iter = _tmp13_;
#line 382 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		while (TRUE) {
#line 2637 "spice-display.c"
			GVariantIter* _tmp14_;
			gboolean _tmp15_;
			GVariant* _tmp16_;
			GVariant* _tmp17_;
			GVariant* _tmp18_;
			BoxesMachine* _tmp19_;
			BoxesBoxConfig* _tmp20_;
			gchar* _tmp21_;
			gchar* _tmp22_;
			gchar* _tmp23_;
			const gchar* _tmp24_;
			gboolean _tmp25_;
#line 382 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp14_ = iter;
#line 382 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp15_ = g_variant_iter_next (_tmp14_, "v", &entry, NULL);
#line 382 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			if (!_tmp15_) {
#line 382 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				break;
#line 2658 "spice-display.c"
			}
#line 383 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp16_ = entry;
#line 383 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			g_variant_lookup (_tmp16_, "uuid", "s", &uuid_str, NULL);
#line 384 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp17_ = entry;
#line 384 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			g_variant_lookup (_tmp17_, "path", "s", &path_str, NULL);
#line 385 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp18_ = entry;
#line 385 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			g_variant_lookup (_tmp18_, "name", "s", &name_str, NULL);
#line 387 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp19_ = self->priv->machine;
#line 387 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp20_ = _tmp19_->config;
#line 387 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp21_ = boxes_box_config_get_uuid (_tmp20_);
#line 387 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp22_ = _tmp21_;
#line 387 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp23_ = _tmp22_;
#line 387 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp24_ = uuid_str;
#line 387 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp25_ = g_strcmp0 (_tmp23_, _tmp24_) == 0;
#line 387 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_g_free0 (_tmp23_);
#line 387 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			if (_tmp25_) {
#line 2690 "spice-display.c"
				GHashTable* _tmp26_;
				const gchar* _tmp27_;
				gchar* _tmp28_;
				const gchar* _tmp29_;
				gchar* _tmp30_;
#line 388 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp26_ = hash;
#line 388 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp27_ = name_str;
#line 388 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp28_ = g_strdup (_tmp27_);
#line 388 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp29_ = path_str;
#line 388 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp30_ = g_strdup (_tmp29_);
#line 388 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				g_hash_table_insert (_tmp26_, _tmp28_, _tmp30_);
#line 2708 "spice-display.c"
			}
		}
#line 374 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_variant_iter_free0 (iter);
#line 374 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_variant_unref0 (variant);
#line 374 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_free0 (name_str);
#line 374 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_free0 (path_str);
#line 374 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_free0 (uuid_str);
#line 374 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_variant_unref0 (entry);
#line 2723 "spice-display.c"
	}
	goto __finally78;
	__catch78_g_variant_parse_error:
	{
		GError* err = NULL;
		GError* _tmp31_;
		const gchar* _tmp32_;
#line 374 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		err = _inner_error_;
#line 374 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_inner_error_ = NULL;
#line 391 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp31_ = err;
#line 391 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp32_ = _tmp31_->message;
#line 391 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_warning ("spice-display.vala:391: %s", _tmp32_);
#line 374 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_error_free0 (err);
#line 2743 "spice-display.c"
	}
	__finally78:
#line 374 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 374 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_free0 (shared_folders);
#line 374 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_hash_table_unref0 (hash);
#line 374 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 374 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_clear_error (&_inner_error_);
#line 374 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		return NULL;
#line 2758 "spice-display.c"
	}
#line 394 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	result = hash;
#line 394 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_free0 (shared_folders);
#line 394 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	return result;
#line 2766 "spice-display.c"
}


static void boxes_spice_display_add_gsetting_shared_folder (BoxesSpiceDisplay* self, const gchar* path, const gchar* name) {
	GVariantBuilder* variant_builder = NULL;
	const GVariantType* _tmp0_;
	GVariantType* _tmp1_;
	GVariantType* _tmp2_;
	GVariantBuilder* _tmp3_;
	GVariantBuilder* _tmp4_;
	gchar* shared_folders = NULL;
	GSettings* _tmp5_;
	gchar* _tmp6_;
	const gchar* _tmp7_;
	GVariantBuilder* entry_variant_builder = NULL;
	const GVariantType* _tmp22_;
	GVariantBuilder* _tmp23_;
	GVariant* uuid_variant = NULL;
	BoxesMachine* _tmp24_;
	BoxesBoxConfig* _tmp25_;
	gchar* _tmp26_;
	gchar* _tmp27_;
	gchar* _tmp28_;
	GVariant* _tmp29_;
	GVariant* _tmp30_;
	GVariant* path_variant = NULL;
	const gchar* _tmp31_;
	GVariant* _tmp32_;
	GVariant* name_variant = NULL;
	const gchar* _tmp33_;
	GVariant* _tmp34_;
	GVariant* entry_variant = NULL;
	GVariant* _tmp35_;
	GVariantBuilder* _tmp36_;
	GVariant* variant = NULL;
	GVariantBuilder* _tmp37_;
	GVariant* _tmp38_;
	GSettings* _tmp39_;
	gchar* _tmp40_;
	gchar* _tmp41_;
	GError * _inner_error_ = NULL;
#line 397 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (self != NULL);
#line 397 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (path != NULL);
#line 397 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (name != NULL);
#line 398 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp0_ = G_VARIANT_TYPE_VARIANT;
#line 398 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp1_ = g_variant_type_new_array (_tmp0_);
#line 398 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp2_ = _tmp1_;
#line 398 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp3_ = g_variant_builder_new (_tmp2_);
#line 398 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp4_ = _tmp3_;
#line 398 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_variant_type_free0 (_tmp2_);
#line 398 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	variant_builder = _tmp4_;
#line 400 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp5_ = self->priv->shared_folder_settings;
#line 400 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp6_ = g_settings_get_string (_tmp5_, "shared-folders");
#line 400 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	shared_folders = _tmp6_;
#line 401 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp7_ = shared_folders;
#line 401 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (g_strcmp0 (_tmp7_, "") != 0) {
#line 2838 "spice-display.c"
		{
			GVariant* entry = NULL;
			GVariant* variant = NULL;
			const GVariantType* _tmp8_;
			GVariantType* _tmp9_;
			GVariantType* _tmp10_;
			const gchar* _tmp11_;
			GVariant* _tmp12_;
			GVariant* _tmp13_;
			GVariantIter* iter = NULL;
			GVariant* _tmp14_;
			GVariantIter* _tmp15_;
#line 403 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			entry = NULL;
#line 405 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp8_ = G_VARIANT_TYPE_VARIANT;
#line 405 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp9_ = g_variant_type_new_array (_tmp8_);
#line 405 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp10_ = _tmp9_;
#line 405 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp11_ = shared_folders;
#line 405 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp12_ = g_variant_parse (_tmp10_, _tmp11_, NULL, NULL, &_inner_error_);
#line 405 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp13_ = _tmp12_;
#line 405 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_g_variant_type_free0 (_tmp10_);
#line 405 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			variant = _tmp13_;
#line 405 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 405 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_g_variant_unref0 (entry);
#line 405 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				if (_inner_error_->domain == G_VARIANT_PARSE_ERROR) {
#line 2875 "spice-display.c"
					goto __catch79_g_variant_parse_error;
				}
#line 405 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_g_variant_unref0 (entry);
#line 405 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_g_free0 (shared_folders);
#line 405 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_g_variant_builder_unref0 (variant_builder);
#line 405 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 405 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				g_clear_error (&_inner_error_);
#line 405 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				return;
#line 2890 "spice-display.c"
			}
#line 406 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp14_ = variant;
#line 406 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp15_ = g_variant_iter_new (_tmp14_);
#line 406 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			iter = _tmp15_;
#line 407 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			while (TRUE) {
#line 2900 "spice-display.c"
				GVariantIter* _tmp16_;
				gboolean _tmp17_;
				GVariantBuilder* _tmp18_;
				GVariant* _tmp19_;
#line 407 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp16_ = iter;
#line 407 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp17_ = g_variant_iter_next (_tmp16_, "v", &entry, NULL);
#line 407 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				if (!_tmp17_) {
#line 407 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					break;
#line 2913 "spice-display.c"
				}
#line 408 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp18_ = variant_builder;
#line 408 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp19_ = entry;
#line 408 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				g_variant_builder_add (_tmp18_, "v", _tmp19_, NULL);
#line 2921 "spice-display.c"
			}
#line 402 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_g_variant_iter_free0 (iter);
#line 402 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_g_variant_unref0 (variant);
#line 402 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_g_variant_unref0 (entry);
#line 2929 "spice-display.c"
		}
		goto __finally79;
		__catch79_g_variant_parse_error:
		{
			GError* err = NULL;
			GError* _tmp20_;
			const gchar* _tmp21_;
#line 402 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			err = _inner_error_;
#line 402 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_inner_error_ = NULL;
#line 411 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp20_ = err;
#line 411 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp21_ = _tmp20_->message;
#line 411 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			g_warning ("spice-display.vala:411: %s", _tmp21_);
#line 402 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_g_error_free0 (err);
#line 2949 "spice-display.c"
		}
		__finally79:
#line 402 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 402 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_g_free0 (shared_folders);
#line 402 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_g_variant_builder_unref0 (variant_builder);
#line 402 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 402 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			g_clear_error (&_inner_error_);
#line 402 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			return;
#line 2964 "spice-display.c"
		}
	}
#line 415 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp22_ = G_VARIANT_TYPE_VARDICT;
#line 415 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp23_ = g_variant_builder_new (_tmp22_);
#line 415 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	entry_variant_builder = _tmp23_;
#line 417 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp24_ = self->priv->machine;
#line 417 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp25_ = _tmp24_->config;
#line 417 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp26_ = boxes_box_config_get_uuid (_tmp25_);
#line 417 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp27_ = _tmp26_;
#line 417 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp28_ = _tmp27_;
#line 417 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp29_ = g_variant_new ("s", _tmp28_, NULL);
#line 417 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_variant_ref_sink (_tmp29_);
#line 417 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp30_ = _tmp29_;
#line 417 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_free0 (_tmp28_);
#line 417 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	uuid_variant = _tmp30_;
#line 418 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp31_ = path;
#line 418 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp32_ = g_variant_new ("s", _tmp31_, NULL);
#line 418 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_variant_ref_sink (_tmp32_);
#line 418 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	path_variant = _tmp32_;
#line 419 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp33_ = name;
#line 419 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp34_ = g_variant_new ("s", _tmp33_, NULL);
#line 419 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_variant_ref_sink (_tmp34_);
#line 419 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	name_variant = _tmp34_;
#line 420 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_variant_builder_add (entry_variant_builder, "{sv}", "uuid", uuid_variant, NULL);
#line 421 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_variant_builder_add (entry_variant_builder, "{sv}", "path", path_variant, NULL);
#line 422 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_variant_builder_add (entry_variant_builder, "{sv}", "name", name_variant, NULL);
#line 423 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp35_ = g_variant_builder_end (entry_variant_builder);
#line 423 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_variant_ref_sink (_tmp35_);
#line 423 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	entry_variant = _tmp35_;
#line 425 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp36_ = variant_builder;
#line 425 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_variant_builder_add (_tmp36_, "v", entry_variant, NULL);
#line 426 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp37_ = variant_builder;
#line 426 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp38_ = g_variant_builder_end (_tmp37_);
#line 426 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_variant_ref_sink (_tmp38_);
#line 426 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	variant = _tmp38_;
#line 428 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp39_ = self->priv->shared_folder_settings;
#line 428 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp40_ = g_variant_print (variant, TRUE);
#line 428 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp41_ = _tmp40_;
#line 428 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_settings_set_string (_tmp39_, "shared-folders", _tmp41_);
#line 428 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_free0 (_tmp41_);
#line 397 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_variant_unref0 (variant);
#line 397 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_variant_unref0 (entry_variant);
#line 397 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_variant_unref0 (name_variant);
#line 397 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_variant_unref0 (path_variant);
#line 397 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_variant_unref0 (uuid_variant);
#line 397 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_variant_builder_unref0 (entry_variant_builder);
#line 397 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_free0 (shared_folders);
#line 397 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_variant_builder_unref0 (variant_builder);
#line 3059 "spice-display.c"
}


static void boxes_spice_display_remove_gsetting_shared_folder (BoxesSpiceDisplay* self, const gchar* name) {
	GVariantBuilder* variant_builder = NULL;
	const GVariantType* _tmp0_;
	GVariantType* _tmp1_;
	GVariantType* _tmp2_;
	GVariantBuilder* _tmp3_;
	GVariantBuilder* _tmp4_;
	gchar* shared_folders = NULL;
	GSettings* _tmp5_;
	gchar* _tmp6_;
	const gchar* _tmp7_;
	GError * _inner_error_ = NULL;
#line 431 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (self != NULL);
#line 431 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (name != NULL);
#line 432 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp0_ = G_VARIANT_TYPE_VARIANT;
#line 432 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp1_ = g_variant_type_new_array (_tmp0_);
#line 432 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp2_ = _tmp1_;
#line 432 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp3_ = g_variant_builder_new (_tmp2_);
#line 432 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp4_ = _tmp3_;
#line 432 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_variant_type_free0 (_tmp2_);
#line 432 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	variant_builder = _tmp4_;
#line 434 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp5_ = self->priv->shared_folder_settings;
#line 434 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp6_ = g_settings_get_string (_tmp5_, "shared-folders");
#line 434 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	shared_folders = _tmp6_;
#line 435 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp7_ = shared_folders;
#line 435 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (g_strcmp0 (_tmp7_, "") == 0) {
#line 436 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_free0 (shared_folders);
#line 436 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_variant_builder_unref0 (variant_builder);
#line 436 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		return;
#line 3109 "spice-display.c"
	}
	{
		GVariant* entry = NULL;
		gchar* name_str = NULL;
		gchar* uuid_str = NULL;
		GVariant* variant = NULL;
		const GVariantType* _tmp8_;
		GVariantType* _tmp9_;
		GVariantType* _tmp10_;
		const gchar* _tmp11_;
		GVariant* _tmp12_;
		GVariant* _tmp13_;
		GVariantIter* iter = NULL;
		GVariant* _tmp14_;
		GVariantIter* _tmp15_;
		GVariantBuilder* _tmp32_;
		GVariant* _tmp33_;
		GSettings* _tmp34_;
		GVariant* _tmp35_;
		gchar* _tmp36_;
		gchar* _tmp37_;
#line 439 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		entry = NULL;
#line 443 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp8_ = G_VARIANT_TYPE_VARIANT;
#line 443 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp9_ = g_variant_type_new_array (_tmp8_);
#line 443 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp10_ = _tmp9_;
#line 443 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp11_ = shared_folders;
#line 443 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp12_ = g_variant_parse (_tmp10_, _tmp11_, NULL, NULL, &_inner_error_);
#line 443 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp13_ = _tmp12_;
#line 443 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_variant_type_free0 (_tmp10_);
#line 443 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		variant = _tmp13_;
#line 443 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 443 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_g_free0 (uuid_str);
#line 443 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_g_free0 (name_str);
#line 443 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_g_variant_unref0 (entry);
#line 443 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			if (_inner_error_->domain == G_VARIANT_PARSE_ERROR) {
#line 3159 "spice-display.c"
				goto __catch80_g_variant_parse_error;
			}
#line 443 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_g_free0 (uuid_str);
#line 443 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_g_free0 (name_str);
#line 443 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_g_variant_unref0 (entry);
#line 443 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_g_free0 (shared_folders);
#line 443 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_g_variant_builder_unref0 (variant_builder);
#line 443 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 443 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			g_clear_error (&_inner_error_);
#line 443 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			return;
#line 3178 "spice-display.c"
		}
#line 444 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp14_ = variant;
#line 444 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp15_ = g_variant_iter_new (_tmp14_);
#line 444 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		iter = _tmp15_;
#line 445 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		while (TRUE) {
#line 3188 "spice-display.c"
			GVariantIter* _tmp16_;
			gboolean _tmp17_;
			GVariant* _tmp18_;
			GVariant* _tmp19_;
			gboolean _tmp20_ = FALSE;
			const gchar* _tmp21_;
			BoxesMachine* _tmp22_;
			BoxesBoxConfig* _tmp23_;
			gchar* _tmp24_;
			gchar* _tmp25_;
			gchar* _tmp26_;
			gboolean _tmp27_;
			GVariantBuilder* _tmp30_;
			GVariant* _tmp31_;
#line 445 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp16_ = iter;
#line 445 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp17_ = g_variant_iter_next (_tmp16_, "v", &entry, NULL);
#line 445 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			if (!_tmp17_) {
#line 445 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				break;
#line 3211 "spice-display.c"
			}
#line 446 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp18_ = entry;
#line 446 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			g_variant_lookup (_tmp18_, "uuid", "s", &uuid_str, NULL);
#line 447 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp19_ = entry;
#line 447 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			g_variant_lookup (_tmp19_, "name", "s", &name_str, NULL);
#line 449 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp21_ = uuid_str;
#line 449 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp22_ = self->priv->machine;
#line 449 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp23_ = _tmp22_->config;
#line 449 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp24_ = boxes_box_config_get_uuid (_tmp23_);
#line 449 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp25_ = _tmp24_;
#line 449 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp26_ = _tmp25_;
#line 449 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp27_ = g_strcmp0 (_tmp21_, _tmp26_) == 0;
#line 449 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_g_free0 (_tmp26_);
#line 449 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			if (_tmp27_) {
#line 3239 "spice-display.c"
				const gchar* _tmp28_;
				const gchar* _tmp29_;
#line 449 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp28_ = name_str;
#line 449 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp29_ = name;
#line 449 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp20_ = g_strcmp0 (_tmp28_, _tmp29_) == 0;
#line 3248 "spice-display.c"
			} else {
#line 449 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp20_ = FALSE;
#line 3252 "spice-display.c"
			}
#line 449 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			if (_tmp20_) {
#line 450 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				continue;
#line 3258 "spice-display.c"
			}
#line 452 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp30_ = variant_builder;
#line 452 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp31_ = entry;
#line 452 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			g_variant_builder_add (_tmp30_, "v", _tmp31_, NULL);
#line 3266 "spice-display.c"
		}
#line 454 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp32_ = variant_builder;
#line 454 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp33_ = g_variant_builder_end (_tmp32_);
#line 454 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_variant_ref_sink (_tmp33_);
#line 454 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_variant_unref0 (variant);
#line 454 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		variant = _tmp33_;
#line 456 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp34_ = self->priv->shared_folder_settings;
#line 456 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp35_ = variant;
#line 456 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp36_ = g_variant_print (_tmp35_, TRUE);
#line 456 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp37_ = _tmp36_;
#line 456 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_settings_set_string (_tmp34_, "shared-folders", _tmp37_);
#line 456 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_free0 (_tmp37_);
#line 438 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_variant_iter_free0 (iter);
#line 438 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_variant_unref0 (variant);
#line 438 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_free0 (uuid_str);
#line 438 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_free0 (name_str);
#line 438 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_variant_unref0 (entry);
#line 3300 "spice-display.c"
	}
	goto __finally80;
	__catch80_g_variant_parse_error:
	{
		GError* err = NULL;
		GError* _tmp38_;
		const gchar* _tmp39_;
#line 438 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		err = _inner_error_;
#line 438 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_inner_error_ = NULL;
#line 458 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp38_ = err;
#line 458 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp39_ = _tmp38_->message;
#line 458 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_warning ("spice-display.vala:458: %s", _tmp39_);
#line 438 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_error_free0 (err);
#line 3320 "spice-display.c"
	}
	__finally80:
#line 438 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 438 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_free0 (shared_folders);
#line 438 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_variant_builder_unref0 (variant_builder);
#line 438 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 438 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_clear_error (&_inner_error_);
#line 438 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		return;
#line 3335 "spice-display.c"
	}
#line 431 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_free0 (shared_folders);
#line 431 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_variant_builder_unref0 (variant_builder);
#line 3341 "spice-display.c"
}


static void boxes_spice_display_main_event (BoxesSpiceDisplay* self, SpiceChannelEvent event) {
	SpiceChannelEvent _tmp0_;
#line 462 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (self != NULL);
#line 463 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp0_ = event;
#line 463 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	switch (_tmp0_) {
#line 463 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		case SPICE_CHANNEL_CLOSED:
#line 3355 "spice-display.c"
		{
#line 465 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			self->priv->closed = TRUE;
#line 466 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			g_signal_emit_by_name ((BoxesDisplay*) self, "disconnected", FALSE);
#line 467 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			break;
#line 3363 "spice-display.c"
		}
#line 463 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		case SPICE_CHANNEL_ERROR_AUTH:
#line 3367 "spice-display.c"
		{
#line 470 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			boxes_display_set_need_password ((BoxesDisplay*) self, TRUE);
#line 471 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			break;
#line 3373 "spice-display.c"
		}
#line 463 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		case SPICE_CHANNEL_ERROR_CONNECT:
#line 463 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		case SPICE_CHANNEL_ERROR_TLS:
#line 463 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		case SPICE_CHANNEL_ERROR_LINK:
#line 463 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		case SPICE_CHANNEL_ERROR_IO:
#line 3383 "spice-display.c"
		{
			SpiceChannelEvent _tmp1_;
#line 477 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp1_ = event;
#line 477 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			g_debug ("spice-display.vala:477: main SPICE channel error: %d", (gint) _tmp1_);
#line 478 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			self->priv->closed = TRUE;
#line 479 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			g_signal_emit_by_name ((BoxesDisplay*) self, "disconnected", TRUE);
#line 480 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			break;
#line 3396 "spice-display.c"
		}
#line 463 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		case SPICE_CHANNEL_OPENED:
#line 3400 "spice-display.c"
		{
#line 483 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			break;
#line 3404 "spice-display.c"
		}
		default:
		{
			SpiceChannelEvent _tmp2_;
#line 486 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp2_ = event;
#line 486 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			g_debug ("spice-display.vala:486: unhandled main SPICE channel event: %d", (gint) _tmp2_);
#line 487 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			break;
#line 3415 "spice-display.c"
		}
	}
}


static Block79Data* block79_data_ref (Block79Data* _data79_) {
#line 522 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_atomic_int_inc (&_data79_->_ref_count_);
#line 522 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	return _data79_;
#line 3426 "spice-display.c"
}


static void block79_data_unref (void * _userdata_) {
	Block79Data* _data79_;
	_data79_ = (Block79Data*) _userdata_;
#line 522 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (g_atomic_int_dec_and_test (&_data79_->_ref_count_)) {
#line 3435 "spice-display.c"
		BoxesSpiceDisplay* self;
#line 522 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		self = _data79_->self;
#line 522 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (_data79_->usb_property);
#line 522 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (self);
#line 522 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_slice_free (Block79Data, _data79_);
#line 3445 "spice-display.c"
	}
}


static Block80Data* block80_data_ref (Block80Data* _data80_) {
#line 4965 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
	g_atomic_int_inc (&_data80_->_ref_count_);
#line 4965 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
	return _data80_;
#line 3455 "spice-display.c"
}


static void block80_data_unref (void * _userdata_) {
	Block80Data* _data80_;
	_data80_ = (Block80Data*) _userdata_;
#line 4965 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
	if (g_atomic_int_dec_and_test (&_data80_->_ref_count_)) {
#line 3464 "spice-display.c"
		GPtrArray* self;
#line 4965 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
		self = _data80_->self;
#line 4965 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
		_g_ptr_array_unref0 (self);
#line 4965 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
		g_slice_free (Block80Data, _data80_);
#line 3472 "spice-display.c"
	}
}


static gint __lambda1_ (Block80Data* _data80_, gconstpointer** a, gconstpointer** b) {
	GPtrArray* self;
	gint result = 0;
	GCompareFunc _tmp0_;
	gconstpointer** _tmp1_;
	gconstpointer** _tmp2_;
	gint _tmp3_;
#line 4966 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
	self = _data80_->self;
#line 4967 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
	_tmp0_ = _data80_->compare_func;
#line 4967 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
	_tmp1_ = a;
#line 4967 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
	_tmp2_ = b;
#line 4967 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
	_tmp3_ = _tmp0_ ((gconstpointer**) (*_tmp1_), (gconstpointer**) (*_tmp2_));
#line 4967 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
	result = _tmp3_;
#line 4967 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
	return result;
#line 3498 "spice-display.c"
}


static gint ___lambda1__gcompare_data_func (gconstpointer a, gconstpointer b, gpointer self) {
	gint result;
	result = __lambda1_ (self, a, b);
#line 4966 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
	return result;
#line 3507 "spice-display.c"
}


static void vala_g_ptr_array_sort (GPtrArray* self, GCompareFunc compare_func) {
	Block80Data* _data80_;
	GCompareFunc _tmp0_;
#line 4965 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
	g_return_if_fail (self != NULL);
#line 4965 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
	_data80_ = g_slice_new0 (Block80Data);
#line 4965 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
	_data80_->_ref_count_ = 1;
#line 4965 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
	_data80_->self = g_ptr_array_ref (self);
#line 4965 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
	_tmp0_ = compare_func;
#line 4965 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
	_data80_->compare_func = _tmp0_;
#line 4966 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
	g_ptr_array_sort_with_data (self, ___lambda1__gcompare_data_func, _data80_);
#line 4965 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
	block80_data_unref (_data80_);
#line 4965 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
	_data80_ = NULL;
#line 3532 "spice-display.c"
}


static gint _____lambda76_ (SpiceUsbDevice* a, SpiceUsbDevice* b) {
	gint result = 0;
	gchar* str_a = NULL;
	SpiceUsbDevice* _tmp0_;
	gchar* _tmp1_;
	gchar* str_b = NULL;
	SpiceUsbDevice* _tmp2_;
	gchar* _tmp3_;
	GCompareFunc _tmp4_;
	gint _tmp5_;
#line 523 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (a != NULL, 0);
#line 523 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (b != NULL, 0);
#line 524 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp0_ = a;
#line 524 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp1_ = spice_usb_device_get_description (_tmp0_, "    %1$s %2$s");
#line 524 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	str_a = _tmp1_;
#line 525 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp2_ = b;
#line 525 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp3_ = spice_usb_device_get_description (_tmp2_, "    %1$s %2$s");
#line 525 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	str_b = _tmp3_;
#line 527 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp4_ = g_strcmp0;
#line 527 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp5_ = _tmp4_ (str_a, str_b);
#line 527 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	result = _tmp5_;
#line 527 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_free0 (str_b);
#line 527 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_free0 (str_a);
#line 527 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	return result;
#line 3574 "spice-display.c"
}


static gint ______lambda76__gcompare_func (gconstpointer a, gconstpointer b) {
	gint result;
	result = _____lambda76_ ((SpiceUsbDevice*) a, (SpiceUsbDevice*) b);
#line 523 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	return result;
#line 3583 "spice-display.c"
}


static void _____lambda79_ (Block79Data* _data79_, SpiceUsbDeviceManager* manager, SpiceUsbDevice* dev) {
	BoxesSpiceDisplay* self;
	BoxesProperty* _tmp0_;
#line 534 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self = _data79_->self;
#line 534 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (manager != NULL);
#line 534 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (dev != NULL);
#line 535 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp0_ = _data79_->usb_property;
#line 535 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_signal_emit_by_name (_tmp0_, "refresh-properties");
#line 3600 "spice-display.c"
}


static void ______lambda79__spice_usb_device_manager_device_added (SpiceUsbDeviceManager* _sender, SpiceUsbDevice* device, gpointer self) {
#line 534 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_____lambda79_ (self, _sender, device);
#line 3607 "spice-display.c"
}


static void _____lambda80_ (Block79Data* _data79_, SpiceUsbDeviceManager* manager, SpiceUsbDevice* dev) {
	BoxesSpiceDisplay* self;
	BoxesProperty* _tmp0_;
#line 537 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self = _data79_->self;
#line 537 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (manager != NULL);
#line 537 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (dev != NULL);
#line 538 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp0_ = _data79_->usb_property;
#line 538 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_signal_emit_by_name (_tmp0_, "refresh-properties");
#line 3624 "spice-display.c"
}


static void ______lambda80__spice_usb_device_manager_device_removed (SpiceUsbDeviceManager* _sender, SpiceUsbDevice* device, gpointer self) {
#line 537 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_____lambda80_ (self, _sender, device);
#line 3631 "spice-display.c"
}


static inline void _g_list_free__g_object_unref0_ (GList* self) {
#line 518 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_list_free_full (self, (GDestroyNotify) _g_object_unref0_);
#line 3638 "spice-display.c"
}


static GList* boxes_spice_display_real_get_properties (BoxesDisplay* base, BoxesPropertiesPage page) {
	BoxesSpiceDisplay * self;
	GList* result = NULL;
	GList* list = NULL;
	BoxesPropertiesPage _tmp0_;
	GError * _inner_error_ = NULL;
#line 491 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) base;
#line 492 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	list = NULL;
#line 494 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp0_ = page;
#line 494 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	switch (_tmp0_) {
#line 494 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		case BOXES_PROPERTIES_PAGE_GENERAL:
#line 3658 "spice-display.c"
		{
			GtkSwitch* toggle = NULL;
			GtkSwitch* _tmp1_;
			SpiceGtkSession* _tmp2_;
			GtkSwitch* _tmp3_;
			GtkSwitch* _tmp4_;
			GtkSwitch* _tmp5_;
			BoxesProperty* _tmp6_;
			BoxesProperty* _tmp7_;
			gboolean _tmp8_ = FALSE;
			gboolean _tmp9_;
			gchar* message = NULL;
			gchar* _tmp14_;
			GtkLabel* label = NULL;
			const gchar* _tmp15_;
			GtkLabel* _tmp16_;
			GtkLabel* _tmp17_;
			GtkLabel* _tmp18_;
			GtkLabel* _tmp19_;
			GtkLabel* _tmp20_;
			GtkLabel* _tmp21_;
			GtkLabel* _tmp22_;
			GtkStyleContext* _tmp23_;
			GtkLabel* _tmp24_;
			BoxesProperty* _tmp25_;
			BoxesProperty* _tmp26_;
#line 496 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp1_ = (GtkSwitch*) gtk_switch_new ();
#line 496 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			g_object_ref_sink (_tmp1_);
#line 496 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			toggle = _tmp1_;
#line 497 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp2_ = self->priv->gtk_session;
#line 497 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp3_ = toggle;
#line 497 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			g_object_bind_property_with_closures ((GObject*) _tmp2_, "auto-clipboard", (GObject*) _tmp3_, "active", G_BINDING_BIDIRECTIONAL | G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)));
#line 499 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp4_ = toggle;
#line 499 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			gtk_widget_set_halign ((GtkWidget*) _tmp4_, GTK_ALIGN_START);
#line 500 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp5_ = toggle;
#line 500 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp6_ = boxes_iproperties_provider_add_property ((BoxesIPropertiesProvider*) self, &list, _ ("Share Clipboard"), (GtkWidget*) _tmp5_, NULL);
#line 500 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp7_ = _tmp6_;
#line 500 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_g_object_unref0 (_tmp7_);
#line 502 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp9_ = ((BoxesDisplay*) self)->connected;
#line 502 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			if (!_tmp9_) {
#line 502 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp8_ = TRUE;
#line 3715 "spice-display.c"
			} else {
				SpiceMainChannel* _tmp10_;
				SpiceMainChannel* _tmp11_;
				gboolean _tmp12_;
				gboolean _tmp13_;
#line 502 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp10_ = boxes_spice_display_get_main_channel (self);
#line 502 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp11_ = _tmp10_;
#line 502 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				g_object_get (_tmp11_, "agent-connected", &_tmp12_, NULL);
#line 502 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp13_ = _tmp12_;
#line 502 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp8_ = _tmp13_;
#line 3731 "spice-display.c"
			}
#line 502 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			if (_tmp8_) {
#line 503 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_g_object_unref0 (toggle);
#line 503 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				break;
#line 3739 "spice-display.c"
			}
#line 505 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp14_ = g_strdup (_ ("SPICE guest tools are not installed. These tools improve user experien" \
"ce and enable host and box interactions, such as copy&amp;paste. Pleas" \
"e visit <a href=\"http://www.spice-space.org/download.html\">http://ww" \
"w.spice-space.org/download.html</a> to download and install these tool" \
"s from within the box."));
#line 505 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			message = _tmp14_;
#line 506 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp15_ = message;
#line 506 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp16_ = (GtkLabel*) gtk_label_new (_tmp15_);
#line 506 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			g_object_ref_sink (_tmp16_);
#line 506 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			label = _tmp16_;
#line 507 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp17_ = label;
#line 507 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			gtk_widget_set_vexpand ((GtkWidget*) _tmp17_, TRUE);
#line 508 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp18_ = label;
#line 508 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			gtk_widget_set_valign ((GtkWidget*) _tmp18_, GTK_ALIGN_END);
#line 509 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp19_ = label;
#line 509 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			g_object_set (_tmp19_, "wrap", TRUE, NULL);
#line 510 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp20_ = label;
#line 510 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			gtk_label_set_max_width_chars (_tmp20_, 80);
#line 511 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp21_ = label;
#line 511 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			gtk_label_set_use_markup (_tmp21_, TRUE);
#line 512 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp22_ = label;
#line 512 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp23_ = gtk_widget_get_style_context ((GtkWidget*) _tmp22_);
#line 512 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			gtk_style_context_add_class (_tmp23_, "boxes-spice-tools-notice-label");
#line 514 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp24_ = label;
#line 514 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp25_ = boxes_iproperties_provider_add_property ((BoxesIPropertiesProvider*) self, &list, NULL, (GtkWidget*) _tmp24_, NULL);
#line 514 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp26_ = _tmp25_;
#line 514 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_g_object_unref0 (_tmp26_);
#line 515 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_g_object_unref0 (label);
#line 515 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_g_free0 (message);
#line 515 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_g_object_unref0 (toggle);
#line 515 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			break;
#line 3795 "spice-display.c"
		}
#line 494 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		case BOXES_PROPERTIES_PAGE_DEVICES:
#line 3799 "spice-display.c"
		{
			gboolean _tmp48_ = FALSE;
			SpicePortChannel* _tmp49_;
			SpiceSession* _tmp53_;
			const gchar* _tmp54_;
			GtkFrame* frame = NULL;
			GtkFrame* _tmp55_;
			GtkLabel* _tmp56_;
			GtkLabel* _tmp57_;
			GtkFrame* _tmp58_;
			BoxesProperty* _tmp59_;
			BoxesProperty* _tmp60_;
			{
				SpiceUsbDeviceManager* manager = NULL;
				SpiceSession* _tmp27_;
				SpiceUsbDeviceManager* _tmp28_;
				SpiceUsbDeviceManager* _tmp29_;
				GPtrArray* devs = NULL;
				SpiceUsbDeviceManager* _tmp30_;
				GPtrArray* _tmp31_;
				gboolean _tmp32_ = FALSE;
				gboolean _tmp33_;
#line 519 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp27_ = self->priv->session;
#line 519 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp28_ = spice_usb_device_manager_get (_tmp27_, &_inner_error_);
#line 519 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp29_ = _g_object_ref0 (_tmp28_);
#line 519 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				manager = _tmp29_;
#line 519 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3832 "spice-display.c"
					goto __catch81_g_error;
				}
#line 520 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp30_ = manager;
#line 520 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp31_ = boxes_spice_display_get_usb_devices (self, _tmp30_);
#line 520 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				devs = _tmp31_;
#line 522 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp33_ = ((BoxesDisplay*) self)->connected;
#line 522 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				if (_tmp33_) {
#line 3845 "spice-display.c"
					GPtrArray* _tmp34_;
					gint _tmp35_;
					gint _tmp36_;
#line 522 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_tmp34_ = devs;
#line 522 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_tmp35_ = g_ptr_array_get_length (_tmp34_);
#line 522 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_tmp36_ = _tmp35_;
#line 522 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_tmp32_ = _tmp36_ > 0;
#line 3857 "spice-display.c"
				} else {
#line 522 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_tmp32_ = FALSE;
#line 3861 "spice-display.c"
				}
#line 522 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				if (_tmp32_) {
#line 3865 "spice-display.c"
					Block79Data* _data79_;
					GPtrArray* _tmp37_;
					GtkFrame* frame = NULL;
					SpiceUsbDeviceManager* _tmp38_;
					GPtrArray* _tmp39_;
					GtkFrame* _tmp40_;
					GtkLabel* _tmp41_;
					GtkLabel* _tmp42_;
					GtkFrame* _tmp43_;
					BoxesProperty* _tmp44_;
					BoxesProperty* _tmp45_;
					SpiceUsbDeviceManager* _tmp46_;
					SpiceUsbDeviceManager* _tmp47_;
#line 522 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_data79_ = g_slice_new0 (Block79Data);
#line 522 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_data79_->_ref_count_ = 1;
#line 522 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_data79_->self = g_object_ref (self);
#line 523 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_tmp37_ = devs;
#line 523 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					vala_g_ptr_array_sort (_tmp37_, ______lambda76__gcompare_func);
#line 530 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_tmp38_ = manager;
#line 530 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_tmp39_ = devs;
#line 530 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_tmp40_ = boxes_spice_display_create_usb_frame (self, _tmp38_, _tmp39_);
#line 530 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					frame = _tmp40_;
#line 532 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_tmp41_ = (GtkLabel*) gtk_label_new ("");
#line 532 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					g_object_ref_sink (_tmp41_);
#line 532 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_tmp42_ = _tmp41_;
#line 532 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_tmp43_ = frame;
#line 532 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_tmp44_ = boxes_iproperties_provider_add_property ((BoxesIPropertiesProvider*) self, &list, _ ("USB devices"), (GtkWidget*) _tmp42_, (GtkWidget*) _tmp43_);
#line 532 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_tmp45_ = _tmp44_;
#line 532 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_g_object_unref0 (_tmp42_);
#line 532 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_data79_->usb_property = _tmp45_;
#line 534 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_tmp46_ = manager;
#line 534 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					g_signal_connect_data (_tmp46_, "device-added", (GCallback) ______lambda79__spice_usb_device_manager_device_added, block79_data_ref (_data79_), (GClosureNotify) block79_data_unref, 0);
#line 537 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_tmp47_ = manager;
#line 537 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					g_signal_connect_data (_tmp47_, "device-removed", (GCallback) ______lambda80__spice_usb_device_manager_device_removed, block79_data_ref (_data79_), (GClosureNotify) block79_data_unref, 0);
#line 522 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_g_object_unref0 (frame);
#line 522 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					block79_data_unref (_data79_);
#line 522 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_data79_ = NULL;
#line 3927 "spice-display.c"
				}
#line 518 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_g_ptr_array_unref0 (devs);
#line 518 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_g_object_unref0 (manager);
#line 3933 "spice-display.c"
			}
			goto __finally81;
			__catch81_g_error:
			{
				GError* _error_ = NULL;
#line 518 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_error_ = _inner_error_;
#line 518 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_inner_error_ = NULL;
#line 518 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_g_error_free0 (_error_);
#line 3945 "spice-display.c"
			}
			__finally81:
#line 518 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 518 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				__g_list_free__g_object_unref0_0 (list);
#line 518 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 518 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				g_clear_error (&_inner_error_);
#line 518 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				return NULL;
#line 3958 "spice-display.c"
			}
#line 544 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp49_ = self->priv->webdav_channel;
#line 544 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			if (_tmp49_ == NULL) {
#line 544 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp48_ = TRUE;
#line 3966 "spice-display.c"
			} else {
				SpicePortChannel* _tmp50_;
				gboolean _tmp51_;
				gboolean _tmp52_;
#line 544 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp50_ = self->priv->webdav_channel;
#line 544 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				g_object_get (_tmp50_, "port-opened", &_tmp51_, NULL);
#line 544 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp52_ = _tmp51_;
#line 544 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp48_ = !_tmp52_;
#line 3979 "spice-display.c"
			}
#line 544 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			if (_tmp48_) {
#line 545 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				break;
#line 3985 "spice-display.c"
			}
#line 547 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp53_ = self->priv->session;
#line 547 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp54_ = self->priv->shared_folder;
#line 547 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			g_object_set (_tmp53_, "shared-dir", _tmp54_, NULL);
#line 549 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp55_ = boxes_spice_display_create_shared_folders_frame (self);
#line 549 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			frame = _tmp55_;
#line 550 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp56_ = (GtkLabel*) gtk_label_new ("");
#line 550 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			g_object_ref_sink (_tmp56_);
#line 550 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp57_ = _tmp56_;
#line 550 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp58_ = frame;
#line 550 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp59_ = boxes_iproperties_provider_add_property ((BoxesIPropertiesProvider*) self, &list, _ ("Folder Shares"), (GtkWidget*) _tmp57_, (GtkWidget*) _tmp58_);
#line 550 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp60_ = _tmp59_;
#line 550 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_g_object_unref0 (_tmp60_);
#line 550 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_g_object_unref0 (_tmp57_);
#line 552 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_g_object_unref0 (frame);
#line 552 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			break;
#line 4017 "spice-display.c"
		}
		default:
#line 494 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		break;
#line 4022 "spice-display.c"
	}
#line 555 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	result = list;
#line 555 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	return result;
#line 4028 "spice-display.c"
}


static void boxes_spice_display_real_send_keys (BoxesDisplay* base, guint* keyvals, int keyvals_length1) {
	BoxesSpiceDisplay * self;
	SpiceDisplay* display = NULL;
	GtkWidget* _tmp0_;
	SpiceDisplay* _tmp1_;
	guint* _tmp2_;
	gint _tmp2__length1;
#line 558 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) base;
#line 560 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp0_ = boxes_display_get_display ((BoxesDisplay*) self, 0);
#line 560 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp1_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, spice_display_get_type ()) ? ((SpiceDisplay*) _tmp0_) : NULL;
#line 560 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (_tmp1_ == NULL) {
#line 560 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (_tmp0_);
#line 4049 "spice-display.c"
	}
#line 560 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	display = _tmp1_;
#line 562 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp2_ = keyvals;
#line 562 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp2__length1 = keyvals_length1;
#line 562 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	spice_display_send_keys (display, _tmp2_, _tmp2__length1, SPICE_DISPLAY_KEY_EVENT_CLICK);
#line 558 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_object_unref0 (display);
#line 4061 "spice-display.c"
}


static void __vala_SpiceUsbDevice_free0_ (gpointer var) {
#line 566 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	(var == NULL) ? NULL : (var = (_vala_SpiceUsbDevice_free (var), NULL));
#line 4068 "spice-display.c"
}


static gpointer _libusb_ref_device0 (gpointer self) {
#line 574 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	return self ? libusb_ref_device (self) : NULL;
#line 4075 "spice-display.c"
}


static GPtrArray* boxes_spice_display_get_usb_devices (BoxesSpiceDisplay* self, SpiceUsbDeviceManager* manager) {
	GPtrArray* result = NULL;
	GPtrArray* ret = NULL;
	GPtrArray* _tmp0_;
	GPtrArray* devs = NULL;
	SpiceUsbDeviceManager* _tmp1_;
	GPtrArray* _tmp2_;
	const gchar* _tmp3_;
#line 565 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 565 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (manager != NULL, NULL);
#line 566 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp0_ = g_ptr_array_new_full ((guint) 0, __vala_SpiceUsbDevice_free0_);
#line 566 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	ret = _tmp0_;
#line 567 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp1_ = manager;
#line 567 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp2_ = spice_usb_device_manager_get_devices (_tmp1_);
#line 567 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	devs = _tmp2_;
#line 569 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp3_ = g_getenv ("BOXES_USB_REDIR_ALL");
#line 569 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (_tmp3_ != NULL) {
#line 570 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		result = devs;
#line 570 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_ptr_array_unref0 (ret);
#line 570 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		return result;
#line 4111 "spice-display.c"
	}
	{
		gint i = 0;
#line 572 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		i = 0;
#line 4117 "spice-display.c"
		{
			gboolean _tmp4_ = FALSE;
#line 572 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp4_ = TRUE;
#line 572 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			while (TRUE) {
#line 4124 "spice-display.c"
				gint _tmp6_;
				GPtrArray* _tmp7_;
				gint _tmp8_;
				gint _tmp9_;
				SpiceUsbDevice* dev = NULL;
				GPtrArray* _tmp10_;
				gint _tmp11_;
				gconstpointer _tmp12_;
				SpiceUsbDevice* _tmp13_;
				libusb_device* libusb_dev = NULL;
				SpiceUsbDevice* _tmp14_;
				void* _tmp15_;
				libusb_device* _tmp16_;
				struct libusb_device_descriptor desc = {0};
				libusb_device* _tmp17_;
				struct libusb_device_descriptor _tmp18_ = {0};
				gint _tmp19_;
				struct libusb_device_descriptor _tmp20_;
				guint8 _tmp21_;
				struct libusb_device_descriptor _tmp22_;
				guint8 _tmp23_;
				struct libusb_device_descriptor _tmp24_;
				guint8 _tmp25_;
				gboolean _tmp26_;
				struct libusb_device_descriptor _tmp27_;
				guint8 _tmp28_;
				GPtrArray* _tmp78_;
				SpiceUsbDevice* _tmp79_;
				SpiceUsbDevice* _tmp80_;
#line 572 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				if (!_tmp4_) {
#line 4156 "spice-display.c"
					gint _tmp5_;
#line 572 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_tmp5_ = i;
#line 572 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					i = _tmp5_ + 1;
#line 4162 "spice-display.c"
				}
#line 572 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp4_ = FALSE;
#line 572 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp6_ = i;
#line 572 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp7_ = devs;
#line 572 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp8_ = g_ptr_array_get_length (_tmp7_);
#line 572 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp9_ = _tmp8_;
#line 572 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				if (!(_tmp6_ < _tmp9_)) {
#line 572 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					break;
#line 4178 "spice-display.c"
				}
#line 573 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp10_ = devs;
#line 573 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp11_ = i;
#line 573 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp12_ = g_ptr_array_index (_tmp10_, (guint) _tmp11_);
#line 573 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp13_ = __vala_SpiceUsbDevice_copy0 ((SpiceUsbDevice*) _tmp12_);
#line 573 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				dev = _tmp13_;
#line 574 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp14_ = dev;
#line 574 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp15_ = spice_usb_device_get_libusb_device (_tmp14_);
#line 574 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp16_ = _libusb_ref_device0 ((libusb_device*) _tmp15_);
#line 574 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				libusb_dev = _tmp16_;
#line 578 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp17_ = libusb_dev;
#line 578 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp19_ = libusb_get_device_descriptor (_tmp17_, &_tmp18_);
#line 578 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				desc = _tmp18_;
#line 578 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				if (_tmp19_ != 0) {
#line 579 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_libusb_unref_device0 (libusb_dev);
#line 579 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					__vala_SpiceUsbDevice_free0 (dev);
#line 579 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					continue;
#line 4212 "spice-display.c"
				}
#line 581 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp20_ = desc;
#line 581 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp21_ = _tmp20_.bDeviceClass;
#line 581 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp22_ = desc;
#line 581 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp23_ = _tmp22_.bDeviceSubClass;
#line 581 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp24_ = desc;
#line 581 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp25_ = _tmp24_.bDeviceProtocol;
#line 581 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp26_ = boxes_spice_display_is_usb_kbd_or_mouse (self, _tmp21_, _tmp23_, _tmp25_);
#line 581 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				if (_tmp26_) {
#line 582 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_libusb_unref_device0 (libusb_dev);
#line 582 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					__vala_SpiceUsbDevice_free0 (dev);
#line 582 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					continue;
#line 4236 "spice-display.c"
				}
#line 585 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp27_ = desc;
#line 585 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp28_ = _tmp27_.bDeviceClass;
#line 585 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				if (_tmp28_ == LIBUSB_CLASS_PER_INTERFACE) {
#line 4244 "spice-display.c"
					struct libusb_config_descriptor* config = NULL;
					libusb_device* _tmp29_;
					struct libusb_config_descriptor* _tmp30_ = NULL;
					gint _tmp31_;
					gboolean kbd_or_mouse = FALSE;
					gboolean _tmp77_;
#line 587 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_tmp29_ = libusb_dev;
#line 587 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_tmp31_ = libusb_get_active_config_descriptor (_tmp29_, &_tmp30_);
#line 587 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_libusb_free_config_descriptor0 (config);
#line 587 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					config = _tmp30_;
#line 587 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					if (_tmp31_ != 0) {
#line 588 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
						_libusb_free_config_descriptor0 (config);
#line 588 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
						_libusb_unref_device0 (libusb_dev);
#line 588 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
						__vala_SpiceUsbDevice_free0 (dev);
#line 588 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
						continue;
#line 4269 "spice-display.c"
					}
#line 590 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					kbd_or_mouse = FALSE;
#line 4273 "spice-display.c"
					{
						gint j = 0;
#line 591 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
						j = 0;
#line 4278 "spice-display.c"
						{
							gboolean _tmp32_ = FALSE;
#line 591 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
							_tmp32_ = TRUE;
#line 591 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
							while (TRUE) {
#line 4285 "spice-display.c"
								gboolean _tmp34_ = FALSE;
								gint _tmp35_;
								struct libusb_config_descriptor* _tmp36_;
								struct libusb_interface* _tmp37_;
								gint _tmp37__length1;
#line 591 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
								if (!_tmp32_) {
#line 4293 "spice-display.c"
									gint _tmp33_;
#line 591 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
									_tmp33_ = j;
#line 591 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
									j = _tmp33_ + 1;
#line 4299 "spice-display.c"
								}
#line 591 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
								_tmp32_ = FALSE;
#line 591 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
								_tmp35_ = j;
#line 591 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
								_tmp36_ = config;
#line 591 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
								_tmp37_ = _tmp36_->interface;
#line 591 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
								_tmp37__length1 = _tmp36_->bNumInterfaces;
#line 591 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
								if (_tmp35_ < _tmp37__length1) {
#line 4313 "spice-display.c"
									gboolean _tmp38_;
#line 591 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
									_tmp38_ = kbd_or_mouse;
#line 591 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
									_tmp34_ = !_tmp38_;
#line 4319 "spice-display.c"
								} else {
#line 591 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
									_tmp34_ = FALSE;
#line 4323 "spice-display.c"
								}
#line 591 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
								if (!_tmp34_) {
#line 591 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
									break;
#line 4329 "spice-display.c"
								}
								{
									gint k = 0;
#line 592 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
									k = 0;
#line 4335 "spice-display.c"
									{
										gboolean _tmp39_ = FALSE;
#line 592 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
										_tmp39_ = TRUE;
#line 592 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
										while (TRUE) {
#line 4342 "spice-display.c"
											gboolean _tmp41_ = FALSE;
											gint _tmp42_;
											struct libusb_config_descriptor* _tmp43_;
											struct libusb_interface* _tmp44_;
											gint _tmp44__length1;
											gint _tmp45_;
											struct libusb_interface _tmp46_;
											struct libusb_interface_descriptor* _tmp47_;
											gint _tmp47__length1;
											guint8 class = 0U;
											struct libusb_config_descriptor* _tmp49_;
											struct libusb_interface* _tmp50_;
											gint _tmp50__length1;
											gint _tmp51_;
											struct libusb_interface _tmp52_;
											struct libusb_interface_descriptor* _tmp53_;
											gint _tmp53__length1;
											gint _tmp54_;
											struct libusb_interface_descriptor _tmp55_;
											guint8 _tmp56_;
											guint8 subclass = 0U;
											struct libusb_config_descriptor* _tmp57_;
											struct libusb_interface* _tmp58_;
											gint _tmp58__length1;
											gint _tmp59_;
											struct libusb_interface _tmp60_;
											struct libusb_interface_descriptor* _tmp61_;
											gint _tmp61__length1;
											gint _tmp62_;
											struct libusb_interface_descriptor _tmp63_;
											guint8 _tmp64_;
											guint8 protocol = 0U;
											struct libusb_config_descriptor* _tmp65_;
											struct libusb_interface* _tmp66_;
											gint _tmp66__length1;
											gint _tmp67_;
											struct libusb_interface _tmp68_;
											struct libusb_interface_descriptor* _tmp69_;
											gint _tmp69__length1;
											gint _tmp70_;
											struct libusb_interface_descriptor _tmp71_;
											guint8 _tmp72_;
											guint8 _tmp73_;
											guint8 _tmp74_;
											guint8 _tmp75_;
											gboolean _tmp76_;
#line 592 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
											if (!_tmp39_) {
#line 4391 "spice-display.c"
												gint _tmp40_;
#line 592 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
												_tmp40_ = k;
#line 592 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
												k = _tmp40_ + 1;
#line 4397 "spice-display.c"
											}
#line 592 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
											_tmp39_ = FALSE;
#line 592 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
											_tmp42_ = k;
#line 592 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
											_tmp43_ = config;
#line 592 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
											_tmp44_ = _tmp43_->interface;
#line 592 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
											_tmp44__length1 = _tmp43_->bNumInterfaces;
#line 592 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
											_tmp45_ = j;
#line 592 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
											_tmp46_ = _tmp44_[_tmp45_];
#line 592 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
											_tmp47_ = _tmp46_.altsetting;
#line 592 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
											_tmp47__length1 = _tmp46_.num_altsetting;
#line 592 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
											if (_tmp42_ < _tmp47__length1) {
#line 4419 "spice-display.c"
												gboolean _tmp48_;
#line 592 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
												_tmp48_ = kbd_or_mouse;
#line 592 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
												_tmp41_ = !_tmp48_;
#line 4425 "spice-display.c"
											} else {
#line 592 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
												_tmp41_ = FALSE;
#line 4429 "spice-display.c"
											}
#line 592 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
											if (!_tmp41_) {
#line 592 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
												break;
#line 4435 "spice-display.c"
											}
#line 593 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
											_tmp49_ = config;
#line 593 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
											_tmp50_ = _tmp49_->interface;
#line 593 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
											_tmp50__length1 = _tmp49_->bNumInterfaces;
#line 593 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
											_tmp51_ = j;
#line 593 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
											_tmp52_ = _tmp50_[_tmp51_];
#line 593 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
											_tmp53_ = _tmp52_.altsetting;
#line 593 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
											_tmp53__length1 = _tmp52_.num_altsetting;
#line 593 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
											_tmp54_ = k;
#line 593 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
											_tmp55_ = _tmp53_[_tmp54_];
#line 593 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
											_tmp56_ = _tmp55_.bInterfaceClass;
#line 593 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
											class = _tmp56_;
#line 594 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
											_tmp57_ = config;
#line 594 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
											_tmp58_ = _tmp57_->interface;
#line 594 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
											_tmp58__length1 = _tmp57_->bNumInterfaces;
#line 594 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
											_tmp59_ = j;
#line 594 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
											_tmp60_ = _tmp58_[_tmp59_];
#line 594 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
											_tmp61_ = _tmp60_.altsetting;
#line 594 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
											_tmp61__length1 = _tmp60_.num_altsetting;
#line 594 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
											_tmp62_ = k;
#line 594 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
											_tmp63_ = _tmp61_[_tmp62_];
#line 594 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
											_tmp64_ = _tmp63_.bInterfaceSubClass;
#line 594 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
											subclass = _tmp64_;
#line 595 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
											_tmp65_ = config;
#line 595 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
											_tmp66_ = _tmp65_->interface;
#line 595 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
											_tmp66__length1 = _tmp65_->bNumInterfaces;
#line 595 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
											_tmp67_ = j;
#line 595 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
											_tmp68_ = _tmp66_[_tmp67_];
#line 595 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
											_tmp69_ = _tmp68_.altsetting;
#line 595 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
											_tmp69__length1 = _tmp68_.num_altsetting;
#line 595 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
											_tmp70_ = k;
#line 595 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
											_tmp71_ = _tmp69_[_tmp70_];
#line 595 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
											_tmp72_ = _tmp71_.bInterfaceProtocol;
#line 595 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
											protocol = _tmp72_;
#line 597 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
											_tmp73_ = class;
#line 597 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
											_tmp74_ = subclass;
#line 597 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
											_tmp75_ = protocol;
#line 597 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
											_tmp76_ = boxes_spice_display_is_usb_kbd_or_mouse (self, _tmp73_, _tmp74_, _tmp75_);
#line 597 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
											kbd_or_mouse = _tmp76_;
#line 4513 "spice-display.c"
										}
									}
								}
							}
						}
					}
#line 601 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_tmp77_ = kbd_or_mouse;
#line 601 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					if (_tmp77_) {
#line 602 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
						_libusb_free_config_descriptor0 (config);
#line 602 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
						_libusb_unref_device0 (libusb_dev);
#line 602 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
						__vala_SpiceUsbDevice_free0 (dev);
#line 602 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
						continue;
#line 4532 "spice-display.c"
					}
#line 585 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_libusb_free_config_descriptor0 (config);
#line 4536 "spice-display.c"
				}
#line 605 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp78_ = ret;
#line 605 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp79_ = dev;
#line 605 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp80_ = __vala_SpiceUsbDevice_copy0 (_tmp79_);
#line 605 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				g_ptr_array_add (_tmp78_, _tmp80_);
#line 572 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_libusb_unref_device0 (libusb_dev);
#line 572 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				__vala_SpiceUsbDevice_free0 (dev);
#line 4550 "spice-display.c"
			}
		}
	}
#line 608 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	result = ret;
#line 608 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_ptr_array_unref0 (devs);
#line 608 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	return result;
#line 4560 "spice-display.c"
}


static Block81Data* block81_data_ref (Block81Data* _data81_) {
#line 611 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_atomic_int_inc (&_data81_->_ref_count_);
#line 611 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	return _data81_;
#line 4569 "spice-display.c"
}


static void block81_data_unref (void * _userdata_) {
	Block81Data* _data81_;
	_data81_ = (Block81Data*) _userdata_;
#line 611 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (g_atomic_int_dec_and_test (&_data81_->_ref_count_)) {
#line 4578 "spice-display.c"
		BoxesSpiceDisplay* self;
#line 611 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		self = _data81_->self;
#line 611 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (_data81_->manager);
#line 611 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (self);
#line 611 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_slice_free (Block81Data, _data81_);
#line 4588 "spice-display.c"
	}
}


static Block82Data* block82_data_ref (Block82Data* _data82_) {
#line 617 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_atomic_int_inc (&_data82_->_ref_count_);
#line 617 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	return _data82_;
#line 4598 "spice-display.c"
}


static void block82_data_unref (void * _userdata_) {
	Block82Data* _data82_;
	_data82_ = (Block82Data*) _userdata_;
#line 617 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (g_atomic_int_dec_and_test (&_data82_->_ref_count_)) {
#line 4607 "spice-display.c"
		BoxesSpiceDisplay* self;
#line 617 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		self = _data82_->_data81_->self;
#line 617 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (_data82_->dev_toggle);
#line 617 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		__vala_SpiceUsbDevice_free0 (_data82_->dev);
#line 617 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		block81_data_unref (_data82_->_data81_);
#line 617 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_data82_->_data81_ = NULL;
#line 617 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_slice_free (Block82Data, _data82_);
#line 4621 "spice-display.c"
	}
}


static void ___lambda78_ (Block82Data* _data82_, GObject* obj, GAsyncResult* res) {
	Block81Data* _data81_;
	BoxesSpiceDisplay* self;
	GError * _inner_error_ = NULL;
#line 637 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_data81_ = _data82_->_data81_;
#line 637 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self = _data81_->self;
#line 637 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (res != NULL);
#line 4636 "spice-display.c"
	{
		SpiceUsbDeviceManager* _tmp0_;
		GAsyncResult* _tmp1_;
#line 639 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp0_ = _data81_->manager;
#line 639 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp1_ = res;
#line 639 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		spice_usb_device_manager_connect_device_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 639 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 4648 "spice-display.c"
			goto __catch82_g_error;
		}
	}
	goto __finally82;
	__catch82_g_error:
	{
		GError* err = NULL;
		GtkSwitch* _tmp2_;
		gchar* device_desc = NULL;
		SpiceUsbDevice* _tmp3_;
		gchar* _tmp4_;
		gchar* box_name = NULL;
		gchar* _tmp5_;
		gchar* msg = NULL;
		gchar* _tmp6_;
		const gchar* _tmp7_;
		const gchar* _tmp8_;
		const gchar* _tmp9_;
		gchar* _tmp10_;
		gchar* _tmp11_;
		const gchar* _tmp12_;
		const gchar* _tmp13_;
		GError* _tmp14_;
		const gchar* _tmp15_;
#line 638 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		err = _inner_error_;
#line 638 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_inner_error_ = NULL;
#line 641 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp2_ = _data82_->dev_toggle;
#line 641 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		gtk_switch_set_active (_tmp2_, FALSE);
#line 642 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp3_ = _data82_->dev;
#line 642 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp4_ = spice_usb_device_get_description (_tmp3_, "%1$s %2$s");
#line 642 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		device_desc = _tmp4_;
#line 643 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp5_ = boxes_spice_display_get_box_name (self);
#line 643 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		box_name = _tmp5_;
#line 644 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp6_ = g_strdup (_ ("Redirection of USB device “%s” for “%s” failed"));
#line 644 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		msg = _tmp6_;
#line 645 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp7_ = msg;
#line 645 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp8_ = device_desc;
#line 645 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp9_ = box_name;
#line 645 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp10_ = g_strdup_printf (_tmp7_, _tmp8_, _tmp9_);
#line 645 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp11_ = _tmp10_;
#line 645 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_signal_emit_by_name ((BoxesDisplay*) self, "got-error", _tmp11_);
#line 645 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_free0 (_tmp11_);
#line 646 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp12_ = device_desc;
#line 646 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp13_ = box_name;
#line 646 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp14_ = err;
#line 646 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp15_ = _tmp14_->message;
#line 646 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_debug ("spice-display.vala:646: Error connecting %s to %s: %s", _tmp12_, _tmp13_, _tmp15_);
#line 638 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_free0 (msg);
#line 638 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_free0 (box_name);
#line 638 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_free0 (device_desc);
#line 638 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_error_free0 (err);
#line 4727 "spice-display.c"
	}
	__finally82:
#line 638 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 638 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 638 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_clear_error (&_inner_error_);
#line 638 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		return;
#line 4738 "spice-display.c"
	}
}


static void ____lambda78__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 637 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	___lambda78_ (self, source_object, res);
#line 637 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	block82_data_unref (self);
#line 4748 "spice-display.c"
}


static void _____lambda77_ (Block82Data* _data82_) {
	Block81Data* _data81_;
	BoxesSpiceDisplay* self;
	GtkSwitch* _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
#line 635 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_data81_ = _data82_->_data81_;
#line 635 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self = _data81_->self;
#line 636 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp0_ = _data82_->dev_toggle;
#line 636 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp1_ = gtk_switch_get_active (_tmp0_);
#line 636 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp2_ = _tmp1_;
#line 636 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (_tmp2_) {
#line 4770 "spice-display.c"
		SpiceUsbDeviceManager* _tmp3_;
		SpiceUsbDevice* _tmp4_;
#line 637 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp3_ = _data81_->manager;
#line 637 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp4_ = _data82_->dev;
#line 637 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		spice_usb_device_manager_connect_device_async (_tmp3_, _tmp4_, NULL, ____lambda78__gasync_ready_callback, block82_data_ref (_data82_));
#line 4779 "spice-display.c"
	} else {
		SpiceUsbDeviceManager* _tmp5_;
		SpiceUsbDevice* _tmp6_;
#line 652 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp5_ = _data81_->manager;
#line 652 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp6_ = _data82_->dev;
#line 652 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		spice_usb_device_manager_disconnect_device (_tmp5_, _tmp6_);
#line 4789 "spice-display.c"
	}
}


static void ______lambda77__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 635 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_____lambda77_ (self);
#line 4797 "spice-display.c"
}


static GtkFrame* boxes_spice_display_create_usb_frame (BoxesSpiceDisplay* self, SpiceUsbDeviceManager* manager, GPtrArray* devs) {
	GtkFrame* result = NULL;
	Block81Data* _data81_;
	SpiceUsbDeviceManager* _tmp0_;
	SpiceUsbDeviceManager* _tmp1_;
	GtkFrame* frame = NULL;
	GtkFrame* _tmp2_;
	GtkListBox* listbox = NULL;
	GtkListBox* _tmp3_;
	GtkListBox* _tmp4_;
	GtkFrame* _tmp5_;
	GtkListBox* _tmp6_;
#line 611 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 611 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (manager != NULL, NULL);
#line 611 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (devs != NULL, NULL);
#line 611 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_data81_ = g_slice_new0 (Block81Data);
#line 611 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_data81_->_ref_count_ = 1;
#line 611 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_data81_->self = g_object_ref (self);
#line 611 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp0_ = manager;
#line 611 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 611 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_object_unref0 (_data81_->manager);
#line 611 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_data81_->manager = _tmp1_;
#line 612 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp2_ = (GtkFrame*) gtk_frame_new (NULL);
#line 612 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_object_ref_sink (_tmp2_);
#line 612 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	frame = _tmp2_;
#line 613 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp3_ = (GtkListBox*) gtk_list_box_new ();
#line 613 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_object_ref_sink (_tmp3_);
#line 613 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	listbox = _tmp3_;
#line 614 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp4_ = listbox;
#line 614 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	gtk_widget_set_hexpand ((GtkWidget*) _tmp4_, TRUE);
#line 615 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp5_ = frame;
#line 615 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp6_ = listbox;
#line 615 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	gtk_container_add ((GtkContainer*) _tmp5_, (GtkWidget*) _tmp6_);
#line 4855 "spice-display.c"
	{
		gint i = 0;
#line 617 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		i = 0;
#line 4860 "spice-display.c"
		{
			gboolean _tmp7_ = FALSE;
#line 617 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp7_ = TRUE;
#line 617 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			while (TRUE) {
#line 4867 "spice-display.c"
				Block82Data* _data82_;
				gint _tmp9_;
				GPtrArray* _tmp10_;
				gint _tmp11_;
				gint _tmp12_;
				GPtrArray* _tmp13_;
				gint _tmp14_;
				gconstpointer _tmp15_;
				SpiceUsbDevice* _tmp16_;
				GtkBox* hbox = NULL;
				GtkBox* _tmp17_;
				GtkBox* _tmp18_;
				GtkBox* _tmp19_;
				GtkBox* _tmp20_;
				GtkBox* _tmp21_;
				GtkLabel* label = NULL;
				SpiceUsbDevice* _tmp22_;
				gchar* _tmp23_;
				gchar* _tmp24_;
				GtkLabel* _tmp25_;
				GtkLabel* _tmp26_;
				GtkLabel* _tmp27_;
				GtkBox* _tmp28_;
				GtkLabel* _tmp29_;
				GtkSwitch* _tmp30_;
				GtkSwitch* _tmp31_;
				GtkBox* _tmp32_;
				GtkSwitch* _tmp33_;
				GtkListBox* _tmp34_;
				GtkBox* _tmp35_;
				GtkSwitch* _tmp36_;
				SpiceUsbDeviceManager* _tmp37_;
				SpiceUsbDevice* _tmp38_;
				gboolean _tmp39_;
				GtkSwitch* _tmp40_;
#line 617 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_data82_ = g_slice_new0 (Block82Data);
#line 617 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_data82_->_ref_count_ = 1;
#line 617 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_data82_->_data81_ = block81_data_ref (_data81_);
#line 617 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				if (!_tmp7_) {
#line 4911 "spice-display.c"
					gint _tmp8_;
#line 617 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_tmp8_ = i;
#line 617 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					i = _tmp8_ + 1;
#line 4917 "spice-display.c"
				}
#line 617 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp7_ = FALSE;
#line 617 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp9_ = i;
#line 617 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp10_ = devs;
#line 617 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp11_ = g_ptr_array_get_length (_tmp10_);
#line 617 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp12_ = _tmp11_;
#line 617 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				if (!(_tmp9_ < _tmp12_)) {
#line 617 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					block82_data_unref (_data82_);
#line 617 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_data82_ = NULL;
#line 617 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					break;
#line 4937 "spice-display.c"
				}
#line 618 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp13_ = devs;
#line 618 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp14_ = i;
#line 618 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp15_ = g_ptr_array_index (_tmp13_, (guint) _tmp14_);
#line 618 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp16_ = __vala_SpiceUsbDevice_copy0 ((SpiceUsbDevice*) _tmp15_);
#line 618 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_data82_->dev = _tmp16_;
#line 620 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp17_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
#line 620 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				g_object_ref_sink (_tmp17_);
#line 620 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				hbox = _tmp17_;
#line 621 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp18_ = hbox;
#line 621 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				gtk_widget_set_margin_start ((GtkWidget*) _tmp18_, 12);
#line 622 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp19_ = hbox;
#line 622 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				gtk_widget_set_margin_end ((GtkWidget*) _tmp19_, 12);
#line 623 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp20_ = hbox;
#line 623 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				gtk_widget_set_margin_top ((GtkWidget*) _tmp20_, 6);
#line 624 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp21_ = hbox;
#line 624 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				gtk_widget_set_margin_bottom ((GtkWidget*) _tmp21_, 6);
#line 625 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp22_ = _data82_->dev;
#line 625 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp23_ = spice_usb_device_get_description (_tmp22_, "%1$s %2$s");
#line 625 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp24_ = _tmp23_;
#line 625 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp25_ = (GtkLabel*) gtk_label_new (_tmp24_);
#line 625 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				g_object_ref_sink (_tmp25_);
#line 625 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp26_ = _tmp25_;
#line 625 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_g_free0 (_tmp24_);
#line 625 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				label = _tmp26_;
#line 626 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp27_ = label;
#line 626 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				gtk_widget_set_halign ((GtkWidget*) _tmp27_, GTK_ALIGN_START);
#line 627 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp28_ = hbox;
#line 627 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp29_ = label;
#line 627 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				gtk_box_pack_start (_tmp28_, (GtkWidget*) _tmp29_, TRUE, TRUE, (guint) 0);
#line 628 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp30_ = (GtkSwitch*) gtk_switch_new ();
#line 628 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				g_object_ref_sink (_tmp30_);
#line 628 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_data82_->dev_toggle = _tmp30_;
#line 629 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp31_ = _data82_->dev_toggle;
#line 629 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				gtk_widget_set_halign ((GtkWidget*) _tmp31_, GTK_ALIGN_END);
#line 630 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp32_ = hbox;
#line 630 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp33_ = _data82_->dev_toggle;
#line 630 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				gtk_box_pack_start (_tmp32_, (GtkWidget*) _tmp33_, TRUE, TRUE, (guint) 0);
#line 631 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp34_ = listbox;
#line 631 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp35_ = hbox;
#line 631 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				gtk_list_box_prepend (_tmp34_, (GtkWidget*) _tmp35_);
#line 633 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp36_ = _data82_->dev_toggle;
#line 633 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp37_ = _data81_->manager;
#line 633 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp38_ = _data82_->dev;
#line 633 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp39_ = spice_usb_device_manager_is_device_connected (_tmp37_, _tmp38_);
#line 633 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				gtk_switch_set_active (_tmp36_, _tmp39_);
#line 635 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp40_ = _data82_->dev_toggle;
#line 635 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				g_signal_connect_data ((GObject*) _tmp40_, "notify::active", (GCallback) ______lambda77__g_object_notify, block82_data_ref (_data82_), (GClosureNotify) block82_data_unref, 0);
#line 617 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_g_object_unref0 (label);
#line 617 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_g_object_unref0 (hbox);
#line 617 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				block82_data_unref (_data82_);
#line 617 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_data82_ = NULL;
#line 5041 "spice-display.c"
			}
		}
	}
#line 657 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	result = frame;
#line 657 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_object_unref0 (listbox);
#line 657 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	block81_data_unref (_data81_);
#line 657 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_data81_ = NULL;
#line 657 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	return result;
#line 5055 "spice-display.c"
}


static Block83Data* block83_data_ref (Block83Data* _data83_) {
#line 660 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_atomic_int_inc (&_data83_->_ref_count_);
#line 660 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	return _data83_;
#line 5064 "spice-display.c"
}


static void block83_data_unref (void * _userdata_) {
	Block83Data* _data83_;
	_data83_ = (Block83Data*) _userdata_;
#line 660 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (g_atomic_int_dec_and_test (&_data83_->_ref_count_)) {
#line 5073 "spice-display.c"
		BoxesSpiceDisplay* self;
#line 660 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		self = _data83_->self;
#line 660 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (_data83_->popover);
#line 660 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (_data83_->button_plus);
#line 660 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (_data83_->listbox);
#line 660 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (self);
#line 660 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_slice_free (Block83Data, _data83_);
#line 5087 "spice-display.c"
	}
}


static void __lambda81_ (Block83Data* _data83_) {
	BoxesSpiceDisplay* self;
	BoxesSharedFolderPopover* _tmp0_;
	GtkButton* _tmp1_;
	BoxesSharedFolderPopover* _tmp2_;
	BoxesSharedFolderPopover* _tmp3_;
#line 674 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self = _data83_->self;
#line 675 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp0_ = _data83_->popover;
#line 675 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp1_ = _data83_->button_plus;
#line 675 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	gtk_popover_set_relative_to ((GtkPopover*) _tmp0_, (GtkWidget*) _tmp1_);
#line 676 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp2_ = _data83_->popover;
#line 676 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp2_->target_position = -1;
#line 678 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp3_ = _data83_->popover;
#line 678 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	gtk_popover_popup ((GtkPopover*) _tmp3_);
#line 5114 "spice-display.c"
}


static void ___lambda81__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 674 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	__lambda81_ (self);
#line 5121 "spice-display.c"
}


static void __lambda82_ (Block83Data* _data83_, GtkListBoxRow* row) {
	BoxesSpiceDisplay* self;
	BoxesSharedFolderPopover* _tmp0_;
	GtkListBoxRow* _tmp1_;
	BoxesSharedFolderPopover* _tmp2_;
	GtkListBoxRow* _tmp3_;
	gint _tmp4_;
	BoxesSharedFolderRow* folder_row = NULL;
	GtkListBoxRow* _tmp5_;
	BoxesSharedFolderRow* _tmp6_;
	BoxesSharedFolderPopover* _tmp7_;
	GtkFileChooserButton* _tmp8_;
	const gchar* _tmp9_;
	const gchar* _tmp10_;
	gchar* _tmp11_;
	gchar* _tmp12_;
	BoxesSharedFolderPopover* _tmp13_;
	GtkEntry* _tmp14_;
	const gchar* _tmp15_;
	const gchar* _tmp16_;
	BoxesSharedFolderPopover* _tmp17_;
#line 681 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self = _data83_->self;
#line 681 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (row != NULL);
#line 682 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp0_ = _data83_->popover;
#line 682 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp1_ = row;
#line 682 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	gtk_popover_set_relative_to ((GtkPopover*) _tmp0_, (GtkWidget*) _tmp1_);
#line 683 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp2_ = _data83_->popover;
#line 683 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp3_ = row;
#line 683 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp4_ = gtk_list_box_row_get_index (_tmp3_);
#line 683 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp2_->target_position = _tmp4_;
#line 685 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp5_ = row;
#line 685 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp6_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, BOXES_TYPE_SHARED_FOLDER_ROW) ? ((BoxesSharedFolderRow*) _tmp5_) : NULL);
#line 685 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	folder_row = _tmp6_;
#line 686 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp7_ = _data83_->popover;
#line 686 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp8_ = _tmp7_->file_chooser_button;
#line 686 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp9_ = boxes_shared_folder_row_get_folder_path (folder_row);
#line 686 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp10_ = _tmp9_;
#line 686 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp11_ = g_strconcat ("file://", _tmp10_, NULL);
#line 686 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp12_ = _tmp11_;
#line 686 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	gtk_file_chooser_set_uri ((GtkFileChooser*) _tmp8_, _tmp12_);
#line 686 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_free0 (_tmp12_);
#line 687 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp13_ = _data83_->popover;
#line 687 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp14_ = _tmp13_->name_entry;
#line 687 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp15_ = boxes_shared_folder_row_get_folder_name (folder_row);
#line 687 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp16_ = _tmp15_;
#line 687 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	gtk_entry_set_text (_tmp14_, _tmp16_);
#line 689 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp17_ = _data83_->popover;
#line 689 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	gtk_popover_popup ((GtkPopover*) _tmp17_);
#line 681 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_object_unref0 (folder_row);
#line 5202 "spice-display.c"
}


static void ___lambda82__gtk_list_box_row_activated (GtkListBox* _sender, GtkListBoxRow* row, gpointer self) {
#line 681 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	__lambda82_ (self, row);
#line 5209 "spice-display.c"
}


static void __lambda84_ (Block83Data* _data83_, const gchar* path, const gchar* name, gint target_position) {
	BoxesSpiceDisplay* self;
	gint _tmp0_;
	const gchar* _tmp8_;
	const gchar* _tmp9_;
	gboolean _tmp10_;
#line 700 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self = _data83_->self;
#line 700 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (path != NULL);
#line 700 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (name != NULL);
#line 702 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp0_ = target_position;
#line 702 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (_tmp0_ != -1) {
#line 5229 "spice-display.c"
		BoxesSharedFolderRow* row = NULL;
		GtkListBox* _tmp1_;
		gint _tmp2_;
		GtkListBoxRow* _tmp3_;
		BoxesSharedFolderRow* _tmp4_;
		BoxesSharedFolderRow* _tmp5_;
		const gchar* _tmp6_;
		const gchar* _tmp7_;
#line 703 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp1_ = _data83_->listbox;
#line 703 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp2_ = target_position;
#line 703 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp3_ = gtk_list_box_get_row_at_index (_tmp1_, _tmp2_);
#line 703 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp4_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, BOXES_TYPE_SHARED_FOLDER_ROW) ? ((BoxesSharedFolderRow*) _tmp3_) : NULL);
#line 703 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		row = _tmp4_;
#line 704 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp5_ = row;
#line 704 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp6_ = boxes_shared_folder_row_get_folder_name (_tmp5_);
#line 704 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp7_ = _tmp6_;
#line 704 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		boxes_spice_display_remove_shared_folder (self, _tmp7_);
#line 702 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (row);
#line 5258 "spice-display.c"
	}
#line 707 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp8_ = path;
#line 707 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp9_ = name;
#line 707 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp10_ = boxes_spice_display_add_shared_folder (self, _tmp8_, _tmp9_);
#line 707 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (_tmp10_) {
#line 5268 "spice-display.c"
		GtkListBox* _tmp11_;
		const gchar* _tmp12_;
		const gchar* _tmp13_;
		gint _tmp14_;
#line 708 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp11_ = _data83_->listbox;
#line 708 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp12_ = path;
#line 708 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp13_ = name;
#line 708 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp14_ = target_position;
#line 708 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		boxes_spice_display_add_listbox_row (self, _tmp11_, _tmp12_, _tmp13_, _tmp14_);
#line 5283 "spice-display.c"
	}
}


static void ___lambda84__boxes_shared_folder_popover_saved (BoxesSharedFolderPopover* _sender, const gchar* local_folder, const gchar* name, gint target_position, gpointer self) {
#line 700 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	__lambda84_ (self, local_folder, name, target_position);
#line 5291 "spice-display.c"
}


static GtkFrame* boxes_spice_display_create_shared_folders_frame (BoxesSpiceDisplay* self) {
	GtkFrame* result = NULL;
	Block83Data* _data83_;
	GtkFrame* frame = NULL;
	GtkFrame* _tmp0_;
	GtkBox* box = NULL;
	GtkBox* _tmp1_;
	GtkListBox* _tmp2_;
	GtkButton* _tmp3_;
	GtkButton* _tmp4_;
	GtkButton* _tmp5_;
	GtkStyleContext* _tmp6_;
	GtkBox* _tmp7_;
	GtkListBox* _tmp8_;
	GtkBox* _tmp9_;
	GtkButton* _tmp10_;
	GtkFrame* _tmp11_;
	GtkBox* _tmp12_;
	BoxesSharedFolderPopover* _tmp13_;
	GtkButton* _tmp14_;
	GtkListBox* _tmp15_;
	GHashTable* hash = NULL;
	GHashTable* _tmp16_;
	GHashTable* _tmp17_;
	BoxesSharedFolderPopover* _tmp26_;
#line 660 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 660 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_data83_ = g_slice_new0 (Block83Data);
#line 660 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_data83_->_ref_count_ = 1;
#line 660 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_data83_->self = g_object_ref (self);
#line 661 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp0_ = (GtkFrame*) gtk_frame_new (NULL);
#line 661 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_object_ref_sink (_tmp0_);
#line 661 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	frame = _tmp0_;
#line 662 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp1_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
#line 662 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_object_ref_sink (_tmp1_);
#line 662 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	box = _tmp1_;
#line 663 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp2_ = (GtkListBox*) gtk_list_box_new ();
#line 663 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_object_ref_sink (_tmp2_);
#line 663 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_data83_->listbox = _tmp2_;
#line 664 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp3_ = (GtkButton*) gtk_button_new_from_icon_name ("list-add-symbolic", GTK_ICON_SIZE_BUTTON);
#line 664 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_object_ref_sink (_tmp3_);
#line 664 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_data83_->button_plus = _tmp3_;
#line 665 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp4_ = _data83_->button_plus;
#line 665 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	gtk_widget_set_halign ((GtkWidget*) _tmp4_, GTK_ALIGN_CENTER);
#line 666 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp5_ = _data83_->button_plus;
#line 666 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp6_ = gtk_widget_get_style_context ((GtkWidget*) _tmp5_);
#line 666 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	gtk_style_context_add_class (_tmp6_, "flat");
#line 668 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp7_ = box;
#line 668 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp8_ = _data83_->listbox;
#line 668 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	gtk_box_pack_start (_tmp7_, (GtkWidget*) _tmp8_, TRUE, TRUE, (guint) 0);
#line 669 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp9_ = box;
#line 669 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp10_ = _data83_->button_plus;
#line 669 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	gtk_box_pack_end (_tmp9_, (GtkWidget*) _tmp10_, FALSE, FALSE, (guint) 6);
#line 670 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp11_ = frame;
#line 670 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp12_ = box;
#line 670 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	gtk_container_add ((GtkContainer*) _tmp11_, (GtkWidget*) _tmp12_);
#line 672 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp13_ = boxes_shared_folder_popover_new ();
#line 672 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_object_ref_sink (_tmp13_);
#line 672 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_data83_->popover = _tmp13_;
#line 674 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp14_ = _data83_->button_plus;
#line 674 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_signal_connect_data (_tmp14_, "clicked", (GCallback) ___lambda81__gtk_button_clicked, block83_data_ref (_data83_), (GClosureNotify) block83_data_unref, 0);
#line 681 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp15_ = _data83_->listbox;
#line 681 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_signal_connect_data (_tmp15_, "row-activated", (GCallback) ___lambda82__gtk_list_box_row_activated, block83_data_ref (_data83_), (GClosureNotify) block83_data_unref, 0);
#line 692 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp16_ = boxes_spice_display_get_shared_folders (self);
#line 692 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	hash = _tmp16_;
#line 693 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp17_ = hash;
#line 693 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (_tmp17_ != NULL) {
#line 5402 "spice-display.c"
		GList* keys = NULL;
		GHashTable* _tmp18_;
		GList* _tmp19_;
		GList* _tmp20_;
#line 694 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp18_ = hash;
#line 694 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp19_ = g_hash_table_get_keys (_tmp18_);
#line 694 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		keys = _tmp19_;
#line 695 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp20_ = keys;
#line 5415 "spice-display.c"
		{
			GList* key_collection = NULL;
			GList* key_it = NULL;
#line 695 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			key_collection = _tmp20_;
#line 695 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			for (key_it = key_collection; key_it != NULL; key_it = key_it->next) {
#line 5423 "spice-display.c"
				const gchar* key = NULL;
#line 695 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				key = (const gchar*) key_it->data;
#line 5427 "spice-display.c"
				{
					GtkListBox* _tmp21_;
					GHashTable* _tmp22_;
					const gchar* _tmp23_;
					gconstpointer _tmp24_;
					const gchar* _tmp25_;
#line 696 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_tmp21_ = _data83_->listbox;
#line 696 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_tmp22_ = hash;
#line 696 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_tmp23_ = key;
#line 696 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_tmp24_ = g_hash_table_lookup (_tmp22_, _tmp23_);
#line 696 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_tmp25_ = key;
#line 696 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					boxes_spice_display_add_listbox_row (self, _tmp21_, (const gchar*) _tmp24_, _tmp25_, -1);
#line 5446 "spice-display.c"
				}
			}
		}
#line 693 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_list_free0 (keys);
#line 5452 "spice-display.c"
	}
#line 700 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp26_ = _data83_->popover;
#line 700 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_signal_connect_data (_tmp26_, "saved", (GCallback) ___lambda84__boxes_shared_folder_popover_saved, block83_data_ref (_data83_), (GClosureNotify) block83_data_unref, 0);
#line 711 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	result = frame;
#line 711 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_hash_table_unref0 (hash);
#line 711 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_object_unref0 (box);
#line 711 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	block83_data_unref (_data83_);
#line 711 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_data83_ = NULL;
#line 711 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	return result;
#line 5470 "spice-display.c"
}


static Block84Data* block84_data_ref (Block84Data* _data84_) {
#line 714 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_atomic_int_inc (&_data84_->_ref_count_);
#line 714 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	return _data84_;
#line 5479 "spice-display.c"
}


static void block84_data_unref (void * _userdata_) {
	Block84Data* _data84_;
	_data84_ = (Block84Data*) _userdata_;
#line 714 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (g_atomic_int_dec_and_test (&_data84_->_ref_count_)) {
#line 5488 "spice-display.c"
		BoxesSpiceDisplay* self;
#line 714 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		self = _data84_->self;
#line 714 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (_data84_->listboxrow);
#line 714 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (_data84_->listbox);
#line 714 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_free0 (_data84_->name);
#line 714 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (self);
#line 714 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_slice_free (Block84Data, _data84_);
#line 5502 "spice-display.c"
	}
}


static void __lambda83_ (Block84Data* _data84_) {
	BoxesSpiceDisplay* self;
	GtkListBox* _tmp0_;
	BoxesSharedFolderRow* _tmp1_;
	const gchar* _tmp2_;
#line 722 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self = _data84_->self;
#line 723 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp0_ = _data84_->listbox;
#line 723 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp1_ = _data84_->listboxrow;
#line 723 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	gtk_container_remove ((GtkContainer*) _tmp0_, (GtkWidget*) _tmp1_);
#line 724 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp2_ = _data84_->name;
#line 724 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	boxes_spice_display_remove_shared_folder (self, _tmp2_);
#line 5524 "spice-display.c"
}


static void ___lambda83__boxes_shared_folder_row_removed (BoxesSharedFolderRow* _sender, gpointer self) {
#line 722 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	__lambda83_ (self);
#line 5531 "spice-display.c"
}


static void boxes_spice_display_add_listbox_row (BoxesSpiceDisplay* self, GtkListBox* listbox, const gchar* path, const gchar* name, gint target_position) {
	Block84Data* _data84_;
	GtkListBox* _tmp0_;
	GtkListBox* _tmp1_;
	const gchar* _tmp2_;
	gchar* _tmp3_;
	const gchar* _tmp4_;
	const gchar* _tmp5_;
	BoxesSharedFolderRow* _tmp6_;
	gint _tmp7_;
	GtkListBox* _tmp12_;
	BoxesSharedFolderRow* _tmp13_;
	gint _tmp14_;
	BoxesSharedFolderRow* _tmp15_;
#line 714 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (self != NULL);
#line 714 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (listbox != NULL);
#line 714 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (path != NULL);
#line 714 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (name != NULL);
#line 714 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_data84_ = g_slice_new0 (Block84Data);
#line 714 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_data84_->_ref_count_ = 1;
#line 714 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_data84_->self = g_object_ref (self);
#line 714 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp0_ = listbox;
#line 714 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 714 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_object_unref0 (_data84_->listbox);
#line 714 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_data84_->listbox = _tmp1_;
#line 714 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp2_ = name;
#line 714 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp3_ = g_strdup (_tmp2_);
#line 714 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_free0 (_data84_->name);
#line 714 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_data84_->name = _tmp3_;
#line 715 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp4_ = path;
#line 715 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp5_ = _data84_->name;
#line 715 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp6_ = boxes_shared_folder_row_new (_tmp4_, _tmp5_);
#line 715 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_object_ref_sink (_tmp6_);
#line 715 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_data84_->listboxrow = _tmp6_;
#line 717 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp7_ = target_position;
#line 717 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (_tmp7_ != -1) {
#line 5593 "spice-display.c"
		GtkListBox* _tmp8_;
		GtkListBox* _tmp9_;
		gint _tmp10_;
		GtkListBoxRow* _tmp11_;
#line 718 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp8_ = _data84_->listbox;
#line 718 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp9_ = _data84_->listbox;
#line 718 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp10_ = target_position;
#line 718 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp11_ = gtk_list_box_get_row_at_index (_tmp9_, _tmp10_);
#line 718 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		gtk_container_remove ((GtkContainer*) _tmp8_, (GtkWidget*) _tmp11_);
#line 5608 "spice-display.c"
	}
#line 720 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp12_ = _data84_->listbox;
#line 720 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp13_ = _data84_->listboxrow;
#line 720 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp14_ = target_position;
#line 720 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	gtk_list_box_insert (_tmp12_, (GtkWidget*) _tmp13_, _tmp14_);
#line 722 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp15_ = _data84_->listboxrow;
#line 722 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_signal_connect_data (_tmp15_, "removed", (GCallback) ___lambda83__boxes_shared_folder_row_removed, block84_data_ref (_data84_), (GClosureNotify) block84_data_unref, 0);
#line 714 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	block84_data_unref (_data84_);
#line 714 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_data84_ = NULL;
#line 5626 "spice-display.c"
}


static gboolean boxes_spice_display_is_usb_kbd_or_mouse (BoxesSpiceDisplay* self, guint8 class, guint8 subclass, guint8 protocol) {
	gboolean result = FALSE;
	gboolean ret = FALSE;
	guint8 _tmp0_;
#line 728 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 729 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	ret = FALSE;
#line 731 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp0_ = class;
#line 731 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (_tmp0_ == LIBUSB_CLASS_HID) {
#line 5642 "spice-display.c"
		guint8 _tmp1_;
#line 732 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp1_ = subclass;
#line 732 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		switch (_tmp1_) {
#line 732 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			case 0x00:
#line 5650 "spice-display.c"
			{
#line 734 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				break;
#line 5654 "spice-display.c"
			}
#line 732 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			case 0x01:
#line 5658 "spice-display.c"
			{
				guint8 _tmp2_;
#line 736 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp2_ = protocol;
#line 736 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				switch (_tmp2_) {
#line 736 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					case 0x00:
#line 5667 "spice-display.c"
					{
#line 738 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
						break;
#line 5671 "spice-display.c"
					}
#line 736 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					case 0x01:
#line 736 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					case 0x02:
#line 5677 "spice-display.c"
					{
#line 741 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
						ret = TRUE;
#line 742 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
						break;
#line 5683 "spice-display.c"
					}
					default:
					{
#line 744 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
						break;
#line 5689 "spice-display.c"
					}
				}
#line 746 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				break;
#line 5694 "spice-display.c"
			}
			default:
			{
#line 748 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				break;
#line 5700 "spice-display.c"
			}
		}
	}
#line 752 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	result = ret;
#line 752 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	return result;
#line 5708 "spice-display.c"
}


static const gchar* boxes_spice_display_real_get_protocol (BoxesDisplay* base) {
	const gchar* result;
	BoxesSpiceDisplay* self;
#line 7 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) base;
#line 7 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	result = "SPICE";
#line 7 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	return result;
#line 5721 "spice-display.c"
}


static gchar* boxes_spice_display_real_get_uri (BoxesDisplay* base) {
	gchar* result;
	BoxesSpiceDisplay* self;
	gboolean _tmp0_ = FALSE;
	SpiceSession* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gboolean _tmp5_;
	SpiceSession* _tmp10_;
	gchar* _tmp11_;
	gchar* _tmp12_;
#line 9 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) base;
#line 10 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp1_ = self->priv->session;
#line 10 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_object_get (_tmp1_, "port", &_tmp2_, NULL);
#line 10 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp3_ = _tmp2_;
#line 10 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp4_ = _tmp3_;
#line 10 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp5_ = _tmp4_ == NULL;
#line 10 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_free0 (_tmp4_);
#line 10 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (_tmp5_) {
#line 5753 "spice-display.c"
		SpiceSession* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
#line 10 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp6_ = self->priv->session;
#line 10 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_object_get (_tmp6_, "tls-port", &_tmp7_, NULL);
#line 10 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp8_ = _tmp7_;
#line 10 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp9_ = _tmp8_;
#line 10 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp0_ = _tmp9_ == NULL;
#line 10 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_free0 (_tmp9_);
#line 5770 "spice-display.c"
	} else {
#line 10 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp0_ = FALSE;
#line 5774 "spice-display.c"
	}
#line 10 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (_tmp0_) {
#line 11 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		result = NULL;
#line 11 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		return result;
#line 5782 "spice-display.c"
	}
#line 13 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp10_ = self->priv->session;
#line 13 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_object_get (_tmp10_, "uri", &_tmp11_, NULL);
#line 13 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp12_ = _tmp11_;
#line 13 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	result = _tmp12_;
#line 13 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	return result;
#line 5794 "spice-display.c"
}


GByteArray* boxes_spice_display_get_ca_cert (BoxesSpiceDisplay* self) {
	GByteArray* result;
	SpiceSession* _tmp0_;
	GByteArray* _tmp1_;
	GByteArray* _tmp2_;
#line 16 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 16 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp0_ = self->priv->session;
#line 16 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_object_get (_tmp0_, "ca", &_tmp1_, NULL);
#line 16 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp2_ = _tmp1_;
#line 16 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	result = _tmp2_;
#line 16 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	return result;
#line 5815 "spice-display.c"
}


void boxes_spice_display_set_ca_cert (BoxesSpiceDisplay* self, GByteArray* value) {
	SpiceSession* _tmp0_;
	GByteArray* _tmp1_;
#line 16 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (self != NULL);
#line 16 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp0_ = self->priv->session;
#line 16 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp1_ = value;
#line 16 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_object_set (_tmp0_, "ca", _tmp1_, NULL);
#line 16 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_object_notify_by_pspec ((GObject *) self, boxes_spice_display_properties[BOXES_SPICE_DISPLAY_CA_CERT]);
#line 5832 "spice-display.c"
}


SpiceMainChannel* boxes_spice_display_get_main_channel (BoxesSpiceDisplay* self) {
	SpiceMainChannel* result;
	SpiceMainChannel* _tmp0_;
#line 76 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 77 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp0_ = self->priv->_main_channel;
#line 77 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	result = _tmp0_;
#line 77 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	return result;
#line 5847 "spice-display.c"
}


static void _boxes_spice_display_main_event_spice_channel_channel_event (SpiceChannel* _sender, SpiceChannelEvent event, gpointer self) {
#line 85 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	boxes_spice_display_main_event ((BoxesSpiceDisplay*) self, event);
#line 5854 "spice-display.c"
}


static void _boxes_spice_display_main_channel___lambda73_ (BoxesSpiceDisplay* self) {
	SpiceMainChannel* _tmp0_;
	SpiceMainChannel* _tmp1_;
	gint _tmp2_;
	gint _tmp3_;
#line 87 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp0_ = boxes_spice_display_get_main_channel (self);
#line 87 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp1_ = _tmp0_;
#line 87 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_object_get (_tmp1_, "mouse-mode", &_tmp2_, NULL);
#line 87 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp3_ = _tmp2_;
#line 87 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	boxes_display_set_can_grab_mouse ((BoxesDisplay*) self, _tmp3_ != 2);
#line 5873 "spice-display.c"
}


static void __boxes_spice_display_main_channel___lambda73__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 86 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_boxes_spice_display_main_channel___lambda73_ ((BoxesSpiceDisplay*) self);
#line 5880 "spice-display.c"
}


void boxes_spice_display_set_main_channel (BoxesSpiceDisplay* self, SpiceMainChannel* value) {
	SpiceMainChannel* _tmp0_;
	SpiceMainChannel* _tmp1_;
	SpiceMainChannel* _tmp2_;
	SpiceMainChannel* _tmp3_;
	SpiceMainChannel* _tmp4_;
	gulong _tmp5_;
	SpiceMainChannel* _tmp6_;
	SpiceMainChannel* _tmp7_;
	gulong _tmp8_;
	SpiceMainChannel* _tmp9_;
	SpiceMainChannel* _tmp10_;
	gint _tmp11_;
	gint _tmp12_;
#line 80 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (self != NULL);
#line 81 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp0_ = value;
#line 81 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 81 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_object_unref0 (self->priv->_main_channel);
#line 81 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self->priv->_main_channel = _tmp1_;
#line 82 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp2_ = self->priv->_main_channel;
#line 82 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (_tmp2_ == NULL) {
#line 83 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		return;
#line 5914 "spice-display.c"
	}
#line 85 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp3_ = boxes_spice_display_get_main_channel (self);
#line 85 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp4_ = _tmp3_;
#line 85 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp5_ = g_signal_connect_object ((SpiceChannel*) _tmp4_, "channel-event", (GCallback) _boxes_spice_display_main_event_spice_channel_channel_event, self, 0);
#line 85 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self->priv->main_event_id = _tmp5_;
#line 86 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp6_ = boxes_spice_display_get_main_channel (self);
#line 86 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp7_ = _tmp6_;
#line 86 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp8_ = g_signal_connect_object ((GObject*) _tmp7_, "notify::mouse-mode", (GCallback) __boxes_spice_display_main_channel___lambda73__g_object_notify, self, 0);
#line 86 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self->priv->main_mouse_mode_id = _tmp8_;
#line 90 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp9_ = boxes_spice_display_get_main_channel (self);
#line 90 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp10_ = _tmp9_;
#line 90 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_object_get (_tmp10_, "mouse-mode", &_tmp11_, NULL);
#line 90 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp12_ = _tmp11_;
#line 90 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	boxes_display_set_can_grab_mouse ((BoxesDisplay*) self, _tmp12_ != 2);
#line 80 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_object_notify_by_pspec ((GObject *) self, boxes_spice_display_properties[BOXES_SPICE_DISPLAY_MAIN_CHANNEL]);
#line 5944 "spice-display.c"
}


static void _boxes_spice_display____lambda85_ (BoxesSpiceDisplay* self, SpiceUsbDevice* dev, GError* err) {
	gchar* device_description = NULL;
	SpiceUsbDevice* _tmp0_;
	gchar* _tmp1_;
	gchar* box_name = NULL;
	gchar* _tmp2_;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	const gchar* _tmp7_;
	const gchar* _tmp8_;
	GError* _tmp9_;
	const gchar* _tmp10_;
#line 64 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (dev != NULL);
#line 65 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp0_ = dev;
#line 65 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp1_ = spice_usb_device_get_description (_tmp0_, "%1$s %2$s");
#line 65 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	device_description = _tmp1_;
#line 66 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp2_ = boxes_spice_display_get_box_name (self);
#line 66 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	box_name = _tmp2_;
#line 67 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp3_ = device_description;
#line 67 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp4_ = box_name;
#line 67 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp5_ = g_strdup_printf (_ ("Redirection of USB device “%s” for “%s” failed"), _tmp3_, _tmp4_);
#line 67 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp6_ = _tmp5_;
#line 67 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_signal_emit_by_name ((BoxesDisplay*) self, "got-error", _tmp6_);
#line 67 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_free0 (_tmp6_);
#line 68 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp7_ = device_description;
#line 68 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp8_ = box_name;
#line 68 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp9_ = err;
#line 68 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp10_ = _tmp9_->message;
#line 68 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_debug ("spice-display.vala:68: Error connecting %s to %s: %s", _tmp7_, _tmp8_, _tmp10_);
#line 64 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_free0 (box_name);
#line 64 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_free0 (device_description);
#line 6000 "spice-display.c"
}


static void __boxes_spice_display____lambda85__spice_usb_device_manager_device_error (SpiceUsbDeviceManager* _sender, SpiceUsbDevice* device, GError* _error_, gpointer self) {
#line 64 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_boxes_spice_display____lambda85_ ((BoxesSpiceDisplay*) self, device, _error_);
#line 6007 "spice-display.c"
}


static GObject * boxes_spice_display_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	BoxesSpiceDisplay * self;
	gchar* _tmp0_;
	GValue _tmp1_ = {0};
	BoxesBoxConfigSavedProperty _tmp2_ = {0};
	BoxesBoxConfigSavedProperty* _tmp3_;
	SpiceSession* _tmp4_;
	SpiceSession* _tmp5_;
	SpiceAudio* _tmp6_;
	SpiceSession* _tmp7_;
	SpiceGtkSession* _tmp8_;
	SpiceSession* _tmp9_;
	GError * _inner_error_ = NULL;
#line 50 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	parent_class = G_OBJECT_CLASS (boxes_spice_display_parent_class);
#line 50 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 50 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_SPICE_DISPLAY, BoxesSpiceDisplay);
#line 51 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp0_ = g_strdup ("auto-clipboard");
#line 51 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_value_init (&_tmp1_, G_TYPE_BOOLEAN);
#line 51 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_value_set_boolean (&_tmp1_, TRUE);
#line 51 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	memset (&_tmp2_, 0, sizeof (BoxesBoxConfigSavedProperty));
#line 51 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_free0 (_tmp2_.name);
#line 51 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp2_.name = _tmp0_;
#line 51 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	G_IS_VALUE (&_tmp2_.default_value) ? (g_value_unset (&_tmp2_.default_value), NULL) : NULL;
#line 51 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp2_.default_value = _tmp1_;
#line 51 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp3_ = g_new0 (BoxesBoxConfigSavedProperty, 1);
#line 51 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp3_[0] = _tmp2_;
#line 51 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self->priv->gtk_session_saved_properties = (_vala_BoxesBoxConfigSavedProperty_array_free (self->priv->gtk_session_saved_properties, self->priv->gtk_session_saved_properties_length1), NULL);
#line 51 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self->priv->gtk_session_saved_properties = _tmp3_;
#line 51 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self->priv->gtk_session_saved_properties_length1 = 1;
#line 51 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self->priv->_gtk_session_saved_properties_size_ = self->priv->gtk_session_saved_properties_length1;
#line 55 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	boxes_display_set_need_password ((BoxesDisplay*) self, FALSE);
#line 56 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp4_ = spice_session_new ();
#line 56 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_object_unref0 (self->priv->session);
#line 56 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self->priv->session = _tmp4_;
#line 57 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp5_ = self->priv->session;
#line 57 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp6_ = spice_audio_get (_tmp5_, NULL);
#line 57 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self->priv->audio = _tmp6_;
#line 58 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp7_ = self->priv->session;
#line 58 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp8_ = spice_gtk_session_get (_tmp7_);
#line 58 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self->priv->gtk_session = _tmp8_;
#line 60 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp9_ = self->priv->session;
#line 60 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	spice_set_session_option (_tmp9_);
#line 6084 "spice-display.c"
	{
		SpiceUsbDeviceManager* manager = NULL;
		SpiceSession* _tmp10_;
		SpiceUsbDeviceManager* _tmp11_;
		SpiceUsbDeviceManager* _tmp12_;
		SpiceUsbDeviceManager* _tmp13_;
#line 62 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp10_ = self->priv->session;
#line 62 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp11_ = spice_usb_device_manager_get (_tmp10_, &_inner_error_);
#line 62 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp12_ = _g_object_ref0 (_tmp11_);
#line 62 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		manager = _tmp12_;
#line 62 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 6101 "spice-display.c"
			goto __catch83_g_error;
		}
#line 64 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp13_ = manager;
#line 64 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_signal_connect_object (_tmp13_, "device-error", (GCallback) __boxes_spice_display____lambda85__spice_usb_device_manager_device_error, self, 0);
#line 61 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (manager);
#line 6110 "spice-display.c"
	}
	goto __finally83;
	__catch83_g_error:
	{
		GError* _error_ = NULL;
#line 61 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_error_ = _inner_error_;
#line 61 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_inner_error_ = NULL;
#line 61 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_error_free0 (_error_);
#line 6122 "spice-display.c"
	}
	__finally83:
#line 61 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 61 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 61 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_clear_error (&_inner_error_);
#line 6131 "spice-display.c"
	}
#line 50 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	return obj;
#line 6135 "spice-display.c"
}


static void boxes_spice_display_class_init (BoxesSpiceDisplayClass * klass) {
#line 6 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	boxes_spice_display_parent_class = g_type_class_peek_parent (klass);
#line 6 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_type_class_add_private (klass, sizeof (BoxesSpiceDisplayPrivate));
#line 6 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	((BoxesDisplayClass *) klass)->get_display = (GtkWidget* (*) (BoxesDisplay *, gint)) boxes_spice_display_real_get_display;
#line 6 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	((BoxesDisplayClass *) klass)->should_keep_alive = (gboolean (*) (BoxesDisplay *)) boxes_spice_display_real_should_keep_alive;
#line 6 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	((BoxesDisplayClass *) klass)->set_enable_audio = (void (*) (BoxesDisplay *, gboolean)) boxes_spice_display_real_set_enable_audio;
#line 6 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	((BoxesDisplayClass *) klass)->get_pixbuf = (GdkPixbuf* (*) (BoxesDisplay *, gint, GError**)) boxes_spice_display_real_get_pixbuf;
#line 6 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	((BoxesDisplayClass *) klass)->collect_logs = (void (*) (BoxesDisplay *, GString*)) boxes_spice_display_real_collect_logs;
#line 6 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	((BoxesDisplayClass *) klass)->connect_it = (void (*) (BoxesDisplay *, BoxesDisplayOpenFDFunc, void*, GDestroyNotify, GError**)) boxes_spice_display_real_connect_it;
#line 6 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	((BoxesDisplayClass *) klass)->disconnect_it = (void (*) (BoxesDisplay *)) boxes_spice_display_real_disconnect_it;
#line 6 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	((BoxesDisplayClass *) klass)->get_properties = (GList* (*) (BoxesDisplay *, BoxesPropertiesPage)) boxes_spice_display_real_get_properties;
#line 6 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	((BoxesDisplayClass *) klass)->send_keys = (void (*) (BoxesDisplay *, guint*, int)) boxes_spice_display_real_send_keys;
#line 6 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	BOXES_DISPLAY_CLASS (klass)->get_protocol = boxes_spice_display_real_get_protocol;
#line 6 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	BOXES_DISPLAY_CLASS (klass)->get_uri = boxes_spice_display_real_get_uri;
#line 6 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_spice_display_get_property;
#line 6 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_spice_display_set_property;
#line 6 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	G_OBJECT_CLASS (klass)->constructor = boxes_spice_display_constructor;
#line 6 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_spice_display_finalize;
#line 6 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_SPICE_DISPLAY_PROTOCOL, boxes_spice_display_properties[BOXES_SPICE_DISPLAY_PROTOCOL] = g_param_spec_string ("protocol", "protocol", "protocol", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 6 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_SPICE_DISPLAY_URI, boxes_spice_display_properties[BOXES_SPICE_DISPLAY_URI] = g_param_spec_string ("uri", "uri", "uri", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 6 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_SPICE_DISPLAY_CA_CERT, boxes_spice_display_properties[BOXES_SPICE_DISPLAY_CA_CERT] = g_param_spec_boxed ("ca-cert", "ca-cert", "ca-cert", G_TYPE_BYTE_ARRAY, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 6 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_SPICE_DISPLAY_MAIN_CHANNEL, boxes_spice_display_properties[BOXES_SPICE_DISPLAY_MAIN_CHANNEL] = g_param_spec_object ("main-channel", "main-channel", "main-channel", spice_main_channel_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 6182 "spice-display.c"
}


static void boxes_spice_display_instance_init (BoxesSpiceDisplay * self) {
#line 6 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self->priv = BOXES_SPICE_DISPLAY_GET_PRIVATE (self);
#line 6189 "spice-display.c"
}


static void boxes_spice_display_finalize (GObject * obj) {
	BoxesSpiceDisplay * self;
#line 6 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_SPICE_DISPLAY, BoxesSpiceDisplay);
#line 109 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	boxes_spice_display_main_cleanup (self);
#line 20 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_object_unref0 (self->priv->session);
#line 25 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self->priv->display_saved_properties = (_vala_BoxesBoxConfigSavedProperty_array_free (self->priv->display_saved_properties, self->priv->display_saved_properties_length1), NULL);
#line 26 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self->priv->gtk_session_saved_properties = (_vala_BoxesBoxConfigSavedProperty_array_free (self->priv->gtk_session_saved_properties, self->priv->gtk_session_saved_properties_length1), NULL);
#line 29 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_object_unref0 (self->priv->webdav_channel);
#line 30 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_free0 (self->priv->shared_folder);
#line 31 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_object_unref0 (self->priv->shared_folder_settings);
#line 33 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_hash_table_unref0 (self->priv->channel_handlers);
#line 34 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	(self->priv->open_fd_target_destroy_notify == NULL) ? NULL : (self->priv->open_fd_target_destroy_notify (self->priv->open_fd_target), NULL);
#line 34 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self->priv->open_fd = NULL;
#line 34 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self->priv->open_fd_target = NULL;
#line 34 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self->priv->open_fd_target_destroy_notify = NULL;
#line 74 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_object_unref0 (self->priv->_main_channel);
#line 6 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	G_OBJECT_CLASS (boxes_spice_display_parent_class)->finalize (obj);
#line 6225 "spice-display.c"
}


GType boxes_spice_display_get_type (void) {
	static volatile gsize boxes_spice_display_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_spice_display_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesSpiceDisplayClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_spice_display_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesSpiceDisplay), 0, (GInstanceInitFunc) boxes_spice_display_instance_init, NULL };
		GType boxes_spice_display_type_id;
		boxes_spice_display_type_id = g_type_register_static (BOXES_TYPE_DISPLAY, "BoxesSpiceDisplay", &g_define_type_info, 0);
		g_once_init_leave (&boxes_spice_display_type_id__volatile, boxes_spice_display_type_id);
	}
	return boxes_spice_display_type_id__volatile;
}


static void _vala_boxes_spice_display_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesSpiceDisplay * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_SPICE_DISPLAY, BoxesSpiceDisplay);
#line 6 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	switch (property_id) {
#line 6 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		case BOXES_SPICE_DISPLAY_PROTOCOL:
#line 6 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_value_set_string (value, boxes_display_get_protocol ((BoxesDisplay*) self));
#line 6 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		break;
#line 6 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		case BOXES_SPICE_DISPLAY_URI:
#line 6 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_value_take_string (value, boxes_display_get_uri ((BoxesDisplay*) self));
#line 6 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		break;
#line 6 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		case BOXES_SPICE_DISPLAY_CA_CERT:
#line 6 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_value_take_boxed (value, boxes_spice_display_get_ca_cert (self));
#line 6 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		break;
#line 6 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		case BOXES_SPICE_DISPLAY_MAIN_CHANNEL:
#line 6 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_value_set_object (value, boxes_spice_display_get_main_channel (self));
#line 6 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		break;
#line 6270 "spice-display.c"
		default:
#line 6 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 6 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		break;
#line 6276 "spice-display.c"
	}
}


static void _vala_boxes_spice_display_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesSpiceDisplay * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_SPICE_DISPLAY, BoxesSpiceDisplay);
#line 6 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	switch (property_id) {
#line 6 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		case BOXES_SPICE_DISPLAY_CA_CERT:
#line 6 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		boxes_spice_display_set_ca_cert (self, g_value_get_boxed (value));
#line 6 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		break;
#line 6 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		case BOXES_SPICE_DISPLAY_MAIN_CHANNEL:
#line 6 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		boxes_spice_display_set_main_channel (self, g_value_get_object (value));
#line 6 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		break;
#line 6298 "spice-display.c"
		default:
#line 6 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 6 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		break;
#line 6304 "spice-display.c"
	}
}


static void _boxes_spice_channel_handler_on_open_fd_spice_channel_open_fd (SpiceChannel* _sender, gint with_tls, gpointer self) {
#line 768 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	boxes_spice_channel_handler_on_open_fd ((BoxesSpiceChannelHandler*) self, _sender, with_tls);
#line 6312 "spice-display.c"
}


static void _boxes_spice_channel_handler_on_display_ready_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 778 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	boxes_spice_channel_handler_on_display_ready ((BoxesSpiceChannelHandler*) self, _sender, pspec);
#line 6319 "spice-display.c"
}


BoxesSpiceChannelHandler* boxes_spice_channel_handler_construct (GType object_type, BoxesSpiceDisplay* display, SpiceChannel* channel, BoxesDisplayOpenFDFunc open_fd, void* open_fd_target) {
	BoxesSpiceChannelHandler * self = NULL;
	BoxesSpiceDisplay* _tmp0_;
	SpiceChannel* _tmp1_;
	SpiceChannel* _tmp2_;
	BoxesDisplayOpenFDFunc _tmp3_;
	void* _tmp3__target;
	gint id = 0;
	SpiceChannel* _tmp4_;
	gint _tmp5_;
	gint _tmp6_;
	BoxesDisplayOpenFDFunc _tmp7_;
	void* _tmp7__target;
	SpiceChannel* _tmp9_;
	SpiceChannel* _tmp12_;
	SpiceChannel* _tmp19_;
#line 761 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (display != NULL, NULL);
#line 761 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (channel != NULL, NULL);
#line 761 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceChannelHandler*) g_object_new (object_type, NULL);
#line 762 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp0_ = display;
#line 762 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self->priv->display = _tmp0_;
#line 763 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp1_ = channel;
#line 763 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 763 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_object_unref0 (self->priv->channel);
#line 763 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self->priv->channel = _tmp2_;
#line 764 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp3_ = open_fd;
#line 764 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp3__target = open_fd_target;
#line 764 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	(self->priv->open_fd_target_destroy_notify == NULL) ? NULL : (self->priv->open_fd_target_destroy_notify (self->priv->open_fd_target), NULL);
#line 764 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self->priv->open_fd = NULL;
#line 764 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self->priv->open_fd_target = NULL;
#line 764 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self->priv->open_fd_target_destroy_notify = NULL;
#line 764 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self->priv->open_fd = _tmp3_;
#line 764 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self->priv->open_fd_target = _tmp3__target;
#line 764 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self->priv->open_fd_target_destroy_notify = NULL;
#line 765 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp4_ = channel;
#line 765 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_object_get (_tmp4_, "channel-id", &_tmp5_, NULL);
#line 765 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp6_ = _tmp5_;
#line 765 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	id = _tmp6_;
#line 767 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp7_ = open_fd;
#line 767 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp7__target = open_fd_target;
#line 767 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (_tmp7_ != NULL) {
#line 6389 "spice-display.c"
		SpiceChannel* _tmp8_;
#line 768 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp8_ = channel;
#line 768 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_signal_connect_object (_tmp8_, "open-fd", (GCallback) _boxes_spice_channel_handler_on_open_fd_spice_channel_open_fd, self, 0);
#line 6395 "spice-display.c"
	}
#line 770 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp9_ = channel;
#line 770 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, spice_main_channel_get_type ())) {
#line 6401 "spice-display.c"
		BoxesSpiceDisplay* _tmp10_;
		SpiceChannel* _tmp11_;
#line 771 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp10_ = display;
#line 771 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp11_ = channel;
#line 771 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		boxes_spice_display_set_main_channel (_tmp10_, G_TYPE_CHECK_INSTANCE_TYPE (_tmp11_, spice_main_channel_get_type ()) ? ((SpiceMainChannel*) _tmp11_) : NULL);
#line 6410 "spice-display.c"
	}
#line 773 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp12_ = channel;
#line 773 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp12_, spice_display_channel_get_type ())) {
#line 6416 "spice-display.c"
		gint _tmp13_;
		SpiceDisplay* spice_display = NULL;
		BoxesSpiceDisplay* _tmp14_;
		gint _tmp15_;
		GtkWidget* _tmp16_;
		SpiceDisplay* _tmp17_;
		SpiceDisplay* _tmp18_;
#line 774 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp13_ = id;
#line 774 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		if (_tmp13_ != 0) {
#line 775 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			return self;
#line 6430 "spice-display.c"
		}
#line 777 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp14_ = display;
#line 777 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp15_ = id;
#line 777 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp16_ = boxes_display_get_display ((BoxesDisplay*) _tmp14_, _tmp15_);
#line 777 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp17_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp16_, spice_display_get_type ()) ? ((SpiceDisplay*) _tmp16_) : NULL;
#line 777 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		if (_tmp17_ == NULL) {
#line 777 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_g_object_unref0 (_tmp16_);
#line 6444 "spice-display.c"
		}
#line 777 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		spice_display = _tmp17_;
#line 778 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp18_ = spice_display;
#line 778 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_signal_connect_object ((GObject*) _tmp18_, "notify::ready", (GCallback) _boxes_spice_channel_handler_on_display_ready_g_object_notify, self, 0);
#line 773 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (spice_display);
#line 6454 "spice-display.c"
	}
#line 781 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp19_ = channel;
#line 781 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp19_, spice_webdav_channel_get_type ())) {
#line 6460 "spice-display.c"
		BoxesDisplayOpenFDFunc _tmp20_;
		void* _tmp20__target;
#line 782 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp20_ = open_fd;
#line 782 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp20__target = open_fd_target;
#line 782 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		if (_tmp20_ != NULL) {
#line 6469 "spice-display.c"
			SpiceChannel* _tmp21_;
#line 783 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp21_ = channel;
#line 783 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			boxes_spice_channel_handler_on_open_fd (self, _tmp21_, 0);
#line 6475 "spice-display.c"
		} else {
			SpiceChannel* _tmp22_;
#line 785 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp22_ = channel;
#line 785 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			spice_channel_connect (_tmp22_);
#line 6482 "spice-display.c"
		}
	}
#line 761 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	return self;
#line 6487 "spice-display.c"
}


BoxesSpiceChannelHandler* boxes_spice_channel_handler_new (BoxesSpiceDisplay* display, SpiceChannel* channel, BoxesDisplayOpenFDFunc open_fd, void* open_fd_target) {
#line 761 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	return boxes_spice_channel_handler_construct (BOXES_TYPE_SPICE_CHANNEL_HANDLER, display, channel, open_fd, open_fd_target);
#line 6494 "spice-display.c"
}


static void boxes_spice_channel_handler_on_display_ready (BoxesSpiceChannelHandler* self, GObject* object, GParamSpec* param_spec) {
	SpiceDisplay* spice_display = NULL;
	GObject* _tmp0_;
	SpiceDisplay* _tmp1_;
	SpiceDisplay* _tmp2_;
	gboolean _tmp3_;
	gboolean _tmp4_;
#line 789 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (self != NULL);
#line 789 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (object != NULL);
#line 789 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (param_spec != NULL);
#line 790 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp0_ = object;
#line 790 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, spice_display_get_type ()) ? ((SpiceDisplay*) _tmp0_) : NULL);
#line 790 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	spice_display = _tmp1_;
#line 791 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp2_ = spice_display;
#line 791 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_object_get (_tmp2_, "ready", &_tmp3_, NULL);
#line 791 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp4_ = _tmp3_;
#line 791 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (_tmp4_) {
#line 6525 "spice-display.c"
		BoxesSpiceDisplay* _tmp5_;
		SpiceDisplay* _tmp6_;
		gint _tmp7_;
		gint _tmp8_;
#line 792 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp5_ = self->priv->display;
#line 792 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp6_ = spice_display;
#line 792 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_object_get (_tmp6_, "channel-id", &_tmp7_, NULL);
#line 792 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp8_ = _tmp7_;
#line 792 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_signal_emit_by_name ((BoxesDisplay*) _tmp5_, "show", _tmp8_);
#line 6540 "spice-display.c"
	} else {
		BoxesSpiceDisplay* _tmp9_;
		SpiceDisplay* _tmp10_;
		gint _tmp11_;
		gint _tmp12_;
#line 794 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp9_ = self->priv->display;
#line 794 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp10_ = spice_display;
#line 794 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_object_get (_tmp10_, "channel-id", &_tmp11_, NULL);
#line 794 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp12_ = _tmp11_;
#line 794 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_signal_emit_by_name ((BoxesDisplay*) _tmp9_, "hide", _tmp12_);
#line 6556 "spice-display.c"
	}
#line 789 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_object_unref0 (spice_display);
#line 6560 "spice-display.c"
}


static void boxes_spice_channel_handler_on_open_fd (BoxesSpiceChannelHandler* self, SpiceChannel* channel, gint with_tls) {
	gint fd = 0;
	BoxesDisplayOpenFDFunc _tmp0_;
	void* _tmp0__target;
	gint _tmp1_;
	SpiceChannel* _tmp2_;
#line 797 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (self != NULL);
#line 797 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (channel != NULL);
#line 800 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp0_ = self->priv->open_fd;
#line 800 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp0__target = self->priv->open_fd_target;
#line 800 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp1_ = _tmp0_ (_tmp0__target);
#line 800 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	fd = _tmp1_;
#line 801 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp2_ = channel;
#line 801 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	spice_channel_open_fd (_tmp2_, fd);
#line 6586 "spice-display.c"
}


static void boxes_spice_channel_handler_class_init (BoxesSpiceChannelHandlerClass * klass) {
#line 756 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	boxes_spice_channel_handler_parent_class = g_type_class_peek_parent (klass);
#line 756 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_type_class_add_private (klass, sizeof (BoxesSpiceChannelHandlerPrivate));
#line 756 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_spice_channel_handler_finalize;
#line 6597 "spice-display.c"
}


static void boxes_spice_channel_handler_instance_init (BoxesSpiceChannelHandler * self) {
#line 756 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self->priv = BOXES_SPICE_CHANNEL_HANDLER_GET_PRIVATE (self);
#line 6604 "spice-display.c"
}


static void boxes_spice_channel_handler_finalize (GObject * obj) {
	BoxesSpiceChannelHandler * self;
#line 756 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_SPICE_CHANNEL_HANDLER, BoxesSpiceChannelHandler);
#line 758 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_object_unref0 (self->priv->channel);
#line 759 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	(self->priv->open_fd_target_destroy_notify == NULL) ? NULL : (self->priv->open_fd_target_destroy_notify (self->priv->open_fd_target), NULL);
#line 759 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self->priv->open_fd = NULL;
#line 759 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self->priv->open_fd_target = NULL;
#line 759 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self->priv->open_fd_target_destroy_notify = NULL;
#line 756 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	G_OBJECT_CLASS (boxes_spice_channel_handler_parent_class)->finalize (obj);
#line 6624 "spice-display.c"
}


GType boxes_spice_channel_handler_get_type (void) {
	static volatile gsize boxes_spice_channel_handler_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_spice_channel_handler_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesSpiceChannelHandlerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_spice_channel_handler_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesSpiceChannelHandler), 0, (GInstanceInitFunc) boxes_spice_channel_handler_instance_init, NULL };
		GType boxes_spice_channel_handler_type_id;
		boxes_spice_channel_handler_type_id = g_type_register_static (G_TYPE_OBJECT, "BoxesSpiceChannelHandler", &g_define_type_info, 0);
		g_once_init_leave (&boxes_spice_channel_handler_type_id__volatile, boxes_spice_channel_handler_type_id);
	}
	return boxes_spice_channel_handler_type_id__volatile;
}


static gint* _int_dup (gint* self) {
	gint* dup;
#line 814 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	dup = g_new0 (gint, 1);
#line 814 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	memcpy (dup, self, sizeof (gint));
#line 814 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	return dup;
#line 6648 "spice-display.c"
}


static gpointer __int_dup0 (gpointer self) {
#line 814 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	return self ? _int_dup (self) : NULL;
#line 6655 "spice-display.c"
}


void spice_validate_uri (const gchar* uri_as_text, gint** port, gint** tls_port, GError** error) {
	gint* _vala_port = NULL;
	gint* _vala_tls_port = NULL;
	xmlURI* uri = NULL;
	const gchar* _tmp0_;
	xmlURI* _tmp1_;
	xmlURI* _tmp2_;
	gint _tmp4_;
	gint* _tmp5_;
	xmlURI* _tmp6_;
	gint _tmp7_;
	gint* _tmp8_;
	const gchar* _tmp9_ = NULL;
	xmlURI* _tmp10_;
	const gchar* _tmp11_;
	gchar* query_str = NULL;
	gchar* _tmp14_;
	const gchar* _tmp15_;
	xmlURI* _tmp38_;
	const gchar* _tmp39_;
	const gchar* _tmp40_;
	GQuark _tmp42_ = 0U;
#line 830 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	static GQuark _tmp41_label0 = 0;
#line 830 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	static GQuark _tmp41_label1 = 0;
#line 6685 "spice-display.c"
	GError * _inner_error_ = NULL;
#line 806 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (uri_as_text != NULL);
#line 809 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp0_ = uri_as_text;
#line 809 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp1_ = xmlParseURI (_tmp0_);
#line 809 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	uri = _tmp1_;
#line 811 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp2_ = uri;
#line 811 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (_tmp2_ == NULL) {
#line 6699 "spice-display.c"
		GError* _tmp3_;
#line 812 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp3_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, _ ("Invalid URL"));
#line 812 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_inner_error_ = _tmp3_;
#line 812 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		if (_inner_error_->domain == BOXES_ERROR) {
#line 812 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			g_propagate_error (error, _inner_error_);
#line 812 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_xmlFreeURI0 (uri);
#line 812 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			return;
#line 6713 "spice-display.c"
		} else {
#line 812 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_xmlFreeURI0 (uri);
#line 812 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 812 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			g_clear_error (&_inner_error_);
#line 812 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			return;
#line 6723 "spice-display.c"
		}
	}
#line 814 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp4_ = 0;
#line 814 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp5_ = __int_dup0 (&_tmp4_);
#line 814 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_free0 (_vala_tls_port);
#line 814 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_vala_tls_port = _tmp5_;
#line 815 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp6_ = uri;
#line 815 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp7_ = _tmp6_->port;
#line 815 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp8_ = __int_dup0 (&_tmp7_);
#line 815 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_free0 (_vala_port);
#line 815 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_vala_port = _tmp8_;
#line 816 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp10_ = uri;
#line 816 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp11_ = _tmp10_->query_raw;
#line 816 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp9_ = _tmp11_;
#line 816 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (_tmp9_ == NULL) {
#line 6752 "spice-display.c"
		xmlURI* _tmp12_;
		const gchar* _tmp13_;
#line 816 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp12_ = uri;
#line 816 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp13_ = _tmp12_->query;
#line 816 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp9_ = _tmp13_;
#line 6761 "spice-display.c"
	}
#line 816 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp14_ = g_strdup (_tmp9_);
#line 816 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	query_str = _tmp14_;
#line 818 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp15_ = query_str;
#line 818 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (_tmp15_ != NULL) {
#line 6771 "spice-display.c"
		BoxesQuery* query = NULL;
		const gchar* _tmp16_;
		BoxesQuery* _tmp17_;
		BoxesQuery* _tmp18_;
		gchar* _tmp19_;
		gchar* _tmp20_;
		gboolean _tmp21_;
		BoxesQuery* _tmp29_;
		gchar* _tmp30_;
		gchar* _tmp31_;
		gboolean _tmp32_;
#line 819 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp16_ = query_str;
#line 819 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp17_ = boxes_query_new (_tmp16_);
#line 819 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		query = _tmp17_;
#line 820 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp18_ = query;
#line 820 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp19_ = boxes_query_get (_tmp18_, "port");
#line 820 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp20_ = _tmp19_;
#line 820 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp21_ = _tmp20_ != NULL;
#line 820 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_free0 (_tmp20_);
#line 820 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		if (_tmp21_) {
#line 6801 "spice-display.c"
			gint* _tmp22_;
			BoxesQuery* _tmp24_;
			gchar* _tmp25_;
			gchar* _tmp26_;
			gint _tmp27_;
			gint* _tmp28_;
#line 821 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp22_ = _vala_port;
#line 821 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			if ((*_tmp22_) > 0) {
#line 6812 "spice-display.c"
				GError* _tmp23_;
#line 822 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp23_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, _ ("The port must be specified once"));
#line 822 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_inner_error_ = _tmp23_;
#line 822 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				if (_inner_error_->domain == BOXES_ERROR) {
#line 822 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					g_propagate_error (error, _inner_error_);
#line 822 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_g_object_unref0 (query);
#line 822 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_g_free0 (query_str);
#line 822 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_xmlFreeURI0 (uri);
#line 822 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					return;
#line 6830 "spice-display.c"
				} else {
#line 822 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_g_object_unref0 (query);
#line 822 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_g_free0 (query_str);
#line 822 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_xmlFreeURI0 (uri);
#line 822 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 822 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					g_clear_error (&_inner_error_);
#line 822 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					return;
#line 6844 "spice-display.c"
				}
			}
#line 823 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp24_ = query;
#line 823 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp25_ = boxes_query_get (_tmp24_, "port");
#line 823 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp26_ = _tmp25_;
#line 823 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp27_ = atoi (_tmp26_);
#line 823 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp28_ = __int_dup0 (&_tmp27_);
#line 823 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_g_free0 (_vala_port);
#line 823 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_vala_port = _tmp28_;
#line 823 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_g_free0 (_tmp26_);
#line 6863 "spice-display.c"
		}
#line 826 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp29_ = query;
#line 826 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp30_ = boxes_query_get (_tmp29_, "tls-port");
#line 826 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp31_ = _tmp30_;
#line 826 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp32_ = _tmp31_ != NULL;
#line 826 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_free0 (_tmp31_);
#line 826 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		if (_tmp32_) {
#line 6877 "spice-display.c"
			BoxesQuery* _tmp33_;
			gchar* _tmp34_;
			gchar* _tmp35_;
			gint _tmp36_;
			gint* _tmp37_;
#line 827 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp33_ = query;
#line 827 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp34_ = boxes_query_get (_tmp33_, "tls-port");
#line 827 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp35_ = _tmp34_;
#line 827 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp36_ = atoi (_tmp35_);
#line 827 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_tmp37_ = __int_dup0 (&_tmp36_);
#line 827 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_g_free0 (_vala_tls_port);
#line 827 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_vala_tls_port = _tmp37_;
#line 827 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
			_g_free0 (_tmp35_);
#line 6899 "spice-display.c"
		}
#line 818 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (query);
#line 6903 "spice-display.c"
	}
#line 830 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp38_ = uri;
#line 830 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp39_ = _tmp38_->scheme;
#line 830 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp40_ = _tmp39_;
#line 830 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp42_ = (NULL == _tmp40_) ? 0 : g_quark_from_string (_tmp40_);
#line 830 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (_tmp42_ == ((0 != _tmp41_label0) ? _tmp41_label0 : (_tmp41_label0 = g_quark_from_static_string ("spice")))) {
#line 830 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		switch (0) {
#line 6917 "spice-display.c"
			default:
			{
				gboolean _tmp43_ = FALSE;
				gint* _tmp44_;
#line 832 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp44_ = _vala_port;
#line 832 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				if ((*_tmp44_) <= 0) {
#line 6926 "spice-display.c"
					gint* _tmp45_;
#line 832 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_tmp45_ = _vala_tls_port;
#line 832 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_tmp43_ = (*_tmp45_) <= 0;
#line 6932 "spice-display.c"
				} else {
#line 832 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_tmp43_ = FALSE;
#line 6936 "spice-display.c"
				}
#line 832 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				if (_tmp43_) {
#line 6940 "spice-display.c"
					GError* _tmp46_;
#line 833 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_tmp46_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, _ ("Missing port in Spice URL"));
#line 833 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_inner_error_ = _tmp46_;
#line 833 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					if (_inner_error_->domain == BOXES_ERROR) {
#line 833 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
						g_propagate_error (error, _inner_error_);
#line 833 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
						_g_free0 (query_str);
#line 833 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
						_xmlFreeURI0 (uri);
#line 833 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
						return;
#line 6956 "spice-display.c"
					} else {
#line 833 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
						_g_free0 (query_str);
#line 833 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
						_xmlFreeURI0 (uri);
#line 833 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
						g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 833 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
						g_clear_error (&_inner_error_);
#line 833 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
						return;
#line 6968 "spice-display.c"
					}
				}
#line 834 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				break;
#line 6973 "spice-display.c"
			}
		}
	} else if (_tmp42_ == ((0 != _tmp41_label1) ? _tmp41_label1 : (_tmp41_label1 = g_quark_from_static_string ("spice+unix")))) {
#line 830 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		switch (0) {
#line 6979 "spice-display.c"
			default:
			{
				gboolean _tmp47_ = FALSE;
				gboolean _tmp48_ = FALSE;
				gint* _tmp49_;
#line 836 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp49_ = _vala_port;
#line 836 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				if ((*_tmp49_) > 0) {
#line 836 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_tmp48_ = TRUE;
#line 6991 "spice-display.c"
				} else {
					xmlURI* _tmp50_;
					const gchar* _tmp51_;
#line 836 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_tmp50_ = uri;
#line 836 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_tmp51_ = _tmp50_->query_raw;
#line 836 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_tmp48_ = _tmp51_ != NULL;
#line 7001 "spice-display.c"
				}
#line 836 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				if (_tmp48_) {
#line 836 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_tmp47_ = TRUE;
#line 7007 "spice-display.c"
				} else {
					xmlURI* _tmp52_;
					const gchar* _tmp53_;
#line 836 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_tmp52_ = uri;
#line 836 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_tmp53_ = _tmp52_->query;
#line 836 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_tmp47_ = _tmp53_ != NULL;
#line 7017 "spice-display.c"
				}
#line 836 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				if (_tmp47_) {
#line 7021 "spice-display.c"
					GError* _tmp54_;
#line 837 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_tmp54_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, _ ("Invalid URL"));
#line 837 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_inner_error_ = _tmp54_;
#line 837 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					if (_inner_error_->domain == BOXES_ERROR) {
#line 837 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
						g_propagate_error (error, _inner_error_);
#line 837 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
						_g_free0 (query_str);
#line 837 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
						_xmlFreeURI0 (uri);
#line 837 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
						return;
#line 7037 "spice-display.c"
					} else {
#line 837 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
						_g_free0 (query_str);
#line 837 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
						_xmlFreeURI0 (uri);
#line 837 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
						g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 837 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
						g_clear_error (&_inner_error_);
#line 837 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
						return;
#line 7049 "spice-display.c"
					}
				}
#line 838 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				break;
#line 7054 "spice-display.c"
			}
		}
	} else {
#line 830 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		switch (0) {
#line 7060 "spice-display.c"
			default:
			{
				GError* _tmp55_;
#line 840 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_tmp55_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, _ ("Invalid URL"));
#line 840 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				_inner_error_ = _tmp55_;
#line 840 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
				if (_inner_error_->domain == BOXES_ERROR) {
#line 840 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					g_propagate_error (error, _inner_error_);
#line 840 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_g_free0 (query_str);
#line 840 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_xmlFreeURI0 (uri);
#line 840 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					return;
#line 7078 "spice-display.c"
				} else {
#line 840 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_g_free0 (query_str);
#line 840 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					_xmlFreeURI0 (uri);
#line 840 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 840 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					g_clear_error (&_inner_error_);
#line 840 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
					return;
#line 7090 "spice-display.c"
				}
			}
		}
	}
#line 806 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_free0 (query_str);
#line 806 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_xmlFreeURI0 (uri);
#line 806 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (port) {
#line 806 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		*port = _vala_port;
#line 7103 "spice-display.c"
	} else {
#line 806 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_free0 (_vala_port);
#line 7107 "spice-display.c"
	}
#line 806 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (tls_port) {
#line 806 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		*tls_port = _vala_tls_port;
#line 7113 "spice-display.c"
	} else {
#line 806 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_free0 (_vala_tls_port);
#line 7117 "spice-display.c"
	}
}


BoxesSharedFolderRow* boxes_shared_folder_row_construct (GType object_type, const gchar* path, const gchar* name) {
	BoxesSharedFolderRow * self = NULL;
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	GtkLabel* _tmp2_;
	GtkLabel* _tmp3_;
#line 855 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (path != NULL, NULL);
#line 855 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 855 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self = (BoxesSharedFolderRow*) g_object_new (object_type, NULL);
#line 856 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp0_ = path;
#line 856 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	boxes_shared_folder_row_set_folder_path (self, _tmp0_);
#line 857 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp1_ = name;
#line 857 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	boxes_shared_folder_row_set_folder_name (self, _tmp1_);
#line 859 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp2_ = self->priv->folder_path_label;
#line 859 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_object_bind_property_with_closures ((GObject*) self, "folder_path", (GObject*) _tmp2_, "label", G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)));
#line 860 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp3_ = self->priv->folder_name_label;
#line 860 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_object_bind_property_with_closures ((GObject*) self, "folder_name", (GObject*) _tmp3_, "label", G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)));
#line 855 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	return self;
#line 7152 "spice-display.c"
}


BoxesSharedFolderRow* boxes_shared_folder_row_new (const gchar* path, const gchar* name) {
#line 855 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	return boxes_shared_folder_row_construct (BOXES_TYPE_SHARED_FOLDER_ROW, path, name);
#line 7159 "spice-display.c"
}


static void boxes_shared_folder_row_on_delete_button_clicked (BoxesSharedFolderRow* self) {
#line 864 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (self != NULL);
#line 865 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_signal_emit (self, boxes_shared_folder_row_signals[BOXES_SHARED_FOLDER_ROW_REMOVED_SIGNAL], 0);
#line 7168 "spice-display.c"
}


static void _boxes_shared_folder_row_on_delete_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 845 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	boxes_shared_folder_row_on_delete_button_clicked ((BoxesSharedFolderRow*) self);
#line 7175 "spice-display.c"
}


const gchar* boxes_shared_folder_row_get_folder_path (BoxesSharedFolderRow* self) {
	const gchar* result;
	const gchar* _tmp0_;
#line 846 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 846 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp0_ = self->priv->_folder_path;
#line 846 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	result = _tmp0_;
#line 846 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	return result;
#line 7190 "spice-display.c"
}


void boxes_shared_folder_row_set_folder_path (BoxesSharedFolderRow* self, const gchar* value) {
#line 846 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (self != NULL);
#line 846 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (g_strcmp0 (value, boxes_shared_folder_row_get_folder_path (self)) != 0) {
#line 7199 "spice-display.c"
		const gchar* _tmp0_;
		gchar* _tmp1_;
#line 846 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp0_ = value;
#line 846 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp1_ = g_strdup (_tmp0_);
#line 846 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_free0 (self->priv->_folder_path);
#line 846 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		self->priv->_folder_path = _tmp1_;
#line 846 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_object_notify_by_pspec ((GObject *) self, boxes_shared_folder_row_properties[BOXES_SHARED_FOLDER_ROW_FOLDER_PATH]);
#line 7212 "spice-display.c"
	}
}


const gchar* boxes_shared_folder_row_get_folder_name (BoxesSharedFolderRow* self) {
	const gchar* result;
	const gchar* _tmp0_;
#line 847 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 847 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_tmp0_ = self->priv->_folder_name;
#line 847 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	result = _tmp0_;
#line 847 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	return result;
#line 7228 "spice-display.c"
}


void boxes_shared_folder_row_set_folder_name (BoxesSharedFolderRow* self, const gchar* value) {
#line 847 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (self != NULL);
#line 847 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	if (g_strcmp0 (value, boxes_shared_folder_row_get_folder_name (self)) != 0) {
#line 7237 "spice-display.c"
		const gchar* _tmp0_;
		gchar* _tmp1_;
#line 847 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp0_ = value;
#line 847 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_tmp1_ = g_strdup (_tmp0_);
#line 847 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		_g_free0 (self->priv->_folder_name);
#line 847 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		self->priv->_folder_name = _tmp1_;
#line 847 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_object_notify_by_pspec ((GObject *) self, boxes_shared_folder_row_properties[BOXES_SHARED_FOLDER_ROW_FOLDER_NAME]);
#line 7250 "spice-display.c"
	}
}


static void boxes_shared_folder_row_class_init (BoxesSharedFolderRowClass * klass) {
	gint BoxesSharedFolderRow_private_offset;
#line 845 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	boxes_shared_folder_row_parent_class = g_type_class_peek_parent (klass);
#line 845 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_type_class_add_private (klass, sizeof (BoxesSharedFolderRowPrivate));
#line 845 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_shared_folder_row_get_property;
#line 845 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_shared_folder_row_set_property;
#line 845 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_shared_folder_row_finalize;
#line 845 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_SHARED_FOLDER_ROW_FOLDER_PATH, boxes_shared_folder_row_properties[BOXES_SHARED_FOLDER_ROW_FOLDER_PATH] = g_param_spec_string ("folder-path", "folder-path", "folder-path", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 845 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_SHARED_FOLDER_ROW_FOLDER_NAME, boxes_shared_folder_row_properties[BOXES_SHARED_FOLDER_ROW_FOLDER_NAME] = g_param_spec_string ("folder-name", "folder-name", "folder-name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 845 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	BoxesSharedFolderRow_private_offset = g_type_class_get_instance_private_offset (klass);
#line 845 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Boxes/ui/properties-shared-folder-row.ui");
#line 845 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	boxes_shared_folder_row_signals[BOXES_SHARED_FOLDER_ROW_REMOVED_SIGNAL] = g_signal_new ("removed", BOXES_TYPE_SHARED_FOLDER_ROW, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 845 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "folder_path_label", FALSE, BoxesSharedFolderRow_private_offset + G_STRUCT_OFFSET (BoxesSharedFolderRowPrivate, folder_path_label));
#line 845 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "folder_name_label", FALSE, BoxesSharedFolderRow_private_offset + G_STRUCT_OFFSET (BoxesSharedFolderRowPrivate, folder_name_label));
#line 845 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_delete_button_clicked", G_CALLBACK(_boxes_shared_folder_row_on_delete_button_clicked_gtk_button_clicked));
#line 7283 "spice-display.c"
}


static void boxes_shared_folder_row_instance_init (BoxesSharedFolderRow * self) {
#line 845 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self->priv = BOXES_SHARED_FOLDER_ROW_GET_PRIVATE (self);
#line 845 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 7292 "spice-display.c"
}


static void boxes_shared_folder_row_finalize (GObject * obj) {
	BoxesSharedFolderRow * self;
#line 845 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_SHARED_FOLDER_ROW, BoxesSharedFolderRow);
#line 846 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_free0 (self->priv->_folder_path);
#line 847 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_free0 (self->priv->_folder_name);
#line 851 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_object_unref0 (self->priv->folder_path_label);
#line 853 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	_g_object_unref0 (self->priv->folder_name_label);
#line 845 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	G_OBJECT_CLASS (boxes_shared_folder_row_parent_class)->finalize (obj);
#line 7310 "spice-display.c"
}


GType boxes_shared_folder_row_get_type (void) {
	static volatile gsize boxes_shared_folder_row_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_shared_folder_row_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesSharedFolderRowClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_shared_folder_row_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesSharedFolderRow), 0, (GInstanceInitFunc) boxes_shared_folder_row_instance_init, NULL };
		GType boxes_shared_folder_row_type_id;
		boxes_shared_folder_row_type_id = g_type_register_static (gtk_list_box_row_get_type (), "BoxesSharedFolderRow", &g_define_type_info, 0);
		g_once_init_leave (&boxes_shared_folder_row_type_id__volatile, boxes_shared_folder_row_type_id);
	}
	return boxes_shared_folder_row_type_id__volatile;
}


static void _vala_boxes_shared_folder_row_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesSharedFolderRow * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_SHARED_FOLDER_ROW, BoxesSharedFolderRow);
#line 845 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	switch (property_id) {
#line 845 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		case BOXES_SHARED_FOLDER_ROW_FOLDER_PATH:
#line 845 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_value_set_string (value, boxes_shared_folder_row_get_folder_path (self));
#line 845 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		break;
#line 845 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		case BOXES_SHARED_FOLDER_ROW_FOLDER_NAME:
#line 845 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		g_value_set_string (value, boxes_shared_folder_row_get_folder_name (self));
#line 845 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		break;
#line 7343 "spice-display.c"
		default:
#line 845 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 845 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		break;
#line 7349 "spice-display.c"
	}
}


static void _vala_boxes_shared_folder_row_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesSharedFolderRow * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_SHARED_FOLDER_ROW, BoxesSharedFolderRow);
#line 845 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
	switch (property_id) {
#line 845 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		case BOXES_SHARED_FOLDER_ROW_FOLDER_PATH:
#line 845 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		boxes_shared_folder_row_set_folder_path (self, g_value_get_string (value));
#line 845 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		break;
#line 845 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		case BOXES_SHARED_FOLDER_ROW_FOLDER_NAME:
#line 845 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		boxes_shared_folder_row_set_folder_name (self, g_value_get_string (value));
#line 845 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		break;
#line 7371 "spice-display.c"
		default:
#line 845 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 845 "/home/fborges/checkout/gnome-boxes/src/spice-display.vala"
		break;
#line 7377 "spice-display.c"
	}
}



